# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/web_request.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/web_request.proto", :syntax => :proto3) do
    add_message "ignition.msgs.WebRequest" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :operation, :string, 2
      optional :topic, :string, 3
      optional :msg_type, :string, 4
      optional :compression, :string, 5
      optional :hz, :double, 6
    end
  end
end

module Ignition
  module Msgs
    WebRequest = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.WebRequest").msgclass
  end
end
