# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/fuel_metadata.proto

require 'ignition/msgs/version_pb'
require 'ignition/msgs/version_range_pb'
require 'ignition/msgs/versioned_name_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/fuel_metadata.proto", :syntax => :proto3) do
    add_message "ignition.msgs.FuelMetadata" do
      optional :name, :string, 3
      optional :description, :string, 4
      optional :version, :int32, 5
      repeated :authors, :message, 6, "ignition.msgs.FuelMetadata.Contact"
      optional :legal, :message, 7, "ignition.msgs.FuelMetadata.Legal"
      repeated :tags, :string, 8
      map :annotations, :string, :string, 9
      repeated :dependencies, :message, 10, "ignition.msgs.FuelMetadata.Dependency"
      repeated :compatibilities, :message, 11, "ignition.msgs.FuelMetadata.Compatibility"
      optional :categories, :message, 12, "ignition.msgs.FuelMetadata.Categories"
      oneof :resource_type do
        optional :model, :message, 1, "ignition.msgs.FuelMetadata.Model"
        optional :world, :message, 2, "ignition.msgs.FuelMetadata.World"
      end
    end
    add_message "ignition.msgs.FuelMetadata.Contact" do
      optional :name, :string, 1
      optional :email, :string, 2
    end
    add_message "ignition.msgs.FuelMetadata.Legal" do
      optional :copyright, :string, 1
      optional :license, :string, 2
    end
    add_message "ignition.msgs.FuelMetadata.Model" do
      optional :file, :string, 1
      optional :file_format, :message, 2, "ignition.msgs.VersionedName"
    end
    add_message "ignition.msgs.FuelMetadata.World" do
      optional :file, :string, 1
      optional :file_format, :message, 2, "ignition.msgs.VersionedName"
    end
    add_message "ignition.msgs.FuelMetadata.Dependency" do
      optional :uri, :string, 1
    end
    add_message "ignition.msgs.FuelMetadata.Compatibility" do
      optional :name, :string, 1
      oneof :version_type do
        optional :version, :message, 2, "ignition.msgs.Version"
        optional :version_range, :message, 3, "ignition.msgs.VersionRange"
      end
    end
    add_message "ignition.msgs.FuelMetadata.Categories" do
      optional :first, :string, 1
      optional :second, :string, 2
    end
  end
end

module Ignition
  module Msgs
    FuelMetadata = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata").msgclass
    FuelMetadata::Contact = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Contact").msgclass
    FuelMetadata::Legal = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Legal").msgclass
    FuelMetadata::Model = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Model").msgclass
    FuelMetadata::World = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.World").msgclass
    FuelMetadata::Dependency = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Dependency").msgclass
    FuelMetadata::Compatibility = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Compatibility").msgclass
    FuelMetadata::Categories = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.FuelMetadata.Categories").msgclass
  end
end
