# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/laserscan.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/laserscan.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LaserScan" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :frame, :string, 2
      optional :world_pose, :message, 3, "ignition.msgs.Pose"
      optional :angle_min, :double, 4
      optional :angle_max, :double, 5
      optional :angle_step, :double, 6
      optional :range_min, :double, 7
      optional :range_max, :double, 8
      optional :count, :uint32, 9
      optional :vertical_angle_min, :double, 10
      optional :vertical_angle_max, :double, 11
      optional :vertical_angle_step, :double, 12
      optional :vertical_count, :uint32, 13
      repeated :ranges, :double, 14
      repeated :intensities, :double, 15
    end
  end
end

module Ignition
  module Msgs
    LaserScan = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LaserScan").msgclass
  end
end
