# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/serialized_map.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/world_stats_pb'
require 'ignition/msgs/serialized_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/serialized_map.proto", :syntax => :proto3) do
    add_message "ignition.msgs.SerializedEntityMap" do
      optional :id, :uint64, 1
      map :components, :int64, :message, 2, "ignition.msgs.SerializedComponent"
      optional :remove, :bool, 3
    end
    add_message "ignition.msgs.SerializedStateMap" do
      optional :header, :message, 1, "ignition.msgs.Header"
      map :entities, :uint64, :message, 2, "ignition.msgs.SerializedEntityMap"
    end
    add_message "ignition.msgs.SerializedStepMap" do
      optional :stats, :message, 1, "ignition.msgs.WorldStatistics"
      optional :state, :message, 2, "ignition.msgs.SerializedStateMap"
    end
  end
end

module Ignition
  module Msgs
    SerializedEntityMap = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedEntityMap").msgclass
    SerializedStateMap = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedStateMap").msgclass
    SerializedStepMap = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedStepMap").msgclass
  end
end
