/*
 * Copyright (C) 2021 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "OccpuancyGridProtos";

/// \ingroup ignition.msgs
/// \interface OccupancyGrid
/// \brief This message is designed to mimic ROS nav_msgs/OccupancyGrid to
/// facilitate transfer/conversion of data between Ignition and ROS.
///
/// See: http://docs.ros.org/melodic/api/nav_msgs/html/msg/OccupancyGrid.html

import "ignition/msgs/header.proto";
import "ignition/msgs/pose.proto";
import "ignition/msgs/time.proto";


message OccupancyGrid
{
  message MapMetaInfo
  {
    /// \brief The map load time
    Time map_load_time = 1;

    /// \brief The map resolution (meters/cell)
    double resolution = 2;

    /// \brief The map width (cells)
    uint32 width = 3;

    /// \brief The map height (cells)
    uint32 height = 4;

    /// \brief  The origin of the map.  This is the real-world pose of the
    /// cell (0,0) in the map
    Pose origin = 5;
  };

  /// \brief Optional header data. This should contain time of map validity
  /// and the coordinate frame ID.
  Header header = 1;

  /// \brief Metadata for the map.
  MapMetaInfo info = 2;

  /// \brief The map data, in row-major order, starting with (0,0).
  /// Occupancy probabilities are in the range [0,100].  Unknown is -1.
  bytes data = 3;
};
