/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "AirPressureSensorProtos";

/// \ingroup ignition.msgs
/// \interface AirPressureSensor
/// \brief Definition of an air pressure sensor

import "ignition/msgs/header.proto";
import "ignition/msgs/sensor_noise.proto";

/// \brief Message that describes an air pressure sensor.
message AirPressureSensor
{
  /// \brief Optional header data
  Header header               = 1; 

  /// \brief Reference altitude in meters. This value can be used by a sensor
  /// implementation to augment the altitude of the sensor. For example, if
  /// you are using simulation, instead of creating a 1000 m mountain model on
  /// which to place your sensor, you could instead set this value to 1000 and
  /// place your model on a ground plane with a Z height of zero.
  double reference_altitude   = 2;

  /// \brief Sensor pressure noise.
  SensorNoise pressure_noise  = 3;
}
