// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/geometry.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fgeometry_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fgeometry_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/boxgeom.pb.h"
#include "ignition/msgs/cylindergeom.pb.h"
#include "ignition/msgs/spheregeom.pb.h"
#include "ignition/msgs/planegeom.pb.h"
#include "ignition/msgs/imagegeom.pb.h"
#include "ignition/msgs/heightmapgeom.pb.h"
#include "ignition/msgs/meshgeom.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/polylinegeom.pb.h"
#include "ignition/msgs/conegeom.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fgeometry_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fgeometry_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fgeometry_2eproto;
namespace ignition {
namespace msgs {
class Geometry;
struct GeometryDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern GeometryDefaultTypeInternal _Geometry_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Geometry* Arena::CreateMaybeMessage<::ignition::msgs::Geometry>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum Geometry_Type : int {
  Geometry_Type_BOX = 0,
  Geometry_Type_CYLINDER = 1,
  Geometry_Type_SPHERE = 2,
  Geometry_Type_PLANE = 3,
  Geometry_Type_IMAGE = 4,
  Geometry_Type_HEIGHTMAP = 5,
  Geometry_Type_MESH = 6,
  Geometry_Type_TRIANGLE_FAN = 7,
  Geometry_Type_LINE_STRIP = 8,
  Geometry_Type_POLYLINE = 9,
  Geometry_Type_CONE = 10,
  Geometry_Type_EMPTY = 11,
  Geometry_Type_ARROW = 12,
  Geometry_Type_AXIS = 13,
  Geometry_Type_Geometry_Type_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Geometry_Type_Geometry_Type_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Geometry_Type_IsValid(int value);
constexpr Geometry_Type Geometry_Type_Type_MIN = Geometry_Type_BOX;
constexpr Geometry_Type Geometry_Type_Type_MAX = Geometry_Type_AXIS;
constexpr int Geometry_Type_Type_ARRAYSIZE = Geometry_Type_Type_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Geometry_Type_descriptor();
template<typename T>
inline const std::string& Geometry_Type_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Geometry_Type>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Geometry_Type_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Geometry_Type_descriptor(), enum_t_value);
}
inline bool Geometry_Type_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Geometry_Type* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Geometry_Type>(
    Geometry_Type_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE Geometry final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Geometry) */ {
 public:
  inline Geometry() : Geometry(nullptr) {}
  ~Geometry() override;
  explicit constexpr Geometry(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Geometry(const Geometry& from);
  Geometry(Geometry&& from) noexcept
    : Geometry() {
    *this = ::std::move(from);
  }

  inline Geometry& operator=(const Geometry& from) {
    CopyFrom(from);
    return *this;
  }
  inline Geometry& operator=(Geometry&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Geometry& default_instance() {
    return *internal_default_instance();
  }
  static inline const Geometry* internal_default_instance() {
    return reinterpret_cast<const Geometry*>(
               &_Geometry_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Geometry& a, Geometry& b) {
    a.Swap(&b);
  }
  inline void Swap(Geometry* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Geometry* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Geometry* New() const final {
    return new Geometry();
  }

  Geometry* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Geometry>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Geometry& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Geometry& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Geometry* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Geometry";
  }
  protected:
  explicit Geometry(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Geometry_Type Type;
  static constexpr Type BOX =
    Geometry_Type_BOX;
  static constexpr Type CYLINDER =
    Geometry_Type_CYLINDER;
  static constexpr Type SPHERE =
    Geometry_Type_SPHERE;
  static constexpr Type PLANE =
    Geometry_Type_PLANE;
  static constexpr Type IMAGE =
    Geometry_Type_IMAGE;
  static constexpr Type HEIGHTMAP =
    Geometry_Type_HEIGHTMAP;
  static constexpr Type MESH =
    Geometry_Type_MESH;
  static constexpr Type TRIANGLE_FAN =
    Geometry_Type_TRIANGLE_FAN;
  static constexpr Type LINE_STRIP =
    Geometry_Type_LINE_STRIP;
  static constexpr Type POLYLINE =
    Geometry_Type_POLYLINE;
  static constexpr Type CONE =
    Geometry_Type_CONE;
  static constexpr Type EMPTY =
    Geometry_Type_EMPTY;
  static constexpr Type ARROW =
    Geometry_Type_ARROW;
  static constexpr Type AXIS =
    Geometry_Type_AXIS;
  static inline bool Type_IsValid(int value) {
    return Geometry_Type_IsValid(value);
  }
  static constexpr Type Type_MIN =
    Geometry_Type_Type_MIN;
  static constexpr Type Type_MAX =
    Geometry_Type_Type_MAX;
  static constexpr int Type_ARRAYSIZE =
    Geometry_Type_Type_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Type_descriptor() {
    return Geometry_Type_descriptor();
  }
  template<typename T>
  static inline const std::string& Type_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Type>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Type_Name.");
    return Geometry_Type_Name(enum_t_value);
  }
  static inline bool Type_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Type* value) {
    return Geometry_Type_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kPointsFieldNumber = 11,
    kPolylineFieldNumber = 12,
    kHeaderFieldNumber = 1,
    kBoxFieldNumber = 3,
    kCylinderFieldNumber = 4,
    kPlaneFieldNumber = 5,
    kSphereFieldNumber = 6,
    kImageFieldNumber = 7,
    kHeightmapFieldNumber = 8,
    kMeshFieldNumber = 9,
    kConeFieldNumber = 10,
    kTypeFieldNumber = 2,
  };
  // repeated .ignition.msgs.Vector3d points = 11;
  int points_size() const;
  private:
  int _internal_points_size() const;
  public:
  void clear_points();
  ::ignition::msgs::Vector3d* mutable_points(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
      mutable_points();
  private:
  const ::ignition::msgs::Vector3d& _internal_points(int index) const;
  ::ignition::msgs::Vector3d* _internal_add_points();
  public:
  const ::ignition::msgs::Vector3d& points(int index) const;
  ::ignition::msgs::Vector3d* add_points();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
      points() const;

  // repeated .ignition.msgs.Polyline polyline = 12;
  int polyline_size() const;
  private:
  int _internal_polyline_size() const;
  public:
  void clear_polyline();
  ::ignition::msgs::Polyline* mutable_polyline(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Polyline >*
      mutable_polyline();
  private:
  const ::ignition::msgs::Polyline& _internal_polyline(int index) const;
  ::ignition::msgs::Polyline* _internal_add_polyline();
  public:
  const ::ignition::msgs::Polyline& polyline(int index) const;
  ::ignition::msgs::Polyline* add_polyline();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Polyline >&
      polyline() const;

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.BoxGeom box = 3;
  bool has_box() const;
  private:
  bool _internal_has_box() const;
  public:
  void clear_box();
  const ::ignition::msgs::BoxGeom& box() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::BoxGeom* release_box();
  ::ignition::msgs::BoxGeom* mutable_box();
  void set_allocated_box(::ignition::msgs::BoxGeom* box);
  private:
  const ::ignition::msgs::BoxGeom& _internal_box() const;
  ::ignition::msgs::BoxGeom* _internal_mutable_box();
  public:
  void unsafe_arena_set_allocated_box(
      ::ignition::msgs::BoxGeom* box);
  ::ignition::msgs::BoxGeom* unsafe_arena_release_box();

  // .ignition.msgs.CylinderGeom cylinder = 4;
  bool has_cylinder() const;
  private:
  bool _internal_has_cylinder() const;
  public:
  void clear_cylinder();
  const ::ignition::msgs::CylinderGeom& cylinder() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::CylinderGeom* release_cylinder();
  ::ignition::msgs::CylinderGeom* mutable_cylinder();
  void set_allocated_cylinder(::ignition::msgs::CylinderGeom* cylinder);
  private:
  const ::ignition::msgs::CylinderGeom& _internal_cylinder() const;
  ::ignition::msgs::CylinderGeom* _internal_mutable_cylinder();
  public:
  void unsafe_arena_set_allocated_cylinder(
      ::ignition::msgs::CylinderGeom* cylinder);
  ::ignition::msgs::CylinderGeom* unsafe_arena_release_cylinder();

  // .ignition.msgs.PlaneGeom plane = 5;
  bool has_plane() const;
  private:
  bool _internal_has_plane() const;
  public:
  void clear_plane();
  const ::ignition::msgs::PlaneGeom& plane() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::PlaneGeom* release_plane();
  ::ignition::msgs::PlaneGeom* mutable_plane();
  void set_allocated_plane(::ignition::msgs::PlaneGeom* plane);
  private:
  const ::ignition::msgs::PlaneGeom& _internal_plane() const;
  ::ignition::msgs::PlaneGeom* _internal_mutable_plane();
  public:
  void unsafe_arena_set_allocated_plane(
      ::ignition::msgs::PlaneGeom* plane);
  ::ignition::msgs::PlaneGeom* unsafe_arena_release_plane();

  // .ignition.msgs.SphereGeom sphere = 6;
  bool has_sphere() const;
  private:
  bool _internal_has_sphere() const;
  public:
  void clear_sphere();
  const ::ignition::msgs::SphereGeom& sphere() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::SphereGeom* release_sphere();
  ::ignition::msgs::SphereGeom* mutable_sphere();
  void set_allocated_sphere(::ignition::msgs::SphereGeom* sphere);
  private:
  const ::ignition::msgs::SphereGeom& _internal_sphere() const;
  ::ignition::msgs::SphereGeom* _internal_mutable_sphere();
  public:
  void unsafe_arena_set_allocated_sphere(
      ::ignition::msgs::SphereGeom* sphere);
  ::ignition::msgs::SphereGeom* unsafe_arena_release_sphere();

  // .ignition.msgs.ImageGeom image = 7;
  bool has_image() const;
  private:
  bool _internal_has_image() const;
  public:
  void clear_image();
  const ::ignition::msgs::ImageGeom& image() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::ImageGeom* release_image();
  ::ignition::msgs::ImageGeom* mutable_image();
  void set_allocated_image(::ignition::msgs::ImageGeom* image);
  private:
  const ::ignition::msgs::ImageGeom& _internal_image() const;
  ::ignition::msgs::ImageGeom* _internal_mutable_image();
  public:
  void unsafe_arena_set_allocated_image(
      ::ignition::msgs::ImageGeom* image);
  ::ignition::msgs::ImageGeom* unsafe_arena_release_image();

  // .ignition.msgs.HeightmapGeom heightmap = 8;
  bool has_heightmap() const;
  private:
  bool _internal_has_heightmap() const;
  public:
  void clear_heightmap();
  const ::ignition::msgs::HeightmapGeom& heightmap() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::HeightmapGeom* release_heightmap();
  ::ignition::msgs::HeightmapGeom* mutable_heightmap();
  void set_allocated_heightmap(::ignition::msgs::HeightmapGeom* heightmap);
  private:
  const ::ignition::msgs::HeightmapGeom& _internal_heightmap() const;
  ::ignition::msgs::HeightmapGeom* _internal_mutable_heightmap();
  public:
  void unsafe_arena_set_allocated_heightmap(
      ::ignition::msgs::HeightmapGeom* heightmap);
  ::ignition::msgs::HeightmapGeom* unsafe_arena_release_heightmap();

  // .ignition.msgs.MeshGeom mesh = 9;
  bool has_mesh() const;
  private:
  bool _internal_has_mesh() const;
  public:
  void clear_mesh();
  const ::ignition::msgs::MeshGeom& mesh() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::MeshGeom* release_mesh();
  ::ignition::msgs::MeshGeom* mutable_mesh();
  void set_allocated_mesh(::ignition::msgs::MeshGeom* mesh);
  private:
  const ::ignition::msgs::MeshGeom& _internal_mesh() const;
  ::ignition::msgs::MeshGeom* _internal_mutable_mesh();
  public:
  void unsafe_arena_set_allocated_mesh(
      ::ignition::msgs::MeshGeom* mesh);
  ::ignition::msgs::MeshGeom* unsafe_arena_release_mesh();

  // .ignition.msgs.ConeGeom cone = 10;
  bool has_cone() const;
  private:
  bool _internal_has_cone() const;
  public:
  void clear_cone();
  const ::ignition::msgs::ConeGeom& cone() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::ConeGeom* release_cone();
  ::ignition::msgs::ConeGeom* mutable_cone();
  void set_allocated_cone(::ignition::msgs::ConeGeom* cone);
  private:
  const ::ignition::msgs::ConeGeom& _internal_cone() const;
  ::ignition::msgs::ConeGeom* _internal_mutable_cone();
  public:
  void unsafe_arena_set_allocated_cone(
      ::ignition::msgs::ConeGeom* cone);
  ::ignition::msgs::ConeGeom* unsafe_arena_release_cone();

  // .ignition.msgs.Geometry.Type type = 2;
  void clear_type();
  ::ignition::msgs::Geometry_Type type() const;
  void set_type(::ignition::msgs::Geometry_Type value);
  private:
  ::ignition::msgs::Geometry_Type _internal_type() const;
  void _internal_set_type(::ignition::msgs::Geometry_Type value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Geometry)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d > points_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Polyline > polyline_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::BoxGeom* box_;
  ::ignition::msgs::CylinderGeom* cylinder_;
  ::ignition::msgs::PlaneGeom* plane_;
  ::ignition::msgs::SphereGeom* sphere_;
  ::ignition::msgs::ImageGeom* image_;
  ::ignition::msgs::HeightmapGeom* heightmap_;
  ::ignition::msgs::MeshGeom* mesh_;
  ::ignition::msgs::ConeGeom* cone_;
  int type_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fgeometry_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Geometry

// .ignition.msgs.Header header = 1;
inline bool Geometry::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Geometry::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Geometry::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Geometry::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.header)
  return _internal_header();
}
inline void Geometry::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.header)
}
inline ::ignition::msgs::Header* Geometry::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Geometry::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Geometry::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Geometry::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.header)
  return _msg;
}
inline void Geometry::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.header)
}

// .ignition.msgs.Geometry.Type type = 2;
inline void Geometry::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::Geometry_Type Geometry::_internal_type() const {
  return static_cast< ::ignition::msgs::Geometry_Type >(type_);
}
inline ::ignition::msgs::Geometry_Type Geometry::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.type)
  return _internal_type();
}
inline void Geometry::_internal_set_type(::ignition::msgs::Geometry_Type value) {
  
  type_ = value;
}
inline void Geometry::set_type(::ignition::msgs::Geometry_Type value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Geometry.type)
}

// .ignition.msgs.BoxGeom box = 3;
inline bool Geometry::_internal_has_box() const {
  return this != internal_default_instance() && box_ != nullptr;
}
inline bool Geometry::has_box() const {
  return _internal_has_box();
}
inline const ::ignition::msgs::BoxGeom& Geometry::_internal_box() const {
  const ::ignition::msgs::BoxGeom* p = box_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::BoxGeom&>(
      ::ignition::msgs::_BoxGeom_default_instance_);
}
inline const ::ignition::msgs::BoxGeom& Geometry::box() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.box)
  return _internal_box();
}
inline void Geometry::unsafe_arena_set_allocated_box(
    ::ignition::msgs::BoxGeom* box) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(box_);
  }
  box_ = box;
  if (box) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.box)
}
inline ::ignition::msgs::BoxGeom* Geometry::release_box() {
  
  ::ignition::msgs::BoxGeom* temp = box_;
  box_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::BoxGeom* Geometry::unsafe_arena_release_box() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.box)
  
  ::ignition::msgs::BoxGeom* temp = box_;
  box_ = nullptr;
  return temp;
}
inline ::ignition::msgs::BoxGeom* Geometry::_internal_mutable_box() {
  
  if (box_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::BoxGeom>(GetArenaForAllocation());
    box_ = p;
  }
  return box_;
}
inline ::ignition::msgs::BoxGeom* Geometry::mutable_box() {
  ::ignition::msgs::BoxGeom* _msg = _internal_mutable_box();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.box)
  return _msg;
}
inline void Geometry::set_allocated_box(::ignition::msgs::BoxGeom* box) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(box_);
  }
  if (box) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(box));
    if (message_arena != submessage_arena) {
      box = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, box, submessage_arena);
    }
    
  } else {
    
  }
  box_ = box;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.box)
}

// .ignition.msgs.CylinderGeom cylinder = 4;
inline bool Geometry::_internal_has_cylinder() const {
  return this != internal_default_instance() && cylinder_ != nullptr;
}
inline bool Geometry::has_cylinder() const {
  return _internal_has_cylinder();
}
inline const ::ignition::msgs::CylinderGeom& Geometry::_internal_cylinder() const {
  const ::ignition::msgs::CylinderGeom* p = cylinder_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::CylinderGeom&>(
      ::ignition::msgs::_CylinderGeom_default_instance_);
}
inline const ::ignition::msgs::CylinderGeom& Geometry::cylinder() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.cylinder)
  return _internal_cylinder();
}
inline void Geometry::unsafe_arena_set_allocated_cylinder(
    ::ignition::msgs::CylinderGeom* cylinder) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(cylinder_);
  }
  cylinder_ = cylinder;
  if (cylinder) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.cylinder)
}
inline ::ignition::msgs::CylinderGeom* Geometry::release_cylinder() {
  
  ::ignition::msgs::CylinderGeom* temp = cylinder_;
  cylinder_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::CylinderGeom* Geometry::unsafe_arena_release_cylinder() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.cylinder)
  
  ::ignition::msgs::CylinderGeom* temp = cylinder_;
  cylinder_ = nullptr;
  return temp;
}
inline ::ignition::msgs::CylinderGeom* Geometry::_internal_mutable_cylinder() {
  
  if (cylinder_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::CylinderGeom>(GetArenaForAllocation());
    cylinder_ = p;
  }
  return cylinder_;
}
inline ::ignition::msgs::CylinderGeom* Geometry::mutable_cylinder() {
  ::ignition::msgs::CylinderGeom* _msg = _internal_mutable_cylinder();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.cylinder)
  return _msg;
}
inline void Geometry::set_allocated_cylinder(::ignition::msgs::CylinderGeom* cylinder) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(cylinder_);
  }
  if (cylinder) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(cylinder));
    if (message_arena != submessage_arena) {
      cylinder = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, cylinder, submessage_arena);
    }
    
  } else {
    
  }
  cylinder_ = cylinder;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.cylinder)
}

// .ignition.msgs.PlaneGeom plane = 5;
inline bool Geometry::_internal_has_plane() const {
  return this != internal_default_instance() && plane_ != nullptr;
}
inline bool Geometry::has_plane() const {
  return _internal_has_plane();
}
inline const ::ignition::msgs::PlaneGeom& Geometry::_internal_plane() const {
  const ::ignition::msgs::PlaneGeom* p = plane_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::PlaneGeom&>(
      ::ignition::msgs::_PlaneGeom_default_instance_);
}
inline const ::ignition::msgs::PlaneGeom& Geometry::plane() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.plane)
  return _internal_plane();
}
inline void Geometry::unsafe_arena_set_allocated_plane(
    ::ignition::msgs::PlaneGeom* plane) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(plane_);
  }
  plane_ = plane;
  if (plane) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.plane)
}
inline ::ignition::msgs::PlaneGeom* Geometry::release_plane() {
  
  ::ignition::msgs::PlaneGeom* temp = plane_;
  plane_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::PlaneGeom* Geometry::unsafe_arena_release_plane() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.plane)
  
  ::ignition::msgs::PlaneGeom* temp = plane_;
  plane_ = nullptr;
  return temp;
}
inline ::ignition::msgs::PlaneGeom* Geometry::_internal_mutable_plane() {
  
  if (plane_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::PlaneGeom>(GetArenaForAllocation());
    plane_ = p;
  }
  return plane_;
}
inline ::ignition::msgs::PlaneGeom* Geometry::mutable_plane() {
  ::ignition::msgs::PlaneGeom* _msg = _internal_mutable_plane();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.plane)
  return _msg;
}
inline void Geometry::set_allocated_plane(::ignition::msgs::PlaneGeom* plane) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(plane_);
  }
  if (plane) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(plane));
    if (message_arena != submessage_arena) {
      plane = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, plane, submessage_arena);
    }
    
  } else {
    
  }
  plane_ = plane;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.plane)
}

// .ignition.msgs.SphereGeom sphere = 6;
inline bool Geometry::_internal_has_sphere() const {
  return this != internal_default_instance() && sphere_ != nullptr;
}
inline bool Geometry::has_sphere() const {
  return _internal_has_sphere();
}
inline const ::ignition::msgs::SphereGeom& Geometry::_internal_sphere() const {
  const ::ignition::msgs::SphereGeom* p = sphere_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::SphereGeom&>(
      ::ignition::msgs::_SphereGeom_default_instance_);
}
inline const ::ignition::msgs::SphereGeom& Geometry::sphere() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.sphere)
  return _internal_sphere();
}
inline void Geometry::unsafe_arena_set_allocated_sphere(
    ::ignition::msgs::SphereGeom* sphere) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(sphere_);
  }
  sphere_ = sphere;
  if (sphere) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.sphere)
}
inline ::ignition::msgs::SphereGeom* Geometry::release_sphere() {
  
  ::ignition::msgs::SphereGeom* temp = sphere_;
  sphere_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::SphereGeom* Geometry::unsafe_arena_release_sphere() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.sphere)
  
  ::ignition::msgs::SphereGeom* temp = sphere_;
  sphere_ = nullptr;
  return temp;
}
inline ::ignition::msgs::SphereGeom* Geometry::_internal_mutable_sphere() {
  
  if (sphere_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::SphereGeom>(GetArenaForAllocation());
    sphere_ = p;
  }
  return sphere_;
}
inline ::ignition::msgs::SphereGeom* Geometry::mutable_sphere() {
  ::ignition::msgs::SphereGeom* _msg = _internal_mutable_sphere();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.sphere)
  return _msg;
}
inline void Geometry::set_allocated_sphere(::ignition::msgs::SphereGeom* sphere) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(sphere_);
  }
  if (sphere) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(sphere));
    if (message_arena != submessage_arena) {
      sphere = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, sphere, submessage_arena);
    }
    
  } else {
    
  }
  sphere_ = sphere;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.sphere)
}

// .ignition.msgs.ImageGeom image = 7;
inline bool Geometry::_internal_has_image() const {
  return this != internal_default_instance() && image_ != nullptr;
}
inline bool Geometry::has_image() const {
  return _internal_has_image();
}
inline const ::ignition::msgs::ImageGeom& Geometry::_internal_image() const {
  const ::ignition::msgs::ImageGeom* p = image_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::ImageGeom&>(
      ::ignition::msgs::_ImageGeom_default_instance_);
}
inline const ::ignition::msgs::ImageGeom& Geometry::image() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.image)
  return _internal_image();
}
inline void Geometry::unsafe_arena_set_allocated_image(
    ::ignition::msgs::ImageGeom* image) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(image_);
  }
  image_ = image;
  if (image) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.image)
}
inline ::ignition::msgs::ImageGeom* Geometry::release_image() {
  
  ::ignition::msgs::ImageGeom* temp = image_;
  image_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::ImageGeom* Geometry::unsafe_arena_release_image() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.image)
  
  ::ignition::msgs::ImageGeom* temp = image_;
  image_ = nullptr;
  return temp;
}
inline ::ignition::msgs::ImageGeom* Geometry::_internal_mutable_image() {
  
  if (image_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::ImageGeom>(GetArenaForAllocation());
    image_ = p;
  }
  return image_;
}
inline ::ignition::msgs::ImageGeom* Geometry::mutable_image() {
  ::ignition::msgs::ImageGeom* _msg = _internal_mutable_image();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.image)
  return _msg;
}
inline void Geometry::set_allocated_image(::ignition::msgs::ImageGeom* image) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(image_);
  }
  if (image) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(image));
    if (message_arena != submessage_arena) {
      image = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, image, submessage_arena);
    }
    
  } else {
    
  }
  image_ = image;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.image)
}

// .ignition.msgs.HeightmapGeom heightmap = 8;
inline bool Geometry::_internal_has_heightmap() const {
  return this != internal_default_instance() && heightmap_ != nullptr;
}
inline bool Geometry::has_heightmap() const {
  return _internal_has_heightmap();
}
inline const ::ignition::msgs::HeightmapGeom& Geometry::_internal_heightmap() const {
  const ::ignition::msgs::HeightmapGeom* p = heightmap_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::HeightmapGeom&>(
      ::ignition::msgs::_HeightmapGeom_default_instance_);
}
inline const ::ignition::msgs::HeightmapGeom& Geometry::heightmap() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.heightmap)
  return _internal_heightmap();
}
inline void Geometry::unsafe_arena_set_allocated_heightmap(
    ::ignition::msgs::HeightmapGeom* heightmap) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(heightmap_);
  }
  heightmap_ = heightmap;
  if (heightmap) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.heightmap)
}
inline ::ignition::msgs::HeightmapGeom* Geometry::release_heightmap() {
  
  ::ignition::msgs::HeightmapGeom* temp = heightmap_;
  heightmap_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::HeightmapGeom* Geometry::unsafe_arena_release_heightmap() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.heightmap)
  
  ::ignition::msgs::HeightmapGeom* temp = heightmap_;
  heightmap_ = nullptr;
  return temp;
}
inline ::ignition::msgs::HeightmapGeom* Geometry::_internal_mutable_heightmap() {
  
  if (heightmap_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::HeightmapGeom>(GetArenaForAllocation());
    heightmap_ = p;
  }
  return heightmap_;
}
inline ::ignition::msgs::HeightmapGeom* Geometry::mutable_heightmap() {
  ::ignition::msgs::HeightmapGeom* _msg = _internal_mutable_heightmap();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.heightmap)
  return _msg;
}
inline void Geometry::set_allocated_heightmap(::ignition::msgs::HeightmapGeom* heightmap) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(heightmap_);
  }
  if (heightmap) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(heightmap));
    if (message_arena != submessage_arena) {
      heightmap = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, heightmap, submessage_arena);
    }
    
  } else {
    
  }
  heightmap_ = heightmap;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.heightmap)
}

// .ignition.msgs.MeshGeom mesh = 9;
inline bool Geometry::_internal_has_mesh() const {
  return this != internal_default_instance() && mesh_ != nullptr;
}
inline bool Geometry::has_mesh() const {
  return _internal_has_mesh();
}
inline const ::ignition::msgs::MeshGeom& Geometry::_internal_mesh() const {
  const ::ignition::msgs::MeshGeom* p = mesh_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::MeshGeom&>(
      ::ignition::msgs::_MeshGeom_default_instance_);
}
inline const ::ignition::msgs::MeshGeom& Geometry::mesh() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.mesh)
  return _internal_mesh();
}
inline void Geometry::unsafe_arena_set_allocated_mesh(
    ::ignition::msgs::MeshGeom* mesh) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(mesh_);
  }
  mesh_ = mesh;
  if (mesh) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.mesh)
}
inline ::ignition::msgs::MeshGeom* Geometry::release_mesh() {
  
  ::ignition::msgs::MeshGeom* temp = mesh_;
  mesh_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::MeshGeom* Geometry::unsafe_arena_release_mesh() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.mesh)
  
  ::ignition::msgs::MeshGeom* temp = mesh_;
  mesh_ = nullptr;
  return temp;
}
inline ::ignition::msgs::MeshGeom* Geometry::_internal_mutable_mesh() {
  
  if (mesh_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::MeshGeom>(GetArenaForAllocation());
    mesh_ = p;
  }
  return mesh_;
}
inline ::ignition::msgs::MeshGeom* Geometry::mutable_mesh() {
  ::ignition::msgs::MeshGeom* _msg = _internal_mutable_mesh();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.mesh)
  return _msg;
}
inline void Geometry::set_allocated_mesh(::ignition::msgs::MeshGeom* mesh) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(mesh_);
  }
  if (mesh) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(mesh));
    if (message_arena != submessage_arena) {
      mesh = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, mesh, submessage_arena);
    }
    
  } else {
    
  }
  mesh_ = mesh;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.mesh)
}

// .ignition.msgs.ConeGeom cone = 10;
inline bool Geometry::_internal_has_cone() const {
  return this != internal_default_instance() && cone_ != nullptr;
}
inline bool Geometry::has_cone() const {
  return _internal_has_cone();
}
inline const ::ignition::msgs::ConeGeom& Geometry::_internal_cone() const {
  const ::ignition::msgs::ConeGeom* p = cone_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::ConeGeom&>(
      ::ignition::msgs::_ConeGeom_default_instance_);
}
inline const ::ignition::msgs::ConeGeom& Geometry::cone() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.cone)
  return _internal_cone();
}
inline void Geometry::unsafe_arena_set_allocated_cone(
    ::ignition::msgs::ConeGeom* cone) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(cone_);
  }
  cone_ = cone;
  if (cone) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Geometry.cone)
}
inline ::ignition::msgs::ConeGeom* Geometry::release_cone() {
  
  ::ignition::msgs::ConeGeom* temp = cone_;
  cone_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::ConeGeom* Geometry::unsafe_arena_release_cone() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Geometry.cone)
  
  ::ignition::msgs::ConeGeom* temp = cone_;
  cone_ = nullptr;
  return temp;
}
inline ::ignition::msgs::ConeGeom* Geometry::_internal_mutable_cone() {
  
  if (cone_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::ConeGeom>(GetArenaForAllocation());
    cone_ = p;
  }
  return cone_;
}
inline ::ignition::msgs::ConeGeom* Geometry::mutable_cone() {
  ::ignition::msgs::ConeGeom* _msg = _internal_mutable_cone();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.cone)
  return _msg;
}
inline void Geometry::set_allocated_cone(::ignition::msgs::ConeGeom* cone) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(cone_);
  }
  if (cone) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(cone));
    if (message_arena != submessage_arena) {
      cone = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, cone, submessage_arena);
    }
    
  } else {
    
  }
  cone_ = cone;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Geometry.cone)
}

// repeated .ignition.msgs.Vector3d points = 11;
inline int Geometry::_internal_points_size() const {
  return points_.size();
}
inline int Geometry::points_size() const {
  return _internal_points_size();
}
inline ::ignition::msgs::Vector3d* Geometry::mutable_points(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.points)
  return points_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
Geometry::mutable_points() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Geometry.points)
  return &points_;
}
inline const ::ignition::msgs::Vector3d& Geometry::_internal_points(int index) const {
  return points_.Get(index);
}
inline const ::ignition::msgs::Vector3d& Geometry::points(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.points)
  return _internal_points(index);
}
inline ::ignition::msgs::Vector3d* Geometry::_internal_add_points() {
  return points_.Add();
}
inline ::ignition::msgs::Vector3d* Geometry::add_points() {
  ::ignition::msgs::Vector3d* _add = _internal_add_points();
  // @@protoc_insertion_point(field_add:ignition.msgs.Geometry.points)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
Geometry::points() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Geometry.points)
  return points_;
}

// repeated .ignition.msgs.Polyline polyline = 12;
inline int Geometry::_internal_polyline_size() const {
  return polyline_.size();
}
inline int Geometry::polyline_size() const {
  return _internal_polyline_size();
}
inline ::ignition::msgs::Polyline* Geometry::mutable_polyline(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Geometry.polyline)
  return polyline_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Polyline >*
Geometry::mutable_polyline() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Geometry.polyline)
  return &polyline_;
}
inline const ::ignition::msgs::Polyline& Geometry::_internal_polyline(int index) const {
  return polyline_.Get(index);
}
inline const ::ignition::msgs::Polyline& Geometry::polyline(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Geometry.polyline)
  return _internal_polyline(index);
}
inline ::ignition::msgs::Polyline* Geometry::_internal_add_polyline() {
  return polyline_.Add();
}
inline ::ignition::msgs::Polyline* Geometry::add_polyline() {
  ::ignition::msgs::Polyline* _add = _internal_add_polyline();
  // @@protoc_insertion_point(field_add:ignition.msgs.Geometry.polyline)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Polyline >&
Geometry::polyline() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Geometry.polyline)
  return polyline_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Geometry> GeometryUniquePtr;
typedef std::unique_ptr<const Geometry> ConstGeometryUniquePtr;
typedef std::shared_ptr<Geometry> GeometrySharedPtr;
typedef std::shared_ptr<const Geometry> ConstGeometrySharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::Geometry_Type> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Geometry_Type>() {
  return ::ignition::msgs::Geometry_Type_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fgeometry_2eproto
