# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/statistic.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/statistic.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Statistic" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Statistic.DataType"
      optional :name, :string, 3
      optional :value, :double, 4
    end
    add_enum "ignition.msgs.Statistic.DataType" do
      value :UNINITIALIZED, 0
      value :AVERAGE, 1
      value :MINIMUM, 2
      value :MAXIMUM, 3
      value :VARIANCE, 4
      value :STDDEV, 5
      value :SAMPLE_COUNT, 6
      value :ROOT_MEAN_SQUARE, 7
      value :MAX_ABS_VALUE, 8
    end
    add_message "ignition.msgs.StatisticsGroup" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      repeated :statistics, :message, 3, "ignition.msgs.Statistic"
    end
    add_message "ignition.msgs.Metric" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :unit, :string, 2
      repeated :statistics_groups, :message, 3, "ignition.msgs.StatisticsGroup"
      repeated :statistics, :message, 4, "ignition.msgs.Statistic"
    end
  end
end

module Ignition
  module Msgs
    Statistic = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Statistic").msgclass
    Statistic::DataType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Statistic.DataType").enummodule
    StatisticsGroup = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.StatisticsGroup").msgclass
    Metric = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Metric").msgclass
  end
end
