# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/tactile.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/tactile.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Tactile" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :collision_name, :string, 2
      repeated :collision_id, :uint32, 3
      repeated :pressure, :double, 4
    end
  end
end

module Ignition
  module Msgs
    Tactile = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Tactile").msgclass
  end
end
