/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "LogStatusProtos";

/// \ingroup ignition.msgs
/// \interface LogStatus
/// \brief A message that contains information about data logging

import "ignition/msgs/time.proto";
import "ignition/msgs/header.proto";

message LogStatus
{
  message LogFile
  {
    enum Units
    {
      BYTES   = 0;
      K_BYTES = 1;
      M_BYTES = 2;
      G_BYTES = 3;
    }

    string uri        = 1;
    string base_path  = 2;
    string full_path  = 3;
    float size        = 4;
    Units size_units  = 5;
    bool record_resources = 6;
  }

  /// \brief Optional header data
  Header header     = 1;

  Time sim_time     = 2;
  LogFile log_file  = 3;
}
