/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "LidarSensorProtos";

/// \ingroup ignition.msgs
/// \interface LidarSensor 
/// \brief Information about a lidar sensor element

import "ignition/msgs/header.proto";
import "ignition/msgs/sensor_noise.proto";

message LidarSensor
{
  /// \brief Optional header data
  Header header                = 1;

  bool display_scan            = 2;
  int32 horizontal_samples     = 3;
  double horizontal_resolution = 4;
  double horizontal_min_angle  = 5;
  double horizontal_max_angle  = 6;

  int32 vertical_samples       = 7;
  double vertical_resolution   = 8;
  double vertical_min_angle    = 9;
  double vertical_max_angle    = 10;

  double range_min             = 11;
  double range_max             = 12; 
  double range_resolution      = 13;

  SensorNoise noise            = 14;
}
