# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/shadows.proto

require 'ignition/msgs/color_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/shadows.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Shadows" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Shadows.ShadowType"
      optional :color, :message, 3, "ignition.msgs.Color"
    end
    add_enum "ignition.msgs.Shadows.ShadowType" do
      value :STENCIL_ADDITIVE, 0
      value :STENCIL_MODULATIVE, 1
      value :TEXTURE_ADDITIVE, 2
      value :TEXTURE_MODULATIVE, 3
    end
  end
end

module Ignition
  module Msgs
    Shadows = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Shadows").msgclass
    Shadows::ShadowType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Shadows.ShadowType").enummodule
  end
end
