# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/server_control.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/server_control.proto", :syntax => :proto3) do
    add_message "ignition.msgs.ServerControl" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :save_world_name, :string, 2
      optional :save_filename, :string, 3
      optional :open_filename, :string, 4
      optional :new_world, :bool, 5
      optional :stop, :bool, 6
      optional :clone, :bool, 7
      optional :new_port, :uint32, 8
    end
  end
end

module Ignition
  module Msgs
    ServerControl = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.ServerControl").msgclass
  end
end
