// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/material.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmaterial_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmaterial_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/color.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fmaterial_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fmaterial_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[3]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fmaterial_2eproto;
namespace ignition {
namespace msgs {
class Material;
struct MaterialDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern MaterialDefaultTypeInternal _Material_default_instance_;
class Material_PBR;
struct Material_PBRDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern Material_PBRDefaultTypeInternal _Material_PBR_default_instance_;
class Material_Script;
struct Material_ScriptDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern Material_ScriptDefaultTypeInternal _Material_Script_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Material* Arena::CreateMaybeMessage<::ignition::msgs::Material>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Material_PBR* Arena::CreateMaybeMessage<::ignition::msgs::Material_PBR>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Material_Script* Arena::CreateMaybeMessage<::ignition::msgs::Material_Script>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum Material_PBR_WorkflowType : int {
  Material_PBR_WorkflowType_NONE = 0,
  Material_PBR_WorkflowType_METAL = 1,
  Material_PBR_WorkflowType_SPECULAR = 2,
  Material_PBR_WorkflowType_Material_PBR_WorkflowType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Material_PBR_WorkflowType_Material_PBR_WorkflowType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Material_PBR_WorkflowType_IsValid(int value);
constexpr Material_PBR_WorkflowType Material_PBR_WorkflowType_WorkflowType_MIN = Material_PBR_WorkflowType_NONE;
constexpr Material_PBR_WorkflowType Material_PBR_WorkflowType_WorkflowType_MAX = Material_PBR_WorkflowType_SPECULAR;
constexpr int Material_PBR_WorkflowType_WorkflowType_ARRAYSIZE = Material_PBR_WorkflowType_WorkflowType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Material_PBR_WorkflowType_descriptor();
template<typename T>
inline const std::string& Material_PBR_WorkflowType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Material_PBR_WorkflowType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Material_PBR_WorkflowType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Material_PBR_WorkflowType_descriptor(), enum_t_value);
}
inline bool Material_PBR_WorkflowType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Material_PBR_WorkflowType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Material_PBR_WorkflowType>(
    Material_PBR_WorkflowType_descriptor(), name, value);
}
enum Material_ShaderType : int {
  Material_ShaderType_VERTEX = 0,
  Material_ShaderType_PIXEL = 1,
  Material_ShaderType_NORMAL_MAP_OBJECT_SPACE = 2,
  Material_ShaderType_NORMAL_MAP_TANGENT_SPACE = 3,
  Material_ShaderType_Material_ShaderType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Material_ShaderType_Material_ShaderType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Material_ShaderType_IsValid(int value);
constexpr Material_ShaderType Material_ShaderType_ShaderType_MIN = Material_ShaderType_VERTEX;
constexpr Material_ShaderType Material_ShaderType_ShaderType_MAX = Material_ShaderType_NORMAL_MAP_TANGENT_SPACE;
constexpr int Material_ShaderType_ShaderType_ARRAYSIZE = Material_ShaderType_ShaderType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Material_ShaderType_descriptor();
template<typename T>
inline const std::string& Material_ShaderType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Material_ShaderType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Material_ShaderType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Material_ShaderType_descriptor(), enum_t_value);
}
inline bool Material_ShaderType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Material_ShaderType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Material_ShaderType>(
    Material_ShaderType_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE Material_Script final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Material.Script) */ {
 public:
  inline Material_Script() : Material_Script(nullptr) {}
  ~Material_Script() override;
  explicit constexpr Material_Script(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Material_Script(const Material_Script& from);
  Material_Script(Material_Script&& from) noexcept
    : Material_Script() {
    *this = ::std::move(from);
  }

  inline Material_Script& operator=(const Material_Script& from) {
    CopyFrom(from);
    return *this;
  }
  inline Material_Script& operator=(Material_Script&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Material_Script& default_instance() {
    return *internal_default_instance();
  }
  static inline const Material_Script* internal_default_instance() {
    return reinterpret_cast<const Material_Script*>(
               &_Material_Script_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Material_Script& a, Material_Script& b) {
    a.Swap(&b);
  }
  inline void Swap(Material_Script* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Material_Script* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Material_Script* New() const final {
    return new Material_Script();
  }

  Material_Script* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Material_Script>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Material_Script& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Material_Script& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Material_Script* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Material.Script";
  }
  protected:
  explicit Material_Script(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kUriFieldNumber = 1,
    kNameFieldNumber = 2,
  };
  // repeated string uri = 1;
  int uri_size() const;
  private:
  int _internal_uri_size() const;
  public:
  void clear_uri();
  const std::string& uri(int index) const;
  std::string* mutable_uri(int index);
  void set_uri(int index, const std::string& value);
  void set_uri(int index, std::string&& value);
  void set_uri(int index, const char* value);
  void set_uri(int index, const char* value, size_t size);
  std::string* add_uri();
  void add_uri(const std::string& value);
  void add_uri(std::string&& value);
  void add_uri(const char* value);
  void add_uri(const char* value, size_t size);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField<std::string>& uri() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField<std::string>* mutable_uri();
  private:
  const std::string& _internal_uri(int index) const;
  std::string* _internal_add_uri();
  public:

  // string name = 2;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Material.Script)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField<std::string> uri_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fmaterial_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE Material_PBR final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Material.PBR) */ {
 public:
  inline Material_PBR() : Material_PBR(nullptr) {}
  ~Material_PBR() override;
  explicit constexpr Material_PBR(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Material_PBR(const Material_PBR& from);
  Material_PBR(Material_PBR&& from) noexcept
    : Material_PBR() {
    *this = ::std::move(from);
  }

  inline Material_PBR& operator=(const Material_PBR& from) {
    CopyFrom(from);
    return *this;
  }
  inline Material_PBR& operator=(Material_PBR&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Material_PBR& default_instance() {
    return *internal_default_instance();
  }
  static inline const Material_PBR* internal_default_instance() {
    return reinterpret_cast<const Material_PBR*>(
               &_Material_PBR_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(Material_PBR& a, Material_PBR& b) {
    a.Swap(&b);
  }
  inline void Swap(Material_PBR* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Material_PBR* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Material_PBR* New() const final {
    return new Material_PBR();
  }

  Material_PBR* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Material_PBR>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Material_PBR& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Material_PBR& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Material_PBR* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Material.PBR";
  }
  protected:
  explicit Material_PBR(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Material_PBR_WorkflowType WorkflowType;
  static constexpr WorkflowType NONE =
    Material_PBR_WorkflowType_NONE;
  static constexpr WorkflowType METAL =
    Material_PBR_WorkflowType_METAL;
  static constexpr WorkflowType SPECULAR =
    Material_PBR_WorkflowType_SPECULAR;
  static inline bool WorkflowType_IsValid(int value) {
    return Material_PBR_WorkflowType_IsValid(value);
  }
  static constexpr WorkflowType WorkflowType_MIN =
    Material_PBR_WorkflowType_WorkflowType_MIN;
  static constexpr WorkflowType WorkflowType_MAX =
    Material_PBR_WorkflowType_WorkflowType_MAX;
  static constexpr int WorkflowType_ARRAYSIZE =
    Material_PBR_WorkflowType_WorkflowType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  WorkflowType_descriptor() {
    return Material_PBR_WorkflowType_descriptor();
  }
  template<typename T>
  static inline const std::string& WorkflowType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, WorkflowType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function WorkflowType_Name.");
    return Material_PBR_WorkflowType_Name(enum_t_value);
  }
  static inline bool WorkflowType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      WorkflowType* value) {
    return Material_PBR_WorkflowType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kAlbedoMapFieldNumber = 2,
    kNormalMapFieldNumber = 3,
    kMetalnessMapFieldNumber = 5,
    kRoughnessMapFieldNumber = 7,
    kGlossinessMapFieldNumber = 9,
    kSpecularMapFieldNumber = 10,
    kEnvironmentMapFieldNumber = 11,
    kAmbientOcclusionMapFieldNumber = 12,
    kEmissiveMapFieldNumber = 13,
    kMetalnessFieldNumber = 4,
    kRoughnessFieldNumber = 6,
    kGlossinessFieldNumber = 8,
    kTypeFieldNumber = 1,
  };
  // string albedo_map = 2;
  void clear_albedo_map();
  const std::string& albedo_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_albedo_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_albedo_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_albedo_map();
  void set_allocated_albedo_map(std::string* albedo_map);
  private:
  const std::string& _internal_albedo_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_albedo_map(const std::string& value);
  std::string* _internal_mutable_albedo_map();
  public:

  // string normal_map = 3;
  void clear_normal_map();
  const std::string& normal_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_normal_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_normal_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_normal_map();
  void set_allocated_normal_map(std::string* normal_map);
  private:
  const std::string& _internal_normal_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_normal_map(const std::string& value);
  std::string* _internal_mutable_normal_map();
  public:

  // string metalness_map = 5;
  void clear_metalness_map();
  const std::string& metalness_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_metalness_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_metalness_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_metalness_map();
  void set_allocated_metalness_map(std::string* metalness_map);
  private:
  const std::string& _internal_metalness_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_metalness_map(const std::string& value);
  std::string* _internal_mutable_metalness_map();
  public:

  // string roughness_map = 7;
  void clear_roughness_map();
  const std::string& roughness_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_roughness_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_roughness_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_roughness_map();
  void set_allocated_roughness_map(std::string* roughness_map);
  private:
  const std::string& _internal_roughness_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_roughness_map(const std::string& value);
  std::string* _internal_mutable_roughness_map();
  public:

  // string glossiness_map = 9;
  void clear_glossiness_map();
  const std::string& glossiness_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_glossiness_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_glossiness_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_glossiness_map();
  void set_allocated_glossiness_map(std::string* glossiness_map);
  private:
  const std::string& _internal_glossiness_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_glossiness_map(const std::string& value);
  std::string* _internal_mutable_glossiness_map();
  public:

  // string specular_map = 10;
  void clear_specular_map();
  const std::string& specular_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_specular_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_specular_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_specular_map();
  void set_allocated_specular_map(std::string* specular_map);
  private:
  const std::string& _internal_specular_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_specular_map(const std::string& value);
  std::string* _internal_mutable_specular_map();
  public:

  // string environment_map = 11;
  void clear_environment_map();
  const std::string& environment_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_environment_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_environment_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_environment_map();
  void set_allocated_environment_map(std::string* environment_map);
  private:
  const std::string& _internal_environment_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_environment_map(const std::string& value);
  std::string* _internal_mutable_environment_map();
  public:

  // string ambient_occlusion_map = 12;
  void clear_ambient_occlusion_map();
  const std::string& ambient_occlusion_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_ambient_occlusion_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_ambient_occlusion_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_ambient_occlusion_map();
  void set_allocated_ambient_occlusion_map(std::string* ambient_occlusion_map);
  private:
  const std::string& _internal_ambient_occlusion_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_ambient_occlusion_map(const std::string& value);
  std::string* _internal_mutable_ambient_occlusion_map();
  public:

  // string emissive_map = 13;
  void clear_emissive_map();
  const std::string& emissive_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_emissive_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_emissive_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_emissive_map();
  void set_allocated_emissive_map(std::string* emissive_map);
  private:
  const std::string& _internal_emissive_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_emissive_map(const std::string& value);
  std::string* _internal_mutable_emissive_map();
  public:

  // double metalness = 4;
  void clear_metalness();
  double metalness() const;
  void set_metalness(double value);
  private:
  double _internal_metalness() const;
  void _internal_set_metalness(double value);
  public:

  // double roughness = 6;
  void clear_roughness();
  double roughness() const;
  void set_roughness(double value);
  private:
  double _internal_roughness() const;
  void _internal_set_roughness(double value);
  public:

  // double glossiness = 8;
  void clear_glossiness();
  double glossiness() const;
  void set_glossiness(double value);
  private:
  double _internal_glossiness() const;
  void _internal_set_glossiness(double value);
  public:

  // .ignition.msgs.Material.PBR.WorkflowType type = 1;
  void clear_type();
  ::ignition::msgs::Material_PBR_WorkflowType type() const;
  void set_type(::ignition::msgs::Material_PBR_WorkflowType value);
  private:
  ::ignition::msgs::Material_PBR_WorkflowType _internal_type() const;
  void _internal_set_type(::ignition::msgs::Material_PBR_WorkflowType value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Material.PBR)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr albedo_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr normal_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr metalness_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr roughness_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr glossiness_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr specular_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr environment_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr ambient_occlusion_map_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr emissive_map_;
  double metalness_;
  double roughness_;
  double glossiness_;
  int type_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fmaterial_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE Material final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Material) */ {
 public:
  inline Material() : Material(nullptr) {}
  ~Material() override;
  explicit constexpr Material(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Material(const Material& from);
  Material(Material&& from) noexcept
    : Material() {
    *this = ::std::move(from);
  }

  inline Material& operator=(const Material& from) {
    CopyFrom(from);
    return *this;
  }
  inline Material& operator=(Material&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Material& default_instance() {
    return *internal_default_instance();
  }
  static inline const Material* internal_default_instance() {
    return reinterpret_cast<const Material*>(
               &_Material_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(Material& a, Material& b) {
    a.Swap(&b);
  }
  inline void Swap(Material* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Material* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Material* New() const final {
    return new Material();
  }

  Material* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Material>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Material& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Material& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Material* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Material";
  }
  protected:
  explicit Material(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Material_Script Script;
  typedef Material_PBR PBR;

  typedef Material_ShaderType ShaderType;
  static constexpr ShaderType VERTEX =
    Material_ShaderType_VERTEX;
  static constexpr ShaderType PIXEL =
    Material_ShaderType_PIXEL;
  static constexpr ShaderType NORMAL_MAP_OBJECT_SPACE =
    Material_ShaderType_NORMAL_MAP_OBJECT_SPACE;
  static constexpr ShaderType NORMAL_MAP_TANGENT_SPACE =
    Material_ShaderType_NORMAL_MAP_TANGENT_SPACE;
  static inline bool ShaderType_IsValid(int value) {
    return Material_ShaderType_IsValid(value);
  }
  static constexpr ShaderType ShaderType_MIN =
    Material_ShaderType_ShaderType_MIN;
  static constexpr ShaderType ShaderType_MAX =
    Material_ShaderType_ShaderType_MAX;
  static constexpr int ShaderType_ARRAYSIZE =
    Material_ShaderType_ShaderType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  ShaderType_descriptor() {
    return Material_ShaderType_descriptor();
  }
  template<typename T>
  static inline const std::string& ShaderType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, ShaderType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function ShaderType_Name.");
    return Material_ShaderType_Name(enum_t_value);
  }
  static inline bool ShaderType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      ShaderType* value) {
    return Material_ShaderType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kNormalMapFieldNumber = 4,
    kHeaderFieldNumber = 1,
    kScriptFieldNumber = 2,
    kAmbientFieldNumber = 5,
    kDiffuseFieldNumber = 6,
    kSpecularFieldNumber = 7,
    kEmissiveFieldNumber = 8,
    kPbrFieldNumber = 10,
    kShaderTypeFieldNumber = 3,
    kLightingFieldNumber = 9,
  };
  // string normal_map = 4;
  void clear_normal_map();
  const std::string& normal_map() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_normal_map(ArgT0&& arg0, ArgT... args);
  std::string* mutable_normal_map();
  PROTOBUF_MUST_USE_RESULT std::string* release_normal_map();
  void set_allocated_normal_map(std::string* normal_map);
  private:
  const std::string& _internal_normal_map() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_normal_map(const std::string& value);
  std::string* _internal_mutable_normal_map();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Material.Script script = 2;
  bool has_script() const;
  private:
  bool _internal_has_script() const;
  public:
  void clear_script();
  const ::ignition::msgs::Material_Script& script() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Material_Script* release_script();
  ::ignition::msgs::Material_Script* mutable_script();
  void set_allocated_script(::ignition::msgs::Material_Script* script);
  private:
  const ::ignition::msgs::Material_Script& _internal_script() const;
  ::ignition::msgs::Material_Script* _internal_mutable_script();
  public:
  void unsafe_arena_set_allocated_script(
      ::ignition::msgs::Material_Script* script);
  ::ignition::msgs::Material_Script* unsafe_arena_release_script();

  // .ignition.msgs.Color ambient = 5;
  bool has_ambient() const;
  private:
  bool _internal_has_ambient() const;
  public:
  void clear_ambient();
  const ::ignition::msgs::Color& ambient() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_ambient();
  ::ignition::msgs::Color* mutable_ambient();
  void set_allocated_ambient(::ignition::msgs::Color* ambient);
  private:
  const ::ignition::msgs::Color& _internal_ambient() const;
  ::ignition::msgs::Color* _internal_mutable_ambient();
  public:
  void unsafe_arena_set_allocated_ambient(
      ::ignition::msgs::Color* ambient);
  ::ignition::msgs::Color* unsafe_arena_release_ambient();

  // .ignition.msgs.Color diffuse = 6;
  bool has_diffuse() const;
  private:
  bool _internal_has_diffuse() const;
  public:
  void clear_diffuse();
  const ::ignition::msgs::Color& diffuse() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_diffuse();
  ::ignition::msgs::Color* mutable_diffuse();
  void set_allocated_diffuse(::ignition::msgs::Color* diffuse);
  private:
  const ::ignition::msgs::Color& _internal_diffuse() const;
  ::ignition::msgs::Color* _internal_mutable_diffuse();
  public:
  void unsafe_arena_set_allocated_diffuse(
      ::ignition::msgs::Color* diffuse);
  ::ignition::msgs::Color* unsafe_arena_release_diffuse();

  // .ignition.msgs.Color specular = 7;
  bool has_specular() const;
  private:
  bool _internal_has_specular() const;
  public:
  void clear_specular();
  const ::ignition::msgs::Color& specular() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_specular();
  ::ignition::msgs::Color* mutable_specular();
  void set_allocated_specular(::ignition::msgs::Color* specular);
  private:
  const ::ignition::msgs::Color& _internal_specular() const;
  ::ignition::msgs::Color* _internal_mutable_specular();
  public:
  void unsafe_arena_set_allocated_specular(
      ::ignition::msgs::Color* specular);
  ::ignition::msgs::Color* unsafe_arena_release_specular();

  // .ignition.msgs.Color emissive = 8;
  bool has_emissive() const;
  private:
  bool _internal_has_emissive() const;
  public:
  void clear_emissive();
  const ::ignition::msgs::Color& emissive() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_emissive();
  ::ignition::msgs::Color* mutable_emissive();
  void set_allocated_emissive(::ignition::msgs::Color* emissive);
  private:
  const ::ignition::msgs::Color& _internal_emissive() const;
  ::ignition::msgs::Color* _internal_mutable_emissive();
  public:
  void unsafe_arena_set_allocated_emissive(
      ::ignition::msgs::Color* emissive);
  ::ignition::msgs::Color* unsafe_arena_release_emissive();

  // .ignition.msgs.Material.PBR pbr = 10;
  bool has_pbr() const;
  private:
  bool _internal_has_pbr() const;
  public:
  void clear_pbr();
  const ::ignition::msgs::Material_PBR& pbr() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Material_PBR* release_pbr();
  ::ignition::msgs::Material_PBR* mutable_pbr();
  void set_allocated_pbr(::ignition::msgs::Material_PBR* pbr);
  private:
  const ::ignition::msgs::Material_PBR& _internal_pbr() const;
  ::ignition::msgs::Material_PBR* _internal_mutable_pbr();
  public:
  void unsafe_arena_set_allocated_pbr(
      ::ignition::msgs::Material_PBR* pbr);
  ::ignition::msgs::Material_PBR* unsafe_arena_release_pbr();

  // .ignition.msgs.Material.ShaderType shader_type = 3;
  void clear_shader_type();
  ::ignition::msgs::Material_ShaderType shader_type() const;
  void set_shader_type(::ignition::msgs::Material_ShaderType value);
  private:
  ::ignition::msgs::Material_ShaderType _internal_shader_type() const;
  void _internal_set_shader_type(::ignition::msgs::Material_ShaderType value);
  public:

  // bool lighting = 9;
  void clear_lighting();
  bool lighting() const;
  void set_lighting(bool value);
  private:
  bool _internal_lighting() const;
  void _internal_set_lighting(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Material)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr normal_map_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Material_Script* script_;
  ::ignition::msgs::Color* ambient_;
  ::ignition::msgs::Color* diffuse_;
  ::ignition::msgs::Color* specular_;
  ::ignition::msgs::Color* emissive_;
  ::ignition::msgs::Material_PBR* pbr_;
  int shader_type_;
  bool lighting_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fmaterial_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Material_Script

// repeated string uri = 1;
inline int Material_Script::_internal_uri_size() const {
  return uri_.size();
}
inline int Material_Script::uri_size() const {
  return _internal_uri_size();
}
inline void Material_Script::clear_uri() {
  uri_.Clear();
}
inline std::string* Material_Script::add_uri() {
  std::string* _s = _internal_add_uri();
  // @@protoc_insertion_point(field_add_mutable:ignition.msgs.Material.Script.uri)
  return _s;
}
inline const std::string& Material_Script::_internal_uri(int index) const {
  return uri_.Get(index);
}
inline const std::string& Material_Script::uri(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.Script.uri)
  return _internal_uri(index);
}
inline std::string* Material_Script::mutable_uri(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.Script.uri)
  return uri_.Mutable(index);
}
inline void Material_Script::set_uri(int index, const std::string& value) {
  uri_.Mutable(index)->assign(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::set_uri(int index, std::string&& value) {
  uri_.Mutable(index)->assign(std::move(value));
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::set_uri(int index, const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  uri_.Mutable(index)->assign(value);
  // @@protoc_insertion_point(field_set_char:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::set_uri(int index, const char* value, size_t size) {
  uri_.Mutable(index)->assign(
    reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_set_pointer:ignition.msgs.Material.Script.uri)
}
inline std::string* Material_Script::_internal_add_uri() {
  return uri_.Add();
}
inline void Material_Script::add_uri(const std::string& value) {
  uri_.Add()->assign(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::add_uri(std::string&& value) {
  uri_.Add(std::move(value));
  // @@protoc_insertion_point(field_add:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::add_uri(const char* value) {
  GOOGLE_DCHECK(value != nullptr);
  uri_.Add()->assign(value);
  // @@protoc_insertion_point(field_add_char:ignition.msgs.Material.Script.uri)
}
inline void Material_Script::add_uri(const char* value, size_t size) {
  uri_.Add()->assign(reinterpret_cast<const char*>(value), size);
  // @@protoc_insertion_point(field_add_pointer:ignition.msgs.Material.Script.uri)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField<std::string>&
Material_Script::uri() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Material.Script.uri)
  return uri_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField<std::string>*
Material_Script::mutable_uri() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Material.Script.uri)
  return &uri_;
}

// string name = 2;
inline void Material_Script::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& Material_Script::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.Script.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_Script::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.Script.name)
}
inline std::string* Material_Script::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.Script.name)
  return _s;
}
inline const std::string& Material_Script::_internal_name() const {
  return name_.Get();
}
inline void Material_Script::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_Script::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_Script::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.Script.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_Script::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.Script.name)
}

// -------------------------------------------------------------------

// Material_PBR

// .ignition.msgs.Material.PBR.WorkflowType type = 1;
inline void Material_PBR::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::Material_PBR_WorkflowType Material_PBR::_internal_type() const {
  return static_cast< ::ignition::msgs::Material_PBR_WorkflowType >(type_);
}
inline ::ignition::msgs::Material_PBR_WorkflowType Material_PBR::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.type)
  return _internal_type();
}
inline void Material_PBR::_internal_set_type(::ignition::msgs::Material_PBR_WorkflowType value) {
  
  type_ = value;
}
inline void Material_PBR::set_type(::ignition::msgs::Material_PBR_WorkflowType value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.type)
}

// string albedo_map = 2;
inline void Material_PBR::clear_albedo_map() {
  albedo_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::albedo_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.albedo_map)
  return _internal_albedo_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_albedo_map(ArgT0&& arg0, ArgT... args) {
 
 albedo_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.albedo_map)
}
inline std::string* Material_PBR::mutable_albedo_map() {
  std::string* _s = _internal_mutable_albedo_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.albedo_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_albedo_map() const {
  return albedo_map_.Get();
}
inline void Material_PBR::_internal_set_albedo_map(const std::string& value) {
  
  albedo_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_albedo_map() {
  
  return albedo_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_albedo_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.albedo_map)
  return albedo_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_albedo_map(std::string* albedo_map) {
  if (albedo_map != nullptr) {
    
  } else {
    
  }
  albedo_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), albedo_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.albedo_map)
}

// string normal_map = 3;
inline void Material_PBR::clear_normal_map() {
  normal_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::normal_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.normal_map)
  return _internal_normal_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_normal_map(ArgT0&& arg0, ArgT... args) {
 
 normal_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.normal_map)
}
inline std::string* Material_PBR::mutable_normal_map() {
  std::string* _s = _internal_mutable_normal_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.normal_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_normal_map() const {
  return normal_map_.Get();
}
inline void Material_PBR::_internal_set_normal_map(const std::string& value) {
  
  normal_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_normal_map() {
  
  return normal_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_normal_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.normal_map)
  return normal_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_normal_map(std::string* normal_map) {
  if (normal_map != nullptr) {
    
  } else {
    
  }
  normal_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), normal_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.normal_map)
}

// double metalness = 4;
inline void Material_PBR::clear_metalness() {
  metalness_ = 0;
}
inline double Material_PBR::_internal_metalness() const {
  return metalness_;
}
inline double Material_PBR::metalness() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.metalness)
  return _internal_metalness();
}
inline void Material_PBR::_internal_set_metalness(double value) {
  
  metalness_ = value;
}
inline void Material_PBR::set_metalness(double value) {
  _internal_set_metalness(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.metalness)
}

// string metalness_map = 5;
inline void Material_PBR::clear_metalness_map() {
  metalness_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::metalness_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.metalness_map)
  return _internal_metalness_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_metalness_map(ArgT0&& arg0, ArgT... args) {
 
 metalness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.metalness_map)
}
inline std::string* Material_PBR::mutable_metalness_map() {
  std::string* _s = _internal_mutable_metalness_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.metalness_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_metalness_map() const {
  return metalness_map_.Get();
}
inline void Material_PBR::_internal_set_metalness_map(const std::string& value) {
  
  metalness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_metalness_map() {
  
  return metalness_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_metalness_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.metalness_map)
  return metalness_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_metalness_map(std::string* metalness_map) {
  if (metalness_map != nullptr) {
    
  } else {
    
  }
  metalness_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), metalness_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.metalness_map)
}

// double roughness = 6;
inline void Material_PBR::clear_roughness() {
  roughness_ = 0;
}
inline double Material_PBR::_internal_roughness() const {
  return roughness_;
}
inline double Material_PBR::roughness() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.roughness)
  return _internal_roughness();
}
inline void Material_PBR::_internal_set_roughness(double value) {
  
  roughness_ = value;
}
inline void Material_PBR::set_roughness(double value) {
  _internal_set_roughness(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.roughness)
}

// string roughness_map = 7;
inline void Material_PBR::clear_roughness_map() {
  roughness_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::roughness_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.roughness_map)
  return _internal_roughness_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_roughness_map(ArgT0&& arg0, ArgT... args) {
 
 roughness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.roughness_map)
}
inline std::string* Material_PBR::mutable_roughness_map() {
  std::string* _s = _internal_mutable_roughness_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.roughness_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_roughness_map() const {
  return roughness_map_.Get();
}
inline void Material_PBR::_internal_set_roughness_map(const std::string& value) {
  
  roughness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_roughness_map() {
  
  return roughness_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_roughness_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.roughness_map)
  return roughness_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_roughness_map(std::string* roughness_map) {
  if (roughness_map != nullptr) {
    
  } else {
    
  }
  roughness_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), roughness_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.roughness_map)
}

// double glossiness = 8;
inline void Material_PBR::clear_glossiness() {
  glossiness_ = 0;
}
inline double Material_PBR::_internal_glossiness() const {
  return glossiness_;
}
inline double Material_PBR::glossiness() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.glossiness)
  return _internal_glossiness();
}
inline void Material_PBR::_internal_set_glossiness(double value) {
  
  glossiness_ = value;
}
inline void Material_PBR::set_glossiness(double value) {
  _internal_set_glossiness(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.glossiness)
}

// string glossiness_map = 9;
inline void Material_PBR::clear_glossiness_map() {
  glossiness_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::glossiness_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.glossiness_map)
  return _internal_glossiness_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_glossiness_map(ArgT0&& arg0, ArgT... args) {
 
 glossiness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.glossiness_map)
}
inline std::string* Material_PBR::mutable_glossiness_map() {
  std::string* _s = _internal_mutable_glossiness_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.glossiness_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_glossiness_map() const {
  return glossiness_map_.Get();
}
inline void Material_PBR::_internal_set_glossiness_map(const std::string& value) {
  
  glossiness_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_glossiness_map() {
  
  return glossiness_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_glossiness_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.glossiness_map)
  return glossiness_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_glossiness_map(std::string* glossiness_map) {
  if (glossiness_map != nullptr) {
    
  } else {
    
  }
  glossiness_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), glossiness_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.glossiness_map)
}

// string specular_map = 10;
inline void Material_PBR::clear_specular_map() {
  specular_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::specular_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.specular_map)
  return _internal_specular_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_specular_map(ArgT0&& arg0, ArgT... args) {
 
 specular_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.specular_map)
}
inline std::string* Material_PBR::mutable_specular_map() {
  std::string* _s = _internal_mutable_specular_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.specular_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_specular_map() const {
  return specular_map_.Get();
}
inline void Material_PBR::_internal_set_specular_map(const std::string& value) {
  
  specular_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_specular_map() {
  
  return specular_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_specular_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.specular_map)
  return specular_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_specular_map(std::string* specular_map) {
  if (specular_map != nullptr) {
    
  } else {
    
  }
  specular_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), specular_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.specular_map)
}

// string environment_map = 11;
inline void Material_PBR::clear_environment_map() {
  environment_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::environment_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.environment_map)
  return _internal_environment_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_environment_map(ArgT0&& arg0, ArgT... args) {
 
 environment_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.environment_map)
}
inline std::string* Material_PBR::mutable_environment_map() {
  std::string* _s = _internal_mutable_environment_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.environment_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_environment_map() const {
  return environment_map_.Get();
}
inline void Material_PBR::_internal_set_environment_map(const std::string& value) {
  
  environment_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_environment_map() {
  
  return environment_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_environment_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.environment_map)
  return environment_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_environment_map(std::string* environment_map) {
  if (environment_map != nullptr) {
    
  } else {
    
  }
  environment_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), environment_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.environment_map)
}

// string ambient_occlusion_map = 12;
inline void Material_PBR::clear_ambient_occlusion_map() {
  ambient_occlusion_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::ambient_occlusion_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.ambient_occlusion_map)
  return _internal_ambient_occlusion_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_ambient_occlusion_map(ArgT0&& arg0, ArgT... args) {
 
 ambient_occlusion_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.ambient_occlusion_map)
}
inline std::string* Material_PBR::mutable_ambient_occlusion_map() {
  std::string* _s = _internal_mutable_ambient_occlusion_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.ambient_occlusion_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_ambient_occlusion_map() const {
  return ambient_occlusion_map_.Get();
}
inline void Material_PBR::_internal_set_ambient_occlusion_map(const std::string& value) {
  
  ambient_occlusion_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_ambient_occlusion_map() {
  
  return ambient_occlusion_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_ambient_occlusion_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.ambient_occlusion_map)
  return ambient_occlusion_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_ambient_occlusion_map(std::string* ambient_occlusion_map) {
  if (ambient_occlusion_map != nullptr) {
    
  } else {
    
  }
  ambient_occlusion_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ambient_occlusion_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.ambient_occlusion_map)
}

// string emissive_map = 13;
inline void Material_PBR::clear_emissive_map() {
  emissive_map_.ClearToEmpty();
}
inline const std::string& Material_PBR::emissive_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.PBR.emissive_map)
  return _internal_emissive_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material_PBR::set_emissive_map(ArgT0&& arg0, ArgT... args) {
 
 emissive_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.PBR.emissive_map)
}
inline std::string* Material_PBR::mutable_emissive_map() {
  std::string* _s = _internal_mutable_emissive_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.PBR.emissive_map)
  return _s;
}
inline const std::string& Material_PBR::_internal_emissive_map() const {
  return emissive_map_.Get();
}
inline void Material_PBR::_internal_set_emissive_map(const std::string& value) {
  
  emissive_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material_PBR::_internal_mutable_emissive_map() {
  
  return emissive_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material_PBR::release_emissive_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.PBR.emissive_map)
  return emissive_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material_PBR::set_allocated_emissive_map(std::string* emissive_map) {
  if (emissive_map != nullptr) {
    
  } else {
    
  }
  emissive_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), emissive_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.PBR.emissive_map)
}

// -------------------------------------------------------------------

// Material

// .ignition.msgs.Header header = 1;
inline bool Material::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Material::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Material::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Material::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.header)
  return _internal_header();
}
inline void Material::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.header)
}
inline ::ignition::msgs::Header* Material::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Material::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Material::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Material::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.header)
  return _msg;
}
inline void Material::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.header)
}

// .ignition.msgs.Material.Script script = 2;
inline bool Material::_internal_has_script() const {
  return this != internal_default_instance() && script_ != nullptr;
}
inline bool Material::has_script() const {
  return _internal_has_script();
}
inline void Material::clear_script() {
  if (GetArenaForAllocation() == nullptr && script_ != nullptr) {
    delete script_;
  }
  script_ = nullptr;
}
inline const ::ignition::msgs::Material_Script& Material::_internal_script() const {
  const ::ignition::msgs::Material_Script* p = script_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Material_Script&>(
      ::ignition::msgs::_Material_Script_default_instance_);
}
inline const ::ignition::msgs::Material_Script& Material::script() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.script)
  return _internal_script();
}
inline void Material::unsafe_arena_set_allocated_script(
    ::ignition::msgs::Material_Script* script) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(script_);
  }
  script_ = script;
  if (script) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.script)
}
inline ::ignition::msgs::Material_Script* Material::release_script() {
  
  ::ignition::msgs::Material_Script* temp = script_;
  script_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Material_Script* Material::unsafe_arena_release_script() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.script)
  
  ::ignition::msgs::Material_Script* temp = script_;
  script_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Material_Script* Material::_internal_mutable_script() {
  
  if (script_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Material_Script>(GetArenaForAllocation());
    script_ = p;
  }
  return script_;
}
inline ::ignition::msgs::Material_Script* Material::mutable_script() {
  ::ignition::msgs::Material_Script* _msg = _internal_mutable_script();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.script)
  return _msg;
}
inline void Material::set_allocated_script(::ignition::msgs::Material_Script* script) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete script_;
  }
  if (script) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::Material_Script>::GetOwningArena(script);
    if (message_arena != submessage_arena) {
      script = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, script, submessage_arena);
    }
    
  } else {
    
  }
  script_ = script;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.script)
}

// .ignition.msgs.Material.ShaderType shader_type = 3;
inline void Material::clear_shader_type() {
  shader_type_ = 0;
}
inline ::ignition::msgs::Material_ShaderType Material::_internal_shader_type() const {
  return static_cast< ::ignition::msgs::Material_ShaderType >(shader_type_);
}
inline ::ignition::msgs::Material_ShaderType Material::shader_type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.shader_type)
  return _internal_shader_type();
}
inline void Material::_internal_set_shader_type(::ignition::msgs::Material_ShaderType value) {
  
  shader_type_ = value;
}
inline void Material::set_shader_type(::ignition::msgs::Material_ShaderType value) {
  _internal_set_shader_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.shader_type)
}

// string normal_map = 4;
inline void Material::clear_normal_map() {
  normal_map_.ClearToEmpty();
}
inline const std::string& Material::normal_map() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.normal_map)
  return _internal_normal_map();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Material::set_normal_map(ArgT0&& arg0, ArgT... args) {
 
 normal_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.normal_map)
}
inline std::string* Material::mutable_normal_map() {
  std::string* _s = _internal_mutable_normal_map();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.normal_map)
  return _s;
}
inline const std::string& Material::_internal_normal_map() const {
  return normal_map_.Get();
}
inline void Material::_internal_set_normal_map(const std::string& value) {
  
  normal_map_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Material::_internal_mutable_normal_map() {
  
  return normal_map_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Material::release_normal_map() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.normal_map)
  return normal_map_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Material::set_allocated_normal_map(std::string* normal_map) {
  if (normal_map != nullptr) {
    
  } else {
    
  }
  normal_map_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), normal_map,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.normal_map)
}

// .ignition.msgs.Color ambient = 5;
inline bool Material::_internal_has_ambient() const {
  return this != internal_default_instance() && ambient_ != nullptr;
}
inline bool Material::has_ambient() const {
  return _internal_has_ambient();
}
inline const ::ignition::msgs::Color& Material::_internal_ambient() const {
  const ::ignition::msgs::Color* p = ambient_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Material::ambient() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.ambient)
  return _internal_ambient();
}
inline void Material::unsafe_arena_set_allocated_ambient(
    ::ignition::msgs::Color* ambient) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient_);
  }
  ambient_ = ambient;
  if (ambient) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.ambient)
}
inline ::ignition::msgs::Color* Material::release_ambient() {
  
  ::ignition::msgs::Color* temp = ambient_;
  ambient_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Material::unsafe_arena_release_ambient() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.ambient)
  
  ::ignition::msgs::Color* temp = ambient_;
  ambient_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Material::_internal_mutable_ambient() {
  
  if (ambient_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    ambient_ = p;
  }
  return ambient_;
}
inline ::ignition::msgs::Color* Material::mutable_ambient() {
  ::ignition::msgs::Color* _msg = _internal_mutable_ambient();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.ambient)
  return _msg;
}
inline void Material::set_allocated_ambient(::ignition::msgs::Color* ambient) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient_);
  }
  if (ambient) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient));
    if (message_arena != submessage_arena) {
      ambient = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, ambient, submessage_arena);
    }
    
  } else {
    
  }
  ambient_ = ambient;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.ambient)
}

// .ignition.msgs.Color diffuse = 6;
inline bool Material::_internal_has_diffuse() const {
  return this != internal_default_instance() && diffuse_ != nullptr;
}
inline bool Material::has_diffuse() const {
  return _internal_has_diffuse();
}
inline const ::ignition::msgs::Color& Material::_internal_diffuse() const {
  const ::ignition::msgs::Color* p = diffuse_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Material::diffuse() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.diffuse)
  return _internal_diffuse();
}
inline void Material::unsafe_arena_set_allocated_diffuse(
    ::ignition::msgs::Color* diffuse) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(diffuse_);
  }
  diffuse_ = diffuse;
  if (diffuse) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.diffuse)
}
inline ::ignition::msgs::Color* Material::release_diffuse() {
  
  ::ignition::msgs::Color* temp = diffuse_;
  diffuse_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Material::unsafe_arena_release_diffuse() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.diffuse)
  
  ::ignition::msgs::Color* temp = diffuse_;
  diffuse_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Material::_internal_mutable_diffuse() {
  
  if (diffuse_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    diffuse_ = p;
  }
  return diffuse_;
}
inline ::ignition::msgs::Color* Material::mutable_diffuse() {
  ::ignition::msgs::Color* _msg = _internal_mutable_diffuse();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.diffuse)
  return _msg;
}
inline void Material::set_allocated_diffuse(::ignition::msgs::Color* diffuse) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(diffuse_);
  }
  if (diffuse) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(diffuse));
    if (message_arena != submessage_arena) {
      diffuse = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, diffuse, submessage_arena);
    }
    
  } else {
    
  }
  diffuse_ = diffuse;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.diffuse)
}

// .ignition.msgs.Color specular = 7;
inline bool Material::_internal_has_specular() const {
  return this != internal_default_instance() && specular_ != nullptr;
}
inline bool Material::has_specular() const {
  return _internal_has_specular();
}
inline const ::ignition::msgs::Color& Material::_internal_specular() const {
  const ::ignition::msgs::Color* p = specular_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Material::specular() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.specular)
  return _internal_specular();
}
inline void Material::unsafe_arena_set_allocated_specular(
    ::ignition::msgs::Color* specular) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(specular_);
  }
  specular_ = specular;
  if (specular) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.specular)
}
inline ::ignition::msgs::Color* Material::release_specular() {
  
  ::ignition::msgs::Color* temp = specular_;
  specular_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Material::unsafe_arena_release_specular() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.specular)
  
  ::ignition::msgs::Color* temp = specular_;
  specular_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Material::_internal_mutable_specular() {
  
  if (specular_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    specular_ = p;
  }
  return specular_;
}
inline ::ignition::msgs::Color* Material::mutable_specular() {
  ::ignition::msgs::Color* _msg = _internal_mutable_specular();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.specular)
  return _msg;
}
inline void Material::set_allocated_specular(::ignition::msgs::Color* specular) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(specular_);
  }
  if (specular) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(specular));
    if (message_arena != submessage_arena) {
      specular = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, specular, submessage_arena);
    }
    
  } else {
    
  }
  specular_ = specular;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.specular)
}

// .ignition.msgs.Color emissive = 8;
inline bool Material::_internal_has_emissive() const {
  return this != internal_default_instance() && emissive_ != nullptr;
}
inline bool Material::has_emissive() const {
  return _internal_has_emissive();
}
inline const ::ignition::msgs::Color& Material::_internal_emissive() const {
  const ::ignition::msgs::Color* p = emissive_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Material::emissive() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.emissive)
  return _internal_emissive();
}
inline void Material::unsafe_arena_set_allocated_emissive(
    ::ignition::msgs::Color* emissive) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(emissive_);
  }
  emissive_ = emissive;
  if (emissive) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.emissive)
}
inline ::ignition::msgs::Color* Material::release_emissive() {
  
  ::ignition::msgs::Color* temp = emissive_;
  emissive_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Material::unsafe_arena_release_emissive() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.emissive)
  
  ::ignition::msgs::Color* temp = emissive_;
  emissive_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Material::_internal_mutable_emissive() {
  
  if (emissive_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    emissive_ = p;
  }
  return emissive_;
}
inline ::ignition::msgs::Color* Material::mutable_emissive() {
  ::ignition::msgs::Color* _msg = _internal_mutable_emissive();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.emissive)
  return _msg;
}
inline void Material::set_allocated_emissive(::ignition::msgs::Color* emissive) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(emissive_);
  }
  if (emissive) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(emissive));
    if (message_arena != submessage_arena) {
      emissive = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, emissive, submessage_arena);
    }
    
  } else {
    
  }
  emissive_ = emissive;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.emissive)
}

// bool lighting = 9;
inline void Material::clear_lighting() {
  lighting_ = false;
}
inline bool Material::_internal_lighting() const {
  return lighting_;
}
inline bool Material::lighting() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.lighting)
  return _internal_lighting();
}
inline void Material::_internal_set_lighting(bool value) {
  
  lighting_ = value;
}
inline void Material::set_lighting(bool value) {
  _internal_set_lighting(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Material.lighting)
}

// .ignition.msgs.Material.PBR pbr = 10;
inline bool Material::_internal_has_pbr() const {
  return this != internal_default_instance() && pbr_ != nullptr;
}
inline bool Material::has_pbr() const {
  return _internal_has_pbr();
}
inline void Material::clear_pbr() {
  if (GetArenaForAllocation() == nullptr && pbr_ != nullptr) {
    delete pbr_;
  }
  pbr_ = nullptr;
}
inline const ::ignition::msgs::Material_PBR& Material::_internal_pbr() const {
  const ::ignition::msgs::Material_PBR* p = pbr_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Material_PBR&>(
      ::ignition::msgs::_Material_PBR_default_instance_);
}
inline const ::ignition::msgs::Material_PBR& Material::pbr() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Material.pbr)
  return _internal_pbr();
}
inline void Material::unsafe_arena_set_allocated_pbr(
    ::ignition::msgs::Material_PBR* pbr) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pbr_);
  }
  pbr_ = pbr;
  if (pbr) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Material.pbr)
}
inline ::ignition::msgs::Material_PBR* Material::release_pbr() {
  
  ::ignition::msgs::Material_PBR* temp = pbr_;
  pbr_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Material_PBR* Material::unsafe_arena_release_pbr() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Material.pbr)
  
  ::ignition::msgs::Material_PBR* temp = pbr_;
  pbr_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Material_PBR* Material::_internal_mutable_pbr() {
  
  if (pbr_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Material_PBR>(GetArenaForAllocation());
    pbr_ = p;
  }
  return pbr_;
}
inline ::ignition::msgs::Material_PBR* Material::mutable_pbr() {
  ::ignition::msgs::Material_PBR* _msg = _internal_mutable_pbr();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Material.pbr)
  return _msg;
}
inline void Material::set_allocated_pbr(::ignition::msgs::Material_PBR* pbr) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete pbr_;
  }
  if (pbr) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::Material_PBR>::GetOwningArena(pbr);
    if (message_arena != submessage_arena) {
      pbr = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pbr, submessage_arena);
    }
    
  } else {
    
  }
  pbr_ = pbr;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Material.pbr)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<Material> MaterialUniquePtr;
typedef std::unique_ptr<const Material> ConstMaterialUniquePtr;
typedef std::shared_ptr<Material> MaterialSharedPtr;
typedef std::shared_ptr<const Material> ConstMaterialSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::Material_PBR_WorkflowType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Material_PBR_WorkflowType>() {
  return ::ignition::msgs::Material_PBR_WorkflowType_descriptor();
}
template <> struct is_proto_enum< ::ignition::msgs::Material_ShaderType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Material_ShaderType>() {
  return ::ignition::msgs::Material_ShaderType_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmaterial_2eproto
