/* Config.hh. Generated by CMake for ignition-msgs. */

/* Version number */
#define IGNITION_MSGS_MAJOR_VERSION 6
#define IGNITION_MSGS_MINOR_VERSION 5
#define IGNITION_MSGS_PATCH_VERSION 0

#define IGNITION_MSGS_VERSION "6.5"
#define IGNITION_MSGS_VERSION_FULL "6.5.0"

#define IGNITION_MSGS_VERSION_NAMESPACE v6

#define IGNITION_MSGS_VERSION_HEADER "Ignition msgs, version 6.5.0\nCopyright (C) 2016 Open Source Robotics Foundation.\nReleased under the Apache 2.0 License.\n\n"

/* #undef IGNITION_MSGS_BUILD_TYPE_PROFILE */
/* #undef IGNITION_MSGS_BUILD_TYPE_DEBUG */
/* #undef IGNITION_MSGS_BUILD_TYPE_RELEASE */
