# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/time.proto

require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/time.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Time" do
      optional :sec, :int64, 1
      optional :nsec, :int32, 2
    end
  end
end

module Ignition
  module Msgs
    Time = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Time").msgclass
  end
end
