// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/entity_factory.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fentity_5ffactory_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fentity_5ffactory_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/light.pb.h"
#include "ignition/msgs/model.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fentity_5ffactory_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fentity_5ffactory_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fentity_5ffactory_2eproto;
namespace ignition {
namespace msgs {
class EntityFactory;
struct EntityFactoryDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern EntityFactoryDefaultTypeInternal _EntityFactory_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::EntityFactory* Arena::CreateMaybeMessage<::ignition::msgs::EntityFactory>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE EntityFactory final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.EntityFactory) */ {
 public:
  inline EntityFactory() : EntityFactory(nullptr) {}
  ~EntityFactory() override;
  explicit constexpr EntityFactory(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  EntityFactory(const EntityFactory& from);
  EntityFactory(EntityFactory&& from) noexcept
    : EntityFactory() {
    *this = ::std::move(from);
  }

  inline EntityFactory& operator=(const EntityFactory& from) {
    CopyFrom(from);
    return *this;
  }
  inline EntityFactory& operator=(EntityFactory&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const EntityFactory& default_instance() {
    return *internal_default_instance();
  }
  enum FromCase {
    kSdf = 2,
    kSdfFilename = 3,
    kModel = 4,
    kLight = 5,
    kCloneName = 6,
    FROM_NOT_SET = 0,
  };

  static inline const EntityFactory* internal_default_instance() {
    return reinterpret_cast<const EntityFactory*>(
               &_EntityFactory_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(EntityFactory& a, EntityFactory& b) {
    a.Swap(&b);
  }
  inline void Swap(EntityFactory* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(EntityFactory* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline EntityFactory* New() const final {
    return new EntityFactory();
  }

  EntityFactory* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<EntityFactory>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const EntityFactory& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const EntityFactory& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(EntityFactory* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.EntityFactory";
  }
  protected:
  explicit EntityFactory(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 8,
    kRelativeToFieldNumber = 10,
    kHeaderFieldNumber = 1,
    kPoseFieldNumber = 7,
    kAllowRenamingFieldNumber = 9,
    kSdfFieldNumber = 2,
    kSdfFilenameFieldNumber = 3,
    kModelFieldNumber = 4,
    kLightFieldNumber = 5,
    kCloneNameFieldNumber = 6,
  };
  // string name = 8;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // string relative_to = 10;
  void clear_relative_to();
  const std::string& relative_to() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_relative_to(ArgT0&& arg0, ArgT... args);
  std::string* mutable_relative_to();
  PROTOBUF_MUST_USE_RESULT std::string* release_relative_to();
  void set_allocated_relative_to(std::string* relative_to);
  private:
  const std::string& _internal_relative_to() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_relative_to(const std::string& value);
  std::string* _internal_mutable_relative_to();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Pose pose = 7;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // bool allow_renaming = 9;
  void clear_allow_renaming();
  bool allow_renaming() const;
  void set_allow_renaming(bool value);
  private:
  bool _internal_allow_renaming() const;
  void _internal_set_allow_renaming(bool value);
  public:

  // string sdf = 2;
  bool has_sdf() const;
  private:
  bool _internal_has_sdf() const;
  public:
  void clear_sdf();
  const std::string& sdf() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_sdf(ArgT0&& arg0, ArgT... args);
  std::string* mutable_sdf();
  PROTOBUF_MUST_USE_RESULT std::string* release_sdf();
  void set_allocated_sdf(std::string* sdf);
  private:
  const std::string& _internal_sdf() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_sdf(const std::string& value);
  std::string* _internal_mutable_sdf();
  public:

  // string sdf_filename = 3;
  bool has_sdf_filename() const;
  private:
  bool _internal_has_sdf_filename() const;
  public:
  void clear_sdf_filename();
  const std::string& sdf_filename() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_sdf_filename(ArgT0&& arg0, ArgT... args);
  std::string* mutable_sdf_filename();
  PROTOBUF_MUST_USE_RESULT std::string* release_sdf_filename();
  void set_allocated_sdf_filename(std::string* sdf_filename);
  private:
  const std::string& _internal_sdf_filename() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_sdf_filename(const std::string& value);
  std::string* _internal_mutable_sdf_filename();
  public:

  // .ignition.msgs.Model model = 4;
  bool has_model() const;
  private:
  bool _internal_has_model() const;
  public:
  void clear_model();
  const ::ignition::msgs::Model& model() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Model* release_model();
  ::ignition::msgs::Model* mutable_model();
  void set_allocated_model(::ignition::msgs::Model* model);
  private:
  const ::ignition::msgs::Model& _internal_model() const;
  ::ignition::msgs::Model* _internal_mutable_model();
  public:
  void unsafe_arena_set_allocated_model(
      ::ignition::msgs::Model* model);
  ::ignition::msgs::Model* unsafe_arena_release_model();

  // .ignition.msgs.Light light = 5;
  bool has_light() const;
  private:
  bool _internal_has_light() const;
  public:
  void clear_light();
  const ::ignition::msgs::Light& light() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Light* release_light();
  ::ignition::msgs::Light* mutable_light();
  void set_allocated_light(::ignition::msgs::Light* light);
  private:
  const ::ignition::msgs::Light& _internal_light() const;
  ::ignition::msgs::Light* _internal_mutable_light();
  public:
  void unsafe_arena_set_allocated_light(
      ::ignition::msgs::Light* light);
  ::ignition::msgs::Light* unsafe_arena_release_light();

  // string clone_name = 6;
  bool has_clone_name() const;
  private:
  bool _internal_has_clone_name() const;
  public:
  void clear_clone_name();
  const std::string& clone_name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_clone_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_clone_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_clone_name();
  void set_allocated_clone_name(std::string* clone_name);
  private:
  const std::string& _internal_clone_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_clone_name(const std::string& value);
  std::string* _internal_mutable_clone_name();
  public:

  void clear_from();
  FromCase from_case() const;
  // @@protoc_insertion_point(class_scope:ignition.msgs.EntityFactory)
 private:
  class _Internal;
  void set_has_sdf();
  void set_has_sdf_filename();
  void set_has_model();
  void set_has_light();
  void set_has_clone_name();

  inline bool has_from() const;
  inline void clear_has_from();

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr relative_to_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Pose* pose_;
  bool allow_renaming_;
  union FromUnion {
    constexpr FromUnion() : _constinit_{} {}
      ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized _constinit_;
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr sdf_;
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr sdf_filename_;
    ::ignition::msgs::Model* model_;
    ::ignition::msgs::Light* light_;
    ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr clone_name_;
  } from_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  ::PROTOBUF_NAMESPACE_ID::uint32 _oneof_case_[1];

  friend struct ::TableStruct_ignition_2fmsgs_2fentity_5ffactory_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// EntityFactory

// .ignition.msgs.Header header = 1;
inline bool EntityFactory::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool EntityFactory::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& EntityFactory::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& EntityFactory::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.header)
  return _internal_header();
}
inline void EntityFactory::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.EntityFactory.header)
}
inline ::ignition::msgs::Header* EntityFactory::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* EntityFactory::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* EntityFactory::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* EntityFactory::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.header)
  return _msg;
}
inline void EntityFactory::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.header)
}

// string sdf = 2;
inline bool EntityFactory::_internal_has_sdf() const {
  return from_case() == kSdf;
}
inline bool EntityFactory::has_sdf() const {
  return _internal_has_sdf();
}
inline void EntityFactory::set_has_sdf() {
  _oneof_case_[0] = kSdf;
}
inline void EntityFactory::clear_sdf() {
  if (_internal_has_sdf()) {
    from_.sdf_.Destroy(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
    clear_has_from();
  }
}
inline const std::string& EntityFactory::sdf() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.sdf)
  return _internal_sdf();
}
template <typename ArgT0, typename... ArgT>
inline void EntityFactory::set_sdf(ArgT0&& arg0, ArgT... args) {
  if (!_internal_has_sdf()) {
    clear_from();
    set_has_sdf();
    from_.sdf_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.sdf_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.sdf)
}
inline std::string* EntityFactory::mutable_sdf() {
  std::string* _s = _internal_mutable_sdf();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.sdf)
  return _s;
}
inline const std::string& EntityFactory::_internal_sdf() const {
  if (_internal_has_sdf()) {
    return from_.sdf_.Get();
  }
  return ::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited();
}
inline void EntityFactory::_internal_set_sdf(const std::string& value) {
  if (!_internal_has_sdf()) {
    clear_from();
    set_has_sdf();
    from_.sdf_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.sdf_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* EntityFactory::_internal_mutable_sdf() {
  if (!_internal_has_sdf()) {
    clear_from();
    set_has_sdf();
    from_.sdf_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  return from_.sdf_.Mutable(
      ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* EntityFactory::release_sdf() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.sdf)
  if (_internal_has_sdf()) {
    clear_has_from();
    return from_.sdf_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
  } else {
    return nullptr;
  }
}
inline void EntityFactory::set_allocated_sdf(std::string* sdf) {
  if (has_from()) {
    clear_from();
  }
  if (sdf != nullptr) {
    set_has_sdf();
    from_.sdf_.UnsafeSetDefault(sdf);
    ::PROTOBUF_NAMESPACE_ID::Arena* arena = GetArenaForAllocation();
    if (arena != nullptr) {
      arena->Own(sdf);
    }
  }
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.sdf)
}

// string sdf_filename = 3;
inline bool EntityFactory::_internal_has_sdf_filename() const {
  return from_case() == kSdfFilename;
}
inline bool EntityFactory::has_sdf_filename() const {
  return _internal_has_sdf_filename();
}
inline void EntityFactory::set_has_sdf_filename() {
  _oneof_case_[0] = kSdfFilename;
}
inline void EntityFactory::clear_sdf_filename() {
  if (_internal_has_sdf_filename()) {
    from_.sdf_filename_.Destroy(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
    clear_has_from();
  }
}
inline const std::string& EntityFactory::sdf_filename() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.sdf_filename)
  return _internal_sdf_filename();
}
template <typename ArgT0, typename... ArgT>
inline void EntityFactory::set_sdf_filename(ArgT0&& arg0, ArgT... args) {
  if (!_internal_has_sdf_filename()) {
    clear_from();
    set_has_sdf_filename();
    from_.sdf_filename_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.sdf_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.sdf_filename)
}
inline std::string* EntityFactory::mutable_sdf_filename() {
  std::string* _s = _internal_mutable_sdf_filename();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.sdf_filename)
  return _s;
}
inline const std::string& EntityFactory::_internal_sdf_filename() const {
  if (_internal_has_sdf_filename()) {
    return from_.sdf_filename_.Get();
  }
  return ::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited();
}
inline void EntityFactory::_internal_set_sdf_filename(const std::string& value) {
  if (!_internal_has_sdf_filename()) {
    clear_from();
    set_has_sdf_filename();
    from_.sdf_filename_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.sdf_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* EntityFactory::_internal_mutable_sdf_filename() {
  if (!_internal_has_sdf_filename()) {
    clear_from();
    set_has_sdf_filename();
    from_.sdf_filename_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  return from_.sdf_filename_.Mutable(
      ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* EntityFactory::release_sdf_filename() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.sdf_filename)
  if (_internal_has_sdf_filename()) {
    clear_has_from();
    return from_.sdf_filename_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
  } else {
    return nullptr;
  }
}
inline void EntityFactory::set_allocated_sdf_filename(std::string* sdf_filename) {
  if (has_from()) {
    clear_from();
  }
  if (sdf_filename != nullptr) {
    set_has_sdf_filename();
    from_.sdf_filename_.UnsafeSetDefault(sdf_filename);
    ::PROTOBUF_NAMESPACE_ID::Arena* arena = GetArenaForAllocation();
    if (arena != nullptr) {
      arena->Own(sdf_filename);
    }
  }
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.sdf_filename)
}

// .ignition.msgs.Model model = 4;
inline bool EntityFactory::_internal_has_model() const {
  return from_case() == kModel;
}
inline bool EntityFactory::has_model() const {
  return _internal_has_model();
}
inline void EntityFactory::set_has_model() {
  _oneof_case_[0] = kModel;
}
inline ::ignition::msgs::Model* EntityFactory::release_model() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.model)
  if (_internal_has_model()) {
    clear_has_from();
      ::ignition::msgs::Model* temp = from_.model_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    from_.model_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Model& EntityFactory::_internal_model() const {
  return _internal_has_model()
      ? *from_.model_
      : reinterpret_cast< ::ignition::msgs::Model&>(::ignition::msgs::_Model_default_instance_);
}
inline const ::ignition::msgs::Model& EntityFactory::model() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.model)
  return _internal_model();
}
inline ::ignition::msgs::Model* EntityFactory::unsafe_arena_release_model() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.EntityFactory.model)
  if (_internal_has_model()) {
    clear_has_from();
    ::ignition::msgs::Model* temp = from_.model_;
    from_.model_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void EntityFactory::unsafe_arena_set_allocated_model(::ignition::msgs::Model* model) {
  clear_from();
  if (model) {
    set_has_model();
    from_.model_ = model;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.EntityFactory.model)
}
inline ::ignition::msgs::Model* EntityFactory::_internal_mutable_model() {
  if (!_internal_has_model()) {
    clear_from();
    set_has_model();
    from_.model_ = CreateMaybeMessage< ::ignition::msgs::Model >(GetArenaForAllocation());
  }
  return from_.model_;
}
inline ::ignition::msgs::Model* EntityFactory::mutable_model() {
  ::ignition::msgs::Model* _msg = _internal_mutable_model();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.model)
  return _msg;
}

// .ignition.msgs.Light light = 5;
inline bool EntityFactory::_internal_has_light() const {
  return from_case() == kLight;
}
inline bool EntityFactory::has_light() const {
  return _internal_has_light();
}
inline void EntityFactory::set_has_light() {
  _oneof_case_[0] = kLight;
}
inline ::ignition::msgs::Light* EntityFactory::release_light() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.light)
  if (_internal_has_light()) {
    clear_has_from();
      ::ignition::msgs::Light* temp = from_.light_;
    if (GetArenaForAllocation() != nullptr) {
      temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
    }
    from_.light_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline const ::ignition::msgs::Light& EntityFactory::_internal_light() const {
  return _internal_has_light()
      ? *from_.light_
      : reinterpret_cast< ::ignition::msgs::Light&>(::ignition::msgs::_Light_default_instance_);
}
inline const ::ignition::msgs::Light& EntityFactory::light() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.light)
  return _internal_light();
}
inline ::ignition::msgs::Light* EntityFactory::unsafe_arena_release_light() {
  // @@protoc_insertion_point(field_unsafe_arena_release:ignition.msgs.EntityFactory.light)
  if (_internal_has_light()) {
    clear_has_from();
    ::ignition::msgs::Light* temp = from_.light_;
    from_.light_ = nullptr;
    return temp;
  } else {
    return nullptr;
  }
}
inline void EntityFactory::unsafe_arena_set_allocated_light(::ignition::msgs::Light* light) {
  clear_from();
  if (light) {
    set_has_light();
    from_.light_ = light;
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.EntityFactory.light)
}
inline ::ignition::msgs::Light* EntityFactory::_internal_mutable_light() {
  if (!_internal_has_light()) {
    clear_from();
    set_has_light();
    from_.light_ = CreateMaybeMessage< ::ignition::msgs::Light >(GetArenaForAllocation());
  }
  return from_.light_;
}
inline ::ignition::msgs::Light* EntityFactory::mutable_light() {
  ::ignition::msgs::Light* _msg = _internal_mutable_light();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.light)
  return _msg;
}

// string clone_name = 6;
inline bool EntityFactory::_internal_has_clone_name() const {
  return from_case() == kCloneName;
}
inline bool EntityFactory::has_clone_name() const {
  return _internal_has_clone_name();
}
inline void EntityFactory::set_has_clone_name() {
  _oneof_case_[0] = kCloneName;
}
inline void EntityFactory::clear_clone_name() {
  if (_internal_has_clone_name()) {
    from_.clone_name_.Destroy(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
    clear_has_from();
  }
}
inline const std::string& EntityFactory::clone_name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.clone_name)
  return _internal_clone_name();
}
template <typename ArgT0, typename... ArgT>
inline void EntityFactory::set_clone_name(ArgT0&& arg0, ArgT... args) {
  if (!_internal_has_clone_name()) {
    clear_from();
    set_has_clone_name();
    from_.clone_name_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.clone_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.clone_name)
}
inline std::string* EntityFactory::mutable_clone_name() {
  std::string* _s = _internal_mutable_clone_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.clone_name)
  return _s;
}
inline const std::string& EntityFactory::_internal_clone_name() const {
  if (_internal_has_clone_name()) {
    return from_.clone_name_.Get();
  }
  return ::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited();
}
inline void EntityFactory::_internal_set_clone_name(const std::string& value) {
  if (!_internal_has_clone_name()) {
    clear_from();
    set_has_clone_name();
    from_.clone_name_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  from_.clone_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* EntityFactory::_internal_mutable_clone_name() {
  if (!_internal_has_clone_name()) {
    clear_from();
    set_has_clone_name();
    from_.clone_name_.UnsafeSetDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited());
  }
  return from_.clone_name_.Mutable(
      ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* EntityFactory::release_clone_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.clone_name)
  if (_internal_has_clone_name()) {
    clear_has_from();
    return from_.clone_name_.ReleaseNonDefault(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
  } else {
    return nullptr;
  }
}
inline void EntityFactory::set_allocated_clone_name(std::string* clone_name) {
  if (has_from()) {
    clear_from();
  }
  if (clone_name != nullptr) {
    set_has_clone_name();
    from_.clone_name_.UnsafeSetDefault(clone_name);
    ::PROTOBUF_NAMESPACE_ID::Arena* arena = GetArenaForAllocation();
    if (arena != nullptr) {
      arena->Own(clone_name);
    }
  }
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.clone_name)
}

// .ignition.msgs.Pose pose = 7;
inline bool EntityFactory::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool EntityFactory::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& EntityFactory::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& EntityFactory::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.pose)
  return _internal_pose();
}
inline void EntityFactory::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.EntityFactory.pose)
}
inline ::ignition::msgs::Pose* EntityFactory::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* EntityFactory::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* EntityFactory::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* EntityFactory::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.pose)
  return _msg;
}
inline void EntityFactory::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.pose)
}

// string name = 8;
inline void EntityFactory::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& EntityFactory::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void EntityFactory::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.name)
}
inline std::string* EntityFactory::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.name)
  return _s;
}
inline const std::string& EntityFactory::_internal_name() const {
  return name_.Get();
}
inline void EntityFactory::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* EntityFactory::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* EntityFactory::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void EntityFactory::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.name)
}

// bool allow_renaming = 9;
inline void EntityFactory::clear_allow_renaming() {
  allow_renaming_ = false;
}
inline bool EntityFactory::_internal_allow_renaming() const {
  return allow_renaming_;
}
inline bool EntityFactory::allow_renaming() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.allow_renaming)
  return _internal_allow_renaming();
}
inline void EntityFactory::_internal_set_allow_renaming(bool value) {
  
  allow_renaming_ = value;
}
inline void EntityFactory::set_allow_renaming(bool value) {
  _internal_set_allow_renaming(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.allow_renaming)
}

// string relative_to = 10;
inline void EntityFactory::clear_relative_to() {
  relative_to_.ClearToEmpty();
}
inline const std::string& EntityFactory::relative_to() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.EntityFactory.relative_to)
  return _internal_relative_to();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void EntityFactory::set_relative_to(ArgT0&& arg0, ArgT... args) {
 
 relative_to_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.EntityFactory.relative_to)
}
inline std::string* EntityFactory::mutable_relative_to() {
  std::string* _s = _internal_mutable_relative_to();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.EntityFactory.relative_to)
  return _s;
}
inline const std::string& EntityFactory::_internal_relative_to() const {
  return relative_to_.Get();
}
inline void EntityFactory::_internal_set_relative_to(const std::string& value) {
  
  relative_to_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* EntityFactory::_internal_mutable_relative_to() {
  
  return relative_to_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* EntityFactory::release_relative_to() {
  // @@protoc_insertion_point(field_release:ignition.msgs.EntityFactory.relative_to)
  return relative_to_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void EntityFactory::set_allocated_relative_to(std::string* relative_to) {
  if (relative_to != nullptr) {
    
  } else {
    
  }
  relative_to_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), relative_to,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.EntityFactory.relative_to)
}

inline bool EntityFactory::has_from() const {
  return from_case() != FROM_NOT_SET;
}
inline void EntityFactory::clear_has_from() {
  _oneof_case_[0] = FROM_NOT_SET;
}
inline EntityFactory::FromCase EntityFactory::from_case() const {
  return EntityFactory::FromCase(_oneof_case_[0]);
}
#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<EntityFactory> EntityFactoryUniquePtr;
typedef std::unique_ptr<const EntityFactory> ConstEntityFactoryUniquePtr;
typedef std::shared_ptr<EntityFactory> EntityFactorySharedPtr;
typedef std::shared_ptr<const EntityFactory> ConstEntityFactorySharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fentity_5ffactory_2eproto
