# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/track_visual.proto

require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/track_visual.proto", :syntax => :proto3) do
    add_message "ignition.msgs.TrackVisual" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :inherit_orientation, :bool, 4
      optional :min_dist, :double, 5
      optional :max_dist, :double, 6
      optional :static, :bool, 7
      optional :use_model_frame, :bool, 8
      optional :xyz, :message, 9, "ignition.msgs.Vector3d"
      optional :inherit_yaw, :bool, 10
    end
  end
end

module Ignition
  module Msgs
    TrackVisual = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.TrackVisual").msgclass
  end
end
