// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/pid.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpid_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpid_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/double.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fpid_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fpid_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fpid_2eproto;
namespace ignition {
namespace msgs {
class PID;
struct PIDDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PIDDefaultTypeInternal _PID_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::PID* Arena::CreateMaybeMessage<::ignition::msgs::PID>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE PID final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.PID) */ {
 public:
  inline PID() : PID(nullptr) {}
  ~PID() override;
  explicit constexpr PID(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PID(const PID& from);
  PID(PID&& from) noexcept
    : PID() {
    *this = ::std::move(from);
  }

  inline PID& operator=(const PID& from) {
    CopyFrom(from);
    return *this;
  }
  inline PID& operator=(PID&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PID& default_instance() {
    return *internal_default_instance();
  }
  static inline const PID* internal_default_instance() {
    return reinterpret_cast<const PID*>(
               &_PID_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(PID& a, PID& b) {
    a.Swap(&b);
  }
  inline void Swap(PID* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PID* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline PID* New() const final {
    return new PID();
  }

  PID* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<PID>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PID& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PID& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PID* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.PID";
  }
  protected:
  explicit PID(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kHeaderFieldNumber = 1,
    kTargetOptionalFieldNumber = 9,
    kPGainOptionalFieldNumber = 10,
    kIGainOptionalFieldNumber = 11,
    kDGainOptionalFieldNumber = 12,
    kIMaxOptionalFieldNumber = 13,
    kIMinOptionalFieldNumber = 14,
    kLimitOptionalFieldNumber = 15,
    kTargetFieldNumber = 2,
    kPGainFieldNumber = 3,
    kIGainFieldNumber = 4,
    kDGainFieldNumber = 5,
    kIMaxFieldNumber = 6,
    kIMinFieldNumber = 7,
    kLimitFieldNumber = 8,
  };
  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Double target_optional = 9;
  bool has_target_optional() const;
  private:
  bool _internal_has_target_optional() const;
  public:
  void clear_target_optional();
  const ::ignition::msgs::Double& target_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_target_optional();
  ::ignition::msgs::Double* mutable_target_optional();
  void set_allocated_target_optional(::ignition::msgs::Double* target_optional);
  private:
  const ::ignition::msgs::Double& _internal_target_optional() const;
  ::ignition::msgs::Double* _internal_mutable_target_optional();
  public:
  void unsafe_arena_set_allocated_target_optional(
      ::ignition::msgs::Double* target_optional);
  ::ignition::msgs::Double* unsafe_arena_release_target_optional();

  // .ignition.msgs.Double p_gain_optional = 10;
  bool has_p_gain_optional() const;
  private:
  bool _internal_has_p_gain_optional() const;
  public:
  void clear_p_gain_optional();
  const ::ignition::msgs::Double& p_gain_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_p_gain_optional();
  ::ignition::msgs::Double* mutable_p_gain_optional();
  void set_allocated_p_gain_optional(::ignition::msgs::Double* p_gain_optional);
  private:
  const ::ignition::msgs::Double& _internal_p_gain_optional() const;
  ::ignition::msgs::Double* _internal_mutable_p_gain_optional();
  public:
  void unsafe_arena_set_allocated_p_gain_optional(
      ::ignition::msgs::Double* p_gain_optional);
  ::ignition::msgs::Double* unsafe_arena_release_p_gain_optional();

  // .ignition.msgs.Double i_gain_optional = 11;
  bool has_i_gain_optional() const;
  private:
  bool _internal_has_i_gain_optional() const;
  public:
  void clear_i_gain_optional();
  const ::ignition::msgs::Double& i_gain_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_i_gain_optional();
  ::ignition::msgs::Double* mutable_i_gain_optional();
  void set_allocated_i_gain_optional(::ignition::msgs::Double* i_gain_optional);
  private:
  const ::ignition::msgs::Double& _internal_i_gain_optional() const;
  ::ignition::msgs::Double* _internal_mutable_i_gain_optional();
  public:
  void unsafe_arena_set_allocated_i_gain_optional(
      ::ignition::msgs::Double* i_gain_optional);
  ::ignition::msgs::Double* unsafe_arena_release_i_gain_optional();

  // .ignition.msgs.Double d_gain_optional = 12;
  bool has_d_gain_optional() const;
  private:
  bool _internal_has_d_gain_optional() const;
  public:
  void clear_d_gain_optional();
  const ::ignition::msgs::Double& d_gain_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_d_gain_optional();
  ::ignition::msgs::Double* mutable_d_gain_optional();
  void set_allocated_d_gain_optional(::ignition::msgs::Double* d_gain_optional);
  private:
  const ::ignition::msgs::Double& _internal_d_gain_optional() const;
  ::ignition::msgs::Double* _internal_mutable_d_gain_optional();
  public:
  void unsafe_arena_set_allocated_d_gain_optional(
      ::ignition::msgs::Double* d_gain_optional);
  ::ignition::msgs::Double* unsafe_arena_release_d_gain_optional();

  // .ignition.msgs.Double i_max_optional = 13;
  bool has_i_max_optional() const;
  private:
  bool _internal_has_i_max_optional() const;
  public:
  void clear_i_max_optional();
  const ::ignition::msgs::Double& i_max_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_i_max_optional();
  ::ignition::msgs::Double* mutable_i_max_optional();
  void set_allocated_i_max_optional(::ignition::msgs::Double* i_max_optional);
  private:
  const ::ignition::msgs::Double& _internal_i_max_optional() const;
  ::ignition::msgs::Double* _internal_mutable_i_max_optional();
  public:
  void unsafe_arena_set_allocated_i_max_optional(
      ::ignition::msgs::Double* i_max_optional);
  ::ignition::msgs::Double* unsafe_arena_release_i_max_optional();

  // .ignition.msgs.Double i_min_optional = 14;
  bool has_i_min_optional() const;
  private:
  bool _internal_has_i_min_optional() const;
  public:
  void clear_i_min_optional();
  const ::ignition::msgs::Double& i_min_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_i_min_optional();
  ::ignition::msgs::Double* mutable_i_min_optional();
  void set_allocated_i_min_optional(::ignition::msgs::Double* i_min_optional);
  private:
  const ::ignition::msgs::Double& _internal_i_min_optional() const;
  ::ignition::msgs::Double* _internal_mutable_i_min_optional();
  public:
  void unsafe_arena_set_allocated_i_min_optional(
      ::ignition::msgs::Double* i_min_optional);
  ::ignition::msgs::Double* unsafe_arena_release_i_min_optional();

  // .ignition.msgs.Double limit_optional = 15;
  bool has_limit_optional() const;
  private:
  bool _internal_has_limit_optional() const;
  public:
  void clear_limit_optional();
  const ::ignition::msgs::Double& limit_optional() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Double* release_limit_optional();
  ::ignition::msgs::Double* mutable_limit_optional();
  void set_allocated_limit_optional(::ignition::msgs::Double* limit_optional);
  private:
  const ::ignition::msgs::Double& _internal_limit_optional() const;
  ::ignition::msgs::Double* _internal_mutable_limit_optional();
  public:
  void unsafe_arena_set_allocated_limit_optional(
      ::ignition::msgs::Double* limit_optional);
  ::ignition::msgs::Double* unsafe_arena_release_limit_optional();

  // double target = 2 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_target();
  PROTOBUF_DEPRECATED double target() const;
  PROTOBUF_DEPRECATED void set_target(double value);
  private:
  double _internal_target() const;
  void _internal_set_target(double value);
  public:

  // double p_gain = 3 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_p_gain();
  PROTOBUF_DEPRECATED double p_gain() const;
  PROTOBUF_DEPRECATED void set_p_gain(double value);
  private:
  double _internal_p_gain() const;
  void _internal_set_p_gain(double value);
  public:

  // double i_gain = 4 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_i_gain();
  PROTOBUF_DEPRECATED double i_gain() const;
  PROTOBUF_DEPRECATED void set_i_gain(double value);
  private:
  double _internal_i_gain() const;
  void _internal_set_i_gain(double value);
  public:

  // double d_gain = 5 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_d_gain();
  PROTOBUF_DEPRECATED double d_gain() const;
  PROTOBUF_DEPRECATED void set_d_gain(double value);
  private:
  double _internal_d_gain() const;
  void _internal_set_d_gain(double value);
  public:

  // double i_max = 6 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_i_max();
  PROTOBUF_DEPRECATED double i_max() const;
  PROTOBUF_DEPRECATED void set_i_max(double value);
  private:
  double _internal_i_max() const;
  void _internal_set_i_max(double value);
  public:

  // double i_min = 7 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_i_min();
  PROTOBUF_DEPRECATED double i_min() const;
  PROTOBUF_DEPRECATED void set_i_min(double value);
  private:
  double _internal_i_min() const;
  void _internal_set_i_min(double value);
  public:

  // double limit = 8 [deprecated = true];
  PROTOBUF_DEPRECATED void clear_limit();
  PROTOBUF_DEPRECATED double limit() const;
  PROTOBUF_DEPRECATED void set_limit(double value);
  private:
  double _internal_limit() const;
  void _internal_set_limit(double value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.PID)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Double* target_optional_;
  ::ignition::msgs::Double* p_gain_optional_;
  ::ignition::msgs::Double* i_gain_optional_;
  ::ignition::msgs::Double* d_gain_optional_;
  ::ignition::msgs::Double* i_max_optional_;
  ::ignition::msgs::Double* i_min_optional_;
  ::ignition::msgs::Double* limit_optional_;
  double target_;
  double p_gain_;
  double i_gain_;
  double d_gain_;
  double i_max_;
  double i_min_;
  double limit_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fpid_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// PID

// .ignition.msgs.Header header = 1;
inline bool PID::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool PID::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& PID::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& PID::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.header)
  return _internal_header();
}
inline void PID::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.header)
}
inline ::ignition::msgs::Header* PID::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* PID::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* PID::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* PID::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.header)
  return _msg;
}
inline void PID::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.header)
}

// double target = 2 [deprecated = true];
inline void PID::clear_target() {
  target_ = 0;
}
inline double PID::_internal_target() const {
  return target_;
}
inline double PID::target() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.target)
  return _internal_target();
}
inline void PID::_internal_set_target(double value) {
  
  target_ = value;
}
inline void PID::set_target(double value) {
  _internal_set_target(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.target)
}

// double p_gain = 3 [deprecated = true];
inline void PID::clear_p_gain() {
  p_gain_ = 0;
}
inline double PID::_internal_p_gain() const {
  return p_gain_;
}
inline double PID::p_gain() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.p_gain)
  return _internal_p_gain();
}
inline void PID::_internal_set_p_gain(double value) {
  
  p_gain_ = value;
}
inline void PID::set_p_gain(double value) {
  _internal_set_p_gain(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.p_gain)
}

// double i_gain = 4 [deprecated = true];
inline void PID::clear_i_gain() {
  i_gain_ = 0;
}
inline double PID::_internal_i_gain() const {
  return i_gain_;
}
inline double PID::i_gain() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_gain)
  return _internal_i_gain();
}
inline void PID::_internal_set_i_gain(double value) {
  
  i_gain_ = value;
}
inline void PID::set_i_gain(double value) {
  _internal_set_i_gain(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.i_gain)
}

// double d_gain = 5 [deprecated = true];
inline void PID::clear_d_gain() {
  d_gain_ = 0;
}
inline double PID::_internal_d_gain() const {
  return d_gain_;
}
inline double PID::d_gain() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.d_gain)
  return _internal_d_gain();
}
inline void PID::_internal_set_d_gain(double value) {
  
  d_gain_ = value;
}
inline void PID::set_d_gain(double value) {
  _internal_set_d_gain(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.d_gain)
}

// double i_max = 6 [deprecated = true];
inline void PID::clear_i_max() {
  i_max_ = 0;
}
inline double PID::_internal_i_max() const {
  return i_max_;
}
inline double PID::i_max() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_max)
  return _internal_i_max();
}
inline void PID::_internal_set_i_max(double value) {
  
  i_max_ = value;
}
inline void PID::set_i_max(double value) {
  _internal_set_i_max(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.i_max)
}

// double i_min = 7 [deprecated = true];
inline void PID::clear_i_min() {
  i_min_ = 0;
}
inline double PID::_internal_i_min() const {
  return i_min_;
}
inline double PID::i_min() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_min)
  return _internal_i_min();
}
inline void PID::_internal_set_i_min(double value) {
  
  i_min_ = value;
}
inline void PID::set_i_min(double value) {
  _internal_set_i_min(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.i_min)
}

// double limit = 8 [deprecated = true];
inline void PID::clear_limit() {
  limit_ = 0;
}
inline double PID::_internal_limit() const {
  return limit_;
}
inline double PID::limit() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.limit)
  return _internal_limit();
}
inline void PID::_internal_set_limit(double value) {
  
  limit_ = value;
}
inline void PID::set_limit(double value) {
  _internal_set_limit(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PID.limit)
}

// .ignition.msgs.Double target_optional = 9;
inline bool PID::_internal_has_target_optional() const {
  return this != internal_default_instance() && target_optional_ != nullptr;
}
inline bool PID::has_target_optional() const {
  return _internal_has_target_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_target_optional() const {
  const ::ignition::msgs::Double* p = target_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::target_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.target_optional)
  return _internal_target_optional();
}
inline void PID::unsafe_arena_set_allocated_target_optional(
    ::ignition::msgs::Double* target_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(target_optional_);
  }
  target_optional_ = target_optional;
  if (target_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.target_optional)
}
inline ::ignition::msgs::Double* PID::release_target_optional() {
  
  ::ignition::msgs::Double* temp = target_optional_;
  target_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_target_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.target_optional)
  
  ::ignition::msgs::Double* temp = target_optional_;
  target_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_target_optional() {
  
  if (target_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    target_optional_ = p;
  }
  return target_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_target_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_target_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.target_optional)
  return _msg;
}
inline void PID::set_allocated_target_optional(::ignition::msgs::Double* target_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(target_optional_);
  }
  if (target_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(target_optional));
    if (message_arena != submessage_arena) {
      target_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, target_optional, submessage_arena);
    }
    
  } else {
    
  }
  target_optional_ = target_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.target_optional)
}

// .ignition.msgs.Double p_gain_optional = 10;
inline bool PID::_internal_has_p_gain_optional() const {
  return this != internal_default_instance() && p_gain_optional_ != nullptr;
}
inline bool PID::has_p_gain_optional() const {
  return _internal_has_p_gain_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_p_gain_optional() const {
  const ::ignition::msgs::Double* p = p_gain_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::p_gain_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.p_gain_optional)
  return _internal_p_gain_optional();
}
inline void PID::unsafe_arena_set_allocated_p_gain_optional(
    ::ignition::msgs::Double* p_gain_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(p_gain_optional_);
  }
  p_gain_optional_ = p_gain_optional;
  if (p_gain_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.p_gain_optional)
}
inline ::ignition::msgs::Double* PID::release_p_gain_optional() {
  
  ::ignition::msgs::Double* temp = p_gain_optional_;
  p_gain_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_p_gain_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.p_gain_optional)
  
  ::ignition::msgs::Double* temp = p_gain_optional_;
  p_gain_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_p_gain_optional() {
  
  if (p_gain_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    p_gain_optional_ = p;
  }
  return p_gain_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_p_gain_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_p_gain_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.p_gain_optional)
  return _msg;
}
inline void PID::set_allocated_p_gain_optional(::ignition::msgs::Double* p_gain_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(p_gain_optional_);
  }
  if (p_gain_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(p_gain_optional));
    if (message_arena != submessage_arena) {
      p_gain_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, p_gain_optional, submessage_arena);
    }
    
  } else {
    
  }
  p_gain_optional_ = p_gain_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.p_gain_optional)
}

// .ignition.msgs.Double i_gain_optional = 11;
inline bool PID::_internal_has_i_gain_optional() const {
  return this != internal_default_instance() && i_gain_optional_ != nullptr;
}
inline bool PID::has_i_gain_optional() const {
  return _internal_has_i_gain_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_i_gain_optional() const {
  const ::ignition::msgs::Double* p = i_gain_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::i_gain_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_gain_optional)
  return _internal_i_gain_optional();
}
inline void PID::unsafe_arena_set_allocated_i_gain_optional(
    ::ignition::msgs::Double* i_gain_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_gain_optional_);
  }
  i_gain_optional_ = i_gain_optional;
  if (i_gain_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.i_gain_optional)
}
inline ::ignition::msgs::Double* PID::release_i_gain_optional() {
  
  ::ignition::msgs::Double* temp = i_gain_optional_;
  i_gain_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_i_gain_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.i_gain_optional)
  
  ::ignition::msgs::Double* temp = i_gain_optional_;
  i_gain_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_i_gain_optional() {
  
  if (i_gain_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    i_gain_optional_ = p;
  }
  return i_gain_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_i_gain_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_i_gain_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.i_gain_optional)
  return _msg;
}
inline void PID::set_allocated_i_gain_optional(::ignition::msgs::Double* i_gain_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_gain_optional_);
  }
  if (i_gain_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_gain_optional));
    if (message_arena != submessage_arena) {
      i_gain_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, i_gain_optional, submessage_arena);
    }
    
  } else {
    
  }
  i_gain_optional_ = i_gain_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.i_gain_optional)
}

// .ignition.msgs.Double d_gain_optional = 12;
inline bool PID::_internal_has_d_gain_optional() const {
  return this != internal_default_instance() && d_gain_optional_ != nullptr;
}
inline bool PID::has_d_gain_optional() const {
  return _internal_has_d_gain_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_d_gain_optional() const {
  const ::ignition::msgs::Double* p = d_gain_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::d_gain_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.d_gain_optional)
  return _internal_d_gain_optional();
}
inline void PID::unsafe_arena_set_allocated_d_gain_optional(
    ::ignition::msgs::Double* d_gain_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(d_gain_optional_);
  }
  d_gain_optional_ = d_gain_optional;
  if (d_gain_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.d_gain_optional)
}
inline ::ignition::msgs::Double* PID::release_d_gain_optional() {
  
  ::ignition::msgs::Double* temp = d_gain_optional_;
  d_gain_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_d_gain_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.d_gain_optional)
  
  ::ignition::msgs::Double* temp = d_gain_optional_;
  d_gain_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_d_gain_optional() {
  
  if (d_gain_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    d_gain_optional_ = p;
  }
  return d_gain_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_d_gain_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_d_gain_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.d_gain_optional)
  return _msg;
}
inline void PID::set_allocated_d_gain_optional(::ignition::msgs::Double* d_gain_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(d_gain_optional_);
  }
  if (d_gain_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(d_gain_optional));
    if (message_arena != submessage_arena) {
      d_gain_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, d_gain_optional, submessage_arena);
    }
    
  } else {
    
  }
  d_gain_optional_ = d_gain_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.d_gain_optional)
}

// .ignition.msgs.Double i_max_optional = 13;
inline bool PID::_internal_has_i_max_optional() const {
  return this != internal_default_instance() && i_max_optional_ != nullptr;
}
inline bool PID::has_i_max_optional() const {
  return _internal_has_i_max_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_i_max_optional() const {
  const ::ignition::msgs::Double* p = i_max_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::i_max_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_max_optional)
  return _internal_i_max_optional();
}
inline void PID::unsafe_arena_set_allocated_i_max_optional(
    ::ignition::msgs::Double* i_max_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_max_optional_);
  }
  i_max_optional_ = i_max_optional;
  if (i_max_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.i_max_optional)
}
inline ::ignition::msgs::Double* PID::release_i_max_optional() {
  
  ::ignition::msgs::Double* temp = i_max_optional_;
  i_max_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_i_max_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.i_max_optional)
  
  ::ignition::msgs::Double* temp = i_max_optional_;
  i_max_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_i_max_optional() {
  
  if (i_max_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    i_max_optional_ = p;
  }
  return i_max_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_i_max_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_i_max_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.i_max_optional)
  return _msg;
}
inline void PID::set_allocated_i_max_optional(::ignition::msgs::Double* i_max_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_max_optional_);
  }
  if (i_max_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_max_optional));
    if (message_arena != submessage_arena) {
      i_max_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, i_max_optional, submessage_arena);
    }
    
  } else {
    
  }
  i_max_optional_ = i_max_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.i_max_optional)
}

// .ignition.msgs.Double i_min_optional = 14;
inline bool PID::_internal_has_i_min_optional() const {
  return this != internal_default_instance() && i_min_optional_ != nullptr;
}
inline bool PID::has_i_min_optional() const {
  return _internal_has_i_min_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_i_min_optional() const {
  const ::ignition::msgs::Double* p = i_min_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::i_min_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.i_min_optional)
  return _internal_i_min_optional();
}
inline void PID::unsafe_arena_set_allocated_i_min_optional(
    ::ignition::msgs::Double* i_min_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_min_optional_);
  }
  i_min_optional_ = i_min_optional;
  if (i_min_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.i_min_optional)
}
inline ::ignition::msgs::Double* PID::release_i_min_optional() {
  
  ::ignition::msgs::Double* temp = i_min_optional_;
  i_min_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_i_min_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.i_min_optional)
  
  ::ignition::msgs::Double* temp = i_min_optional_;
  i_min_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_i_min_optional() {
  
  if (i_min_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    i_min_optional_ = p;
  }
  return i_min_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_i_min_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_i_min_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.i_min_optional)
  return _msg;
}
inline void PID::set_allocated_i_min_optional(::ignition::msgs::Double* i_min_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_min_optional_);
  }
  if (i_min_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(i_min_optional));
    if (message_arena != submessage_arena) {
      i_min_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, i_min_optional, submessage_arena);
    }
    
  } else {
    
  }
  i_min_optional_ = i_min_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.i_min_optional)
}

// .ignition.msgs.Double limit_optional = 15;
inline bool PID::_internal_has_limit_optional() const {
  return this != internal_default_instance() && limit_optional_ != nullptr;
}
inline bool PID::has_limit_optional() const {
  return _internal_has_limit_optional();
}
inline const ::ignition::msgs::Double& PID::_internal_limit_optional() const {
  const ::ignition::msgs::Double* p = limit_optional_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Double&>(
      ::ignition::msgs::_Double_default_instance_);
}
inline const ::ignition::msgs::Double& PID::limit_optional() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PID.limit_optional)
  return _internal_limit_optional();
}
inline void PID::unsafe_arena_set_allocated_limit_optional(
    ::ignition::msgs::Double* limit_optional) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(limit_optional_);
  }
  limit_optional_ = limit_optional;
  if (limit_optional) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PID.limit_optional)
}
inline ::ignition::msgs::Double* PID::release_limit_optional() {
  
  ::ignition::msgs::Double* temp = limit_optional_;
  limit_optional_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Double* PID::unsafe_arena_release_limit_optional() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PID.limit_optional)
  
  ::ignition::msgs::Double* temp = limit_optional_;
  limit_optional_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Double* PID::_internal_mutable_limit_optional() {
  
  if (limit_optional_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Double>(GetArenaForAllocation());
    limit_optional_ = p;
  }
  return limit_optional_;
}
inline ::ignition::msgs::Double* PID::mutable_limit_optional() {
  ::ignition::msgs::Double* _msg = _internal_mutable_limit_optional();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PID.limit_optional)
  return _msg;
}
inline void PID::set_allocated_limit_optional(::ignition::msgs::Double* limit_optional) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(limit_optional_);
  }
  if (limit_optional) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(limit_optional));
    if (message_arena != submessage_arena) {
      limit_optional = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, limit_optional, submessage_arena);
    }
    
  } else {
    
  }
  limit_optional_ = limit_optional;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PID.limit_optional)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<PID> PIDUniquePtr;
typedef std::unique_ptr<const PID> ConstPIDUniquePtr;
typedef std::shared_ptr<PID> PIDSharedPtr;
typedef std::shared_ptr<const PID> ConstPIDSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpid_2eproto
