# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/model_configuration.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/model_configuration.proto", :syntax => :proto3) do
    add_message "ignition.msgs.ModelConfiguration" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :time, :message, 2, "ignition.msgs.Time"
      repeated :joint_names, :string, 3
      repeated :joint_positions, :double, 4
      optional :pose, :message, 5, "ignition.msgs.Pose"
      optional :link_name, :string, 6
    end
  end
end

module Ignition
  module Msgs
    ModelConfiguration = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.ModelConfiguration").msgclass
  end
end
