# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/world_stats.proto

require 'ignition/msgs/log_playback_stats_pb'
require 'ignition/msgs/time_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/world_stats.proto", :syntax => :proto3) do
    add_message "ignition.msgs.WorldStatistics" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :sim_time, :message, 2, "ignition.msgs.Time"
      optional :pause_time, :message, 3, "ignition.msgs.Time"
      optional :real_time, :message, 4, "ignition.msgs.Time"
      optional :paused, :bool, 5
      optional :iterations, :uint64, 6
      optional :model_count, :int32, 7
      optional :log_playback_stats, :message, 8, "ignition.msgs.LogPlaybackStatistics"
      optional :real_time_factor, :double, 9
      optional :step_size, :message, 10, "ignition.msgs.Time"
    end
  end
end

module Ignition
  module Msgs
    WorldStatistics = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.WorldStatistics").msgclass
  end
end
