/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "Version";

/// \ingroup ignition.msgs
/// \interface Version.
/// \brief Message that contains major, minor, and patch numbers. Prelease and
/// build information can also be included.

message Version
{
  /// \brief Major version.
  int32 major = 1;

  /// \brief Minor version.
  int32 minor = 2;

  /// \brief Patch version.
  int32 patch = 3;

  /// \brief Pre-release version.
  string prerelease = 4;

  /// \brief Build version.
  string build = 5;
}
