# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/entity.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/entity.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Entity" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :id, :uint64, 2
      optional :name, :string, 3
      optional :type, :enum, 4, "ignition.msgs.Entity.Type"
    end
    add_enum "ignition.msgs.Entity.Type" do
      value :NONE, 0
      value :LIGHT, 1
      value :MODEL, 2
      value :LINK, 3
      value :VISUAL, 4
      value :COLLISION, 5
      value :SENSOR, 6
      value :JOINT, 7
    end
  end
end

module Ignition
  module Msgs
    Entity = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Entity").msgclass
    Entity::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Entity.Type").enummodule
  end
end
