# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/visual.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/geometry_pb'
require 'ignition/msgs/material_pb'
require 'ignition/msgs/plugin_pb'
require 'ignition/msgs/vector3d_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/visual.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Visual" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :parent_name, :string, 4
      optional :parent_id, :uint32, 5
      optional :cast_shadows, :bool, 6
      optional :transparency, :double, 7
      optional :laser_retro, :double, 8
      optional :pose, :message, 9, "ignition.msgs.Pose"
      optional :geometry, :message, 10, "ignition.msgs.Geometry"
      optional :material, :message, 11, "ignition.msgs.Material"
      optional :visible, :bool, 12
      optional :delete_me, :bool, 13
      optional :is_static, :bool, 14
      repeated :plugin, :message, 15, "ignition.msgs.Plugin"
      optional :scale, :message, 16, "ignition.msgs.Vector3d"
      optional :meta, :message, 17, "ignition.msgs.Visual.Meta"
      optional :type, :enum, 18, "ignition.msgs.Visual.Type"
    end
    add_message "ignition.msgs.Visual.Meta" do
      optional :layer, :int32, 1
    end
    add_enum "ignition.msgs.Visual.Type" do
      value :ENTITY, 0
      value :MODEL, 1
      value :LINK, 2
      value :VISUAL, 3
      value :COLLISION, 4
      value :SENSOR, 5
      value :GUI, 6
      value :PHYSICS, 7
    end
  end
end

module Ignition
  module Msgs
    Visual = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Visual").msgclass
    Visual::Meta = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Visual.Meta").msgclass
    Visual::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Visual.Type").enummodule
  end
end
