/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "LinkDataProtos";

/// \ingroup ignition.msgs
/// \interface LinkData
/// \brief Link data

import "ignition/msgs/vector3d.proto";
import "ignition/msgs/header.proto";

message LinkData
{
  /// \brief Optional header data
  Header header         = 1;

  string name           = 2;
  Vector3d linear_velocity  = 3;
  Vector3d angular_velocity = 4;
}
