# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/fog.proto

require 'ignition/msgs/color_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/fog.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Fog" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Fog.FogType"
      optional :color, :message, 3, "ignition.msgs.Color"
      optional :density, :float, 4
      optional :start, :float, 5
      optional :end, :float, 6
    end
    add_enum "ignition.msgs.Fog.FogType" do
      value :NONE, 0
      value :LINEAR, 1
      value :EXPONENTIAL, 2
      value :EXPONENTIAL2, 3
    end
  end
end

module Ignition
  module Msgs
    Fog = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Fog").msgclass
    Fog::FogType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Fog.FogType").enummodule
  end
end
