/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "BatteryStateProtos";

/// \ingroup ignition.msgs
/// \interface BatteryState
/// \brief Message for battery state

import "ignition/msgs/header.proto";

message BatteryState
{
  enum PowerSupplyStatus
  {
    UNKNOWN       = 0;
    CHARGING      = 1;
    DISCHARGING   = 2;
    NOT_CHARGING  = 3;
    FULL          = 4; 
  }

  /// \brief Optional header data
  Header header                     = 1;

  /// \brief Voltage in Volts
  double voltage                    = 2;

  /// \brief Current draw in Ampere
  double current                    = 3;

  /// \brief Amount of charge in the battery in Ah
  double charge                     = 4;

  /// \brief Capacity in Ah
  double capacity                   = 5;

  /// \brief Percentage of charge left
  double percentage                 = 6;

  /// \brief The charging status
  PowerSupplyStatus power_supply_status  = 7;
}
