# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/camera_lens.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/camera_lens.proto", :syntax => :proto3) do
    add_message "ignition.msgs.CameraLens" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :string, 2
      optional :c1, :double, 3
      optional :c2, :double, 4
      optional :c3, :double, 5
      optional :f, :double, 6
      optional :fun, :string, 7
      optional :scale_to_hfov, :bool, 8
      optional :cutoff_angle, :double, 9
      optional :hfov, :double, 10
      optional :env_texture_size, :int32, 11
    end
  end
end

module Ignition
  module Msgs
    CameraLens = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraLens").msgclass
  end
end
