# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/raysensor.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/raysensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.RaySensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :display_scan, :bool, 2
      optional :horizontal_samples, :int32, 3
      optional :horizontal_resolution, :double, 4
      optional :horizontal_min_angle, :double, 5
      optional :horizontal_max_angle, :double, 6
      optional :vertical_samples, :int32, 7
      optional :vertical_resolution, :double, 8
      optional :vertical_min_angle, :double, 9
      optional :vertical_max_angle, :double, 10
      optional :range_min, :double, 11
      optional :range_max, :double, 12
      optional :range_resolution, :double, 13
    end
  end
end

module Ignition
  module Msgs
    RaySensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.RaySensor").msgclass
  end
end
