# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/user_cmd_stats.proto

require 'ignition/msgs/user_cmd_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/user_cmd_stats.proto", :syntax => :proto3) do
    add_message "ignition.msgs.UserCmdStats" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :undo_cmd, :message, 2, "ignition.msgs.UserCmd"
      repeated :redo_cmd, :message, 3, "ignition.msgs.UserCmd"
    end
  end
end

module Ignition
  module Msgs
    UserCmdStats = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.UserCmdStats").msgclass
  end
end
