/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "CollisionProtos";

/// \ingroup ignition.msgs
/// \interface Collision 
/// \brief Information about a collision element

import "ignition/msgs/pose.proto";
import "ignition/msgs/geometry.proto";
import "ignition/msgs/surface.proto";
import "ignition/msgs/visual.proto";
import "ignition/msgs/header.proto";

message Collision
{
  /// \brief Optional header data
  Header header        = 1;

  uint32 id            = 2;
  string name          = 3;
  double laser_retro   = 4;
  double max_contacts  = 5;
  Pose pose            = 6;
  Geometry geometry    = 7;
  Surface surface      = 8;

  repeated Visual visual        = 9;
}

