# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/particle_emitter.proto

require 'ignition/msgs/boolean_pb'
require 'ignition/msgs/color_pb'
require 'ignition/msgs/float_pb'
require 'ignition/msgs/header_pb'
require 'ignition/msgs/material_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/stringmsg_pb'
require 'ignition/msgs/vector3d_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/particle_emitter.proto", :syntax => :proto3) do
    add_message "ignition.msgs.ParticleEmitter" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :type, :enum, 4, "ignition.msgs.ParticleEmitter.EmitterType"
      optional :pose, :message, 5, "ignition.msgs.Pose"
      optional :size, :message, 6, "ignition.msgs.Vector3d"
      optional :rate, :message, 7, "ignition.msgs.Float"
      optional :duration, :message, 8, "ignition.msgs.Float"
      optional :emitting, :message, 9, "ignition.msgs.Boolean"
      optional :particle_size, :message, 10, "ignition.msgs.Vector3d"
      optional :lifetime, :message, 11, "ignition.msgs.Float"
      optional :material, :message, 12, "ignition.msgs.Material"
      optional :min_velocity, :message, 13, "ignition.msgs.Float"
      optional :max_velocity, :message, 14, "ignition.msgs.Float"
      optional :color_start, :message, 15, "ignition.msgs.Color"
      optional :color_end, :message, 16, "ignition.msgs.Color"
      optional :scale_rate, :message, 17, "ignition.msgs.Float"
      optional :color_range_image, :message, 18, "ignition.msgs.StringMsg"
    end
    add_enum "ignition.msgs.ParticleEmitter.EmitterType" do
      value :POINT, 0
      value :BOX, 1
      value :CYLINDER, 2
      value :ELLIPSOID, 3
    end
  end
end

module Ignition
  module Msgs
    ParticleEmitter = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.ParticleEmitter").msgclass
    ParticleEmitter::EmitterType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.ParticleEmitter.EmitterType").enummodule
  end
end
