# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/pid.proto

require 'ignition/msgs/double_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/pid.proto", :syntax => :proto3) do
    add_message "ignition.msgs.PID" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :target, :double, 2
      optional :p_gain, :double, 3
      optional :i_gain, :double, 4
      optional :d_gain, :double, 5
      optional :i_max, :double, 6
      optional :i_min, :double, 7
      optional :limit, :double, 8
      optional :target_optional, :message, 9, "ignition.msgs.Double"
      optional :p_gain_optional, :message, 10, "ignition.msgs.Double"
      optional :i_gain_optional, :message, 11, "ignition.msgs.Double"
      optional :d_gain_optional, :message, 12, "ignition.msgs.Double"
      optional :i_max_optional, :message, 13, "ignition.msgs.Double"
      optional :i_min_optional, :message, 14, "ignition.msgs.Double"
      optional :limit_optional, :message, 15, "ignition.msgs.Double"
    end
  end
end

module Ignition
  module Msgs
    PID = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PID").msgclass
  end
end
