# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/scene.proto

require 'ignition/msgs/color_pb'
require 'ignition/msgs/fog_pb'
require 'ignition/msgs/sky_pb'
require 'ignition/msgs/light_pb'
require 'ignition/msgs/joint_pb'
require 'ignition/msgs/model_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/scene.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Scene" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :ambient, :message, 3, "ignition.msgs.Color"
      optional :background, :message, 4, "ignition.msgs.Color"
      optional :sky, :message, 5, "ignition.msgs.Sky"
      optional :shadows, :bool, 6
      optional :fog, :message, 7, "ignition.msgs.Fog"
      optional :grid, :bool, 8
      repeated :model, :message, 9, "ignition.msgs.Model"
      repeated :light, :message, 10, "ignition.msgs.Light"
      repeated :joint, :message, 11, "ignition.msgs.Joint"
      optional :origin_visual, :bool, 12
    end
  end
end

module Ignition
  module Msgs
    Scene = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Scene").msgclass
  end
end
