# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/serialized.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/world_stats_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/serialized.proto", :syntax => :proto3) do
    add_message "ignition.msgs.SerializedComponent" do
      optional :type, :uint64, 1
      optional :component, :bytes, 2
      optional :remove, :bool, 3
    end
    add_message "ignition.msgs.SerializedEntity" do
      optional :id, :uint64, 1
      repeated :components, :message, 2, "ignition.msgs.SerializedComponent"
      optional :remove, :bool, 3
    end
    add_message "ignition.msgs.SerializedState" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :entities, :message, 2, "ignition.msgs.SerializedEntity"
    end
    add_message "ignition.msgs.SerializedStep" do
      optional :stats, :message, 1, "ignition.msgs.WorldStatistics"
      optional :state, :message, 2, "ignition.msgs.SerializedState"
    end
  end
end

module Ignition
  module Msgs
    SerializedComponent = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedComponent").msgclass
    SerializedEntity = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedEntity").msgclass
    SerializedState = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedState").msgclass
    SerializedStep = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SerializedStep").msgclass
  end
end
