// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/particle_emitter_v.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/particle_emitter.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto;
namespace ignition {
namespace msgs {
class ParticleEmitter_V;
struct ParticleEmitter_VDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern ParticleEmitter_VDefaultTypeInternal _ParticleEmitter_V_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::ParticleEmitter_V* Arena::CreateMaybeMessage<::ignition::msgs::ParticleEmitter_V>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE ParticleEmitter_V final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.ParticleEmitter_V) */ {
 public:
  inline ParticleEmitter_V() : ParticleEmitter_V(nullptr) {}
  ~ParticleEmitter_V() override;
  explicit constexpr ParticleEmitter_V(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ParticleEmitter_V(const ParticleEmitter_V& from);
  ParticleEmitter_V(ParticleEmitter_V&& from) noexcept
    : ParticleEmitter_V() {
    *this = ::std::move(from);
  }

  inline ParticleEmitter_V& operator=(const ParticleEmitter_V& from) {
    CopyFrom(from);
    return *this;
  }
  inline ParticleEmitter_V& operator=(ParticleEmitter_V&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ParticleEmitter_V& default_instance() {
    return *internal_default_instance();
  }
  static inline const ParticleEmitter_V* internal_default_instance() {
    return reinterpret_cast<const ParticleEmitter_V*>(
               &_ParticleEmitter_V_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(ParticleEmitter_V& a, ParticleEmitter_V& b) {
    a.Swap(&b);
  }
  inline void Swap(ParticleEmitter_V* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ParticleEmitter_V* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline ParticleEmitter_V* New() const final {
    return new ParticleEmitter_V();
  }

  ParticleEmitter_V* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<ParticleEmitter_V>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const ParticleEmitter_V& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const ParticleEmitter_V& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ParticleEmitter_V* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.ParticleEmitter_V";
  }
  protected:
  explicit ParticleEmitter_V(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kParticleEmitterFieldNumber = 2,
    kHeaderFieldNumber = 1,
  };
  // repeated .ignition.msgs.ParticleEmitter particle_emitter = 2;
  int particle_emitter_size() const;
  private:
  int _internal_particle_emitter_size() const;
  public:
  void clear_particle_emitter();
  ::ignition::msgs::ParticleEmitter* mutable_particle_emitter(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::ParticleEmitter >*
      mutable_particle_emitter();
  private:
  const ::ignition::msgs::ParticleEmitter& _internal_particle_emitter(int index) const;
  ::ignition::msgs::ParticleEmitter* _internal_add_particle_emitter();
  public:
  const ::ignition::msgs::ParticleEmitter& particle_emitter(int index) const;
  ::ignition::msgs::ParticleEmitter* add_particle_emitter();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::ParticleEmitter >&
      particle_emitter() const;

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // @@protoc_insertion_point(class_scope:ignition.msgs.ParticleEmitter_V)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::ParticleEmitter > particle_emitter_;
  ::ignition::msgs::Header* header_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// ParticleEmitter_V

// .ignition.msgs.Header header = 1;
inline bool ParticleEmitter_V::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool ParticleEmitter_V::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& ParticleEmitter_V::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& ParticleEmitter_V::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter_V.header)
  return _internal_header();
}
inline void ParticleEmitter_V::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter_V.header)
}
inline ::ignition::msgs::Header* ParticleEmitter_V::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* ParticleEmitter_V::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter_V.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* ParticleEmitter_V::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* ParticleEmitter_V::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter_V.header)
  return _msg;
}
inline void ParticleEmitter_V::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter_V.header)
}

// repeated .ignition.msgs.ParticleEmitter particle_emitter = 2;
inline int ParticleEmitter_V::_internal_particle_emitter_size() const {
  return particle_emitter_.size();
}
inline int ParticleEmitter_V::particle_emitter_size() const {
  return _internal_particle_emitter_size();
}
inline ::ignition::msgs::ParticleEmitter* ParticleEmitter_V::mutable_particle_emitter(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter_V.particle_emitter)
  return particle_emitter_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::ParticleEmitter >*
ParticleEmitter_V::mutable_particle_emitter() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.ParticleEmitter_V.particle_emitter)
  return &particle_emitter_;
}
inline const ::ignition::msgs::ParticleEmitter& ParticleEmitter_V::_internal_particle_emitter(int index) const {
  return particle_emitter_.Get(index);
}
inline const ::ignition::msgs::ParticleEmitter& ParticleEmitter_V::particle_emitter(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter_V.particle_emitter)
  return _internal_particle_emitter(index);
}
inline ::ignition::msgs::ParticleEmitter* ParticleEmitter_V::_internal_add_particle_emitter() {
  return particle_emitter_.Add();
}
inline ::ignition::msgs::ParticleEmitter* ParticleEmitter_V::add_particle_emitter() {
  ::ignition::msgs::ParticleEmitter* _add = _internal_add_particle_emitter();
  // @@protoc_insertion_point(field_add:ignition.msgs.ParticleEmitter_V.particle_emitter)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::ParticleEmitter >&
ParticleEmitter_V::particle_emitter() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.ParticleEmitter_V.particle_emitter)
  return particle_emitter_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<ParticleEmitter_V> ParticleEmitter_VUniquePtr;
typedef std::unique_ptr<const ParticleEmitter_V> ConstParticleEmitter_VUniquePtr;
typedef std::shared_ptr<ParticleEmitter_V> ParticleEmitter_VSharedPtr;
typedef std::shared_ptr<const ParticleEmitter_V> ConstParticleEmitter_VSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_5fv_2eproto
