/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "UserCmdProtos";

import "ignition/msgs/light.proto";
import "ignition/msgs/model.proto";
import "ignition/msgs/world_control.proto";
import "ignition/msgs/wrench.proto";
import "ignition/msgs/header.proto";

/// \ingroup ignition.msgs
/// \interface UserCmd
/// \brief Notifies that a new command has been executed by a user

message UserCmd
{
  /// \brief Types of user commands
  enum Type
  {
    /// \brief Moving an entity.
    MOVING = 0;

    /// \brief Controlling the world.
    WORLD_CONTROL = 1;

    /// \brief Applying wrench.
    WRENCH = 2;

    /// \brief Scaling an entity.
    SCALING = 3;
  }

  /// \brief Optional header data
  Header header = 1;

  /// \brief Unique id for user command.
  uint32 id = 2;

  /// \brief Description for the command.
  string description = 3;

  /// \brief Type of command.
  Type type = 4;

  /// \brief For model modify commands.
  repeated Model model = 5;

  /// \brief For light modify commands.
  repeated Light light = 6;

  /// \brief Name of entity targeted by command
  string entity_name = 7;

  /// \brief For World Control commands.
  WorldControl world_control = 8;

  /// \brief Wrench for apply wrench commands.
  Wrench wrench = 9;
}
