# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/world_modify.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/world_modify.proto", :syntax => :proto3) do
    add_message "ignition.msgs.WorldModify" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :world_name, :string, 2
      optional :remove, :bool, 3
      optional :create, :bool, 4
      optional :cloned, :bool, 5
      optional :cloned_uri, :string, 6
    end
  end
end

module Ignition
  module Msgs
    WorldModify = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.WorldModify").msgclass
  end
end
