# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/empty.proto

require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/empty.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Empty" do
      optional :unused, :bool, 1
    end
  end
end

module Ignition
  module Msgs
    Empty = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Empty").msgclass
  end
end
