# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/logical_camera_image.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/logical_camera_image.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LogicalCameraImage" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :pose, :message, 2, "ignition.msgs.Pose"
      repeated :model, :message, 3, "ignition.msgs.LogicalCameraImage.Model"
    end
    add_message "ignition.msgs.LogicalCameraImage.Model" do
      optional :name, :string, 1
      optional :pose, :message, 2, "ignition.msgs.Pose"
    end
  end
end

module Ignition
  module Msgs
    LogicalCameraImage = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogicalCameraImage").msgclass
    LogicalCameraImage::Model = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogicalCameraImage.Model").msgclass
  end
end
