# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/entity_factory.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/light_pb'
require 'ignition/msgs/model_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/entity_factory.proto", :syntax => :proto3) do
    add_message "ignition.msgs.EntityFactory" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :pose, :message, 7, "ignition.msgs.Pose"
      optional :name, :string, 8
      optional :allow_renaming, :bool, 9
      optional :relative_to, :string, 10
      oneof :from do
        optional :sdf, :string, 2
        optional :sdf_filename, :string, 3
        optional :model, :message, 4, "ignition.msgs.Model"
        optional :light, :message, 5, "ignition.msgs.Light"
        optional :clone_name, :string, 6
      end
    end
  end
end

module Ignition
  module Msgs
    EntityFactory = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.EntityFactory").msgclass
  end
end
