# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/packet.proto

require 'ignition/msgs/double_v_pb'
require 'ignition/msgs/clock_pb'
require 'ignition/msgs/cmd_vel2d_pb'
require 'ignition/msgs/image_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/pose_v_pb'
require 'ignition/msgs/stringmsg_v_pb'
require 'ignition/msgs/time_pb'
require 'ignition/msgs/web_request_pb'
require 'ignition/msgs/world_stats_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/packet.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Packet" do
      optional :topic, :string, 1
      optional :type, :string, 2
      oneof :content do
        optional :cmd_vel2d, :message, 3, "ignition.msgs.CmdVel2D"
        optional :image, :message, 4, "ignition.msgs.Image"
        optional :string_msg_v, :message, 5, "ignition.msgs.StringMsg_V"
        optional :web_request, :message, 6, "ignition.msgs.WebRequest"
        optional :pose, :message, 7, "ignition.msgs.Pose"
        optional :doublev, :message, 8, "ignition.msgs.Double_V"
        optional :pose_v, :message, 9, "ignition.msgs.Pose_V"
        optional :time, :message, 10, "ignition.msgs.Time"
        optional :clock, :message, 11, "ignition.msgs.Clock"
        optional :world_stats, :message, 12, "ignition.msgs.WorldStatistics"
      end
    end
  end
end

module Ignition
  module Msgs
    Packet = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Packet").msgclass
  end
end
