# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/model.proto

require 'ignition/msgs/axis_aligned_box_pb'
require 'ignition/msgs/joint_pb'
require 'ignition/msgs/link_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/visual_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/model.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Model" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :is_static, :bool, 4
      optional :pose, :message, 5, "ignition.msgs.Pose"
      repeated :joint, :message, 6, "ignition.msgs.Joint"
      repeated :link, :message, 7, "ignition.msgs.Link"
      optional :deleted, :bool, 8
      repeated :visual, :message, 9, "ignition.msgs.Visual"
      optional :scale, :message, 10, "ignition.msgs.Vector3d"
      optional :self_collide, :bool, 11
      repeated :model, :message, 12, "ignition.msgs.Model"
      optional :bounding_box, :message, 13, "ignition.msgs.AxisAlignedBox"
    end
  end
end

module Ignition
  module Msgs
    Model = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Model").msgclass
  end
end
