# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/logical_camera_sensor.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/logical_camera_sensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LogicalCameraSensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :near_clip, :double, 2
      optional :far_clip, :double, 3
      optional :horizontal_fov, :double, 4
      optional :aspect_ratio, :double, 5
    end
  end
end

module Ignition
  module Msgs
    LogicalCameraSensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogicalCameraSensor").msgclass
  end
end
