# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/link.proto

require 'ignition/msgs/inertial_pb'
require 'ignition/msgs/collision_pb'
require 'ignition/msgs/visual_pb'
require 'ignition/msgs/light_pb'
require 'ignition/msgs/sensor_pb'
require 'ignition/msgs/projector_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/battery_pb'
require 'ignition/msgs/density_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/link.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Link" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :id, :uint32, 2
      optional :name, :string, 3
      optional :self_collide, :bool, 4
      optional :gravity, :bool, 5
      optional :kinematic, :bool, 6
      optional :enabled, :bool, 7
      optional :density, :message, 8, "ignition.msgs.Density"
      optional :inertial, :message, 9, "ignition.msgs.Inertial"
      optional :pose, :message, 10, "ignition.msgs.Pose"
      repeated :visual, :message, 11, "ignition.msgs.Visual"
      repeated :collision, :message, 12, "ignition.msgs.Collision"
      repeated :sensor, :message, 13, "ignition.msgs.Sensor"
      repeated :projector, :message, 14, "ignition.msgs.Projector"
      optional :canonical, :bool, 15
      repeated :battery, :message, 16, "ignition.msgs.Battery"
      repeated :light, :message, 17, "ignition.msgs.Light"
    end
  end
end

module Ignition
  module Msgs
    Link = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Link").msgclass
  end
end
