# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/actor.proto

require 'ignition/msgs/entity_pb'
require 'ignition/msgs/header_pb'
require 'ignition/msgs/pose_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/actor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Actor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :entity, :message, 2, "ignition.msgs.Entity"
      optional :pose, :message, 3, "ignition.msgs.Pose"
      optional :skin_filename, :string, 4
      optional :skin_scale, :float, 5
      repeated :animations, :message, 6, "ignition.msgs.Actor.Animation"
      optional :script_loop, :bool, 7
      optional :script_delay_start, :float, 8
      optional :script_auto_start, :bool, 9
      repeated :trajectories, :message, 10, "ignition.msgs.Actor.Trajectory"
      optional :parent, :message, 11, "ignition.msgs.Entity"
    end
    add_message "ignition.msgs.Actor.Animation" do
      optional :name, :string, 1
      optional :filename, :string, 2
      optional :scale, :float, 3
      optional :interpolate_x, :bool, 4
    end
    add_message "ignition.msgs.Actor.Waypoint" do
      optional :time, :float, 1
      optional :pose, :message, 2, "ignition.msgs.Pose"
    end
    add_message "ignition.msgs.Actor.Trajectory" do
      optional :id, :uint32, 1
      optional :type, :string, 2
      optional :tension, :float, 3
      repeated :waypoints, :message, 4, "ignition.msgs.Actor.Waypoint"
    end
  end
end

module Ignition
  module Msgs
    Actor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Actor").msgclass
    Actor::Animation = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Actor.Animation").msgclass
    Actor::Waypoint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Actor.Waypoint").msgclass
    Actor::Trajectory = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Actor.Trajectory").msgclass
  end
end
