# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/friction.proto

require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/friction.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Friction" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :mu, :double, 2
      optional :mu2, :double, 3
      optional :fdir1, :message, 4, "ignition.msgs.Vector3d"
      optional :slip1, :double, 5
      optional :slip2, :double, 6
      optional :torsional, :message, 7, "ignition.msgs.Friction.Torsional"
    end
    add_message "ignition.msgs.Friction.Torsional" do
      optional :coefficient, :double, 1
      optional :use_patch_radius, :bool, 2
      optional :patch_radius, :double, 3
      optional :surface_radius, :double, 4
      optional :ode, :message, 5, "ignition.msgs.Friction.Torsional.ODE"
    end
    add_message "ignition.msgs.Friction.Torsional.ODE" do
      optional :slip, :double, 1
    end
  end
end

module Ignition
  module Msgs
    Friction = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Friction").msgclass
    Friction::Torsional = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Friction.Torsional").msgclass
    Friction::Torsional::ODE = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Friction.Torsional.ODE").msgclass
  end
end
