# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/color.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/color.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Color" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :r, :float, 2
      optional :g, :float, 3
      optional :b, :float, 4
      optional :a, :float, 5
    end
  end
end

module Ignition
  module Msgs
    Color = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Color").msgclass
  end
end
