// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/physics.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fphysics_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fphysics_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fphysics_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fphysics_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fphysics_2eproto;
namespace ignition {
namespace msgs {
class Physics;
struct PhysicsDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PhysicsDefaultTypeInternal _Physics_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Physics* Arena::CreateMaybeMessage<::ignition::msgs::Physics>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum Physics_Type : int {
  Physics_Type_ODE = 0,
  Physics_Type_BULLET = 1,
  Physics_Type_SIMBODY = 2,
  Physics_Type_DART = 3,
  Physics_Type_Physics_Type_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Physics_Type_Physics_Type_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Physics_Type_IsValid(int value);
constexpr Physics_Type Physics_Type_Type_MIN = Physics_Type_ODE;
constexpr Physics_Type Physics_Type_Type_MAX = Physics_Type_DART;
constexpr int Physics_Type_Type_ARRAYSIZE = Physics_Type_Type_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Physics_Type_descriptor();
template<typename T>
inline const std::string& Physics_Type_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Physics_Type>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Physics_Type_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Physics_Type_descriptor(), enum_t_value);
}
inline bool Physics_Type_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Physics_Type* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Physics_Type>(
    Physics_Type_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE Physics final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Physics) */ {
 public:
  inline Physics() : Physics(nullptr) {}
  ~Physics() override;
  explicit constexpr Physics(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Physics(const Physics& from);
  Physics(Physics&& from) noexcept
    : Physics() {
    *this = ::std::move(from);
  }

  inline Physics& operator=(const Physics& from) {
    CopyFrom(from);
    return *this;
  }
  inline Physics& operator=(Physics&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Physics& default_instance() {
    return *internal_default_instance();
  }
  static inline const Physics* internal_default_instance() {
    return reinterpret_cast<const Physics*>(
               &_Physics_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Physics& a, Physics& b) {
    a.Swap(&b);
  }
  inline void Swap(Physics* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Physics* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Physics* New() const final {
    return new Physics();
  }

  Physics* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Physics>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Physics& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Physics& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Physics* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Physics";
  }
  protected:
  explicit Physics(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Physics_Type Type;
  static constexpr Type ODE =
    Physics_Type_ODE;
  static constexpr Type BULLET =
    Physics_Type_BULLET;
  static constexpr Type SIMBODY =
    Physics_Type_SIMBODY;
  static constexpr Type DART =
    Physics_Type_DART;
  static inline bool Type_IsValid(int value) {
    return Physics_Type_IsValid(value);
  }
  static constexpr Type Type_MIN =
    Physics_Type_Type_MIN;
  static constexpr Type Type_MAX =
    Physics_Type_Type_MAX;
  static constexpr int Type_ARRAYSIZE =
    Physics_Type_Type_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Type_descriptor() {
    return Physics_Type_descriptor();
  }
  template<typename T>
  static inline const std::string& Type_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Type>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Type_Name.");
    return Physics_Type_Name(enum_t_value);
  }
  static inline bool Type_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Type* value) {
    return Physics_Type_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kSolverTypeFieldNumber = 3,
    kProfileNameFieldNumber = 17,
    kHeaderFieldNumber = 1,
    kGravityFieldNumber = 12,
    kMagneticFieldFieldNumber = 18,
    kTypeFieldNumber = 2,
    kPreconItersFieldNumber = 5,
    kMinStepSizeFieldNumber = 4,
    kSorFieldNumber = 7,
    kCfmFieldNumber = 8,
    kErpFieldNumber = 9,
    kItersFieldNumber = 6,
    kEnablePhysicsFieldNumber = 13,
    kContactMaxCorrectingVelFieldNumber = 10,
    kContactSurfaceLayerFieldNumber = 11,
    kRealTimeFactorFieldNumber = 14,
    kRealTimeUpdateRateFieldNumber = 15,
    kMaxStepSizeFieldNumber = 16,
  };
  // string solver_type = 3;
  void clear_solver_type();
  const std::string& solver_type() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_solver_type(ArgT0&& arg0, ArgT... args);
  std::string* mutable_solver_type();
  PROTOBUF_MUST_USE_RESULT std::string* release_solver_type();
  void set_allocated_solver_type(std::string* solver_type);
  private:
  const std::string& _internal_solver_type() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_solver_type(const std::string& value);
  std::string* _internal_mutable_solver_type();
  public:

  // string profile_name = 17;
  void clear_profile_name();
  const std::string& profile_name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_profile_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_profile_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_profile_name();
  void set_allocated_profile_name(std::string* profile_name);
  private:
  const std::string& _internal_profile_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_profile_name(const std::string& value);
  std::string* _internal_mutable_profile_name();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Vector3d gravity = 12;
  bool has_gravity() const;
  private:
  bool _internal_has_gravity() const;
  public:
  void clear_gravity();
  const ::ignition::msgs::Vector3d& gravity() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_gravity();
  ::ignition::msgs::Vector3d* mutable_gravity();
  void set_allocated_gravity(::ignition::msgs::Vector3d* gravity);
  private:
  const ::ignition::msgs::Vector3d& _internal_gravity() const;
  ::ignition::msgs::Vector3d* _internal_mutable_gravity();
  public:
  void unsafe_arena_set_allocated_gravity(
      ::ignition::msgs::Vector3d* gravity);
  ::ignition::msgs::Vector3d* unsafe_arena_release_gravity();

  // .ignition.msgs.Vector3d magnetic_field = 18;
  bool has_magnetic_field() const;
  private:
  bool _internal_has_magnetic_field() const;
  public:
  void clear_magnetic_field();
  const ::ignition::msgs::Vector3d& magnetic_field() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_magnetic_field();
  ::ignition::msgs::Vector3d* mutable_magnetic_field();
  void set_allocated_magnetic_field(::ignition::msgs::Vector3d* magnetic_field);
  private:
  const ::ignition::msgs::Vector3d& _internal_magnetic_field() const;
  ::ignition::msgs::Vector3d* _internal_mutable_magnetic_field();
  public:
  void unsafe_arena_set_allocated_magnetic_field(
      ::ignition::msgs::Vector3d* magnetic_field);
  ::ignition::msgs::Vector3d* unsafe_arena_release_magnetic_field();

  // .ignition.msgs.Physics.Type type = 2;
  void clear_type();
  ::ignition::msgs::Physics_Type type() const;
  void set_type(::ignition::msgs::Physics_Type value);
  private:
  ::ignition::msgs::Physics_Type _internal_type() const;
  void _internal_set_type(::ignition::msgs::Physics_Type value);
  public:

  // int32 precon_iters = 5;
  void clear_precon_iters();
  ::PROTOBUF_NAMESPACE_ID::int32 precon_iters() const;
  void set_precon_iters(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_precon_iters() const;
  void _internal_set_precon_iters(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // double min_step_size = 4;
  void clear_min_step_size();
  double min_step_size() const;
  void set_min_step_size(double value);
  private:
  double _internal_min_step_size() const;
  void _internal_set_min_step_size(double value);
  public:

  // double sor = 7;
  void clear_sor();
  double sor() const;
  void set_sor(double value);
  private:
  double _internal_sor() const;
  void _internal_set_sor(double value);
  public:

  // double cfm = 8;
  void clear_cfm();
  double cfm() const;
  void set_cfm(double value);
  private:
  double _internal_cfm() const;
  void _internal_set_cfm(double value);
  public:

  // double erp = 9;
  void clear_erp();
  double erp() const;
  void set_erp(double value);
  private:
  double _internal_erp() const;
  void _internal_set_erp(double value);
  public:

  // int32 iters = 6;
  void clear_iters();
  ::PROTOBUF_NAMESPACE_ID::int32 iters() const;
  void set_iters(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_iters() const;
  void _internal_set_iters(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // bool enable_physics = 13;
  void clear_enable_physics();
  bool enable_physics() const;
  void set_enable_physics(bool value);
  private:
  bool _internal_enable_physics() const;
  void _internal_set_enable_physics(bool value);
  public:

  // double contact_max_correcting_vel = 10;
  void clear_contact_max_correcting_vel();
  double contact_max_correcting_vel() const;
  void set_contact_max_correcting_vel(double value);
  private:
  double _internal_contact_max_correcting_vel() const;
  void _internal_set_contact_max_correcting_vel(double value);
  public:

  // double contact_surface_layer = 11;
  void clear_contact_surface_layer();
  double contact_surface_layer() const;
  void set_contact_surface_layer(double value);
  private:
  double _internal_contact_surface_layer() const;
  void _internal_set_contact_surface_layer(double value);
  public:

  // double real_time_factor = 14;
  void clear_real_time_factor();
  double real_time_factor() const;
  void set_real_time_factor(double value);
  private:
  double _internal_real_time_factor() const;
  void _internal_set_real_time_factor(double value);
  public:

  // double real_time_update_rate = 15;
  void clear_real_time_update_rate();
  double real_time_update_rate() const;
  void set_real_time_update_rate(double value);
  private:
  double _internal_real_time_update_rate() const;
  void _internal_set_real_time_update_rate(double value);
  public:

  // double max_step_size = 16;
  void clear_max_step_size();
  double max_step_size() const;
  void set_max_step_size(double value);
  private:
  double _internal_max_step_size() const;
  void _internal_set_max_step_size(double value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Physics)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr solver_type_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr profile_name_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Vector3d* gravity_;
  ::ignition::msgs::Vector3d* magnetic_field_;
  int type_;
  ::PROTOBUF_NAMESPACE_ID::int32 precon_iters_;
  double min_step_size_;
  double sor_;
  double cfm_;
  double erp_;
  ::PROTOBUF_NAMESPACE_ID::int32 iters_;
  bool enable_physics_;
  double contact_max_correcting_vel_;
  double contact_surface_layer_;
  double real_time_factor_;
  double real_time_update_rate_;
  double max_step_size_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fphysics_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Physics

// .ignition.msgs.Header header = 1;
inline bool Physics::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Physics::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Physics::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Physics::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.header)
  return _internal_header();
}
inline void Physics::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Physics.header)
}
inline ::ignition::msgs::Header* Physics::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Physics::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Physics.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Physics::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Physics::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Physics.header)
  return _msg;
}
inline void Physics::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Physics.header)
}

// .ignition.msgs.Physics.Type type = 2;
inline void Physics::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::Physics_Type Physics::_internal_type() const {
  return static_cast< ::ignition::msgs::Physics_Type >(type_);
}
inline ::ignition::msgs::Physics_Type Physics::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.type)
  return _internal_type();
}
inline void Physics::_internal_set_type(::ignition::msgs::Physics_Type value) {
  
  type_ = value;
}
inline void Physics::set_type(::ignition::msgs::Physics_Type value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.type)
}

// string solver_type = 3;
inline void Physics::clear_solver_type() {
  solver_type_.ClearToEmpty();
}
inline const std::string& Physics::solver_type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.solver_type)
  return _internal_solver_type();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Physics::set_solver_type(ArgT0&& arg0, ArgT... args) {
 
 solver_type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.solver_type)
}
inline std::string* Physics::mutable_solver_type() {
  std::string* _s = _internal_mutable_solver_type();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Physics.solver_type)
  return _s;
}
inline const std::string& Physics::_internal_solver_type() const {
  return solver_type_.Get();
}
inline void Physics::_internal_set_solver_type(const std::string& value) {
  
  solver_type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Physics::_internal_mutable_solver_type() {
  
  return solver_type_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Physics::release_solver_type() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Physics.solver_type)
  return solver_type_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Physics::set_allocated_solver_type(std::string* solver_type) {
  if (solver_type != nullptr) {
    
  } else {
    
  }
  solver_type_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), solver_type,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Physics.solver_type)
}

// double min_step_size = 4;
inline void Physics::clear_min_step_size() {
  min_step_size_ = 0;
}
inline double Physics::_internal_min_step_size() const {
  return min_step_size_;
}
inline double Physics::min_step_size() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.min_step_size)
  return _internal_min_step_size();
}
inline void Physics::_internal_set_min_step_size(double value) {
  
  min_step_size_ = value;
}
inline void Physics::set_min_step_size(double value) {
  _internal_set_min_step_size(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.min_step_size)
}

// int32 precon_iters = 5;
inline void Physics::clear_precon_iters() {
  precon_iters_ = 0;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Physics::_internal_precon_iters() const {
  return precon_iters_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Physics::precon_iters() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.precon_iters)
  return _internal_precon_iters();
}
inline void Physics::_internal_set_precon_iters(::PROTOBUF_NAMESPACE_ID::int32 value) {
  
  precon_iters_ = value;
}
inline void Physics::set_precon_iters(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_precon_iters(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.precon_iters)
}

// int32 iters = 6;
inline void Physics::clear_iters() {
  iters_ = 0;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Physics::_internal_iters() const {
  return iters_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Physics::iters() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.iters)
  return _internal_iters();
}
inline void Physics::_internal_set_iters(::PROTOBUF_NAMESPACE_ID::int32 value) {
  
  iters_ = value;
}
inline void Physics::set_iters(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_iters(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.iters)
}

// double sor = 7;
inline void Physics::clear_sor() {
  sor_ = 0;
}
inline double Physics::_internal_sor() const {
  return sor_;
}
inline double Physics::sor() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.sor)
  return _internal_sor();
}
inline void Physics::_internal_set_sor(double value) {
  
  sor_ = value;
}
inline void Physics::set_sor(double value) {
  _internal_set_sor(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.sor)
}

// double cfm = 8;
inline void Physics::clear_cfm() {
  cfm_ = 0;
}
inline double Physics::_internal_cfm() const {
  return cfm_;
}
inline double Physics::cfm() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.cfm)
  return _internal_cfm();
}
inline void Physics::_internal_set_cfm(double value) {
  
  cfm_ = value;
}
inline void Physics::set_cfm(double value) {
  _internal_set_cfm(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.cfm)
}

// double erp = 9;
inline void Physics::clear_erp() {
  erp_ = 0;
}
inline double Physics::_internal_erp() const {
  return erp_;
}
inline double Physics::erp() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.erp)
  return _internal_erp();
}
inline void Physics::_internal_set_erp(double value) {
  
  erp_ = value;
}
inline void Physics::set_erp(double value) {
  _internal_set_erp(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.erp)
}

// double contact_max_correcting_vel = 10;
inline void Physics::clear_contact_max_correcting_vel() {
  contact_max_correcting_vel_ = 0;
}
inline double Physics::_internal_contact_max_correcting_vel() const {
  return contact_max_correcting_vel_;
}
inline double Physics::contact_max_correcting_vel() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.contact_max_correcting_vel)
  return _internal_contact_max_correcting_vel();
}
inline void Physics::_internal_set_contact_max_correcting_vel(double value) {
  
  contact_max_correcting_vel_ = value;
}
inline void Physics::set_contact_max_correcting_vel(double value) {
  _internal_set_contact_max_correcting_vel(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.contact_max_correcting_vel)
}

// double contact_surface_layer = 11;
inline void Physics::clear_contact_surface_layer() {
  contact_surface_layer_ = 0;
}
inline double Physics::_internal_contact_surface_layer() const {
  return contact_surface_layer_;
}
inline double Physics::contact_surface_layer() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.contact_surface_layer)
  return _internal_contact_surface_layer();
}
inline void Physics::_internal_set_contact_surface_layer(double value) {
  
  contact_surface_layer_ = value;
}
inline void Physics::set_contact_surface_layer(double value) {
  _internal_set_contact_surface_layer(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.contact_surface_layer)
}

// .ignition.msgs.Vector3d gravity = 12;
inline bool Physics::_internal_has_gravity() const {
  return this != internal_default_instance() && gravity_ != nullptr;
}
inline bool Physics::has_gravity() const {
  return _internal_has_gravity();
}
inline const ::ignition::msgs::Vector3d& Physics::_internal_gravity() const {
  const ::ignition::msgs::Vector3d* p = gravity_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Physics::gravity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.gravity)
  return _internal_gravity();
}
inline void Physics::unsafe_arena_set_allocated_gravity(
    ::ignition::msgs::Vector3d* gravity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gravity_);
  }
  gravity_ = gravity;
  if (gravity) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Physics.gravity)
}
inline ::ignition::msgs::Vector3d* Physics::release_gravity() {
  
  ::ignition::msgs::Vector3d* temp = gravity_;
  gravity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* Physics::unsafe_arena_release_gravity() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Physics.gravity)
  
  ::ignition::msgs::Vector3d* temp = gravity_;
  gravity_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* Physics::_internal_mutable_gravity() {
  
  if (gravity_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    gravity_ = p;
  }
  return gravity_;
}
inline ::ignition::msgs::Vector3d* Physics::mutable_gravity() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_gravity();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Physics.gravity)
  return _msg;
}
inline void Physics::set_allocated_gravity(::ignition::msgs::Vector3d* gravity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(gravity_);
  }
  if (gravity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gravity));
    if (message_arena != submessage_arena) {
      gravity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, gravity, submessage_arena);
    }
    
  } else {
    
  }
  gravity_ = gravity;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Physics.gravity)
}

// bool enable_physics = 13;
inline void Physics::clear_enable_physics() {
  enable_physics_ = false;
}
inline bool Physics::_internal_enable_physics() const {
  return enable_physics_;
}
inline bool Physics::enable_physics() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.enable_physics)
  return _internal_enable_physics();
}
inline void Physics::_internal_set_enable_physics(bool value) {
  
  enable_physics_ = value;
}
inline void Physics::set_enable_physics(bool value) {
  _internal_set_enable_physics(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.enable_physics)
}

// double real_time_factor = 14;
inline void Physics::clear_real_time_factor() {
  real_time_factor_ = 0;
}
inline double Physics::_internal_real_time_factor() const {
  return real_time_factor_;
}
inline double Physics::real_time_factor() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.real_time_factor)
  return _internal_real_time_factor();
}
inline void Physics::_internal_set_real_time_factor(double value) {
  
  real_time_factor_ = value;
}
inline void Physics::set_real_time_factor(double value) {
  _internal_set_real_time_factor(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.real_time_factor)
}

// double real_time_update_rate = 15;
inline void Physics::clear_real_time_update_rate() {
  real_time_update_rate_ = 0;
}
inline double Physics::_internal_real_time_update_rate() const {
  return real_time_update_rate_;
}
inline double Physics::real_time_update_rate() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.real_time_update_rate)
  return _internal_real_time_update_rate();
}
inline void Physics::_internal_set_real_time_update_rate(double value) {
  
  real_time_update_rate_ = value;
}
inline void Physics::set_real_time_update_rate(double value) {
  _internal_set_real_time_update_rate(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.real_time_update_rate)
}

// double max_step_size = 16;
inline void Physics::clear_max_step_size() {
  max_step_size_ = 0;
}
inline double Physics::_internal_max_step_size() const {
  return max_step_size_;
}
inline double Physics::max_step_size() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.max_step_size)
  return _internal_max_step_size();
}
inline void Physics::_internal_set_max_step_size(double value) {
  
  max_step_size_ = value;
}
inline void Physics::set_max_step_size(double value) {
  _internal_set_max_step_size(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.max_step_size)
}

// string profile_name = 17;
inline void Physics::clear_profile_name() {
  profile_name_.ClearToEmpty();
}
inline const std::string& Physics::profile_name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.profile_name)
  return _internal_profile_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Physics::set_profile_name(ArgT0&& arg0, ArgT... args) {
 
 profile_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Physics.profile_name)
}
inline std::string* Physics::mutable_profile_name() {
  std::string* _s = _internal_mutable_profile_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Physics.profile_name)
  return _s;
}
inline const std::string& Physics::_internal_profile_name() const {
  return profile_name_.Get();
}
inline void Physics::_internal_set_profile_name(const std::string& value) {
  
  profile_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Physics::_internal_mutable_profile_name() {
  
  return profile_name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Physics::release_profile_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Physics.profile_name)
  return profile_name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Physics::set_allocated_profile_name(std::string* profile_name) {
  if (profile_name != nullptr) {
    
  } else {
    
  }
  profile_name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), profile_name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Physics.profile_name)
}

// .ignition.msgs.Vector3d magnetic_field = 18;
inline bool Physics::_internal_has_magnetic_field() const {
  return this != internal_default_instance() && magnetic_field_ != nullptr;
}
inline bool Physics::has_magnetic_field() const {
  return _internal_has_magnetic_field();
}
inline const ::ignition::msgs::Vector3d& Physics::_internal_magnetic_field() const {
  const ::ignition::msgs::Vector3d* p = magnetic_field_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Physics::magnetic_field() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Physics.magnetic_field)
  return _internal_magnetic_field();
}
inline void Physics::unsafe_arena_set_allocated_magnetic_field(
    ::ignition::msgs::Vector3d* magnetic_field) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetic_field_);
  }
  magnetic_field_ = magnetic_field;
  if (magnetic_field) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Physics.magnetic_field)
}
inline ::ignition::msgs::Vector3d* Physics::release_magnetic_field() {
  
  ::ignition::msgs::Vector3d* temp = magnetic_field_;
  magnetic_field_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* Physics::unsafe_arena_release_magnetic_field() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Physics.magnetic_field)
  
  ::ignition::msgs::Vector3d* temp = magnetic_field_;
  magnetic_field_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* Physics::_internal_mutable_magnetic_field() {
  
  if (magnetic_field_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    magnetic_field_ = p;
  }
  return magnetic_field_;
}
inline ::ignition::msgs::Vector3d* Physics::mutable_magnetic_field() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_magnetic_field();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Physics.magnetic_field)
  return _msg;
}
inline void Physics::set_allocated_magnetic_field(::ignition::msgs::Vector3d* magnetic_field) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetic_field_);
  }
  if (magnetic_field) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetic_field));
    if (message_arena != submessage_arena) {
      magnetic_field = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, magnetic_field, submessage_arena);
    }
    
  } else {
    
  }
  magnetic_field_ = magnetic_field;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Physics.magnetic_field)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Physics> PhysicsUniquePtr;
typedef std::unique_ptr<const Physics> ConstPhysicsUniquePtr;
typedef std::shared_ptr<Physics> PhysicsSharedPtr;
typedef std::shared_ptr<const Physics> ConstPhysicsSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::Physics_Type> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Physics_Type>() {
  return ::ignition::msgs::Physics_Type_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fphysics_2eproto
