# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/joint_trajectory_point.proto

require 'ignition/msgs/duration_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/joint_trajectory_point.proto", :syntax => :proto3) do
    add_message "ignition.msgs.JointTrajectoryPoint" do
      repeated :positions, :double, 1
      repeated :velocities, :double, 2
      repeated :accelerations, :double, 3
      repeated :effort, :double, 4
      optional :time_from_start, :message, 5, "ignition.msgs.Duration"
    end
  end
end

module Ignition
  module Msgs
    JointTrajectoryPoint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.JointTrajectoryPoint").msgclass
  end
end
