# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/projector.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/projector.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Projector" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :texture, :string, 3
      optional :pose, :message, 4, "ignition.msgs.Pose"
      optional :fov, :double, 5
      optional :near_clip, :double, 6
      optional :far_clip, :double, 7
      optional :enabled, :bool, 8
    end
  end
end

module Ignition
  module Msgs
    Projector = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Projector").msgclass
  end
end
