# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/contact.proto

require 'ignition/msgs/entity_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/joint_wrench_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/contact.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Contact" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :collision1, :message, 2, "ignition.msgs.Entity"
      optional :collision2, :message, 3, "ignition.msgs.Entity"
      repeated :position, :message, 4, "ignition.msgs.Vector3d"
      repeated :normal, :message, 5, "ignition.msgs.Vector3d"
      repeated :depth, :double, 6
      repeated :wrench, :message, 7, "ignition.msgs.JointWrench"
      optional :world, :message, 8, "ignition.msgs.Entity"
    end
  end
end

module Ignition
  module Msgs
    Contact = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Contact").msgclass
  end
end
