# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/geometry.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/boxgeom_pb'
require 'ignition/msgs/cylindergeom_pb'
require 'ignition/msgs/spheregeom_pb'
require 'ignition/msgs/planegeom_pb'
require 'ignition/msgs/imagegeom_pb'
require 'ignition/msgs/heightmapgeom_pb'
require 'ignition/msgs/meshgeom_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/polylinegeom_pb'
require 'ignition/msgs/conegeom_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/geometry.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Geometry" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Geometry.Type"
      optional :box, :message, 3, "ignition.msgs.BoxGeom"
      optional :cylinder, :message, 4, "ignition.msgs.CylinderGeom"
      optional :plane, :message, 5, "ignition.msgs.PlaneGeom"
      optional :sphere, :message, 6, "ignition.msgs.SphereGeom"
      optional :image, :message, 7, "ignition.msgs.ImageGeom"
      optional :heightmap, :message, 8, "ignition.msgs.HeightmapGeom"
      optional :mesh, :message, 9, "ignition.msgs.MeshGeom"
      optional :cone, :message, 10, "ignition.msgs.ConeGeom"
      repeated :points, :message, 11, "ignition.msgs.Vector3d"
      repeated :polyline, :message, 12, "ignition.msgs.Polyline"
    end
    add_enum "ignition.msgs.Geometry.Type" do
      value :BOX, 0
      value :CYLINDER, 1
      value :SPHERE, 2
      value :PLANE, 3
      value :IMAGE, 4
      value :HEIGHTMAP, 5
      value :MESH, 6
      value :TRIANGLE_FAN, 7
      value :LINE_STRIP, 8
      value :POLYLINE, 9
      value :CONE, 10
      value :EMPTY, 11
      value :ARROW, 12
      value :AXIS, 13
    end
  end
end

module Ignition
  module Msgs
    Geometry = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Geometry").msgclass
    Geometry::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Geometry.Type").enummodule
  end
end
