# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/pose_animation.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/time_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/pose_animation.proto", :syntax => :proto3) do
    add_message "ignition.msgs.PoseAnimation" do
      optional :model_name, :string, 1
      optional :model_id, :uint32, 2
      repeated :pose, :message, 3, "ignition.msgs.Pose"
      repeated :time, :message, 4, "ignition.msgs.Time"
    end
  end
end

module Ignition
  module Msgs
    PoseAnimation = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PoseAnimation").msgclass
  end
end
