# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/joint_wrench.proto

require 'ignition/msgs/wrench_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/joint_wrench.proto", :syntax => :proto3) do
    add_message "ignition.msgs.JointWrench" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :body_1_name, :string, 2
      optional :body_1_id, :uint32, 3
      optional :body_2_name, :string, 4
      optional :body_2_id, :uint32, 5
      optional :body_1_wrench, :message, 6, "ignition.msgs.Wrench"
      optional :body_2_wrench, :message, 7, "ignition.msgs.Wrench"
    end
  end
end

module Ignition
  module Msgs
    JointWrench = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.JointWrench").msgclass
  end
end
