# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/cessna.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/cessna.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Cessna" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :propeller_speed, :float, 2
      optional :left_aileron, :float, 3
      optional :left_flap, :float, 4
      optional :right_aileron, :float, 5
      optional :right_flap, :float, 6
      optional :elevators, :float, 7
      optional :rudder, :float, 8
      optional :cmd_propeller_speed, :float, 9
      optional :cmd_left_aileron, :float, 10
      optional :cmd_left_flap, :float, 11
      optional :cmd_right_aileron, :float, 12
      optional :cmd_right_flap, :float, 13
      optional :cmd_elevators, :float, 14
      optional :cmd_rudder, :float, 15
    end
  end
end

module Ignition
  module Msgs
    Cessna = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Cessna").msgclass
  end
end
