# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/camera_info.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/camera_info.proto", :syntax => :proto3) do
    add_message "ignition.msgs.CameraInfo" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :width, :uint32, 2
      optional :height, :uint32, 3
      optional :distortion, :message, 4, "ignition.msgs.CameraInfo.Distortion"
      optional :intrinsics, :message, 5, "ignition.msgs.CameraInfo.Intrinsics"
      optional :projection, :message, 6, "ignition.msgs.CameraInfo.Projection"
      repeated :rectification_matrix, :double, 7
    end
    add_message "ignition.msgs.CameraInfo.Distortion" do
      optional :model, :enum, 1, "ignition.msgs.CameraInfo.Distortion.DistortionModelType"
      repeated :k, :double, 2
    end
    add_enum "ignition.msgs.CameraInfo.Distortion.DistortionModelType" do
      value :PLUMB_BOB, 0
      value :RATIONAL_POLYNOMIAL, 1
      value :EQUIDISTANT, 2
    end
    add_message "ignition.msgs.CameraInfo.Intrinsics" do
      repeated :k, :double, 1
    end
    add_message "ignition.msgs.CameraInfo.Projection" do
      repeated :p, :double, 1
    end
  end
end

module Ignition
  module Msgs
    CameraInfo = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraInfo").msgclass
    CameraInfo::Distortion = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraInfo.Distortion").msgclass
    CameraInfo::Distortion::DistortionModelType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraInfo.Distortion.DistortionModelType").enummodule
    CameraInfo::Intrinsics = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraInfo.Intrinsics").msgclass
    CameraInfo::Projection = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraInfo.Projection").msgclass
  end
end
