# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/joint_cmd.proto

require 'ignition/msgs/double_pb'
require 'ignition/msgs/pid_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/joint_cmd.proto", :syntax => :proto3) do
    add_message "ignition.msgs.JointCmd" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :axis, :int32, 3
      optional :force, :double, 4
      optional :position, :message, 5, "ignition.msgs.PID"
      optional :velocity, :message, 6, "ignition.msgs.PID"
      optional :reset, :bool, 7
      optional :force_optional, :message, 8, "ignition.msgs.Double"
    end
  end
end

module Ignition
  module Msgs
    JointCmd = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.JointCmd").msgclass
  end
end
