/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "SonarProtos";

/// \ingroup ignition.msgs
/// \interface Sonar
/// \brief Message for a sonar value

import "ignition/msgs/pose.proto";
import "ignition/msgs/vector3d.proto";
import "ignition/msgs/header.proto";

message Sonar
{
  /// \brief Optional header data
  Header header    = 1;

  string frame     = 2;
  Pose world_pose  = 3;
  double range_min = 4;
  double range_max = 5;
  double radius    = 6;
  double range     = 7;

  /// \brief The sonar collision shape.
  ///        possible values are "cone", "sphere".
  ///        If you set this value to "cone" you need to specify
  ///        the `radius`.
  string geometry  = 8;

  /// Location of the contact in the world frame.
  Vector3d contact  = 9;
}
