// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/scene.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fscene_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fscene_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/color.pb.h"
#include "ignition/msgs/fog.pb.h"
#include "ignition/msgs/sky.pb.h"
#include "ignition/msgs/light.pb.h"
#include "ignition/msgs/joint.pb.h"
#include "ignition/msgs/model.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fscene_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fscene_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fscene_2eproto;
namespace ignition {
namespace msgs {
class Scene;
struct SceneDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SceneDefaultTypeInternal _Scene_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Scene* Arena::CreateMaybeMessage<::ignition::msgs::Scene>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Scene final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Scene) */ {
 public:
  inline Scene() : Scene(nullptr) {}
  ~Scene() override;
  explicit constexpr Scene(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Scene(const Scene& from);
  Scene(Scene&& from) noexcept
    : Scene() {
    *this = ::std::move(from);
  }

  inline Scene& operator=(const Scene& from) {
    CopyFrom(from);
    return *this;
  }
  inline Scene& operator=(Scene&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Scene& default_instance() {
    return *internal_default_instance();
  }
  static inline const Scene* internal_default_instance() {
    return reinterpret_cast<const Scene*>(
               &_Scene_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Scene& a, Scene& b) {
    a.Swap(&b);
  }
  inline void Swap(Scene* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Scene* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Scene* New() const final {
    return new Scene();
  }

  Scene* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Scene>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Scene& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Scene& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Scene* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Scene";
  }
  protected:
  explicit Scene(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kModelFieldNumber = 9,
    kLightFieldNumber = 10,
    kJointFieldNumber = 11,
    kNameFieldNumber = 2,
    kHeaderFieldNumber = 1,
    kAmbientFieldNumber = 3,
    kBackgroundFieldNumber = 4,
    kSkyFieldNumber = 5,
    kFogFieldNumber = 7,
    kShadowsFieldNumber = 6,
    kGridFieldNumber = 8,
    kOriginVisualFieldNumber = 12,
  };
  // repeated .ignition.msgs.Model model = 9;
  int model_size() const;
  private:
  int _internal_model_size() const;
  public:
  void clear_model();
  ::ignition::msgs::Model* mutable_model(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >*
      mutable_model();
  private:
  const ::ignition::msgs::Model& _internal_model(int index) const;
  ::ignition::msgs::Model* _internal_add_model();
  public:
  const ::ignition::msgs::Model& model(int index) const;
  ::ignition::msgs::Model* add_model();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >&
      model() const;

  // repeated .ignition.msgs.Light light = 10;
  int light_size() const;
  private:
  int _internal_light_size() const;
  public:
  void clear_light();
  ::ignition::msgs::Light* mutable_light(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >*
      mutable_light();
  private:
  const ::ignition::msgs::Light& _internal_light(int index) const;
  ::ignition::msgs::Light* _internal_add_light();
  public:
  const ::ignition::msgs::Light& light(int index) const;
  ::ignition::msgs::Light* add_light();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >&
      light() const;

  // repeated .ignition.msgs.Joint joint = 11;
  int joint_size() const;
  private:
  int _internal_joint_size() const;
  public:
  void clear_joint();
  ::ignition::msgs::Joint* mutable_joint(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >*
      mutable_joint();
  private:
  const ::ignition::msgs::Joint& _internal_joint(int index) const;
  ::ignition::msgs::Joint* _internal_add_joint();
  public:
  const ::ignition::msgs::Joint& joint(int index) const;
  ::ignition::msgs::Joint* add_joint();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >&
      joint() const;

  // string name = 2;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Color ambient = 3;
  bool has_ambient() const;
  private:
  bool _internal_has_ambient() const;
  public:
  void clear_ambient();
  const ::ignition::msgs::Color& ambient() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_ambient();
  ::ignition::msgs::Color* mutable_ambient();
  void set_allocated_ambient(::ignition::msgs::Color* ambient);
  private:
  const ::ignition::msgs::Color& _internal_ambient() const;
  ::ignition::msgs::Color* _internal_mutable_ambient();
  public:
  void unsafe_arena_set_allocated_ambient(
      ::ignition::msgs::Color* ambient);
  ::ignition::msgs::Color* unsafe_arena_release_ambient();

  // .ignition.msgs.Color background = 4;
  bool has_background() const;
  private:
  bool _internal_has_background() const;
  public:
  void clear_background();
  const ::ignition::msgs::Color& background() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_background();
  ::ignition::msgs::Color* mutable_background();
  void set_allocated_background(::ignition::msgs::Color* background);
  private:
  const ::ignition::msgs::Color& _internal_background() const;
  ::ignition::msgs::Color* _internal_mutable_background();
  public:
  void unsafe_arena_set_allocated_background(
      ::ignition::msgs::Color* background);
  ::ignition::msgs::Color* unsafe_arena_release_background();

  // .ignition.msgs.Sky sky = 5;
  bool has_sky() const;
  private:
  bool _internal_has_sky() const;
  public:
  void clear_sky();
  const ::ignition::msgs::Sky& sky() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Sky* release_sky();
  ::ignition::msgs::Sky* mutable_sky();
  void set_allocated_sky(::ignition::msgs::Sky* sky);
  private:
  const ::ignition::msgs::Sky& _internal_sky() const;
  ::ignition::msgs::Sky* _internal_mutable_sky();
  public:
  void unsafe_arena_set_allocated_sky(
      ::ignition::msgs::Sky* sky);
  ::ignition::msgs::Sky* unsafe_arena_release_sky();

  // .ignition.msgs.Fog fog = 7;
  bool has_fog() const;
  private:
  bool _internal_has_fog() const;
  public:
  void clear_fog();
  const ::ignition::msgs::Fog& fog() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Fog* release_fog();
  ::ignition::msgs::Fog* mutable_fog();
  void set_allocated_fog(::ignition::msgs::Fog* fog);
  private:
  const ::ignition::msgs::Fog& _internal_fog() const;
  ::ignition::msgs::Fog* _internal_mutable_fog();
  public:
  void unsafe_arena_set_allocated_fog(
      ::ignition::msgs::Fog* fog);
  ::ignition::msgs::Fog* unsafe_arena_release_fog();

  // bool shadows = 6;
  void clear_shadows();
  bool shadows() const;
  void set_shadows(bool value);
  private:
  bool _internal_shadows() const;
  void _internal_set_shadows(bool value);
  public:

  // bool grid = 8;
  void clear_grid();
  bool grid() const;
  void set_grid(bool value);
  private:
  bool _internal_grid() const;
  void _internal_set_grid(bool value);
  public:

  // bool origin_visual = 12;
  void clear_origin_visual();
  bool origin_visual() const;
  void set_origin_visual(bool value);
  private:
  bool _internal_origin_visual() const;
  void _internal_set_origin_visual(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Scene)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model > model_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light > light_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint > joint_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Color* ambient_;
  ::ignition::msgs::Color* background_;
  ::ignition::msgs::Sky* sky_;
  ::ignition::msgs::Fog* fog_;
  bool shadows_;
  bool grid_;
  bool origin_visual_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fscene_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Scene

// .ignition.msgs.Header header = 1;
inline bool Scene::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Scene::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Scene::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Scene::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.header)
  return _internal_header();
}
inline void Scene::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Scene.header)
}
inline ::ignition::msgs::Header* Scene::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Scene::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Scene::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Scene::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.header)
  return _msg;
}
inline void Scene::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.header)
}

// string name = 2;
inline void Scene::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& Scene::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Scene::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Scene.name)
}
inline std::string* Scene::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.name)
  return _s;
}
inline const std::string& Scene::_internal_name() const {
  return name_.Get();
}
inline void Scene::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Scene::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Scene::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Scene::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.name)
}

// .ignition.msgs.Color ambient = 3;
inline bool Scene::_internal_has_ambient() const {
  return this != internal_default_instance() && ambient_ != nullptr;
}
inline bool Scene::has_ambient() const {
  return _internal_has_ambient();
}
inline const ::ignition::msgs::Color& Scene::_internal_ambient() const {
  const ::ignition::msgs::Color* p = ambient_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Scene::ambient() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.ambient)
  return _internal_ambient();
}
inline void Scene::unsafe_arena_set_allocated_ambient(
    ::ignition::msgs::Color* ambient) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient_);
  }
  ambient_ = ambient;
  if (ambient) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Scene.ambient)
}
inline ::ignition::msgs::Color* Scene::release_ambient() {
  
  ::ignition::msgs::Color* temp = ambient_;
  ambient_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Scene::unsafe_arena_release_ambient() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.ambient)
  
  ::ignition::msgs::Color* temp = ambient_;
  ambient_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Scene::_internal_mutable_ambient() {
  
  if (ambient_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    ambient_ = p;
  }
  return ambient_;
}
inline ::ignition::msgs::Color* Scene::mutable_ambient() {
  ::ignition::msgs::Color* _msg = _internal_mutable_ambient();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.ambient)
  return _msg;
}
inline void Scene::set_allocated_ambient(::ignition::msgs::Color* ambient) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient_);
  }
  if (ambient) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(ambient));
    if (message_arena != submessage_arena) {
      ambient = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, ambient, submessage_arena);
    }
    
  } else {
    
  }
  ambient_ = ambient;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.ambient)
}

// .ignition.msgs.Color background = 4;
inline bool Scene::_internal_has_background() const {
  return this != internal_default_instance() && background_ != nullptr;
}
inline bool Scene::has_background() const {
  return _internal_has_background();
}
inline const ::ignition::msgs::Color& Scene::_internal_background() const {
  const ::ignition::msgs::Color* p = background_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& Scene::background() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.background)
  return _internal_background();
}
inline void Scene::unsafe_arena_set_allocated_background(
    ::ignition::msgs::Color* background) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(background_);
  }
  background_ = background;
  if (background) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Scene.background)
}
inline ::ignition::msgs::Color* Scene::release_background() {
  
  ::ignition::msgs::Color* temp = background_;
  background_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* Scene::unsafe_arena_release_background() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.background)
  
  ::ignition::msgs::Color* temp = background_;
  background_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* Scene::_internal_mutable_background() {
  
  if (background_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    background_ = p;
  }
  return background_;
}
inline ::ignition::msgs::Color* Scene::mutable_background() {
  ::ignition::msgs::Color* _msg = _internal_mutable_background();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.background)
  return _msg;
}
inline void Scene::set_allocated_background(::ignition::msgs::Color* background) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(background_);
  }
  if (background) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(background));
    if (message_arena != submessage_arena) {
      background = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, background, submessage_arena);
    }
    
  } else {
    
  }
  background_ = background;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.background)
}

// .ignition.msgs.Sky sky = 5;
inline bool Scene::_internal_has_sky() const {
  return this != internal_default_instance() && sky_ != nullptr;
}
inline bool Scene::has_sky() const {
  return _internal_has_sky();
}
inline const ::ignition::msgs::Sky& Scene::_internal_sky() const {
  const ::ignition::msgs::Sky* p = sky_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Sky&>(
      ::ignition::msgs::_Sky_default_instance_);
}
inline const ::ignition::msgs::Sky& Scene::sky() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.sky)
  return _internal_sky();
}
inline void Scene::unsafe_arena_set_allocated_sky(
    ::ignition::msgs::Sky* sky) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(sky_);
  }
  sky_ = sky;
  if (sky) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Scene.sky)
}
inline ::ignition::msgs::Sky* Scene::release_sky() {
  
  ::ignition::msgs::Sky* temp = sky_;
  sky_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Sky* Scene::unsafe_arena_release_sky() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.sky)
  
  ::ignition::msgs::Sky* temp = sky_;
  sky_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Sky* Scene::_internal_mutable_sky() {
  
  if (sky_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Sky>(GetArenaForAllocation());
    sky_ = p;
  }
  return sky_;
}
inline ::ignition::msgs::Sky* Scene::mutable_sky() {
  ::ignition::msgs::Sky* _msg = _internal_mutable_sky();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.sky)
  return _msg;
}
inline void Scene::set_allocated_sky(::ignition::msgs::Sky* sky) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(sky_);
  }
  if (sky) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(sky));
    if (message_arena != submessage_arena) {
      sky = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, sky, submessage_arena);
    }
    
  } else {
    
  }
  sky_ = sky;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.sky)
}

// bool shadows = 6;
inline void Scene::clear_shadows() {
  shadows_ = false;
}
inline bool Scene::_internal_shadows() const {
  return shadows_;
}
inline bool Scene::shadows() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.shadows)
  return _internal_shadows();
}
inline void Scene::_internal_set_shadows(bool value) {
  
  shadows_ = value;
}
inline void Scene::set_shadows(bool value) {
  _internal_set_shadows(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Scene.shadows)
}

// .ignition.msgs.Fog fog = 7;
inline bool Scene::_internal_has_fog() const {
  return this != internal_default_instance() && fog_ != nullptr;
}
inline bool Scene::has_fog() const {
  return _internal_has_fog();
}
inline const ::ignition::msgs::Fog& Scene::_internal_fog() const {
  const ::ignition::msgs::Fog* p = fog_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Fog&>(
      ::ignition::msgs::_Fog_default_instance_);
}
inline const ::ignition::msgs::Fog& Scene::fog() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.fog)
  return _internal_fog();
}
inline void Scene::unsafe_arena_set_allocated_fog(
    ::ignition::msgs::Fog* fog) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(fog_);
  }
  fog_ = fog;
  if (fog) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Scene.fog)
}
inline ::ignition::msgs::Fog* Scene::release_fog() {
  
  ::ignition::msgs::Fog* temp = fog_;
  fog_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Fog* Scene::unsafe_arena_release_fog() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Scene.fog)
  
  ::ignition::msgs::Fog* temp = fog_;
  fog_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Fog* Scene::_internal_mutable_fog() {
  
  if (fog_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Fog>(GetArenaForAllocation());
    fog_ = p;
  }
  return fog_;
}
inline ::ignition::msgs::Fog* Scene::mutable_fog() {
  ::ignition::msgs::Fog* _msg = _internal_mutable_fog();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.fog)
  return _msg;
}
inline void Scene::set_allocated_fog(::ignition::msgs::Fog* fog) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(fog_);
  }
  if (fog) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(fog));
    if (message_arena != submessage_arena) {
      fog = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, fog, submessage_arena);
    }
    
  } else {
    
  }
  fog_ = fog;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Scene.fog)
}

// bool grid = 8;
inline void Scene::clear_grid() {
  grid_ = false;
}
inline bool Scene::_internal_grid() const {
  return grid_;
}
inline bool Scene::grid() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.grid)
  return _internal_grid();
}
inline void Scene::_internal_set_grid(bool value) {
  
  grid_ = value;
}
inline void Scene::set_grid(bool value) {
  _internal_set_grid(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Scene.grid)
}

// repeated .ignition.msgs.Model model = 9;
inline int Scene::_internal_model_size() const {
  return model_.size();
}
inline int Scene::model_size() const {
  return _internal_model_size();
}
inline ::ignition::msgs::Model* Scene::mutable_model(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.model)
  return model_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >*
Scene::mutable_model() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Scene.model)
  return &model_;
}
inline const ::ignition::msgs::Model& Scene::_internal_model(int index) const {
  return model_.Get(index);
}
inline const ::ignition::msgs::Model& Scene::model(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.model)
  return _internal_model(index);
}
inline ::ignition::msgs::Model* Scene::_internal_add_model() {
  return model_.Add();
}
inline ::ignition::msgs::Model* Scene::add_model() {
  ::ignition::msgs::Model* _add = _internal_add_model();
  // @@protoc_insertion_point(field_add:ignition.msgs.Scene.model)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Model >&
Scene::model() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Scene.model)
  return model_;
}

// repeated .ignition.msgs.Light light = 10;
inline int Scene::_internal_light_size() const {
  return light_.size();
}
inline int Scene::light_size() const {
  return _internal_light_size();
}
inline ::ignition::msgs::Light* Scene::mutable_light(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.light)
  return light_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >*
Scene::mutable_light() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Scene.light)
  return &light_;
}
inline const ::ignition::msgs::Light& Scene::_internal_light(int index) const {
  return light_.Get(index);
}
inline const ::ignition::msgs::Light& Scene::light(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.light)
  return _internal_light(index);
}
inline ::ignition::msgs::Light* Scene::_internal_add_light() {
  return light_.Add();
}
inline ::ignition::msgs::Light* Scene::add_light() {
  ::ignition::msgs::Light* _add = _internal_add_light();
  // @@protoc_insertion_point(field_add:ignition.msgs.Scene.light)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Light >&
Scene::light() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Scene.light)
  return light_;
}

// repeated .ignition.msgs.Joint joint = 11;
inline int Scene::_internal_joint_size() const {
  return joint_.size();
}
inline int Scene::joint_size() const {
  return _internal_joint_size();
}
inline ::ignition::msgs::Joint* Scene::mutable_joint(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Scene.joint)
  return joint_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >*
Scene::mutable_joint() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Scene.joint)
  return &joint_;
}
inline const ::ignition::msgs::Joint& Scene::_internal_joint(int index) const {
  return joint_.Get(index);
}
inline const ::ignition::msgs::Joint& Scene::joint(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.joint)
  return _internal_joint(index);
}
inline ::ignition::msgs::Joint* Scene::_internal_add_joint() {
  return joint_.Add();
}
inline ::ignition::msgs::Joint* Scene::add_joint() {
  ::ignition::msgs::Joint* _add = _internal_add_joint();
  // @@protoc_insertion_point(field_add:ignition.msgs.Scene.joint)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Joint >&
Scene::joint() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Scene.joint)
  return joint_;
}

// bool origin_visual = 12;
inline void Scene::clear_origin_visual() {
  origin_visual_ = false;
}
inline bool Scene::_internal_origin_visual() const {
  return origin_visual_;
}
inline bool Scene::origin_visual() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Scene.origin_visual)
  return _internal_origin_visual();
}
inline void Scene::_internal_set_origin_visual(bool value) {
  
  origin_visual_ = value;
}
inline void Scene::set_origin_visual(bool value) {
  _internal_set_origin_visual(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Scene.origin_visual)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Scene> SceneUniquePtr;
typedef std::unique_ptr<const Scene> ConstSceneUniquePtr;
typedef std::shared_ptr<Scene> SceneSharedPtr;
typedef std::shared_ptr<const Scene> ConstSceneSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fscene_2eproto
