# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/occupancy_grid.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/time_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/occupancy_grid.proto", :syntax => :proto3) do
    add_message "ignition.msgs.OccupancyGrid" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :info, :message, 2, "ignition.msgs.OccupancyGrid.MapMetaInfo"
      optional :data, :bytes, 3
    end
    add_message "ignition.msgs.OccupancyGrid.MapMetaInfo" do
      optional :map_load_time, :message, 1, "ignition.msgs.Time"
      optional :resolution, :double, 2
      optional :width, :uint32, 3
      optional :height, :uint32, 4
      optional :origin, :message, 5, "ignition.msgs.Pose"
    end
  end
end

module Ignition
  module Msgs
    OccupancyGrid = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.OccupancyGrid").msgclass
    OccupancyGrid::MapMetaInfo = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.OccupancyGrid.MapMetaInfo").msgclass
  end
end
