// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/sdf_generator_config.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/map.h>  // IWYU pragma: export
#include <google/protobuf/map_entry.h>
#include <google/protobuf/map_field_inl.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/boolean.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[3]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto;
namespace ignition {
namespace msgs {
class SdfGeneratorConfig;
struct SdfGeneratorConfigDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SdfGeneratorConfigDefaultTypeInternal _SdfGeneratorConfig_default_instance_;
class SdfGeneratorConfig_EntityGeneratorConfig;
struct SdfGeneratorConfig_EntityGeneratorConfigDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SdfGeneratorConfig_EntityGeneratorConfigDefaultTypeInternal _SdfGeneratorConfig_EntityGeneratorConfig_default_instance_;
class SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse;
struct SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUseDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUseDefaultTypeInternal _SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SdfGeneratorConfig* Arena::CreateMaybeMessage<::ignition::msgs::SdfGeneratorConfig>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* Arena::CreateMaybeMessage<::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse* Arena::CreateMaybeMessage<::ignition::msgs::SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE SdfGeneratorConfig_EntityGeneratorConfig final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig) */ {
 public:
  inline SdfGeneratorConfig_EntityGeneratorConfig() : SdfGeneratorConfig_EntityGeneratorConfig(nullptr) {}
  ~SdfGeneratorConfig_EntityGeneratorConfig() override;
  explicit constexpr SdfGeneratorConfig_EntityGeneratorConfig(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SdfGeneratorConfig_EntityGeneratorConfig(const SdfGeneratorConfig_EntityGeneratorConfig& from);
  SdfGeneratorConfig_EntityGeneratorConfig(SdfGeneratorConfig_EntityGeneratorConfig&& from) noexcept
    : SdfGeneratorConfig_EntityGeneratorConfig() {
    *this = ::std::move(from);
  }

  inline SdfGeneratorConfig_EntityGeneratorConfig& operator=(const SdfGeneratorConfig_EntityGeneratorConfig& from) {
    CopyFrom(from);
    return *this;
  }
  inline SdfGeneratorConfig_EntityGeneratorConfig& operator=(SdfGeneratorConfig_EntityGeneratorConfig&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SdfGeneratorConfig_EntityGeneratorConfig& default_instance() {
    return *internal_default_instance();
  }
  static inline const SdfGeneratorConfig_EntityGeneratorConfig* internal_default_instance() {
    return reinterpret_cast<const SdfGeneratorConfig_EntityGeneratorConfig*>(
               &_SdfGeneratorConfig_EntityGeneratorConfig_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(SdfGeneratorConfig_EntityGeneratorConfig& a, SdfGeneratorConfig_EntityGeneratorConfig& b) {
    a.Swap(&b);
  }
  inline void Swap(SdfGeneratorConfig_EntityGeneratorConfig* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SdfGeneratorConfig_EntityGeneratorConfig* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SdfGeneratorConfig_EntityGeneratorConfig* New() const final {
    return new SdfGeneratorConfig_EntityGeneratorConfig();
  }

  SdfGeneratorConfig_EntityGeneratorConfig* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SdfGeneratorConfig_EntityGeneratorConfig>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SdfGeneratorConfig_EntityGeneratorConfig& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SdfGeneratorConfig_EntityGeneratorConfig& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SdfGeneratorConfig_EntityGeneratorConfig* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig";
  }
  protected:
  explicit SdfGeneratorConfig_EntityGeneratorConfig(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kExpandIncludeTagsFieldNumber = 1,
    kSaveFuelVersionFieldNumber = 2,
    kResourcesUseAbsolutePathsFieldNumber = 3,
    kCopyModelResourcesFieldNumber = 4,
  };
  // .ignition.msgs.Boolean expand_include_tags = 1;
  bool has_expand_include_tags() const;
  private:
  bool _internal_has_expand_include_tags() const;
  public:
  void clear_expand_include_tags();
  const ::ignition::msgs::Boolean& expand_include_tags() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Boolean* release_expand_include_tags();
  ::ignition::msgs::Boolean* mutable_expand_include_tags();
  void set_allocated_expand_include_tags(::ignition::msgs::Boolean* expand_include_tags);
  private:
  const ::ignition::msgs::Boolean& _internal_expand_include_tags() const;
  ::ignition::msgs::Boolean* _internal_mutable_expand_include_tags();
  public:
  void unsafe_arena_set_allocated_expand_include_tags(
      ::ignition::msgs::Boolean* expand_include_tags);
  ::ignition::msgs::Boolean* unsafe_arena_release_expand_include_tags();

  // .ignition.msgs.Boolean save_fuel_version = 2;
  bool has_save_fuel_version() const;
  private:
  bool _internal_has_save_fuel_version() const;
  public:
  void clear_save_fuel_version();
  const ::ignition::msgs::Boolean& save_fuel_version() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Boolean* release_save_fuel_version();
  ::ignition::msgs::Boolean* mutable_save_fuel_version();
  void set_allocated_save_fuel_version(::ignition::msgs::Boolean* save_fuel_version);
  private:
  const ::ignition::msgs::Boolean& _internal_save_fuel_version() const;
  ::ignition::msgs::Boolean* _internal_mutable_save_fuel_version();
  public:
  void unsafe_arena_set_allocated_save_fuel_version(
      ::ignition::msgs::Boolean* save_fuel_version);
  ::ignition::msgs::Boolean* unsafe_arena_release_save_fuel_version();

  // .ignition.msgs.Boolean resources_use_absolute_paths = 3;
  bool has_resources_use_absolute_paths() const;
  private:
  bool _internal_has_resources_use_absolute_paths() const;
  public:
  void clear_resources_use_absolute_paths();
  const ::ignition::msgs::Boolean& resources_use_absolute_paths() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Boolean* release_resources_use_absolute_paths();
  ::ignition::msgs::Boolean* mutable_resources_use_absolute_paths();
  void set_allocated_resources_use_absolute_paths(::ignition::msgs::Boolean* resources_use_absolute_paths);
  private:
  const ::ignition::msgs::Boolean& _internal_resources_use_absolute_paths() const;
  ::ignition::msgs::Boolean* _internal_mutable_resources_use_absolute_paths();
  public:
  void unsafe_arena_set_allocated_resources_use_absolute_paths(
      ::ignition::msgs::Boolean* resources_use_absolute_paths);
  ::ignition::msgs::Boolean* unsafe_arena_release_resources_use_absolute_paths();

  // .ignition.msgs.Boolean copy_model_resources = 4;
  bool has_copy_model_resources() const;
  private:
  bool _internal_has_copy_model_resources() const;
  public:
  void clear_copy_model_resources();
  const ::ignition::msgs::Boolean& copy_model_resources() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Boolean* release_copy_model_resources();
  ::ignition::msgs::Boolean* mutable_copy_model_resources();
  void set_allocated_copy_model_resources(::ignition::msgs::Boolean* copy_model_resources);
  private:
  const ::ignition::msgs::Boolean& _internal_copy_model_resources() const;
  ::ignition::msgs::Boolean* _internal_mutable_copy_model_resources();
  public:
  void unsafe_arena_set_allocated_copy_model_resources(
      ::ignition::msgs::Boolean* copy_model_resources);
  ::ignition::msgs::Boolean* unsafe_arena_release_copy_model_resources();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Boolean* expand_include_tags_;
  ::ignition::msgs::Boolean* save_fuel_version_;
  ::ignition::msgs::Boolean* resources_use_absolute_paths_;
  ::ignition::msgs::Boolean* copy_model_resources_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto;
};
// -------------------------------------------------------------------

class SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse : public ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse, 
    std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_STRING,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> {
public:
  typedef ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse, 
    std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_STRING,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> SuperType;
  SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse();
  explicit constexpr SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse(
      ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);
  explicit SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  void MergeFrom(const SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse& other);
  static const SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse* internal_default_instance() { return reinterpret_cast<const SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse*>(&_SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse_default_instance_); }
  static bool ValidateKey(std::string* s) {
    return ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::VerifyUtf8String(s->data(), static_cast<int>(s->size()), ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::PARSE, "ignition.msgs.SdfGeneratorConfig.OverrideEntityGenConfigsEntry.key");
 }
  static bool ValidateValue(void*) { return true; }
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
};

// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SdfGeneratorConfig final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SdfGeneratorConfig) */ {
 public:
  inline SdfGeneratorConfig() : SdfGeneratorConfig(nullptr) {}
  ~SdfGeneratorConfig() override;
  explicit constexpr SdfGeneratorConfig(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SdfGeneratorConfig(const SdfGeneratorConfig& from);
  SdfGeneratorConfig(SdfGeneratorConfig&& from) noexcept
    : SdfGeneratorConfig() {
    *this = ::std::move(from);
  }

  inline SdfGeneratorConfig& operator=(const SdfGeneratorConfig& from) {
    CopyFrom(from);
    return *this;
  }
  inline SdfGeneratorConfig& operator=(SdfGeneratorConfig&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SdfGeneratorConfig& default_instance() {
    return *internal_default_instance();
  }
  static inline const SdfGeneratorConfig* internal_default_instance() {
    return reinterpret_cast<const SdfGeneratorConfig*>(
               &_SdfGeneratorConfig_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(SdfGeneratorConfig& a, SdfGeneratorConfig& b) {
    a.Swap(&b);
  }
  inline void Swap(SdfGeneratorConfig* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SdfGeneratorConfig* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SdfGeneratorConfig* New() const final {
    return new SdfGeneratorConfig();
  }

  SdfGeneratorConfig* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SdfGeneratorConfig>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SdfGeneratorConfig& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SdfGeneratorConfig& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SdfGeneratorConfig* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SdfGeneratorConfig";
  }
  protected:
  explicit SdfGeneratorConfig(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef SdfGeneratorConfig_EntityGeneratorConfig EntityGeneratorConfig;

  // accessors -------------------------------------------------------

  enum : int {
    kOverrideEntityGenConfigsFieldNumber = 3,
    kHeaderFieldNumber = 1,
    kGlobalEntityGenConfigFieldNumber = 2,
  };
  // map<string, .ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig> override_entity_gen_configs = 3;
  int override_entity_gen_configs_size() const;
  private:
  int _internal_override_entity_gen_configs_size() const;
  public:
  void clear_override_entity_gen_configs();
  private:
  const ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >&
      _internal_override_entity_gen_configs() const;
  ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >*
      _internal_mutable_override_entity_gen_configs();
  public:
  const ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >&
      override_entity_gen_configs() const;
  ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >*
      mutable_override_entity_gen_configs();

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig global_entity_gen_config = 2;
  bool has_global_entity_gen_config() const;
  private:
  bool _internal_has_global_entity_gen_config() const;
  public:
  void clear_global_entity_gen_config();
  const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig& global_entity_gen_config() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* release_global_entity_gen_config();
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* mutable_global_entity_gen_config();
  void set_allocated_global_entity_gen_config(::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* global_entity_gen_config);
  private:
  const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig& _internal_global_entity_gen_config() const;
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* _internal_mutable_global_entity_gen_config();
  public:
  void unsafe_arena_set_allocated_global_entity_gen_config(
      ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* global_entity_gen_config);
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* unsafe_arena_release_global_entity_gen_config();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SdfGeneratorConfig)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::MapField<
      SdfGeneratorConfig_OverrideEntityGenConfigsEntry_DoNotUse,
      std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_STRING,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> override_entity_gen_configs_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* global_entity_gen_config_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// SdfGeneratorConfig_EntityGeneratorConfig

// .ignition.msgs.Boolean expand_include_tags = 1;
inline bool SdfGeneratorConfig_EntityGeneratorConfig::_internal_has_expand_include_tags() const {
  return this != internal_default_instance() && expand_include_tags_ != nullptr;
}
inline bool SdfGeneratorConfig_EntityGeneratorConfig::has_expand_include_tags() const {
  return _internal_has_expand_include_tags();
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::_internal_expand_include_tags() const {
  const ::ignition::msgs::Boolean* p = expand_include_tags_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Boolean&>(
      ::ignition::msgs::_Boolean_default_instance_);
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::expand_include_tags() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.expand_include_tags)
  return _internal_expand_include_tags();
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_set_allocated_expand_include_tags(
    ::ignition::msgs::Boolean* expand_include_tags) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(expand_include_tags_);
  }
  expand_include_tags_ = expand_include_tags;
  if (expand_include_tags) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.expand_include_tags)
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::release_expand_include_tags() {
  
  ::ignition::msgs::Boolean* temp = expand_include_tags_;
  expand_include_tags_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_release_expand_include_tags() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.expand_include_tags)
  
  ::ignition::msgs::Boolean* temp = expand_include_tags_;
  expand_include_tags_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::_internal_mutable_expand_include_tags() {
  
  if (expand_include_tags_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Boolean>(GetArenaForAllocation());
    expand_include_tags_ = p;
  }
  return expand_include_tags_;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::mutable_expand_include_tags() {
  ::ignition::msgs::Boolean* _msg = _internal_mutable_expand_include_tags();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.expand_include_tags)
  return _msg;
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::set_allocated_expand_include_tags(::ignition::msgs::Boolean* expand_include_tags) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(expand_include_tags_);
  }
  if (expand_include_tags) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(expand_include_tags));
    if (message_arena != submessage_arena) {
      expand_include_tags = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, expand_include_tags, submessage_arena);
    }
    
  } else {
    
  }
  expand_include_tags_ = expand_include_tags;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.expand_include_tags)
}

// .ignition.msgs.Boolean save_fuel_version = 2;
inline bool SdfGeneratorConfig_EntityGeneratorConfig::_internal_has_save_fuel_version() const {
  return this != internal_default_instance() && save_fuel_version_ != nullptr;
}
inline bool SdfGeneratorConfig_EntityGeneratorConfig::has_save_fuel_version() const {
  return _internal_has_save_fuel_version();
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::_internal_save_fuel_version() const {
  const ::ignition::msgs::Boolean* p = save_fuel_version_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Boolean&>(
      ::ignition::msgs::_Boolean_default_instance_);
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::save_fuel_version() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.save_fuel_version)
  return _internal_save_fuel_version();
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_set_allocated_save_fuel_version(
    ::ignition::msgs::Boolean* save_fuel_version) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(save_fuel_version_);
  }
  save_fuel_version_ = save_fuel_version;
  if (save_fuel_version) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.save_fuel_version)
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::release_save_fuel_version() {
  
  ::ignition::msgs::Boolean* temp = save_fuel_version_;
  save_fuel_version_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_release_save_fuel_version() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.save_fuel_version)
  
  ::ignition::msgs::Boolean* temp = save_fuel_version_;
  save_fuel_version_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::_internal_mutable_save_fuel_version() {
  
  if (save_fuel_version_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Boolean>(GetArenaForAllocation());
    save_fuel_version_ = p;
  }
  return save_fuel_version_;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::mutable_save_fuel_version() {
  ::ignition::msgs::Boolean* _msg = _internal_mutable_save_fuel_version();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.save_fuel_version)
  return _msg;
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::set_allocated_save_fuel_version(::ignition::msgs::Boolean* save_fuel_version) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(save_fuel_version_);
  }
  if (save_fuel_version) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(save_fuel_version));
    if (message_arena != submessage_arena) {
      save_fuel_version = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, save_fuel_version, submessage_arena);
    }
    
  } else {
    
  }
  save_fuel_version_ = save_fuel_version;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.save_fuel_version)
}

// .ignition.msgs.Boolean resources_use_absolute_paths = 3;
inline bool SdfGeneratorConfig_EntityGeneratorConfig::_internal_has_resources_use_absolute_paths() const {
  return this != internal_default_instance() && resources_use_absolute_paths_ != nullptr;
}
inline bool SdfGeneratorConfig_EntityGeneratorConfig::has_resources_use_absolute_paths() const {
  return _internal_has_resources_use_absolute_paths();
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::_internal_resources_use_absolute_paths() const {
  const ::ignition::msgs::Boolean* p = resources_use_absolute_paths_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Boolean&>(
      ::ignition::msgs::_Boolean_default_instance_);
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::resources_use_absolute_paths() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.resources_use_absolute_paths)
  return _internal_resources_use_absolute_paths();
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_set_allocated_resources_use_absolute_paths(
    ::ignition::msgs::Boolean* resources_use_absolute_paths) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(resources_use_absolute_paths_);
  }
  resources_use_absolute_paths_ = resources_use_absolute_paths;
  if (resources_use_absolute_paths) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.resources_use_absolute_paths)
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::release_resources_use_absolute_paths() {
  
  ::ignition::msgs::Boolean* temp = resources_use_absolute_paths_;
  resources_use_absolute_paths_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_release_resources_use_absolute_paths() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.resources_use_absolute_paths)
  
  ::ignition::msgs::Boolean* temp = resources_use_absolute_paths_;
  resources_use_absolute_paths_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::_internal_mutable_resources_use_absolute_paths() {
  
  if (resources_use_absolute_paths_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Boolean>(GetArenaForAllocation());
    resources_use_absolute_paths_ = p;
  }
  return resources_use_absolute_paths_;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::mutable_resources_use_absolute_paths() {
  ::ignition::msgs::Boolean* _msg = _internal_mutable_resources_use_absolute_paths();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.resources_use_absolute_paths)
  return _msg;
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::set_allocated_resources_use_absolute_paths(::ignition::msgs::Boolean* resources_use_absolute_paths) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(resources_use_absolute_paths_);
  }
  if (resources_use_absolute_paths) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(resources_use_absolute_paths));
    if (message_arena != submessage_arena) {
      resources_use_absolute_paths = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, resources_use_absolute_paths, submessage_arena);
    }
    
  } else {
    
  }
  resources_use_absolute_paths_ = resources_use_absolute_paths;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.resources_use_absolute_paths)
}

// .ignition.msgs.Boolean copy_model_resources = 4;
inline bool SdfGeneratorConfig_EntityGeneratorConfig::_internal_has_copy_model_resources() const {
  return this != internal_default_instance() && copy_model_resources_ != nullptr;
}
inline bool SdfGeneratorConfig_EntityGeneratorConfig::has_copy_model_resources() const {
  return _internal_has_copy_model_resources();
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::_internal_copy_model_resources() const {
  const ::ignition::msgs::Boolean* p = copy_model_resources_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Boolean&>(
      ::ignition::msgs::_Boolean_default_instance_);
}
inline const ::ignition::msgs::Boolean& SdfGeneratorConfig_EntityGeneratorConfig::copy_model_resources() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.copy_model_resources)
  return _internal_copy_model_resources();
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_set_allocated_copy_model_resources(
    ::ignition::msgs::Boolean* copy_model_resources) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(copy_model_resources_);
  }
  copy_model_resources_ = copy_model_resources;
  if (copy_model_resources) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.copy_model_resources)
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::release_copy_model_resources() {
  
  ::ignition::msgs::Boolean* temp = copy_model_resources_;
  copy_model_resources_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::unsafe_arena_release_copy_model_resources() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.copy_model_resources)
  
  ::ignition::msgs::Boolean* temp = copy_model_resources_;
  copy_model_resources_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::_internal_mutable_copy_model_resources() {
  
  if (copy_model_resources_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Boolean>(GetArenaForAllocation());
    copy_model_resources_ = p;
  }
  return copy_model_resources_;
}
inline ::ignition::msgs::Boolean* SdfGeneratorConfig_EntityGeneratorConfig::mutable_copy_model_resources() {
  ::ignition::msgs::Boolean* _msg = _internal_mutable_copy_model_resources();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.copy_model_resources)
  return _msg;
}
inline void SdfGeneratorConfig_EntityGeneratorConfig::set_allocated_copy_model_resources(::ignition::msgs::Boolean* copy_model_resources) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(copy_model_resources_);
  }
  if (copy_model_resources) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(copy_model_resources));
    if (message_arena != submessage_arena) {
      copy_model_resources = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, copy_model_resources, submessage_arena);
    }
    
  } else {
    
  }
  copy_model_resources_ = copy_model_resources;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig.copy_model_resources)
}

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// SdfGeneratorConfig

// .ignition.msgs.Header header = 1;
inline bool SdfGeneratorConfig::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool SdfGeneratorConfig::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& SdfGeneratorConfig::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& SdfGeneratorConfig::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.header)
  return _internal_header();
}
inline void SdfGeneratorConfig::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.header)
}
inline ::ignition::msgs::Header* SdfGeneratorConfig::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* SdfGeneratorConfig::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* SdfGeneratorConfig::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* SdfGeneratorConfig::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.header)
  return _msg;
}
inline void SdfGeneratorConfig::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.header)
}

// .ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig global_entity_gen_config = 2;
inline bool SdfGeneratorConfig::_internal_has_global_entity_gen_config() const {
  return this != internal_default_instance() && global_entity_gen_config_ != nullptr;
}
inline bool SdfGeneratorConfig::has_global_entity_gen_config() const {
  return _internal_has_global_entity_gen_config();
}
inline void SdfGeneratorConfig::clear_global_entity_gen_config() {
  if (GetArenaForAllocation() == nullptr && global_entity_gen_config_ != nullptr) {
    delete global_entity_gen_config_;
  }
  global_entity_gen_config_ = nullptr;
}
inline const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig& SdfGeneratorConfig::_internal_global_entity_gen_config() const {
  const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* p = global_entity_gen_config_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig&>(
      ::ignition::msgs::_SdfGeneratorConfig_EntityGeneratorConfig_default_instance_);
}
inline const ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig& SdfGeneratorConfig::global_entity_gen_config() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SdfGeneratorConfig.global_entity_gen_config)
  return _internal_global_entity_gen_config();
}
inline void SdfGeneratorConfig::unsafe_arena_set_allocated_global_entity_gen_config(
    ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* global_entity_gen_config) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(global_entity_gen_config_);
  }
  global_entity_gen_config_ = global_entity_gen_config;
  if (global_entity_gen_config) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SdfGeneratorConfig.global_entity_gen_config)
}
inline ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* SdfGeneratorConfig::release_global_entity_gen_config() {
  
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* temp = global_entity_gen_config_;
  global_entity_gen_config_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* SdfGeneratorConfig::unsafe_arena_release_global_entity_gen_config() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SdfGeneratorConfig.global_entity_gen_config)
  
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* temp = global_entity_gen_config_;
  global_entity_gen_config_ = nullptr;
  return temp;
}
inline ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* SdfGeneratorConfig::_internal_mutable_global_entity_gen_config() {
  
  if (global_entity_gen_config_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig>(GetArenaForAllocation());
    global_entity_gen_config_ = p;
  }
  return global_entity_gen_config_;
}
inline ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* SdfGeneratorConfig::mutable_global_entity_gen_config() {
  ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* _msg = _internal_mutable_global_entity_gen_config();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SdfGeneratorConfig.global_entity_gen_config)
  return _msg;
}
inline void SdfGeneratorConfig::set_allocated_global_entity_gen_config(::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig* global_entity_gen_config) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete global_entity_gen_config_;
  }
  if (global_entity_gen_config) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig>::GetOwningArena(global_entity_gen_config);
    if (message_arena != submessage_arena) {
      global_entity_gen_config = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, global_entity_gen_config, submessage_arena);
    }
    
  } else {
    
  }
  global_entity_gen_config_ = global_entity_gen_config;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SdfGeneratorConfig.global_entity_gen_config)
}

// map<string, .ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig> override_entity_gen_configs = 3;
inline int SdfGeneratorConfig::_internal_override_entity_gen_configs_size() const {
  return override_entity_gen_configs_.size();
}
inline int SdfGeneratorConfig::override_entity_gen_configs_size() const {
  return _internal_override_entity_gen_configs_size();
}
inline void SdfGeneratorConfig::clear_override_entity_gen_configs() {
  override_entity_gen_configs_.Clear();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >&
SdfGeneratorConfig::_internal_override_entity_gen_configs() const {
  return override_entity_gen_configs_.GetMap();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >&
SdfGeneratorConfig::override_entity_gen_configs() const {
  // @@protoc_insertion_point(field_map:ignition.msgs.SdfGeneratorConfig.override_entity_gen_configs)
  return _internal_override_entity_gen_configs();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >*
SdfGeneratorConfig::_internal_mutable_override_entity_gen_configs() {
  return override_entity_gen_configs_.MutableMap();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< std::string, ::ignition::msgs::SdfGeneratorConfig_EntityGeneratorConfig >*
SdfGeneratorConfig::mutable_override_entity_gen_configs() {
  // @@protoc_insertion_point(field_mutable_map:ignition.msgs.SdfGeneratorConfig.override_entity_gen_configs)
  return _internal_mutable_override_entity_gen_configs();
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<SdfGeneratorConfig> SdfGeneratorConfigUniquePtr;
typedef std::unique_ptr<const SdfGeneratorConfig> ConstSdfGeneratorConfigUniquePtr;
typedef std::shared_ptr<SdfGeneratorConfig> SdfGeneratorConfigSharedPtr;
typedef std::shared_ptr<const SdfGeneratorConfig> ConstSdfGeneratorConfigSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsdf_5fgenerator_5fconfig_2eproto
