# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/camerasensor.proto

require 'ignition/msgs/vector2d_pb'
require 'ignition/msgs/distortion_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/camerasensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.CameraSensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :horizontal_fov, :double, 2
      optional :image_size, :message, 3, "ignition.msgs.Vector2d"
      optional :image_format, :string, 4
      optional :near_clip, :double, 5
      optional :far_clip, :double, 6
      optional :save_enabled, :bool, 7
      optional :save_path, :string, 8
      optional :distortion, :message, 9, "ignition.msgs.Distortion"
    end
  end
end

module Ignition
  module Msgs
    CameraSensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.CameraSensor").msgclass
  end
end
