// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/occupancy_grid.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2foccupancy_5fgrid_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2foccupancy_5fgrid_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/time.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2foccupancy_5fgrid_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2foccupancy_5fgrid_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[2]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2foccupancy_5fgrid_2eproto;
namespace ignition {
namespace msgs {
class OccupancyGrid;
struct OccupancyGridDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern OccupancyGridDefaultTypeInternal _OccupancyGrid_default_instance_;
class OccupancyGrid_MapMetaInfo;
struct OccupancyGrid_MapMetaInfoDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern OccupancyGrid_MapMetaInfoDefaultTypeInternal _OccupancyGrid_MapMetaInfo_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::OccupancyGrid* Arena::CreateMaybeMessage<::ignition::msgs::OccupancyGrid>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::OccupancyGrid_MapMetaInfo* Arena::CreateMaybeMessage<::ignition::msgs::OccupancyGrid_MapMetaInfo>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE OccupancyGrid_MapMetaInfo final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.OccupancyGrid.MapMetaInfo) */ {
 public:
  inline OccupancyGrid_MapMetaInfo() : OccupancyGrid_MapMetaInfo(nullptr) {}
  ~OccupancyGrid_MapMetaInfo() override;
  explicit constexpr OccupancyGrid_MapMetaInfo(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  OccupancyGrid_MapMetaInfo(const OccupancyGrid_MapMetaInfo& from);
  OccupancyGrid_MapMetaInfo(OccupancyGrid_MapMetaInfo&& from) noexcept
    : OccupancyGrid_MapMetaInfo() {
    *this = ::std::move(from);
  }

  inline OccupancyGrid_MapMetaInfo& operator=(const OccupancyGrid_MapMetaInfo& from) {
    CopyFrom(from);
    return *this;
  }
  inline OccupancyGrid_MapMetaInfo& operator=(OccupancyGrid_MapMetaInfo&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const OccupancyGrid_MapMetaInfo& default_instance() {
    return *internal_default_instance();
  }
  static inline const OccupancyGrid_MapMetaInfo* internal_default_instance() {
    return reinterpret_cast<const OccupancyGrid_MapMetaInfo*>(
               &_OccupancyGrid_MapMetaInfo_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(OccupancyGrid_MapMetaInfo& a, OccupancyGrid_MapMetaInfo& b) {
    a.Swap(&b);
  }
  inline void Swap(OccupancyGrid_MapMetaInfo* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(OccupancyGrid_MapMetaInfo* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline OccupancyGrid_MapMetaInfo* New() const final {
    return new OccupancyGrid_MapMetaInfo();
  }

  OccupancyGrid_MapMetaInfo* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<OccupancyGrid_MapMetaInfo>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const OccupancyGrid_MapMetaInfo& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const OccupancyGrid_MapMetaInfo& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(OccupancyGrid_MapMetaInfo* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.OccupancyGrid.MapMetaInfo";
  }
  protected:
  explicit OccupancyGrid_MapMetaInfo(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kMapLoadTimeFieldNumber = 1,
    kOriginFieldNumber = 5,
    kResolutionFieldNumber = 2,
    kWidthFieldNumber = 3,
    kHeightFieldNumber = 4,
  };
  // .ignition.msgs.Time map_load_time = 1;
  bool has_map_load_time() const;
  private:
  bool _internal_has_map_load_time() const;
  public:
  void clear_map_load_time();
  const ::ignition::msgs::Time& map_load_time() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Time* release_map_load_time();
  ::ignition::msgs::Time* mutable_map_load_time();
  void set_allocated_map_load_time(::ignition::msgs::Time* map_load_time);
  private:
  const ::ignition::msgs::Time& _internal_map_load_time() const;
  ::ignition::msgs::Time* _internal_mutable_map_load_time();
  public:
  void unsafe_arena_set_allocated_map_load_time(
      ::ignition::msgs::Time* map_load_time);
  ::ignition::msgs::Time* unsafe_arena_release_map_load_time();

  // .ignition.msgs.Pose origin = 5;
  bool has_origin() const;
  private:
  bool _internal_has_origin() const;
  public:
  void clear_origin();
  const ::ignition::msgs::Pose& origin() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_origin();
  ::ignition::msgs::Pose* mutable_origin();
  void set_allocated_origin(::ignition::msgs::Pose* origin);
  private:
  const ::ignition::msgs::Pose& _internal_origin() const;
  ::ignition::msgs::Pose* _internal_mutable_origin();
  public:
  void unsafe_arena_set_allocated_origin(
      ::ignition::msgs::Pose* origin);
  ::ignition::msgs::Pose* unsafe_arena_release_origin();

  // double resolution = 2;
  void clear_resolution();
  double resolution() const;
  void set_resolution(double value);
  private:
  double _internal_resolution() const;
  void _internal_set_resolution(double value);
  public:

  // uint32 width = 3;
  void clear_width();
  ::PROTOBUF_NAMESPACE_ID::uint32 width() const;
  void set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_width() const;
  void _internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 height = 4;
  void clear_height();
  ::PROTOBUF_NAMESPACE_ID::uint32 height() const;
  void set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_height() const;
  void _internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.OccupancyGrid.MapMetaInfo)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Time* map_load_time_;
  ::ignition::msgs::Pose* origin_;
  double resolution_;
  ::PROTOBUF_NAMESPACE_ID::uint32 width_;
  ::PROTOBUF_NAMESPACE_ID::uint32 height_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2foccupancy_5fgrid_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE OccupancyGrid final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.OccupancyGrid) */ {
 public:
  inline OccupancyGrid() : OccupancyGrid(nullptr) {}
  ~OccupancyGrid() override;
  explicit constexpr OccupancyGrid(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  OccupancyGrid(const OccupancyGrid& from);
  OccupancyGrid(OccupancyGrid&& from) noexcept
    : OccupancyGrid() {
    *this = ::std::move(from);
  }

  inline OccupancyGrid& operator=(const OccupancyGrid& from) {
    CopyFrom(from);
    return *this;
  }
  inline OccupancyGrid& operator=(OccupancyGrid&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const OccupancyGrid& default_instance() {
    return *internal_default_instance();
  }
  static inline const OccupancyGrid* internal_default_instance() {
    return reinterpret_cast<const OccupancyGrid*>(
               &_OccupancyGrid_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(OccupancyGrid& a, OccupancyGrid& b) {
    a.Swap(&b);
  }
  inline void Swap(OccupancyGrid* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(OccupancyGrid* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline OccupancyGrid* New() const final {
    return new OccupancyGrid();
  }

  OccupancyGrid* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<OccupancyGrid>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const OccupancyGrid& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const OccupancyGrid& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(OccupancyGrid* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.OccupancyGrid";
  }
  protected:
  explicit OccupancyGrid(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef OccupancyGrid_MapMetaInfo MapMetaInfo;

  // accessors -------------------------------------------------------

  enum : int {
    kDataFieldNumber = 3,
    kHeaderFieldNumber = 1,
    kInfoFieldNumber = 2,
  };
  // bytes data = 3;
  void clear_data();
  const std::string& data() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_data(ArgT0&& arg0, ArgT... args);
  std::string* mutable_data();
  PROTOBUF_MUST_USE_RESULT std::string* release_data();
  void set_allocated_data(std::string* data);
  private:
  const std::string& _internal_data() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_data(const std::string& value);
  std::string* _internal_mutable_data();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.OccupancyGrid.MapMetaInfo info = 2;
  bool has_info() const;
  private:
  bool _internal_has_info() const;
  public:
  void clear_info();
  const ::ignition::msgs::OccupancyGrid_MapMetaInfo& info() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::OccupancyGrid_MapMetaInfo* release_info();
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* mutable_info();
  void set_allocated_info(::ignition::msgs::OccupancyGrid_MapMetaInfo* info);
  private:
  const ::ignition::msgs::OccupancyGrid_MapMetaInfo& _internal_info() const;
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* _internal_mutable_info();
  public:
  void unsafe_arena_set_allocated_info(
      ::ignition::msgs::OccupancyGrid_MapMetaInfo* info);
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* unsafe_arena_release_info();

  // @@protoc_insertion_point(class_scope:ignition.msgs.OccupancyGrid)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr data_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* info_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2foccupancy_5fgrid_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// OccupancyGrid_MapMetaInfo

// .ignition.msgs.Time map_load_time = 1;
inline bool OccupancyGrid_MapMetaInfo::_internal_has_map_load_time() const {
  return this != internal_default_instance() && map_load_time_ != nullptr;
}
inline bool OccupancyGrid_MapMetaInfo::has_map_load_time() const {
  return _internal_has_map_load_time();
}
inline const ::ignition::msgs::Time& OccupancyGrid_MapMetaInfo::_internal_map_load_time() const {
  const ::ignition::msgs::Time* p = map_load_time_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Time&>(
      ::ignition::msgs::_Time_default_instance_);
}
inline const ::ignition::msgs::Time& OccupancyGrid_MapMetaInfo::map_load_time() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.MapMetaInfo.map_load_time)
  return _internal_map_load_time();
}
inline void OccupancyGrid_MapMetaInfo::unsafe_arena_set_allocated_map_load_time(
    ::ignition::msgs::Time* map_load_time) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(map_load_time_);
  }
  map_load_time_ = map_load_time;
  if (map_load_time) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.OccupancyGrid.MapMetaInfo.map_load_time)
}
inline ::ignition::msgs::Time* OccupancyGrid_MapMetaInfo::release_map_load_time() {
  
  ::ignition::msgs::Time* temp = map_load_time_;
  map_load_time_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Time* OccupancyGrid_MapMetaInfo::unsafe_arena_release_map_load_time() {
  // @@protoc_insertion_point(field_release:ignition.msgs.OccupancyGrid.MapMetaInfo.map_load_time)
  
  ::ignition::msgs::Time* temp = map_load_time_;
  map_load_time_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Time* OccupancyGrid_MapMetaInfo::_internal_mutable_map_load_time() {
  
  if (map_load_time_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Time>(GetArenaForAllocation());
    map_load_time_ = p;
  }
  return map_load_time_;
}
inline ::ignition::msgs::Time* OccupancyGrid_MapMetaInfo::mutable_map_load_time() {
  ::ignition::msgs::Time* _msg = _internal_mutable_map_load_time();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.OccupancyGrid.MapMetaInfo.map_load_time)
  return _msg;
}
inline void OccupancyGrid_MapMetaInfo::set_allocated_map_load_time(::ignition::msgs::Time* map_load_time) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(map_load_time_);
  }
  if (map_load_time) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(map_load_time));
    if (message_arena != submessage_arena) {
      map_load_time = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, map_load_time, submessage_arena);
    }
    
  } else {
    
  }
  map_load_time_ = map_load_time;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.OccupancyGrid.MapMetaInfo.map_load_time)
}

// double resolution = 2;
inline void OccupancyGrid_MapMetaInfo::clear_resolution() {
  resolution_ = 0;
}
inline double OccupancyGrid_MapMetaInfo::_internal_resolution() const {
  return resolution_;
}
inline double OccupancyGrid_MapMetaInfo::resolution() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.MapMetaInfo.resolution)
  return _internal_resolution();
}
inline void OccupancyGrid_MapMetaInfo::_internal_set_resolution(double value) {
  
  resolution_ = value;
}
inline void OccupancyGrid_MapMetaInfo::set_resolution(double value) {
  _internal_set_resolution(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.OccupancyGrid.MapMetaInfo.resolution)
}

// uint32 width = 3;
inline void OccupancyGrid_MapMetaInfo::clear_width() {
  width_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 OccupancyGrid_MapMetaInfo::_internal_width() const {
  return width_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 OccupancyGrid_MapMetaInfo::width() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.MapMetaInfo.width)
  return _internal_width();
}
inline void OccupancyGrid_MapMetaInfo::_internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  width_ = value;
}
inline void OccupancyGrid_MapMetaInfo::set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_width(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.OccupancyGrid.MapMetaInfo.width)
}

// uint32 height = 4;
inline void OccupancyGrid_MapMetaInfo::clear_height() {
  height_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 OccupancyGrid_MapMetaInfo::_internal_height() const {
  return height_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 OccupancyGrid_MapMetaInfo::height() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.MapMetaInfo.height)
  return _internal_height();
}
inline void OccupancyGrid_MapMetaInfo::_internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  height_ = value;
}
inline void OccupancyGrid_MapMetaInfo::set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_height(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.OccupancyGrid.MapMetaInfo.height)
}

// .ignition.msgs.Pose origin = 5;
inline bool OccupancyGrid_MapMetaInfo::_internal_has_origin() const {
  return this != internal_default_instance() && origin_ != nullptr;
}
inline bool OccupancyGrid_MapMetaInfo::has_origin() const {
  return _internal_has_origin();
}
inline const ::ignition::msgs::Pose& OccupancyGrid_MapMetaInfo::_internal_origin() const {
  const ::ignition::msgs::Pose* p = origin_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& OccupancyGrid_MapMetaInfo::origin() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.MapMetaInfo.origin)
  return _internal_origin();
}
inline void OccupancyGrid_MapMetaInfo::unsafe_arena_set_allocated_origin(
    ::ignition::msgs::Pose* origin) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(origin_);
  }
  origin_ = origin;
  if (origin) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.OccupancyGrid.MapMetaInfo.origin)
}
inline ::ignition::msgs::Pose* OccupancyGrid_MapMetaInfo::release_origin() {
  
  ::ignition::msgs::Pose* temp = origin_;
  origin_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* OccupancyGrid_MapMetaInfo::unsafe_arena_release_origin() {
  // @@protoc_insertion_point(field_release:ignition.msgs.OccupancyGrid.MapMetaInfo.origin)
  
  ::ignition::msgs::Pose* temp = origin_;
  origin_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* OccupancyGrid_MapMetaInfo::_internal_mutable_origin() {
  
  if (origin_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    origin_ = p;
  }
  return origin_;
}
inline ::ignition::msgs::Pose* OccupancyGrid_MapMetaInfo::mutable_origin() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_origin();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.OccupancyGrid.MapMetaInfo.origin)
  return _msg;
}
inline void OccupancyGrid_MapMetaInfo::set_allocated_origin(::ignition::msgs::Pose* origin) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(origin_);
  }
  if (origin) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(origin));
    if (message_arena != submessage_arena) {
      origin = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, origin, submessage_arena);
    }
    
  } else {
    
  }
  origin_ = origin;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.OccupancyGrid.MapMetaInfo.origin)
}

// -------------------------------------------------------------------

// OccupancyGrid

// .ignition.msgs.Header header = 1;
inline bool OccupancyGrid::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool OccupancyGrid::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& OccupancyGrid::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& OccupancyGrid::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.header)
  return _internal_header();
}
inline void OccupancyGrid::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.OccupancyGrid.header)
}
inline ::ignition::msgs::Header* OccupancyGrid::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* OccupancyGrid::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.OccupancyGrid.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* OccupancyGrid::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* OccupancyGrid::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.OccupancyGrid.header)
  return _msg;
}
inline void OccupancyGrid::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.OccupancyGrid.header)
}

// .ignition.msgs.OccupancyGrid.MapMetaInfo info = 2;
inline bool OccupancyGrid::_internal_has_info() const {
  return this != internal_default_instance() && info_ != nullptr;
}
inline bool OccupancyGrid::has_info() const {
  return _internal_has_info();
}
inline void OccupancyGrid::clear_info() {
  if (GetArenaForAllocation() == nullptr && info_ != nullptr) {
    delete info_;
  }
  info_ = nullptr;
}
inline const ::ignition::msgs::OccupancyGrid_MapMetaInfo& OccupancyGrid::_internal_info() const {
  const ::ignition::msgs::OccupancyGrid_MapMetaInfo* p = info_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::OccupancyGrid_MapMetaInfo&>(
      ::ignition::msgs::_OccupancyGrid_MapMetaInfo_default_instance_);
}
inline const ::ignition::msgs::OccupancyGrid_MapMetaInfo& OccupancyGrid::info() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.info)
  return _internal_info();
}
inline void OccupancyGrid::unsafe_arena_set_allocated_info(
    ::ignition::msgs::OccupancyGrid_MapMetaInfo* info) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(info_);
  }
  info_ = info;
  if (info) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.OccupancyGrid.info)
}
inline ::ignition::msgs::OccupancyGrid_MapMetaInfo* OccupancyGrid::release_info() {
  
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* temp = info_;
  info_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::OccupancyGrid_MapMetaInfo* OccupancyGrid::unsafe_arena_release_info() {
  // @@protoc_insertion_point(field_release:ignition.msgs.OccupancyGrid.info)
  
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* temp = info_;
  info_ = nullptr;
  return temp;
}
inline ::ignition::msgs::OccupancyGrid_MapMetaInfo* OccupancyGrid::_internal_mutable_info() {
  
  if (info_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::OccupancyGrid_MapMetaInfo>(GetArenaForAllocation());
    info_ = p;
  }
  return info_;
}
inline ::ignition::msgs::OccupancyGrid_MapMetaInfo* OccupancyGrid::mutable_info() {
  ::ignition::msgs::OccupancyGrid_MapMetaInfo* _msg = _internal_mutable_info();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.OccupancyGrid.info)
  return _msg;
}
inline void OccupancyGrid::set_allocated_info(::ignition::msgs::OccupancyGrid_MapMetaInfo* info) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete info_;
  }
  if (info) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::OccupancyGrid_MapMetaInfo>::GetOwningArena(info);
    if (message_arena != submessage_arena) {
      info = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, info, submessage_arena);
    }
    
  } else {
    
  }
  info_ = info;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.OccupancyGrid.info)
}

// bytes data = 3;
inline void OccupancyGrid::clear_data() {
  data_.ClearToEmpty();
}
inline const std::string& OccupancyGrid::data() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.OccupancyGrid.data)
  return _internal_data();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void OccupancyGrid::set_data(ArgT0&& arg0, ArgT... args) {
 
 data_.SetBytes(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.OccupancyGrid.data)
}
inline std::string* OccupancyGrid::mutable_data() {
  std::string* _s = _internal_mutable_data();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.OccupancyGrid.data)
  return _s;
}
inline const std::string& OccupancyGrid::_internal_data() const {
  return data_.Get();
}
inline void OccupancyGrid::_internal_set_data(const std::string& value) {
  
  data_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* OccupancyGrid::_internal_mutable_data() {
  
  return data_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* OccupancyGrid::release_data() {
  // @@protoc_insertion_point(field_release:ignition.msgs.OccupancyGrid.data)
  return data_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void OccupancyGrid::set_allocated_data(std::string* data) {
  if (data != nullptr) {
    
  } else {
    
  }
  data_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), data,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.OccupancyGrid.data)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


typedef std::unique_ptr<OccupancyGrid> OccupancyGridUniquePtr;
typedef std::unique_ptr<const OccupancyGrid> ConstOccupancyGridUniquePtr;
typedef std::shared_ptr<OccupancyGrid> OccupancyGridSharedPtr;
typedef std::shared_ptr<const OccupancyGrid> ConstOccupancyGridSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2foccupancy_5fgrid_2eproto
