# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/imu.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/quaternion_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/imu.proto", :syntax => :proto3) do
    add_message "ignition.msgs.IMU" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :entity_name, :string, 2
      optional :orientation, :message, 3, "ignition.msgs.Quaternion"
      optional :angular_velocity, :message, 4, "ignition.msgs.Vector3d"
      optional :linear_acceleration, :message, 5, "ignition.msgs.Vector3d"
    end
  end
end

module Ignition
  module Msgs
    IMU = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.IMU").msgclass
  end
end
