/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "PacketProtos";

/// \ingroup ignition.msgs
/// \interface Packet
/// \brief A message for a vector of string data
import "ignition/msgs/double_v.proto";
import "ignition/msgs/clock.proto";
import "ignition/msgs/cmd_vel2d.proto";
import "ignition/msgs/image.proto";
import "ignition/msgs/pose.proto";
import "ignition/msgs/pose_v.proto";
import "ignition/msgs/stringmsg_v.proto";
import "ignition/msgs/time.proto";
import "ignition/msgs/web_request.proto";
import "ignition/msgs/world_stats.proto";

message Packet
{
  string topic = 1;

  string type  = 2;

  oneof content
  {
    CmdVel2D cmd_vel2d = 3;
    Image image = 4;
    StringMsg_V string_msg_v = 5;
    WebRequest web_request = 6;
    Pose pose = 7;
    Double_V doublev = 8;
    Pose_V pose_v = 9;
    Time time = 10;
    Clock clock = 11;
    WorldStatistics world_stats = 12;
  }
}
