# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/sensor.proto

require 'ignition/msgs/altimeter_sensor_pb'
require 'ignition/msgs/camerasensor_pb'
require 'ignition/msgs/contactsensor_pb'
require 'ignition/msgs/air_pressure_sensor_pb'
require 'ignition/msgs/gps_sensor_pb'
require 'ignition/msgs/header_pb'
require 'ignition/msgs/imu_sensor_pb'
require 'ignition/msgs/lidar_sensor_pb'
require 'ignition/msgs/logical_camera_sensor_pb'
require 'ignition/msgs/magnetometer_sensor_pb'
require 'ignition/msgs/pose_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/sensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Sensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :parent, :string, 4
      optional :parent_id, :uint32, 5
      optional :type, :string, 6
      optional :always_on, :bool, 7
      optional :update_rate, :double, 8
      optional :pose, :message, 9, "ignition.msgs.Pose"
      optional :camera, :message, 10, "ignition.msgs.CameraSensor"
      optional :contact, :message, 11, "ignition.msgs.ContactSensor"
      optional :visualize, :bool, 12
      optional :topic, :string, 13
      optional :logical_camera, :message, 14, "ignition.msgs.LogicalCameraSensor"
      optional :gps, :message, 15, "ignition.msgs.GPSSensor"
      optional :imu, :message, 16, "ignition.msgs.IMUSensor"
      optional :magnetometer, :message, 17, "ignition.msgs.MagnetometerSensor"
      optional :altimeter, :message, 18, "ignition.msgs.AltimeterSensor"
      optional :air_pressure, :message, 19, "ignition.msgs.AirPressureSensor"
      optional :lidar, :message, 20, "ignition.msgs.LidarSensor"
    end
  end
end

module Ignition
  module Msgs
    Sensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Sensor").msgclass
  end
end
