/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "VersionedName";

/// \ingroup ignition.msgs
/// \interface Version.
/// \brief Version information that contains an associated name. This message
/// can be used to represent a versioned library, such as
/// "<library_name> 1.2.3".

import "ignition/msgs/version.proto";

message VersionedName
{
  /// \brief Version information.
  Version version = 1;

  /// \brief Name associated with the version.
  string name     = 2;
}
