# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/int32_v.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/int32_v.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Int32_V" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :data, :int32, 2
    end
  end
end

module Ignition
  module Msgs
    Int32_V = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Int32_V").msgclass
  end
end
