# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/marker.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/material_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/marker.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Marker" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :action, :enum, 2, "ignition.msgs.Marker.Action"
      optional :ns, :string, 3
      optional :id, :uint64, 4
      optional :layer, :int32, 5
      optional :type, :enum, 6, "ignition.msgs.Marker.Type"
      optional :lifetime, :message, 7, "ignition.msgs.Time"
      optional :pose, :message, 8, "ignition.msgs.Pose"
      optional :scale, :message, 9, "ignition.msgs.Vector3d"
      optional :material, :message, 10, "ignition.msgs.Material"
      repeated :point, :message, 11, "ignition.msgs.Vector3d"
      optional :text, :string, 12
      optional :parent, :string, 13
      optional :visibility, :enum, 14, "ignition.msgs.Marker.Visibility"
    end
    add_enum "ignition.msgs.Marker.Type" do
      value :NONE, 0
      value :BOX, 1
      value :CYLINDER, 2
      value :LINE_LIST, 4
      value :LINE_STRIP, 3
      value :POINTS, 5
      value :SPHERE, 6
      value :TEXT, 7
      value :TRIANGLE_FAN, 8
      value :TRIANGLE_LIST, 9
      value :TRIANGLE_STRIP, 10
      value :CONE, 11
      value :ARROW, 12
      value :AXIS, 13
    end
    add_enum "ignition.msgs.Marker.Visibility" do
      value :GUI, 0
      value :ALL, 1
    end
    add_enum "ignition.msgs.Marker.Action" do
      value :ADD_MODIFY, 0
      value :DELETE_MARKER, 1
      value :DELETE_ALL, 2
    end
  end
end

module Ignition
  module Msgs
    Marker = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Marker").msgclass
    Marker::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Marker.Type").enummodule
    Marker::Visibility = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Marker.Visibility").enummodule
    Marker::Action = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Marker.Action").enummodule
  end
end
