# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/gps_sensor.proto

require 'ignition/msgs/sensor_noise_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/gps_sensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.GPSSensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :position, :message, 2, "ignition.msgs.GPSSensor.Sensing"
      optional :velocity, :message, 3, "ignition.msgs.GPSSensor.Sensing"
    end
    add_message "ignition.msgs.GPSSensor.Sensing" do
      optional :horizontal_noise, :message, 1, "ignition.msgs.SensorNoise"
      optional :vertical_noise, :message, 2, "ignition.msgs.SensorNoise"
    end
  end
end

module Ignition
  module Msgs
    GPSSensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.GPSSensor").msgclass
    GPSSensor::Sensing = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.GPSSensor.Sensing").msgclass
  end
end
