// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/pose_animation.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5fanimation_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5fanimation_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/time.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fpose_5fanimation_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fpose_5fanimation_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fpose_5fanimation_2eproto;
namespace ignition {
namespace msgs {
class PoseAnimation;
struct PoseAnimationDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PoseAnimationDefaultTypeInternal _PoseAnimation_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::PoseAnimation* Arena::CreateMaybeMessage<::ignition::msgs::PoseAnimation>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE PoseAnimation final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.PoseAnimation) */ {
 public:
  inline PoseAnimation() : PoseAnimation(nullptr) {}
  ~PoseAnimation() override;
  explicit constexpr PoseAnimation(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PoseAnimation(const PoseAnimation& from);
  PoseAnimation(PoseAnimation&& from) noexcept
    : PoseAnimation() {
    *this = ::std::move(from);
  }

  inline PoseAnimation& operator=(const PoseAnimation& from) {
    CopyFrom(from);
    return *this;
  }
  inline PoseAnimation& operator=(PoseAnimation&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PoseAnimation& default_instance() {
    return *internal_default_instance();
  }
  static inline const PoseAnimation* internal_default_instance() {
    return reinterpret_cast<const PoseAnimation*>(
               &_PoseAnimation_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(PoseAnimation& a, PoseAnimation& b) {
    a.Swap(&b);
  }
  inline void Swap(PoseAnimation* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PoseAnimation* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline PoseAnimation* New() const final {
    return new PoseAnimation();
  }

  PoseAnimation* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<PoseAnimation>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PoseAnimation& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PoseAnimation& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PoseAnimation* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.PoseAnimation";
  }
  protected:
  explicit PoseAnimation(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPoseFieldNumber = 3,
    kTimeFieldNumber = 4,
    kModelNameFieldNumber = 1,
    kModelIdFieldNumber = 2,
  };
  // repeated .ignition.msgs.Pose pose = 3;
  int pose_size() const;
  private:
  int _internal_pose_size() const;
  public:
  void clear_pose();
  ::ignition::msgs::Pose* mutable_pose(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >*
      mutable_pose();
  private:
  const ::ignition::msgs::Pose& _internal_pose(int index) const;
  ::ignition::msgs::Pose* _internal_add_pose();
  public:
  const ::ignition::msgs::Pose& pose(int index) const;
  ::ignition::msgs::Pose* add_pose();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >&
      pose() const;

  // repeated .ignition.msgs.Time time = 4;
  int time_size() const;
  private:
  int _internal_time_size() const;
  public:
  void clear_time();
  ::ignition::msgs::Time* mutable_time(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Time >*
      mutable_time();
  private:
  const ::ignition::msgs::Time& _internal_time(int index) const;
  ::ignition::msgs::Time* _internal_add_time();
  public:
  const ::ignition::msgs::Time& time(int index) const;
  ::ignition::msgs::Time* add_time();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Time >&
      time() const;

  // string model_name = 1;
  void clear_model_name();
  const std::string& model_name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_model_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_model_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_model_name();
  void set_allocated_model_name(std::string* model_name);
  private:
  const std::string& _internal_model_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_model_name(const std::string& value);
  std::string* _internal_mutable_model_name();
  public:

  // uint32 model_id = 2;
  void clear_model_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 model_id() const;
  void set_model_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_model_id() const;
  void _internal_set_model_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.PoseAnimation)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose > pose_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Time > time_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr model_name_;
  ::PROTOBUF_NAMESPACE_ID::uint32 model_id_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fpose_5fanimation_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// PoseAnimation

// string model_name = 1;
inline void PoseAnimation::clear_model_name() {
  model_name_.ClearToEmpty();
}
inline const std::string& PoseAnimation::model_name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseAnimation.model_name)
  return _internal_model_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void PoseAnimation::set_model_name(ArgT0&& arg0, ArgT... args) {
 
 model_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.PoseAnimation.model_name)
}
inline std::string* PoseAnimation::mutable_model_name() {
  std::string* _s = _internal_mutable_model_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PoseAnimation.model_name)
  return _s;
}
inline const std::string& PoseAnimation::_internal_model_name() const {
  return model_name_.Get();
}
inline void PoseAnimation::_internal_set_model_name(const std::string& value) {
  
  model_name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* PoseAnimation::_internal_mutable_model_name() {
  
  return model_name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* PoseAnimation::release_model_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PoseAnimation.model_name)
  return model_name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void PoseAnimation::set_allocated_model_name(std::string* model_name) {
  if (model_name != nullptr) {
    
  } else {
    
  }
  model_name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), model_name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PoseAnimation.model_name)
}

// uint32 model_id = 2;
inline void PoseAnimation::clear_model_id() {
  model_id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PoseAnimation::_internal_model_id() const {
  return model_id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PoseAnimation::model_id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseAnimation.model_id)
  return _internal_model_id();
}
inline void PoseAnimation::_internal_set_model_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  model_id_ = value;
}
inline void PoseAnimation::set_model_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_model_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PoseAnimation.model_id)
}

// repeated .ignition.msgs.Pose pose = 3;
inline int PoseAnimation::_internal_pose_size() const {
  return pose_.size();
}
inline int PoseAnimation::pose_size() const {
  return _internal_pose_size();
}
inline ::ignition::msgs::Pose* PoseAnimation::mutable_pose(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PoseAnimation.pose)
  return pose_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >*
PoseAnimation::mutable_pose() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.PoseAnimation.pose)
  return &pose_;
}
inline const ::ignition::msgs::Pose& PoseAnimation::_internal_pose(int index) const {
  return pose_.Get(index);
}
inline const ::ignition::msgs::Pose& PoseAnimation::pose(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseAnimation.pose)
  return _internal_pose(index);
}
inline ::ignition::msgs::Pose* PoseAnimation::_internal_add_pose() {
  return pose_.Add();
}
inline ::ignition::msgs::Pose* PoseAnimation::add_pose() {
  ::ignition::msgs::Pose* _add = _internal_add_pose();
  // @@protoc_insertion_point(field_add:ignition.msgs.PoseAnimation.pose)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Pose >&
PoseAnimation::pose() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.PoseAnimation.pose)
  return pose_;
}

// repeated .ignition.msgs.Time time = 4;
inline int PoseAnimation::_internal_time_size() const {
  return time_.size();
}
inline int PoseAnimation::time_size() const {
  return _internal_time_size();
}
inline ::ignition::msgs::Time* PoseAnimation::mutable_time(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PoseAnimation.time)
  return time_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Time >*
PoseAnimation::mutable_time() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.PoseAnimation.time)
  return &time_;
}
inline const ::ignition::msgs::Time& PoseAnimation::_internal_time(int index) const {
  return time_.Get(index);
}
inline const ::ignition::msgs::Time& PoseAnimation::time(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PoseAnimation.time)
  return _internal_time(index);
}
inline ::ignition::msgs::Time* PoseAnimation::_internal_add_time() {
  return time_.Add();
}
inline ::ignition::msgs::Time* PoseAnimation::add_time() {
  ::ignition::msgs::Time* _add = _internal_add_time();
  // @@protoc_insertion_point(field_add:ignition.msgs.PoseAnimation.time)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Time >&
PoseAnimation::time() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.PoseAnimation.time)
  return time_;
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<PoseAnimation> PoseAnimationUniquePtr;
typedef std::unique_ptr<const PoseAnimation> ConstPoseAnimationUniquePtr;
typedef std::shared_ptr<PoseAnimation> PoseAnimationSharedPtr;
typedef std::shared_ptr<const PoseAnimation> ConstPoseAnimationSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpose_5fanimation_2eproto
