/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "EmptyProtos";

/// \ingroup ignition.msgs
/// \interface Any
/// \brief A message that is capable of containing a wide variety of data types.

import "ignition/msgs/header.proto";
import "ignition/msgs/color.proto";
import "ignition/msgs/pose.proto";
import "ignition/msgs/quaternion.proto";
import "ignition/msgs/time.proto";
import "ignition/msgs/vector3d.proto";

message Any
{
  /// \brief The type of data the message contains.
  enum ValueType
  {
    /// \brief Indicates that the message is empty
    NONE        = 0;

    /// \brief Indicates that the message contains a double
    DOUBLE      = 1;

    /// \brief Indicates that the message contains an int32
    INT32       = 2;

    /// \brief Indicates that the message contains a string
    STRING      = 3;

    /// \brief Indicates that the message contains a Boolean
    BOOLEAN     = 4;

    /// \brief Indicates that the message contains a Vector3d
    VECTOR3D    = 5;

    /// \brief Indicates that the message contains a Color
    COLOR       = 6;

    /// \brief Indicates that the message contains a Pose
    POSE3D      = 7;

    /// \brief Indicates that the message contains a Quaternion
    QUATERNIOND = 8;

    /// \brief Indicates that the message contains a Time
    TIME        = 9;
  }

  /// \brief Optional header data
  Header header               = 1;

  /// \brief Type of value that is contained in this message.
  ValueType type              = 2;

  oneof value {
    /// \brief A double value
    double double_value         = 3;

    /// \brief An int32 value
    int32 int_value             = 4;

    /// \brief A string value
    string string_value         = 5;

    /// \brief A boolean value
    bool bool_value             = 6;

    /// \brief A Vector3d value
    Vector3d vector3d_value     = 7;

    /// \brief A Color value
    Color color_value           = 8;

    /// \brief A Pose value
    Pose pose3d_value           = 9;

    /// \brief A Quaternion value
    Quaternion quaternion_value = 10;

    /// \brief A Time value
    Time time_value             = 11;
  }
}
