// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/serialized_map.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_5fmap_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_5fmap_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/map.h>  // IWYU pragma: export
#include <google/protobuf/map_entry.h>
#include <google/protobuf/map_field_inl.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/world_stats.pb.h"
#include "ignition/msgs/serialized.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fserialized_5fmap_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fserialized_5fmap_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[5]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fserialized_5fmap_2eproto;
namespace ignition {
namespace msgs {
class SerializedEntityMap;
struct SerializedEntityMapDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedEntityMapDefaultTypeInternal _SerializedEntityMap_default_instance_;
class SerializedEntityMap_ComponentsEntry_DoNotUse;
struct SerializedEntityMap_ComponentsEntry_DoNotUseDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedEntityMap_ComponentsEntry_DoNotUseDefaultTypeInternal _SerializedEntityMap_ComponentsEntry_DoNotUse_default_instance_;
class SerializedStateMap;
struct SerializedStateMapDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedStateMapDefaultTypeInternal _SerializedStateMap_default_instance_;
class SerializedStateMap_EntitiesEntry_DoNotUse;
struct SerializedStateMap_EntitiesEntry_DoNotUseDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedStateMap_EntitiesEntry_DoNotUseDefaultTypeInternal _SerializedStateMap_EntitiesEntry_DoNotUse_default_instance_;
class SerializedStepMap;
struct SerializedStepMapDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedStepMapDefaultTypeInternal _SerializedStepMap_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedEntityMap* Arena::CreateMaybeMessage<::ignition::msgs::SerializedEntityMap>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedEntityMap_ComponentsEntry_DoNotUse* Arena::CreateMaybeMessage<::ignition::msgs::SerializedEntityMap_ComponentsEntry_DoNotUse>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedStateMap* Arena::CreateMaybeMessage<::ignition::msgs::SerializedStateMap>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedStateMap_EntitiesEntry_DoNotUse* Arena::CreateMaybeMessage<::ignition::msgs::SerializedStateMap_EntitiesEntry_DoNotUse>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedStepMap* Arena::CreateMaybeMessage<::ignition::msgs::SerializedStepMap>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class SerializedEntityMap_ComponentsEntry_DoNotUse : public ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SerializedEntityMap_ComponentsEntry_DoNotUse, 
    ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_INT64,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> {
public:
  typedef ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SerializedEntityMap_ComponentsEntry_DoNotUse, 
    ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_INT64,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> SuperType;
  SerializedEntityMap_ComponentsEntry_DoNotUse();
  explicit constexpr SerializedEntityMap_ComponentsEntry_DoNotUse(
      ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);
  explicit SerializedEntityMap_ComponentsEntry_DoNotUse(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  void MergeFrom(const SerializedEntityMap_ComponentsEntry_DoNotUse& other);
  static const SerializedEntityMap_ComponentsEntry_DoNotUse* internal_default_instance() { return reinterpret_cast<const SerializedEntityMap_ComponentsEntry_DoNotUse*>(&_SerializedEntityMap_ComponentsEntry_DoNotUse_default_instance_); }
  static bool ValidateKey(void*) { return true; }
  static bool ValidateValue(void*) { return true; }
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
};

// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedEntityMap final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedEntityMap) */ {
 public:
  inline SerializedEntityMap() : SerializedEntityMap(nullptr) {}
  ~SerializedEntityMap() override;
  explicit constexpr SerializedEntityMap(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedEntityMap(const SerializedEntityMap& from);
  SerializedEntityMap(SerializedEntityMap&& from) noexcept
    : SerializedEntityMap() {
    *this = ::std::move(from);
  }

  inline SerializedEntityMap& operator=(const SerializedEntityMap& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedEntityMap& operator=(SerializedEntityMap&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedEntityMap& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedEntityMap* internal_default_instance() {
    return reinterpret_cast<const SerializedEntityMap*>(
               &_SerializedEntityMap_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(SerializedEntityMap& a, SerializedEntityMap& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedEntityMap* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedEntityMap* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedEntityMap* New() const final {
    return new SerializedEntityMap();
  }

  SerializedEntityMap* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedEntityMap>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedEntityMap& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedEntityMap& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedEntityMap* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedEntityMap";
  }
  protected:
  explicit SerializedEntityMap(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------


  // accessors -------------------------------------------------------

  enum : int {
    kComponentsFieldNumber = 2,
    kIdFieldNumber = 1,
    kRemoveFieldNumber = 3,
  };
  // map<int64, .ignition.msgs.SerializedComponent> components = 2;
  int components_size() const;
  private:
  int _internal_components_size() const;
  public:
  void clear_components();
  private:
  const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >&
      _internal_components() const;
  ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >*
      _internal_mutable_components();
  public:
  const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >&
      components() const;
  ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >*
      mutable_components();

  // uint64 id = 1;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint64 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint64 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  public:

  // bool remove = 3;
  void clear_remove();
  bool remove() const;
  void set_remove(bool value);
  private:
  bool _internal_remove() const;
  void _internal_set_remove(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedEntityMap)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::MapField<
      SerializedEntityMap_ComponentsEntry_DoNotUse,
      ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_INT64,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> components_;
  ::PROTOBUF_NAMESPACE_ID::uint64 id_;
  bool remove_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_5fmap_2eproto;
};
// -------------------------------------------------------------------

class SerializedStateMap_EntitiesEntry_DoNotUse : public ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SerializedStateMap_EntitiesEntry_DoNotUse, 
    ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_UINT64,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> {
public:
  typedef ::PROTOBUF_NAMESPACE_ID::internal::MapEntry<SerializedStateMap_EntitiesEntry_DoNotUse, 
    ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_UINT64,
    ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> SuperType;
  SerializedStateMap_EntitiesEntry_DoNotUse();
  explicit constexpr SerializedStateMap_EntitiesEntry_DoNotUse(
      ::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);
  explicit SerializedStateMap_EntitiesEntry_DoNotUse(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  void MergeFrom(const SerializedStateMap_EntitiesEntry_DoNotUse& other);
  static const SerializedStateMap_EntitiesEntry_DoNotUse* internal_default_instance() { return reinterpret_cast<const SerializedStateMap_EntitiesEntry_DoNotUse*>(&_SerializedStateMap_EntitiesEntry_DoNotUse_default_instance_); }
  static bool ValidateKey(void*) { return true; }
  static bool ValidateValue(void*) { return true; }
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;
};

// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedStateMap final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedStateMap) */ {
 public:
  inline SerializedStateMap() : SerializedStateMap(nullptr) {}
  ~SerializedStateMap() override;
  explicit constexpr SerializedStateMap(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedStateMap(const SerializedStateMap& from);
  SerializedStateMap(SerializedStateMap&& from) noexcept
    : SerializedStateMap() {
    *this = ::std::move(from);
  }

  inline SerializedStateMap& operator=(const SerializedStateMap& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedStateMap& operator=(SerializedStateMap&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedStateMap& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedStateMap* internal_default_instance() {
    return reinterpret_cast<const SerializedStateMap*>(
               &_SerializedStateMap_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    3;

  friend void swap(SerializedStateMap& a, SerializedStateMap& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedStateMap* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedStateMap* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedStateMap* New() const final {
    return new SerializedStateMap();
  }

  SerializedStateMap* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedStateMap>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedStateMap& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedStateMap& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedStateMap* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedStateMap";
  }
  protected:
  explicit SerializedStateMap(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------


  // accessors -------------------------------------------------------

  enum : int {
    kEntitiesFieldNumber = 2,
    kHeaderFieldNumber = 1,
  };
  // map<uint64, .ignition.msgs.SerializedEntityMap> entities = 2;
  int entities_size() const;
  private:
  int _internal_entities_size() const;
  public:
  void clear_entities();
  private:
  const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >&
      _internal_entities() const;
  ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >*
      _internal_mutable_entities();
  public:
  const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >&
      entities() const;
  ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >*
      mutable_entities();

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedStateMap)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::MapField<
      SerializedStateMap_EntitiesEntry_DoNotUse,
      ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_UINT64,
      ::PROTOBUF_NAMESPACE_ID::internal::WireFormatLite::TYPE_MESSAGE> entities_;
  ::ignition::msgs::Header* header_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_5fmap_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedStepMap final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedStepMap) */ {
 public:
  inline SerializedStepMap() : SerializedStepMap(nullptr) {}
  ~SerializedStepMap() override;
  explicit constexpr SerializedStepMap(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedStepMap(const SerializedStepMap& from);
  SerializedStepMap(SerializedStepMap&& from) noexcept
    : SerializedStepMap() {
    *this = ::std::move(from);
  }

  inline SerializedStepMap& operator=(const SerializedStepMap& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedStepMap& operator=(SerializedStepMap&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedStepMap& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedStepMap* internal_default_instance() {
    return reinterpret_cast<const SerializedStepMap*>(
               &_SerializedStepMap_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    4;

  friend void swap(SerializedStepMap& a, SerializedStepMap& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedStepMap* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedStepMap* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedStepMap* New() const final {
    return new SerializedStepMap();
  }

  SerializedStepMap* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedStepMap>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedStepMap& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedStepMap& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedStepMap* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedStepMap";
  }
  protected:
  explicit SerializedStepMap(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kStatsFieldNumber = 1,
    kStateFieldNumber = 2,
  };
  // .ignition.msgs.WorldStatistics stats = 1;
  bool has_stats() const;
  private:
  bool _internal_has_stats() const;
  public:
  void clear_stats();
  const ::ignition::msgs::WorldStatistics& stats() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::WorldStatistics* release_stats();
  ::ignition::msgs::WorldStatistics* mutable_stats();
  void set_allocated_stats(::ignition::msgs::WorldStatistics* stats);
  private:
  const ::ignition::msgs::WorldStatistics& _internal_stats() const;
  ::ignition::msgs::WorldStatistics* _internal_mutable_stats();
  public:
  void unsafe_arena_set_allocated_stats(
      ::ignition::msgs::WorldStatistics* stats);
  ::ignition::msgs::WorldStatistics* unsafe_arena_release_stats();

  // .ignition.msgs.SerializedStateMap state = 2;
  bool has_state() const;
  private:
  bool _internal_has_state() const;
  public:
  void clear_state();
  const ::ignition::msgs::SerializedStateMap& state() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::SerializedStateMap* release_state();
  ::ignition::msgs::SerializedStateMap* mutable_state();
  void set_allocated_state(::ignition::msgs::SerializedStateMap* state);
  private:
  const ::ignition::msgs::SerializedStateMap& _internal_state() const;
  ::ignition::msgs::SerializedStateMap* _internal_mutable_state();
  public:
  void unsafe_arena_set_allocated_state(
      ::ignition::msgs::SerializedStateMap* state);
  ::ignition::msgs::SerializedStateMap* unsafe_arena_release_state();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedStepMap)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::WorldStatistics* stats_;
  ::ignition::msgs::SerializedStateMap* state_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_5fmap_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// SerializedEntityMap

// uint64 id = 1;
inline void SerializedEntityMap::clear_id() {
  id_ = uint64_t{0u};
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedEntityMap::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedEntityMap::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedEntityMap.id)
  return _internal_id();
}
inline void SerializedEntityMap::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  
  id_ = value;
}
inline void SerializedEntityMap::set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedEntityMap.id)
}

// map<int64, .ignition.msgs.SerializedComponent> components = 2;
inline int SerializedEntityMap::_internal_components_size() const {
  return components_.size();
}
inline int SerializedEntityMap::components_size() const {
  return _internal_components_size();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >&
SerializedEntityMap::_internal_components() const {
  return components_.GetMap();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >&
SerializedEntityMap::components() const {
  // @@protoc_insertion_point(field_map:ignition.msgs.SerializedEntityMap.components)
  return _internal_components();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >*
SerializedEntityMap::_internal_mutable_components() {
  return components_.MutableMap();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::int64, ::ignition::msgs::SerializedComponent >*
SerializedEntityMap::mutable_components() {
  // @@protoc_insertion_point(field_mutable_map:ignition.msgs.SerializedEntityMap.components)
  return _internal_mutable_components();
}

// bool remove = 3;
inline void SerializedEntityMap::clear_remove() {
  remove_ = false;
}
inline bool SerializedEntityMap::_internal_remove() const {
  return remove_;
}
inline bool SerializedEntityMap::remove() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedEntityMap.remove)
  return _internal_remove();
}
inline void SerializedEntityMap::_internal_set_remove(bool value) {
  
  remove_ = value;
}
inline void SerializedEntityMap::set_remove(bool value) {
  _internal_set_remove(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedEntityMap.remove)
}

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// SerializedStateMap

// .ignition.msgs.Header header = 1;
inline bool SerializedStateMap::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool SerializedStateMap::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& SerializedStateMap::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& SerializedStateMap::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedStateMap.header)
  return _internal_header();
}
inline void SerializedStateMap::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedStateMap.header)
}
inline ::ignition::msgs::Header* SerializedStateMap::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* SerializedStateMap::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedStateMap.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* SerializedStateMap::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* SerializedStateMap::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedStateMap.header)
  return _msg;
}
inline void SerializedStateMap::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedStateMap.header)
}

// map<uint64, .ignition.msgs.SerializedEntityMap> entities = 2;
inline int SerializedStateMap::_internal_entities_size() const {
  return entities_.size();
}
inline int SerializedStateMap::entities_size() const {
  return _internal_entities_size();
}
inline void SerializedStateMap::clear_entities() {
  entities_.Clear();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >&
SerializedStateMap::_internal_entities() const {
  return entities_.GetMap();
}
inline const ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >&
SerializedStateMap::entities() const {
  // @@protoc_insertion_point(field_map:ignition.msgs.SerializedStateMap.entities)
  return _internal_entities();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >*
SerializedStateMap::_internal_mutable_entities() {
  return entities_.MutableMap();
}
inline ::PROTOBUF_NAMESPACE_ID::Map< ::PROTOBUF_NAMESPACE_ID::uint64, ::ignition::msgs::SerializedEntityMap >*
SerializedStateMap::mutable_entities() {
  // @@protoc_insertion_point(field_mutable_map:ignition.msgs.SerializedStateMap.entities)
  return _internal_mutable_entities();
}

// -------------------------------------------------------------------

// SerializedStepMap

// .ignition.msgs.WorldStatistics stats = 1;
inline bool SerializedStepMap::_internal_has_stats() const {
  return this != internal_default_instance() && stats_ != nullptr;
}
inline bool SerializedStepMap::has_stats() const {
  return _internal_has_stats();
}
inline const ::ignition::msgs::WorldStatistics& SerializedStepMap::_internal_stats() const {
  const ::ignition::msgs::WorldStatistics* p = stats_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::WorldStatistics&>(
      ::ignition::msgs::_WorldStatistics_default_instance_);
}
inline const ::ignition::msgs::WorldStatistics& SerializedStepMap::stats() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedStepMap.stats)
  return _internal_stats();
}
inline void SerializedStepMap::unsafe_arena_set_allocated_stats(
    ::ignition::msgs::WorldStatistics* stats) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats_);
  }
  stats_ = stats;
  if (stats) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedStepMap.stats)
}
inline ::ignition::msgs::WorldStatistics* SerializedStepMap::release_stats() {
  
  ::ignition::msgs::WorldStatistics* temp = stats_;
  stats_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::WorldStatistics* SerializedStepMap::unsafe_arena_release_stats() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedStepMap.stats)
  
  ::ignition::msgs::WorldStatistics* temp = stats_;
  stats_ = nullptr;
  return temp;
}
inline ::ignition::msgs::WorldStatistics* SerializedStepMap::_internal_mutable_stats() {
  
  if (stats_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::WorldStatistics>(GetArenaForAllocation());
    stats_ = p;
  }
  return stats_;
}
inline ::ignition::msgs::WorldStatistics* SerializedStepMap::mutable_stats() {
  ::ignition::msgs::WorldStatistics* _msg = _internal_mutable_stats();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedStepMap.stats)
  return _msg;
}
inline void SerializedStepMap::set_allocated_stats(::ignition::msgs::WorldStatistics* stats) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats_);
  }
  if (stats) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats));
    if (message_arena != submessage_arena) {
      stats = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, stats, submessage_arena);
    }
    
  } else {
    
  }
  stats_ = stats;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedStepMap.stats)
}

// .ignition.msgs.SerializedStateMap state = 2;
inline bool SerializedStepMap::_internal_has_state() const {
  return this != internal_default_instance() && state_ != nullptr;
}
inline bool SerializedStepMap::has_state() const {
  return _internal_has_state();
}
inline void SerializedStepMap::clear_state() {
  if (GetArenaForAllocation() == nullptr && state_ != nullptr) {
    delete state_;
  }
  state_ = nullptr;
}
inline const ::ignition::msgs::SerializedStateMap& SerializedStepMap::_internal_state() const {
  const ::ignition::msgs::SerializedStateMap* p = state_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::SerializedStateMap&>(
      ::ignition::msgs::_SerializedStateMap_default_instance_);
}
inline const ::ignition::msgs::SerializedStateMap& SerializedStepMap::state() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedStepMap.state)
  return _internal_state();
}
inline void SerializedStepMap::unsafe_arena_set_allocated_state(
    ::ignition::msgs::SerializedStateMap* state) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(state_);
  }
  state_ = state;
  if (state) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedStepMap.state)
}
inline ::ignition::msgs::SerializedStateMap* SerializedStepMap::release_state() {
  
  ::ignition::msgs::SerializedStateMap* temp = state_;
  state_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::SerializedStateMap* SerializedStepMap::unsafe_arena_release_state() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedStepMap.state)
  
  ::ignition::msgs::SerializedStateMap* temp = state_;
  state_ = nullptr;
  return temp;
}
inline ::ignition::msgs::SerializedStateMap* SerializedStepMap::_internal_mutable_state() {
  
  if (state_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::SerializedStateMap>(GetArenaForAllocation());
    state_ = p;
  }
  return state_;
}
inline ::ignition::msgs::SerializedStateMap* SerializedStepMap::mutable_state() {
  ::ignition::msgs::SerializedStateMap* _msg = _internal_mutable_state();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedStepMap.state)
  return _msg;
}
inline void SerializedStepMap::set_allocated_state(::ignition::msgs::SerializedStateMap* state) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete state_;
  }
  if (state) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::SerializedStateMap>::GetOwningArena(state);
    if (message_arena != submessage_arena) {
      state = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, state, submessage_arena);
    }
    
  } else {
    
  }
  state_ = state;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedStepMap.state)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<SerializedEntityMap> SerializedEntityMapUniquePtr;
typedef std::unique_ptr<const SerializedEntityMap> ConstSerializedEntityMapUniquePtr;
typedef std::shared_ptr<SerializedEntityMap> SerializedEntityMapSharedPtr;
typedef std::shared_ptr<const SerializedEntityMap> ConstSerializedEntityMapSharedPtr;
typedef std::unique_ptr<SerializedStateMap> SerializedStateMapUniquePtr;
typedef std::unique_ptr<const SerializedStateMap> ConstSerializedStateMapUniquePtr;
typedef std::shared_ptr<SerializedStateMap> SerializedStateMapSharedPtr;
typedef std::shared_ptr<const SerializedStateMap> ConstSerializedStateMapSharedPtr;
typedef std::unique_ptr<SerializedStepMap> SerializedStepMapUniquePtr;
typedef std::unique_ptr<const SerializedStepMap> ConstSerializedStepMapUniquePtr;
typedef std::shared_ptr<SerializedStepMap> SerializedStepMapSharedPtr;
typedef std::shared_ptr<const SerializedStepMap> ConstSerializedStepMapSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_5fmap_2eproto
