# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/spherical_coordinates.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/spherical_coordinates.proto", :syntax => :proto3) do
    add_message "ignition.msgs.SphericalCoordinates" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :surface_model, :enum, 2, "ignition.msgs.SphericalCoordinates.SurfaceModel"
      optional :latitude_deg, :double, 3
      optional :longitude_deg, :double, 4
      optional :elevation, :double, 5
      optional :heading_deg, :double, 6
    end
    add_enum "ignition.msgs.SphericalCoordinates.SurfaceModel" do
      value :EARTH_WGS84, 0
    end
  end
end

module Ignition
  module Msgs
    SphericalCoordinates = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SphericalCoordinates").msgclass
    SphericalCoordinates::SurfaceModel = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SphericalCoordinates.SurfaceModel").enummodule
  end
end
