# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/axis.proto

require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/axis.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Axis" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :xyz, :message, 2, "ignition.msgs.Vector3d"
      optional :limit_lower, :double, 3
      optional :limit_upper, :double, 4
      optional :limit_effort, :double, 5
      optional :limit_velocity, :double, 6
      optional :damping, :double, 7
      optional :friction, :double, 8
      optional :use_parent_model_frame, :bool, 9
      optional :position, :double, 10
      optional :velocity, :double, 11
      optional :force, :double, 12
      optional :acceleration, :double, 13
      optional :xyz_expressed_in, :string, 14
    end
  end
end

module Ignition
  module Msgs
    Axis = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Axis").msgclass
  end
end
