/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "PIDProtos";

/// \ingroup ignition.msgs
/// \interface PID 
/// \brief Message for simple PID controllers

import "ignition/msgs/double.proto";
import "ignition/msgs/header.proto";

message PID
{
  /// \brief Optional header data
  Header header = 1;

  double target = 2[deprecated = true];
  double p_gain = 3[deprecated = true];
  double i_gain = 4[deprecated = true];
  double d_gain = 5[deprecated = true];
  double i_max  = 6[deprecated = true];
  double i_min  = 7[deprecated = true];
  double limit  = 8[deprecated = true];
  Double target_optional = 9;
  Double p_gain_optional = 10;
  Double i_gain_optional = 11;
  Double d_gain_optional = 12;
  Double i_max_optional  = 13;
  Double i_min_optional  = 14;
  Double limit_optional  = 15;
}
