# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/rest_response.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/rest_response.proto", :syntax => :proto3) do
    add_message "ignition.msgs.RestResponse" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :id, :uint32, 2
      optional :type, :enum, 3, "ignition.msgs.RestResponse.Type"
      optional :msg, :string, 4
    end
    add_enum "ignition.msgs.RestResponse.Type" do
      value :SUCCESS, 0
      value :ERR, 1
      value :LOGIN, 2
      value :LOGOUT, 3
    end
  end
end

module Ignition
  module Msgs
    RestResponse = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.RestResponse").msgclass
    RestResponse::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.RestResponse.Type").enummodule
  end
end
