# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/physics.proto

require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/physics.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Physics" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Physics.Type"
      optional :solver_type, :string, 3
      optional :min_step_size, :double, 4
      optional :precon_iters, :int32, 5
      optional :iters, :int32, 6
      optional :sor, :double, 7
      optional :cfm, :double, 8
      optional :erp, :double, 9
      optional :contact_max_correcting_vel, :double, 10
      optional :contact_surface_layer, :double, 11
      optional :gravity, :message, 12, "ignition.msgs.Vector3d"
      optional :enable_physics, :bool, 13
      optional :real_time_factor, :double, 14
      optional :real_time_update_rate, :double, 15
      optional :max_step_size, :double, 16
      optional :profile_name, :string, 17
      optional :magnetic_field, :message, 18, "ignition.msgs.Vector3d"
    end
    add_enum "ignition.msgs.Physics.Type" do
      value :ODE, 0
      value :BULLET, 1
      value :SIMBODY, 2
      value :DART, 3
    end
  end
end

module Ignition
  module Msgs
    Physics = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Physics").msgclass
    Physics::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Physics.Type").enummodule
  end
end
