/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "CessnaProtos";

/// \ingroup ignition.msgs
/// \interface Cessna
/// \brief Cessna message

import "ignition/msgs/header.proto";

message Cessna
{
  /// \brief Optional header data
  Header header = 1;

  /// \brief Current RPM of the propeller.
  float propeller_speed = 2;

  /// \brief Current left aileron angle in rads.
  float left_aileron = 3;

  /// \brief Current left flap angle in rads.
  float left_flap = 4;

  /// \brief Current right aileron angle in rads.
  float right_aileron = 5;

  /// \brief Current right flap angle in rads.
  float right_flap = 6;

  /// \brief Current elevators angle in rads.
  float elevators = 7;

  /// \brief Current ruddle angle in rads.
  float rudder = 8;

  /// \brief Target RPM of the propeller.
  float cmd_propeller_speed = 9;

  /// \brief Target left aileron angle in rads.
  float cmd_left_aileron = 10;

  /// \brief Target left flap angle in rads.
  float cmd_left_flap = 11;

  /// \brief Target right aileron angle in rads.
  float cmd_right_aileron = 12;

  /// \brief Target right flap angle in rads.
  float cmd_right_flap = 13;

  /// \brief Target elevators angle in rads.
  float cmd_elevators = 14;

  /// \brief Target ruddle angle in rads.
  float cmd_rudder = 15;
}
