/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "ModelProtos";

/// \ingroup ignition.msgs
/// \interface Model
/// \brief Information about a model

import "ignition/msgs/axis_aligned_box.proto";
import "ignition/msgs/joint.proto";
import "ignition/msgs/link.proto";
import "ignition/msgs/pose.proto";
import "ignition/msgs/visual.proto";
import "ignition/msgs/vector3d.proto";
import "ignition/msgs/header.proto";

message Model
{
  /// \brief Optional header data
  Header header       = 1;

  /// \brief Name of the model.
  string name         = 2;

  /// \brief Unique ID associated with the model
  uint32 id           = 3;

  /// \brief True if the model is statc.
  bool is_static      = 4;

  /// \brief Pose of the model.
  Pose pose           = 5;

  /// \brief Information about the joints in this model.
  repeated Joint joint         = 6;

  /// \brief Information about the links in this model.
  repeated Link link           = 7;

  /// \brief True if the model was deleted.
  bool deleted        = 8;

  /// \brief Information about the visuals in this model.
  repeated Visual visual       = 9;

  /// \brief Scaling factor applied to the model
  Vector3d scale      = 10;

  /// \brief True if self collide is enabled.
  bool self_collide   = 11;

  /// \brief An array of nested models.
  repeated Model model         = 12;

  /// \brief Axis aligned bounding box for the model. The center of the 
  /// bounding box should coincide with the model's pose.
  AxisAlignedBox bounding_box   = 13;
}
