/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "FluidPressureProtos";

/// \ingroup ignition.msgs
/// \interface Fluid pressure
/// \brief Data from a pressure sensor. The data in message is suitable for
/// fluids, and not force/pressure contact sensors.

import "ignition/msgs/header.proto";

/// \brief Fluid pressure data.
message FluidPressure
{
  // Other Optional header data
  Header header             = 1; 

  /// \brief Pressure reading in Pascals
  double pressure           = 2;

  /// \brief Pressure variance. 0 is interpreted as variance unknown. 
  double variance  = 3;
}
