# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/joint.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/axis_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/sensor_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/joint.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Joint" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :id, :uint32, 3
      optional :type, :enum, 4, "ignition.msgs.Joint.Type"
      optional :parent, :string, 5
      optional :parent_id, :uint32, 6
      optional :child, :string, 7
      optional :child_id, :uint32, 8
      optional :pose, :message, 9, "ignition.msgs.Pose"
      optional :axis1, :message, 10, "ignition.msgs.Axis"
      optional :axis2, :message, 11, "ignition.msgs.Axis"
      optional :cfm, :double, 12
      optional :bounce, :double, 13
      optional :fudge_factor, :double, 14
      optional :limit_cfm, :double, 15
      optional :limit_erp, :double, 16
      optional :suspension_cfm, :double, 17
      optional :suspension_erp, :double, 18
      optional :gearbox, :message, 19, "ignition.msgs.Joint.Gearbox"
      optional :screw, :message, 20, "ignition.msgs.Joint.Screw"
      repeated :sensor, :message, 21, "ignition.msgs.Sensor"
    end
    add_message "ignition.msgs.Joint.Gearbox" do
      optional :gearbox_reference_body, :string, 1
      optional :gearbox_ratio, :double, 2
    end
    add_message "ignition.msgs.Joint.Screw" do
      optional :thread_pitch, :double, 1
    end
    add_enum "ignition.msgs.Joint.Type" do
      value :REVOLUTE, 0
      value :REVOLUTE2, 1
      value :PRISMATIC, 2
      value :UNIVERSAL, 3
      value :BALL, 4
      value :SCREW, 5
      value :GEARBOX, 6
      value :FIXED, 7
    end
  end
end

module Ignition
  module Msgs
    Joint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Joint").msgclass
    Joint::Gearbox = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Joint.Gearbox").msgclass
    Joint::Screw = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Joint.Screw").msgclass
    Joint::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Joint.Type").enummodule
  end
end
