# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/battery_state.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/battery_state.proto", :syntax => :proto3) do
    add_message "ignition.msgs.BatteryState" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :voltage, :double, 2
      optional :current, :double, 3
      optional :charge, :double, 4
      optional :capacity, :double, 5
      optional :percentage, :double, 6
      optional :power_supply_status, :enum, 7, "ignition.msgs.BatteryState.PowerSupplyStatus"
    end
    add_enum "ignition.msgs.BatteryState.PowerSupplyStatus" do
      value :UNKNOWN, 0
      value :CHARGING, 1
      value :DISCHARGING, 2
      value :NOT_CHARGING, 3
      value :FULL, 4
    end
  end
end

module Ignition
  module Msgs
    BatteryState = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.BatteryState").msgclass
    BatteryState::PowerSupplyStatus = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.BatteryState.PowerSupplyStatus").enummodule
  end
end
