# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/double_v.proto

require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/double_v.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Double_V" do
      repeated :data, :double, 1
    end
  end
end

module Ignition
  module Msgs
    Double_V = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Double_V").msgclass
  end
end
