# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/hydra.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/hydra.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Hydra" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :right, :message, 2, "ignition.msgs.Hydra.Paddle"
      optional :left, :message, 3, "ignition.msgs.Hydra.Paddle"
    end
    add_message "ignition.msgs.Hydra.Paddle" do
      optional :pose, :message, 1, "ignition.msgs.Pose"
      optional :button_bumper, :bool, 2
      optional :button_1, :bool, 3
      optional :button_2, :bool, 4
      optional :button_3, :bool, 5
      optional :button_4, :bool, 6
      optional :button_joy, :bool, 7
      optional :button_center, :bool, 8
      optional :joy_x, :double, 9
      optional :joy_y, :double, 10
      optional :trigger, :double, 11
    end
  end
end

module Ignition
  module Msgs
    Hydra = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Hydra").msgclass
    Hydra::Paddle = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Hydra.Paddle").msgclass
  end
end
