// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/marker.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmarker_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmarker_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/time.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#include "ignition/msgs/material.pb.h"
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fmarker_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fmarker_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fmarker_2eproto;
namespace ignition {
namespace msgs {
class Marker;
struct MarkerDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern MarkerDefaultTypeInternal _Marker_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Marker* Arena::CreateMaybeMessage<::ignition::msgs::Marker>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum Marker_Type : int {
  Marker_Type_NONE = 0,
  Marker_Type_BOX = 1,
  Marker_Type_CYLINDER = 2,
  Marker_Type_LINE_LIST = 4,
  Marker_Type_LINE_STRIP = 3,
  Marker_Type_POINTS = 5,
  Marker_Type_SPHERE = 6,
  Marker_Type_TEXT = 7,
  Marker_Type_TRIANGLE_FAN = 8,
  Marker_Type_TRIANGLE_LIST = 9,
  Marker_Type_TRIANGLE_STRIP = 10,
  Marker_Type_CONE = 11,
  Marker_Type_ARROW = 12,
  Marker_Type_AXIS = 13,
  Marker_Type_Marker_Type_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Marker_Type_Marker_Type_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Marker_Type_IsValid(int value);
constexpr Marker_Type Marker_Type_Type_MIN = Marker_Type_NONE;
constexpr Marker_Type Marker_Type_Type_MAX = Marker_Type_AXIS;
constexpr int Marker_Type_Type_ARRAYSIZE = Marker_Type_Type_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Marker_Type_descriptor();
template<typename T>
inline const std::string& Marker_Type_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Marker_Type>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Marker_Type_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Marker_Type_descriptor(), enum_t_value);
}
inline bool Marker_Type_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Marker_Type* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Marker_Type>(
    Marker_Type_descriptor(), name, value);
}
enum Marker_Visibility : int {
  Marker_Visibility_GUI = 0,
  Marker_Visibility_ALL = 1,
  Marker_Visibility_Marker_Visibility_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Marker_Visibility_Marker_Visibility_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Marker_Visibility_IsValid(int value);
constexpr Marker_Visibility Marker_Visibility_Visibility_MIN = Marker_Visibility_GUI;
constexpr Marker_Visibility Marker_Visibility_Visibility_MAX = Marker_Visibility_ALL;
constexpr int Marker_Visibility_Visibility_ARRAYSIZE = Marker_Visibility_Visibility_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Marker_Visibility_descriptor();
template<typename T>
inline const std::string& Marker_Visibility_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Marker_Visibility>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Marker_Visibility_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Marker_Visibility_descriptor(), enum_t_value);
}
inline bool Marker_Visibility_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Marker_Visibility* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Marker_Visibility>(
    Marker_Visibility_descriptor(), name, value);
}
enum Marker_Action : int {
  Marker_Action_ADD_MODIFY = 0,
  Marker_Action_DELETE_MARKER = 1,
  Marker_Action_DELETE_ALL = 2,
  Marker_Action_Marker_Action_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  Marker_Action_Marker_Action_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool Marker_Action_IsValid(int value);
constexpr Marker_Action Marker_Action_Action_MIN = Marker_Action_ADD_MODIFY;
constexpr Marker_Action Marker_Action_Action_MAX = Marker_Action_DELETE_ALL;
constexpr int Marker_Action_Action_ARRAYSIZE = Marker_Action_Action_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* Marker_Action_descriptor();
template<typename T>
inline const std::string& Marker_Action_Name(T enum_t_value) {
  static_assert(::std::is_same<T, Marker_Action>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function Marker_Action_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    Marker_Action_descriptor(), enum_t_value);
}
inline bool Marker_Action_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, Marker_Action* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<Marker_Action>(
    Marker_Action_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE Marker final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Marker) */ {
 public:
  inline Marker() : Marker(nullptr) {}
  ~Marker() override;
  explicit constexpr Marker(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Marker(const Marker& from);
  Marker(Marker&& from) noexcept
    : Marker() {
    *this = ::std::move(from);
  }

  inline Marker& operator=(const Marker& from) {
    CopyFrom(from);
    return *this;
  }
  inline Marker& operator=(Marker&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Marker& default_instance() {
    return *internal_default_instance();
  }
  static inline const Marker* internal_default_instance() {
    return reinterpret_cast<const Marker*>(
               &_Marker_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Marker& a, Marker& b) {
    a.Swap(&b);
  }
  inline void Swap(Marker* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Marker* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Marker* New() const final {
    return new Marker();
  }

  Marker* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Marker>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Marker& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Marker& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Marker* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Marker";
  }
  protected:
  explicit Marker(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Marker_Type Type;
  static constexpr Type NONE =
    Marker_Type_NONE;
  static constexpr Type BOX =
    Marker_Type_BOX;
  static constexpr Type CYLINDER =
    Marker_Type_CYLINDER;
  static constexpr Type LINE_LIST =
    Marker_Type_LINE_LIST;
  static constexpr Type LINE_STRIP =
    Marker_Type_LINE_STRIP;
  static constexpr Type POINTS =
    Marker_Type_POINTS;
  static constexpr Type SPHERE =
    Marker_Type_SPHERE;
  static constexpr Type TEXT =
    Marker_Type_TEXT;
  static constexpr Type TRIANGLE_FAN =
    Marker_Type_TRIANGLE_FAN;
  static constexpr Type TRIANGLE_LIST =
    Marker_Type_TRIANGLE_LIST;
  static constexpr Type TRIANGLE_STRIP =
    Marker_Type_TRIANGLE_STRIP;
  static constexpr Type CONE =
    Marker_Type_CONE;
  static constexpr Type ARROW =
    Marker_Type_ARROW;
  static constexpr Type AXIS =
    Marker_Type_AXIS;
  static inline bool Type_IsValid(int value) {
    return Marker_Type_IsValid(value);
  }
  static constexpr Type Type_MIN =
    Marker_Type_Type_MIN;
  static constexpr Type Type_MAX =
    Marker_Type_Type_MAX;
  static constexpr int Type_ARRAYSIZE =
    Marker_Type_Type_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Type_descriptor() {
    return Marker_Type_descriptor();
  }
  template<typename T>
  static inline const std::string& Type_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Type>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Type_Name.");
    return Marker_Type_Name(enum_t_value);
  }
  static inline bool Type_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Type* value) {
    return Marker_Type_Parse(name, value);
  }

  typedef Marker_Visibility Visibility;
  static constexpr Visibility GUI =
    Marker_Visibility_GUI;
  static constexpr Visibility ALL =
    Marker_Visibility_ALL;
  static inline bool Visibility_IsValid(int value) {
    return Marker_Visibility_IsValid(value);
  }
  static constexpr Visibility Visibility_MIN =
    Marker_Visibility_Visibility_MIN;
  static constexpr Visibility Visibility_MAX =
    Marker_Visibility_Visibility_MAX;
  static constexpr int Visibility_ARRAYSIZE =
    Marker_Visibility_Visibility_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Visibility_descriptor() {
    return Marker_Visibility_descriptor();
  }
  template<typename T>
  static inline const std::string& Visibility_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Visibility>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Visibility_Name.");
    return Marker_Visibility_Name(enum_t_value);
  }
  static inline bool Visibility_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Visibility* value) {
    return Marker_Visibility_Parse(name, value);
  }

  typedef Marker_Action Action;
  static constexpr Action ADD_MODIFY =
    Marker_Action_ADD_MODIFY;
  static constexpr Action DELETE_MARKER =
    Marker_Action_DELETE_MARKER;
  static constexpr Action DELETE_ALL =
    Marker_Action_DELETE_ALL;
  static inline bool Action_IsValid(int value) {
    return Marker_Action_IsValid(value);
  }
  static constexpr Action Action_MIN =
    Marker_Action_Action_MIN;
  static constexpr Action Action_MAX =
    Marker_Action_Action_MAX;
  static constexpr int Action_ARRAYSIZE =
    Marker_Action_Action_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  Action_descriptor() {
    return Marker_Action_descriptor();
  }
  template<typename T>
  static inline const std::string& Action_Name(T enum_t_value) {
    static_assert(::std::is_same<T, Action>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function Action_Name.");
    return Marker_Action_Name(enum_t_value);
  }
  static inline bool Action_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      Action* value) {
    return Marker_Action_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kPointFieldNumber = 11,
    kNsFieldNumber = 3,
    kTextFieldNumber = 12,
    kParentFieldNumber = 13,
    kHeaderFieldNumber = 1,
    kLifetimeFieldNumber = 7,
    kPoseFieldNumber = 8,
    kScaleFieldNumber = 9,
    kMaterialFieldNumber = 10,
    kActionFieldNumber = 2,
    kLayerFieldNumber = 5,
    kIdFieldNumber = 4,
    kTypeFieldNumber = 6,
    kVisibilityFieldNumber = 14,
  };
  // repeated .ignition.msgs.Vector3d point = 11;
  int point_size() const;
  private:
  int _internal_point_size() const;
  public:
  void clear_point();
  ::ignition::msgs::Vector3d* mutable_point(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
      mutable_point();
  private:
  const ::ignition::msgs::Vector3d& _internal_point(int index) const;
  ::ignition::msgs::Vector3d* _internal_add_point();
  public:
  const ::ignition::msgs::Vector3d& point(int index) const;
  ::ignition::msgs::Vector3d* add_point();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
      point() const;

  // string ns = 3;
  void clear_ns();
  const std::string& ns() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_ns(ArgT0&& arg0, ArgT... args);
  std::string* mutable_ns();
  PROTOBUF_MUST_USE_RESULT std::string* release_ns();
  void set_allocated_ns(std::string* ns);
  private:
  const std::string& _internal_ns() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_ns(const std::string& value);
  std::string* _internal_mutable_ns();
  public:

  // string text = 12;
  void clear_text();
  const std::string& text() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_text(ArgT0&& arg0, ArgT... args);
  std::string* mutable_text();
  PROTOBUF_MUST_USE_RESULT std::string* release_text();
  void set_allocated_text(std::string* text);
  private:
  const std::string& _internal_text() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_text(const std::string& value);
  std::string* _internal_mutable_text();
  public:

  // string parent = 13;
  void clear_parent();
  const std::string& parent() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_parent(ArgT0&& arg0, ArgT... args);
  std::string* mutable_parent();
  PROTOBUF_MUST_USE_RESULT std::string* release_parent();
  void set_allocated_parent(std::string* parent);
  private:
  const std::string& _internal_parent() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_parent(const std::string& value);
  std::string* _internal_mutable_parent();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Time lifetime = 7;
  bool has_lifetime() const;
  private:
  bool _internal_has_lifetime() const;
  public:
  void clear_lifetime();
  const ::ignition::msgs::Time& lifetime() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Time* release_lifetime();
  ::ignition::msgs::Time* mutable_lifetime();
  void set_allocated_lifetime(::ignition::msgs::Time* lifetime);
  private:
  const ::ignition::msgs::Time& _internal_lifetime() const;
  ::ignition::msgs::Time* _internal_mutable_lifetime();
  public:
  void unsafe_arena_set_allocated_lifetime(
      ::ignition::msgs::Time* lifetime);
  ::ignition::msgs::Time* unsafe_arena_release_lifetime();

  // .ignition.msgs.Pose pose = 8;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // .ignition.msgs.Vector3d scale = 9;
  bool has_scale() const;
  private:
  bool _internal_has_scale() const;
  public:
  void clear_scale();
  const ::ignition::msgs::Vector3d& scale() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_scale();
  ::ignition::msgs::Vector3d* mutable_scale();
  void set_allocated_scale(::ignition::msgs::Vector3d* scale);
  private:
  const ::ignition::msgs::Vector3d& _internal_scale() const;
  ::ignition::msgs::Vector3d* _internal_mutable_scale();
  public:
  void unsafe_arena_set_allocated_scale(
      ::ignition::msgs::Vector3d* scale);
  ::ignition::msgs::Vector3d* unsafe_arena_release_scale();

  // .ignition.msgs.Material material = 10;
  bool has_material() const;
  private:
  bool _internal_has_material() const;
  public:
  void clear_material();
  const ::ignition::msgs::Material& material() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Material* release_material();
  ::ignition::msgs::Material* mutable_material();
  void set_allocated_material(::ignition::msgs::Material* material);
  private:
  const ::ignition::msgs::Material& _internal_material() const;
  ::ignition::msgs::Material* _internal_mutable_material();
  public:
  void unsafe_arena_set_allocated_material(
      ::ignition::msgs::Material* material);
  ::ignition::msgs::Material* unsafe_arena_release_material();

  // .ignition.msgs.Marker.Action action = 2;
  void clear_action();
  ::ignition::msgs::Marker_Action action() const;
  void set_action(::ignition::msgs::Marker_Action value);
  private:
  ::ignition::msgs::Marker_Action _internal_action() const;
  void _internal_set_action(::ignition::msgs::Marker_Action value);
  public:

  // int32 layer = 5;
  void clear_layer();
  ::PROTOBUF_NAMESPACE_ID::int32 layer() const;
  void set_layer(::PROTOBUF_NAMESPACE_ID::int32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::int32 _internal_layer() const;
  void _internal_set_layer(::PROTOBUF_NAMESPACE_ID::int32 value);
  public:

  // uint64 id = 4;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint64 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint64 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  public:

  // .ignition.msgs.Marker.Type type = 6;
  void clear_type();
  ::ignition::msgs::Marker_Type type() const;
  void set_type(::ignition::msgs::Marker_Type value);
  private:
  ::ignition::msgs::Marker_Type _internal_type() const;
  void _internal_set_type(::ignition::msgs::Marker_Type value);
  public:

  // .ignition.msgs.Marker.Visibility visibility = 14;
  void clear_visibility();
  ::ignition::msgs::Marker_Visibility visibility() const;
  void set_visibility(::ignition::msgs::Marker_Visibility value);
  private:
  ::ignition::msgs::Marker_Visibility _internal_visibility() const;
  void _internal_set_visibility(::ignition::msgs::Marker_Visibility value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Marker)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d > point_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr ns_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr text_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr parent_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Time* lifetime_;
  ::ignition::msgs::Pose* pose_;
  ::ignition::msgs::Vector3d* scale_;
  ::ignition::msgs::Material* material_;
  int action_;
  ::PROTOBUF_NAMESPACE_ID::int32 layer_;
  ::PROTOBUF_NAMESPACE_ID::uint64 id_;
  int type_;
  int visibility_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fmarker_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Marker

// .ignition.msgs.Header header = 1;
inline bool Marker::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Marker::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Marker::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Marker::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.header)
  return _internal_header();
}
inline void Marker::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Marker.header)
}
inline ::ignition::msgs::Header* Marker::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Marker::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Marker::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Marker::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.header)
  return _msg;
}
inline void Marker::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.header)
}

// .ignition.msgs.Marker.Action action = 2;
inline void Marker::clear_action() {
  action_ = 0;
}
inline ::ignition::msgs::Marker_Action Marker::_internal_action() const {
  return static_cast< ::ignition::msgs::Marker_Action >(action_);
}
inline ::ignition::msgs::Marker_Action Marker::action() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.action)
  return _internal_action();
}
inline void Marker::_internal_set_action(::ignition::msgs::Marker_Action value) {
  
  action_ = value;
}
inline void Marker::set_action(::ignition::msgs::Marker_Action value) {
  _internal_set_action(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.action)
}

// string ns = 3;
inline void Marker::clear_ns() {
  ns_.ClearToEmpty();
}
inline const std::string& Marker::ns() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.ns)
  return _internal_ns();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Marker::set_ns(ArgT0&& arg0, ArgT... args) {
 
 ns_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.ns)
}
inline std::string* Marker::mutable_ns() {
  std::string* _s = _internal_mutable_ns();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.ns)
  return _s;
}
inline const std::string& Marker::_internal_ns() const {
  return ns_.Get();
}
inline void Marker::_internal_set_ns(const std::string& value) {
  
  ns_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Marker::_internal_mutable_ns() {
  
  return ns_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Marker::release_ns() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.ns)
  return ns_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Marker::set_allocated_ns(std::string* ns) {
  if (ns != nullptr) {
    
  } else {
    
  }
  ns_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), ns,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.ns)
}

// uint64 id = 4;
inline void Marker::clear_id() {
  id_ = uint64_t{0u};
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 Marker::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 Marker::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.id)
  return _internal_id();
}
inline void Marker::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  
  id_ = value;
}
inline void Marker::set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.id)
}

// int32 layer = 5;
inline void Marker::clear_layer() {
  layer_ = 0;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Marker::_internal_layer() const {
  return layer_;
}
inline ::PROTOBUF_NAMESPACE_ID::int32 Marker::layer() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.layer)
  return _internal_layer();
}
inline void Marker::_internal_set_layer(::PROTOBUF_NAMESPACE_ID::int32 value) {
  
  layer_ = value;
}
inline void Marker::set_layer(::PROTOBUF_NAMESPACE_ID::int32 value) {
  _internal_set_layer(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.layer)
}

// .ignition.msgs.Marker.Type type = 6;
inline void Marker::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::Marker_Type Marker::_internal_type() const {
  return static_cast< ::ignition::msgs::Marker_Type >(type_);
}
inline ::ignition::msgs::Marker_Type Marker::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.type)
  return _internal_type();
}
inline void Marker::_internal_set_type(::ignition::msgs::Marker_Type value) {
  
  type_ = value;
}
inline void Marker::set_type(::ignition::msgs::Marker_Type value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.type)
}

// .ignition.msgs.Time lifetime = 7;
inline bool Marker::_internal_has_lifetime() const {
  return this != internal_default_instance() && lifetime_ != nullptr;
}
inline bool Marker::has_lifetime() const {
  return _internal_has_lifetime();
}
inline const ::ignition::msgs::Time& Marker::_internal_lifetime() const {
  const ::ignition::msgs::Time* p = lifetime_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Time&>(
      ::ignition::msgs::_Time_default_instance_);
}
inline const ::ignition::msgs::Time& Marker::lifetime() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.lifetime)
  return _internal_lifetime();
}
inline void Marker::unsafe_arena_set_allocated_lifetime(
    ::ignition::msgs::Time* lifetime) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime_);
  }
  lifetime_ = lifetime;
  if (lifetime) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Marker.lifetime)
}
inline ::ignition::msgs::Time* Marker::release_lifetime() {
  
  ::ignition::msgs::Time* temp = lifetime_;
  lifetime_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Time* Marker::unsafe_arena_release_lifetime() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.lifetime)
  
  ::ignition::msgs::Time* temp = lifetime_;
  lifetime_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Time* Marker::_internal_mutable_lifetime() {
  
  if (lifetime_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Time>(GetArenaForAllocation());
    lifetime_ = p;
  }
  return lifetime_;
}
inline ::ignition::msgs::Time* Marker::mutable_lifetime() {
  ::ignition::msgs::Time* _msg = _internal_mutable_lifetime();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.lifetime)
  return _msg;
}
inline void Marker::set_allocated_lifetime(::ignition::msgs::Time* lifetime) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime_);
  }
  if (lifetime) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime));
    if (message_arena != submessage_arena) {
      lifetime = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, lifetime, submessage_arena);
    }
    
  } else {
    
  }
  lifetime_ = lifetime;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.lifetime)
}

// .ignition.msgs.Pose pose = 8;
inline bool Marker::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Marker::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Marker::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Marker::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.pose)
  return _internal_pose();
}
inline void Marker::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Marker.pose)
}
inline ::ignition::msgs::Pose* Marker::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* Marker::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Marker::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Marker::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.pose)
  return _msg;
}
inline void Marker::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.pose)
}

// .ignition.msgs.Vector3d scale = 9;
inline bool Marker::_internal_has_scale() const {
  return this != internal_default_instance() && scale_ != nullptr;
}
inline bool Marker::has_scale() const {
  return _internal_has_scale();
}
inline const ::ignition::msgs::Vector3d& Marker::_internal_scale() const {
  const ::ignition::msgs::Vector3d* p = scale_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& Marker::scale() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.scale)
  return _internal_scale();
}
inline void Marker::unsafe_arena_set_allocated_scale(
    ::ignition::msgs::Vector3d* scale) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_);
  }
  scale_ = scale;
  if (scale) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Marker.scale)
}
inline ::ignition::msgs::Vector3d* Marker::release_scale() {
  
  ::ignition::msgs::Vector3d* temp = scale_;
  scale_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* Marker::unsafe_arena_release_scale() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.scale)
  
  ::ignition::msgs::Vector3d* temp = scale_;
  scale_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* Marker::_internal_mutable_scale() {
  
  if (scale_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    scale_ = p;
  }
  return scale_;
}
inline ::ignition::msgs::Vector3d* Marker::mutable_scale() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_scale();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.scale)
  return _msg;
}
inline void Marker::set_allocated_scale(::ignition::msgs::Vector3d* scale) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_);
  }
  if (scale) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale));
    if (message_arena != submessage_arena) {
      scale = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, scale, submessage_arena);
    }
    
  } else {
    
  }
  scale_ = scale;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.scale)
}

// .ignition.msgs.Material material = 10;
inline bool Marker::_internal_has_material() const {
  return this != internal_default_instance() && material_ != nullptr;
}
inline bool Marker::has_material() const {
  return _internal_has_material();
}
inline const ::ignition::msgs::Material& Marker::_internal_material() const {
  const ::ignition::msgs::Material* p = material_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Material&>(
      ::ignition::msgs::_Material_default_instance_);
}
inline const ::ignition::msgs::Material& Marker::material() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.material)
  return _internal_material();
}
inline void Marker::unsafe_arena_set_allocated_material(
    ::ignition::msgs::Material* material) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(material_);
  }
  material_ = material;
  if (material) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Marker.material)
}
inline ::ignition::msgs::Material* Marker::release_material() {
  
  ::ignition::msgs::Material* temp = material_;
  material_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Material* Marker::unsafe_arena_release_material() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.material)
  
  ::ignition::msgs::Material* temp = material_;
  material_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Material* Marker::_internal_mutable_material() {
  
  if (material_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Material>(GetArenaForAllocation());
    material_ = p;
  }
  return material_;
}
inline ::ignition::msgs::Material* Marker::mutable_material() {
  ::ignition::msgs::Material* _msg = _internal_mutable_material();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.material)
  return _msg;
}
inline void Marker::set_allocated_material(::ignition::msgs::Material* material) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(material_);
  }
  if (material) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(material));
    if (message_arena != submessage_arena) {
      material = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, material, submessage_arena);
    }
    
  } else {
    
  }
  material_ = material;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.material)
}

// repeated .ignition.msgs.Vector3d point = 11;
inline int Marker::_internal_point_size() const {
  return point_.size();
}
inline int Marker::point_size() const {
  return _internal_point_size();
}
inline ::ignition::msgs::Vector3d* Marker::mutable_point(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.point)
  return point_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >*
Marker::mutable_point() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Marker.point)
  return &point_;
}
inline const ::ignition::msgs::Vector3d& Marker::_internal_point(int index) const {
  return point_.Get(index);
}
inline const ::ignition::msgs::Vector3d& Marker::point(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.point)
  return _internal_point(index);
}
inline ::ignition::msgs::Vector3d* Marker::_internal_add_point() {
  return point_.Add();
}
inline ::ignition::msgs::Vector3d* Marker::add_point() {
  ::ignition::msgs::Vector3d* _add = _internal_add_point();
  // @@protoc_insertion_point(field_add:ignition.msgs.Marker.point)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Vector3d >&
Marker::point() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Marker.point)
  return point_;
}

// string text = 12;
inline void Marker::clear_text() {
  text_.ClearToEmpty();
}
inline const std::string& Marker::text() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.text)
  return _internal_text();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Marker::set_text(ArgT0&& arg0, ArgT... args) {
 
 text_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.text)
}
inline std::string* Marker::mutable_text() {
  std::string* _s = _internal_mutable_text();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.text)
  return _s;
}
inline const std::string& Marker::_internal_text() const {
  return text_.Get();
}
inline void Marker::_internal_set_text(const std::string& value) {
  
  text_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Marker::_internal_mutable_text() {
  
  return text_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Marker::release_text() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.text)
  return text_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Marker::set_allocated_text(std::string* text) {
  if (text != nullptr) {
    
  } else {
    
  }
  text_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), text,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.text)
}

// string parent = 13;
inline void Marker::clear_parent() {
  parent_.ClearToEmpty();
}
inline const std::string& Marker::parent() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.parent)
  return _internal_parent();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Marker::set_parent(ArgT0&& arg0, ArgT... args) {
 
 parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.parent)
}
inline std::string* Marker::mutable_parent() {
  std::string* _s = _internal_mutable_parent();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Marker.parent)
  return _s;
}
inline const std::string& Marker::_internal_parent() const {
  return parent_.Get();
}
inline void Marker::_internal_set_parent(const std::string& value) {
  
  parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Marker::_internal_mutable_parent() {
  
  return parent_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Marker::release_parent() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Marker.parent)
  return parent_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Marker::set_allocated_parent(std::string* parent) {
  if (parent != nullptr) {
    
  } else {
    
  }
  parent_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), parent,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Marker.parent)
}

// .ignition.msgs.Marker.Visibility visibility = 14;
inline void Marker::clear_visibility() {
  visibility_ = 0;
}
inline ::ignition::msgs::Marker_Visibility Marker::_internal_visibility() const {
  return static_cast< ::ignition::msgs::Marker_Visibility >(visibility_);
}
inline ::ignition::msgs::Marker_Visibility Marker::visibility() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Marker.visibility)
  return _internal_visibility();
}
inline void Marker::_internal_set_visibility(::ignition::msgs::Marker_Visibility value) {
  
  visibility_ = value;
}
inline void Marker::set_visibility(::ignition::msgs::Marker_Visibility value) {
  _internal_set_visibility(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Marker.visibility)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Marker> MarkerUniquePtr;
typedef std::unique_ptr<const Marker> ConstMarkerUniquePtr;
typedef std::shared_ptr<Marker> MarkerSharedPtr;
typedef std::shared_ptr<const Marker> ConstMarkerSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::Marker_Type> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Marker_Type>() {
  return ::ignition::msgs::Marker_Type_descriptor();
}
template <> struct is_proto_enum< ::ignition::msgs::Marker_Visibility> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Marker_Visibility>() {
  return ::ignition::msgs::Marker_Visibility_descriptor();
}
template <> struct is_proto_enum< ::ignition::msgs::Marker_Action> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::Marker_Action>() {
  return ::ignition::msgs::Marker_Action_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fmarker_2eproto
