# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/image.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/image.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Image" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :width, :uint32, 2
      optional :height, :uint32, 3
      optional :step, :uint32, 4
      optional :data, :bytes, 5
      optional :pixel_format_type, :enum, 6, "ignition.msgs.PixelFormatType"
    end
    add_enum "ignition.msgs.PixelFormatType" do
      value :UNKNOWN_PIXEL_FORMAT, 0
      value :L_INT8, 1
      value :L_INT16, 2
      value :RGB_INT8, 3
      value :RGBA_INT8, 4
      value :BGRA_INT8, 5
      value :RGB_INT16, 6
      value :RGB_INT32, 7
      value :BGR_INT8, 8
      value :BGR_INT16, 9
      value :BGR_INT32, 10
      value :R_FLOAT16, 11
      value :RGB_FLOAT16, 12
      value :R_FLOAT32, 13
      value :RGB_FLOAT32, 14
      value :BAYER_RGGB8, 15
      value :BAYER_BGGR8, 16
      value :BAYER_GBRG8, 17
      value :BAYER_GRBG8, 18
    end
  end
end

module Ignition
  module Msgs
    Image = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Image").msgclass
    PixelFormatType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PixelFormatType").enummodule
  end
end
