# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/atmosphere.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/atmosphere.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Atmosphere" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Atmosphere.Type"
      optional :temperature, :double, 3
      optional :pressure, :double, 4
      optional :mass_density, :double, 5
      optional :enable_atmosphere, :bool, 6
    end
    add_enum "ignition.msgs.Atmosphere.Type" do
      value :ADIABATIC, 0
    end
  end
end

module Ignition
  module Msgs
    Atmosphere = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Atmosphere").msgclass
    Atmosphere::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Atmosphere.Type").enummodule
  end
end
