# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/light.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/color_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/light.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Light" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :type, :enum, 3, "ignition.msgs.Light.LightType"
      optional :pose, :message, 4, "ignition.msgs.Pose"
      optional :diffuse, :message, 5, "ignition.msgs.Color"
      optional :specular, :message, 6, "ignition.msgs.Color"
      optional :attenuation_constant, :float, 7
      optional :attenuation_linear, :float, 8
      optional :attenuation_quadratic, :float, 9
      optional :direction, :message, 10, "ignition.msgs.Vector3d"
      optional :range, :float, 11
      optional :cast_shadows, :bool, 12
      optional :spot_inner_angle, :float, 13
      optional :spot_outer_angle, :float, 14
      optional :spot_falloff, :float, 15
      optional :id, :uint32, 16
      optional :parent_id, :uint32, 17
    end
    add_enum "ignition.msgs.Light.LightType" do
      value :POINT, 0
      value :SPOT, 1
      value :DIRECTIONAL, 2
    end
  end
end

module Ignition
  module Msgs
    Light = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Light").msgclass
    Light::LightType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Light.LightType").enummodule
  end
end
