# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/header.proto

require 'ignition/msgs/time_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/header.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Header" do
      optional :stamp, :message, 1, "ignition.msgs.Time"
      repeated :data, :message, 2, "ignition.msgs.Header.Map"
    end
    add_message "ignition.msgs.Header.Map" do
      optional :key, :string, 1
      repeated :value, :string, 2
    end
  end
end

module Ignition
  module Msgs
    Header = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Header").msgclass
    Header::Map = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Header.Map").msgclass
  end
end
