// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/sensor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/altimeter_sensor.pb.h"
#include "ignition/msgs/camerasensor.pb.h"
#include "ignition/msgs/contactsensor.pb.h"
#include "ignition/msgs/air_pressure_sensor.pb.h"
#include "ignition/msgs/gps_sensor.pb.h"
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/imu_sensor.pb.h"
#include "ignition/msgs/lidar_sensor.pb.h"
#include "ignition/msgs/logical_camera_sensor.pb.h"
#include "ignition/msgs/magnetometer_sensor.pb.h"
#include "ignition/msgs/pose.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fsensor_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fsensor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fsensor_2eproto;
namespace ignition {
namespace msgs {
class Sensor;
struct SensorDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SensorDefaultTypeInternal _Sensor_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Sensor* Arena::CreateMaybeMessage<::ignition::msgs::Sensor>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Sensor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Sensor) */ {
 public:
  inline Sensor() : Sensor(nullptr) {}
  ~Sensor() override;
  explicit constexpr Sensor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Sensor(const Sensor& from);
  Sensor(Sensor&& from) noexcept
    : Sensor() {
    *this = ::std::move(from);
  }

  inline Sensor& operator=(const Sensor& from) {
    CopyFrom(from);
    return *this;
  }
  inline Sensor& operator=(Sensor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Sensor& default_instance() {
    return *internal_default_instance();
  }
  static inline const Sensor* internal_default_instance() {
    return reinterpret_cast<const Sensor*>(
               &_Sensor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Sensor& a, Sensor& b) {
    a.Swap(&b);
  }
  inline void Swap(Sensor* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Sensor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Sensor* New() const final {
    return new Sensor();
  }

  Sensor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Sensor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Sensor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Sensor& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Sensor* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Sensor";
  }
  protected:
  explicit Sensor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 2,
    kParentFieldNumber = 4,
    kTypeFieldNumber = 6,
    kTopicFieldNumber = 13,
    kHeaderFieldNumber = 1,
    kPoseFieldNumber = 9,
    kCameraFieldNumber = 10,
    kContactFieldNumber = 11,
    kLogicalCameraFieldNumber = 14,
    kGpsFieldNumber = 15,
    kImuFieldNumber = 16,
    kMagnetometerFieldNumber = 17,
    kAltimeterFieldNumber = 18,
    kAirPressureFieldNumber = 19,
    kLidarFieldNumber = 20,
    kIdFieldNumber = 3,
    kParentIdFieldNumber = 5,
    kUpdateRateFieldNumber = 8,
    kAlwaysOnFieldNumber = 7,
    kVisualizeFieldNumber = 12,
  };
  // string name = 2;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // string parent = 4;
  void clear_parent();
  const std::string& parent() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_parent(ArgT0&& arg0, ArgT... args);
  std::string* mutable_parent();
  PROTOBUF_MUST_USE_RESULT std::string* release_parent();
  void set_allocated_parent(std::string* parent);
  private:
  const std::string& _internal_parent() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_parent(const std::string& value);
  std::string* _internal_mutable_parent();
  public:

  // string type = 6;
  void clear_type();
  const std::string& type() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_type(ArgT0&& arg0, ArgT... args);
  std::string* mutable_type();
  PROTOBUF_MUST_USE_RESULT std::string* release_type();
  void set_allocated_type(std::string* type);
  private:
  const std::string& _internal_type() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_type(const std::string& value);
  std::string* _internal_mutable_type();
  public:

  // string topic = 13;
  void clear_topic();
  const std::string& topic() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_topic(ArgT0&& arg0, ArgT... args);
  std::string* mutable_topic();
  PROTOBUF_MUST_USE_RESULT std::string* release_topic();
  void set_allocated_topic(std::string* topic);
  private:
  const std::string& _internal_topic() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_topic(const std::string& value);
  std::string* _internal_mutable_topic();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Pose pose = 9;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // .ignition.msgs.CameraSensor camera = 10;
  bool has_camera() const;
  private:
  bool _internal_has_camera() const;
  public:
  void clear_camera();
  const ::ignition::msgs::CameraSensor& camera() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::CameraSensor* release_camera();
  ::ignition::msgs::CameraSensor* mutable_camera();
  void set_allocated_camera(::ignition::msgs::CameraSensor* camera);
  private:
  const ::ignition::msgs::CameraSensor& _internal_camera() const;
  ::ignition::msgs::CameraSensor* _internal_mutable_camera();
  public:
  void unsafe_arena_set_allocated_camera(
      ::ignition::msgs::CameraSensor* camera);
  ::ignition::msgs::CameraSensor* unsafe_arena_release_camera();

  // .ignition.msgs.ContactSensor contact = 11;
  bool has_contact() const;
  private:
  bool _internal_has_contact() const;
  public:
  void clear_contact();
  const ::ignition::msgs::ContactSensor& contact() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::ContactSensor* release_contact();
  ::ignition::msgs::ContactSensor* mutable_contact();
  void set_allocated_contact(::ignition::msgs::ContactSensor* contact);
  private:
  const ::ignition::msgs::ContactSensor& _internal_contact() const;
  ::ignition::msgs::ContactSensor* _internal_mutable_contact();
  public:
  void unsafe_arena_set_allocated_contact(
      ::ignition::msgs::ContactSensor* contact);
  ::ignition::msgs::ContactSensor* unsafe_arena_release_contact();

  // .ignition.msgs.LogicalCameraSensor logical_camera = 14;
  bool has_logical_camera() const;
  private:
  bool _internal_has_logical_camera() const;
  public:
  void clear_logical_camera();
  const ::ignition::msgs::LogicalCameraSensor& logical_camera() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::LogicalCameraSensor* release_logical_camera();
  ::ignition::msgs::LogicalCameraSensor* mutable_logical_camera();
  void set_allocated_logical_camera(::ignition::msgs::LogicalCameraSensor* logical_camera);
  private:
  const ::ignition::msgs::LogicalCameraSensor& _internal_logical_camera() const;
  ::ignition::msgs::LogicalCameraSensor* _internal_mutable_logical_camera();
  public:
  void unsafe_arena_set_allocated_logical_camera(
      ::ignition::msgs::LogicalCameraSensor* logical_camera);
  ::ignition::msgs::LogicalCameraSensor* unsafe_arena_release_logical_camera();

  // .ignition.msgs.GPSSensor gps = 15;
  bool has_gps() const;
  private:
  bool _internal_has_gps() const;
  public:
  void clear_gps();
  const ::ignition::msgs::GPSSensor& gps() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::GPSSensor* release_gps();
  ::ignition::msgs::GPSSensor* mutable_gps();
  void set_allocated_gps(::ignition::msgs::GPSSensor* gps);
  private:
  const ::ignition::msgs::GPSSensor& _internal_gps() const;
  ::ignition::msgs::GPSSensor* _internal_mutable_gps();
  public:
  void unsafe_arena_set_allocated_gps(
      ::ignition::msgs::GPSSensor* gps);
  ::ignition::msgs::GPSSensor* unsafe_arena_release_gps();

  // .ignition.msgs.IMUSensor imu = 16;
  bool has_imu() const;
  private:
  bool _internal_has_imu() const;
  public:
  void clear_imu();
  const ::ignition::msgs::IMUSensor& imu() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::IMUSensor* release_imu();
  ::ignition::msgs::IMUSensor* mutable_imu();
  void set_allocated_imu(::ignition::msgs::IMUSensor* imu);
  private:
  const ::ignition::msgs::IMUSensor& _internal_imu() const;
  ::ignition::msgs::IMUSensor* _internal_mutable_imu();
  public:
  void unsafe_arena_set_allocated_imu(
      ::ignition::msgs::IMUSensor* imu);
  ::ignition::msgs::IMUSensor* unsafe_arena_release_imu();

  // .ignition.msgs.MagnetometerSensor magnetometer = 17;
  bool has_magnetometer() const;
  private:
  bool _internal_has_magnetometer() const;
  public:
  void clear_magnetometer();
  const ::ignition::msgs::MagnetometerSensor& magnetometer() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::MagnetometerSensor* release_magnetometer();
  ::ignition::msgs::MagnetometerSensor* mutable_magnetometer();
  void set_allocated_magnetometer(::ignition::msgs::MagnetometerSensor* magnetometer);
  private:
  const ::ignition::msgs::MagnetometerSensor& _internal_magnetometer() const;
  ::ignition::msgs::MagnetometerSensor* _internal_mutable_magnetometer();
  public:
  void unsafe_arena_set_allocated_magnetometer(
      ::ignition::msgs::MagnetometerSensor* magnetometer);
  ::ignition::msgs::MagnetometerSensor* unsafe_arena_release_magnetometer();

  // .ignition.msgs.AltimeterSensor altimeter = 18;
  bool has_altimeter() const;
  private:
  bool _internal_has_altimeter() const;
  public:
  void clear_altimeter();
  const ::ignition::msgs::AltimeterSensor& altimeter() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::AltimeterSensor* release_altimeter();
  ::ignition::msgs::AltimeterSensor* mutable_altimeter();
  void set_allocated_altimeter(::ignition::msgs::AltimeterSensor* altimeter);
  private:
  const ::ignition::msgs::AltimeterSensor& _internal_altimeter() const;
  ::ignition::msgs::AltimeterSensor* _internal_mutable_altimeter();
  public:
  void unsafe_arena_set_allocated_altimeter(
      ::ignition::msgs::AltimeterSensor* altimeter);
  ::ignition::msgs::AltimeterSensor* unsafe_arena_release_altimeter();

  // .ignition.msgs.AirPressureSensor air_pressure = 19;
  bool has_air_pressure() const;
  private:
  bool _internal_has_air_pressure() const;
  public:
  void clear_air_pressure();
  const ::ignition::msgs::AirPressureSensor& air_pressure() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::AirPressureSensor* release_air_pressure();
  ::ignition::msgs::AirPressureSensor* mutable_air_pressure();
  void set_allocated_air_pressure(::ignition::msgs::AirPressureSensor* air_pressure);
  private:
  const ::ignition::msgs::AirPressureSensor& _internal_air_pressure() const;
  ::ignition::msgs::AirPressureSensor* _internal_mutable_air_pressure();
  public:
  void unsafe_arena_set_allocated_air_pressure(
      ::ignition::msgs::AirPressureSensor* air_pressure);
  ::ignition::msgs::AirPressureSensor* unsafe_arena_release_air_pressure();

  // .ignition.msgs.LidarSensor lidar = 20;
  bool has_lidar() const;
  private:
  bool _internal_has_lidar() const;
  public:
  void clear_lidar();
  const ::ignition::msgs::LidarSensor& lidar() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::LidarSensor* release_lidar();
  ::ignition::msgs::LidarSensor* mutable_lidar();
  void set_allocated_lidar(::ignition::msgs::LidarSensor* lidar);
  private:
  const ::ignition::msgs::LidarSensor& _internal_lidar() const;
  ::ignition::msgs::LidarSensor* _internal_mutable_lidar();
  public:
  void unsafe_arena_set_allocated_lidar(
      ::ignition::msgs::LidarSensor* lidar);
  ::ignition::msgs::LidarSensor* unsafe_arena_release_lidar();

  // uint32 id = 3;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 parent_id = 5;
  void clear_parent_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 parent_id() const;
  void set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_parent_id() const;
  void _internal_set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // double update_rate = 8;
  void clear_update_rate();
  double update_rate() const;
  void set_update_rate(double value);
  private:
  double _internal_update_rate() const;
  void _internal_set_update_rate(double value);
  public:

  // bool always_on = 7;
  void clear_always_on();
  bool always_on() const;
  void set_always_on(bool value);
  private:
  bool _internal_always_on() const;
  void _internal_set_always_on(bool value);
  public:

  // bool visualize = 12;
  void clear_visualize();
  bool visualize() const;
  void set_visualize(bool value);
  private:
  bool _internal_visualize() const;
  void _internal_set_visualize(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Sensor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr parent_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr type_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr topic_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Pose* pose_;
  ::ignition::msgs::CameraSensor* camera_;
  ::ignition::msgs::ContactSensor* contact_;
  ::ignition::msgs::LogicalCameraSensor* logical_camera_;
  ::ignition::msgs::GPSSensor* gps_;
  ::ignition::msgs::IMUSensor* imu_;
  ::ignition::msgs::MagnetometerSensor* magnetometer_;
  ::ignition::msgs::AltimeterSensor* altimeter_;
  ::ignition::msgs::AirPressureSensor* air_pressure_;
  ::ignition::msgs::LidarSensor* lidar_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  ::PROTOBUF_NAMESPACE_ID::uint32 parent_id_;
  double update_rate_;
  bool always_on_;
  bool visualize_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fsensor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Sensor

// .ignition.msgs.Header header = 1;
inline bool Sensor::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Sensor::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Sensor::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Sensor::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.header)
  return _internal_header();
}
inline void Sensor::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.header)
}
inline ::ignition::msgs::Header* Sensor::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Sensor::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Sensor::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Sensor::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.header)
  return _msg;
}
inline void Sensor::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.header)
}

// string name = 2;
inline void Sensor::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& Sensor::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.name)
}
inline std::string* Sensor::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.name)
  return _s;
}
inline const std::string& Sensor::_internal_name() const {
  return name_.Get();
}
inline void Sensor::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.name)
}

// uint32 id = 3;
inline void Sensor::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.id)
  return _internal_id();
}
inline void Sensor::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void Sensor::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.id)
}

// string parent = 4;
inline void Sensor::clear_parent() {
  parent_.ClearToEmpty();
}
inline const std::string& Sensor::parent() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.parent)
  return _internal_parent();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_parent(ArgT0&& arg0, ArgT... args) {
 
 parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.parent)
}
inline std::string* Sensor::mutable_parent() {
  std::string* _s = _internal_mutable_parent();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.parent)
  return _s;
}
inline const std::string& Sensor::_internal_parent() const {
  return parent_.Get();
}
inline void Sensor::_internal_set_parent(const std::string& value) {
  
  parent_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_parent() {
  
  return parent_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_parent() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.parent)
  return parent_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_parent(std::string* parent) {
  if (parent != nullptr) {
    
  } else {
    
  }
  parent_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), parent,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.parent)
}

// uint32 parent_id = 5;
inline void Sensor::clear_parent_id() {
  parent_id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::_internal_parent_id() const {
  return parent_id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Sensor::parent_id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.parent_id)
  return _internal_parent_id();
}
inline void Sensor::_internal_set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  parent_id_ = value;
}
inline void Sensor::set_parent_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_parent_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.parent_id)
}

// string type = 6;
inline void Sensor::clear_type() {
  type_.ClearToEmpty();
}
inline const std::string& Sensor::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.type)
  return _internal_type();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_type(ArgT0&& arg0, ArgT... args) {
 
 type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.type)
}
inline std::string* Sensor::mutable_type() {
  std::string* _s = _internal_mutable_type();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.type)
  return _s;
}
inline const std::string& Sensor::_internal_type() const {
  return type_.Get();
}
inline void Sensor::_internal_set_type(const std::string& value) {
  
  type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_type() {
  
  return type_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_type() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.type)
  return type_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_type(std::string* type) {
  if (type != nullptr) {
    
  } else {
    
  }
  type_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), type,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.type)
}

// bool always_on = 7;
inline void Sensor::clear_always_on() {
  always_on_ = false;
}
inline bool Sensor::_internal_always_on() const {
  return always_on_;
}
inline bool Sensor::always_on() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.always_on)
  return _internal_always_on();
}
inline void Sensor::_internal_set_always_on(bool value) {
  
  always_on_ = value;
}
inline void Sensor::set_always_on(bool value) {
  _internal_set_always_on(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.always_on)
}

// double update_rate = 8;
inline void Sensor::clear_update_rate() {
  update_rate_ = 0;
}
inline double Sensor::_internal_update_rate() const {
  return update_rate_;
}
inline double Sensor::update_rate() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.update_rate)
  return _internal_update_rate();
}
inline void Sensor::_internal_set_update_rate(double value) {
  
  update_rate_ = value;
}
inline void Sensor::set_update_rate(double value) {
  _internal_set_update_rate(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.update_rate)
}

// .ignition.msgs.Pose pose = 9;
inline bool Sensor::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Sensor::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Sensor::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Sensor::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.pose)
  return _internal_pose();
}
inline void Sensor::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.pose)
}
inline ::ignition::msgs::Pose* Sensor::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* Sensor::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Sensor::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Sensor::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.pose)
  return _msg;
}
inline void Sensor::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.pose)
}

// .ignition.msgs.CameraSensor camera = 10;
inline bool Sensor::_internal_has_camera() const {
  return this != internal_default_instance() && camera_ != nullptr;
}
inline bool Sensor::has_camera() const {
  return _internal_has_camera();
}
inline const ::ignition::msgs::CameraSensor& Sensor::_internal_camera() const {
  const ::ignition::msgs::CameraSensor* p = camera_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::CameraSensor&>(
      ::ignition::msgs::_CameraSensor_default_instance_);
}
inline const ::ignition::msgs::CameraSensor& Sensor::camera() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.camera)
  return _internal_camera();
}
inline void Sensor::unsafe_arena_set_allocated_camera(
    ::ignition::msgs::CameraSensor* camera) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera_);
  }
  camera_ = camera;
  if (camera) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.camera)
}
inline ::ignition::msgs::CameraSensor* Sensor::release_camera() {
  
  ::ignition::msgs::CameraSensor* temp = camera_;
  camera_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::CameraSensor* Sensor::unsafe_arena_release_camera() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.camera)
  
  ::ignition::msgs::CameraSensor* temp = camera_;
  camera_ = nullptr;
  return temp;
}
inline ::ignition::msgs::CameraSensor* Sensor::_internal_mutable_camera() {
  
  if (camera_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::CameraSensor>(GetArenaForAllocation());
    camera_ = p;
  }
  return camera_;
}
inline ::ignition::msgs::CameraSensor* Sensor::mutable_camera() {
  ::ignition::msgs::CameraSensor* _msg = _internal_mutable_camera();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.camera)
  return _msg;
}
inline void Sensor::set_allocated_camera(::ignition::msgs::CameraSensor* camera) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera_);
  }
  if (camera) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(camera));
    if (message_arena != submessage_arena) {
      camera = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, camera, submessage_arena);
    }
    
  } else {
    
  }
  camera_ = camera;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.camera)
}

// .ignition.msgs.ContactSensor contact = 11;
inline bool Sensor::_internal_has_contact() const {
  return this != internal_default_instance() && contact_ != nullptr;
}
inline bool Sensor::has_contact() const {
  return _internal_has_contact();
}
inline const ::ignition::msgs::ContactSensor& Sensor::_internal_contact() const {
  const ::ignition::msgs::ContactSensor* p = contact_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::ContactSensor&>(
      ::ignition::msgs::_ContactSensor_default_instance_);
}
inline const ::ignition::msgs::ContactSensor& Sensor::contact() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.contact)
  return _internal_contact();
}
inline void Sensor::unsafe_arena_set_allocated_contact(
    ::ignition::msgs::ContactSensor* contact) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact_);
  }
  contact_ = contact;
  if (contact) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.contact)
}
inline ::ignition::msgs::ContactSensor* Sensor::release_contact() {
  
  ::ignition::msgs::ContactSensor* temp = contact_;
  contact_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::ContactSensor* Sensor::unsafe_arena_release_contact() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.contact)
  
  ::ignition::msgs::ContactSensor* temp = contact_;
  contact_ = nullptr;
  return temp;
}
inline ::ignition::msgs::ContactSensor* Sensor::_internal_mutable_contact() {
  
  if (contact_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::ContactSensor>(GetArenaForAllocation());
    contact_ = p;
  }
  return contact_;
}
inline ::ignition::msgs::ContactSensor* Sensor::mutable_contact() {
  ::ignition::msgs::ContactSensor* _msg = _internal_mutable_contact();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.contact)
  return _msg;
}
inline void Sensor::set_allocated_contact(::ignition::msgs::ContactSensor* contact) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact_);
  }
  if (contact) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(contact));
    if (message_arena != submessage_arena) {
      contact = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, contact, submessage_arena);
    }
    
  } else {
    
  }
  contact_ = contact;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.contact)
}

// bool visualize = 12;
inline void Sensor::clear_visualize() {
  visualize_ = false;
}
inline bool Sensor::_internal_visualize() const {
  return visualize_;
}
inline bool Sensor::visualize() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.visualize)
  return _internal_visualize();
}
inline void Sensor::_internal_set_visualize(bool value) {
  
  visualize_ = value;
}
inline void Sensor::set_visualize(bool value) {
  _internal_set_visualize(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.visualize)
}

// string topic = 13;
inline void Sensor::clear_topic() {
  topic_.ClearToEmpty();
}
inline const std::string& Sensor::topic() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.topic)
  return _internal_topic();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Sensor::set_topic(ArgT0&& arg0, ArgT... args) {
 
 topic_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Sensor.topic)
}
inline std::string* Sensor::mutable_topic() {
  std::string* _s = _internal_mutable_topic();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.topic)
  return _s;
}
inline const std::string& Sensor::_internal_topic() const {
  return topic_.Get();
}
inline void Sensor::_internal_set_topic(const std::string& value) {
  
  topic_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Sensor::_internal_mutable_topic() {
  
  return topic_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Sensor::release_topic() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.topic)
  return topic_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Sensor::set_allocated_topic(std::string* topic) {
  if (topic != nullptr) {
    
  } else {
    
  }
  topic_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), topic,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.topic)
}

// .ignition.msgs.LogicalCameraSensor logical_camera = 14;
inline bool Sensor::_internal_has_logical_camera() const {
  return this != internal_default_instance() && logical_camera_ != nullptr;
}
inline bool Sensor::has_logical_camera() const {
  return _internal_has_logical_camera();
}
inline const ::ignition::msgs::LogicalCameraSensor& Sensor::_internal_logical_camera() const {
  const ::ignition::msgs::LogicalCameraSensor* p = logical_camera_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::LogicalCameraSensor&>(
      ::ignition::msgs::_LogicalCameraSensor_default_instance_);
}
inline const ::ignition::msgs::LogicalCameraSensor& Sensor::logical_camera() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.logical_camera)
  return _internal_logical_camera();
}
inline void Sensor::unsafe_arena_set_allocated_logical_camera(
    ::ignition::msgs::LogicalCameraSensor* logical_camera) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera_);
  }
  logical_camera_ = logical_camera;
  if (logical_camera) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.logical_camera)
}
inline ::ignition::msgs::LogicalCameraSensor* Sensor::release_logical_camera() {
  
  ::ignition::msgs::LogicalCameraSensor* temp = logical_camera_;
  logical_camera_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::LogicalCameraSensor* Sensor::unsafe_arena_release_logical_camera() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.logical_camera)
  
  ::ignition::msgs::LogicalCameraSensor* temp = logical_camera_;
  logical_camera_ = nullptr;
  return temp;
}
inline ::ignition::msgs::LogicalCameraSensor* Sensor::_internal_mutable_logical_camera() {
  
  if (logical_camera_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::LogicalCameraSensor>(GetArenaForAllocation());
    logical_camera_ = p;
  }
  return logical_camera_;
}
inline ::ignition::msgs::LogicalCameraSensor* Sensor::mutable_logical_camera() {
  ::ignition::msgs::LogicalCameraSensor* _msg = _internal_mutable_logical_camera();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.logical_camera)
  return _msg;
}
inline void Sensor::set_allocated_logical_camera(::ignition::msgs::LogicalCameraSensor* logical_camera) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera_);
  }
  if (logical_camera) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(logical_camera));
    if (message_arena != submessage_arena) {
      logical_camera = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, logical_camera, submessage_arena);
    }
    
  } else {
    
  }
  logical_camera_ = logical_camera;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.logical_camera)
}

// .ignition.msgs.GPSSensor gps = 15;
inline bool Sensor::_internal_has_gps() const {
  return this != internal_default_instance() && gps_ != nullptr;
}
inline bool Sensor::has_gps() const {
  return _internal_has_gps();
}
inline const ::ignition::msgs::GPSSensor& Sensor::_internal_gps() const {
  const ::ignition::msgs::GPSSensor* p = gps_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::GPSSensor&>(
      ::ignition::msgs::_GPSSensor_default_instance_);
}
inline const ::ignition::msgs::GPSSensor& Sensor::gps() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.gps)
  return _internal_gps();
}
inline void Sensor::unsafe_arena_set_allocated_gps(
    ::ignition::msgs::GPSSensor* gps) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps_);
  }
  gps_ = gps;
  if (gps) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.gps)
}
inline ::ignition::msgs::GPSSensor* Sensor::release_gps() {
  
  ::ignition::msgs::GPSSensor* temp = gps_;
  gps_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::GPSSensor* Sensor::unsafe_arena_release_gps() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.gps)
  
  ::ignition::msgs::GPSSensor* temp = gps_;
  gps_ = nullptr;
  return temp;
}
inline ::ignition::msgs::GPSSensor* Sensor::_internal_mutable_gps() {
  
  if (gps_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::GPSSensor>(GetArenaForAllocation());
    gps_ = p;
  }
  return gps_;
}
inline ::ignition::msgs::GPSSensor* Sensor::mutable_gps() {
  ::ignition::msgs::GPSSensor* _msg = _internal_mutable_gps();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.gps)
  return _msg;
}
inline void Sensor::set_allocated_gps(::ignition::msgs::GPSSensor* gps) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps_);
  }
  if (gps) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(gps));
    if (message_arena != submessage_arena) {
      gps = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, gps, submessage_arena);
    }
    
  } else {
    
  }
  gps_ = gps;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.gps)
}

// .ignition.msgs.IMUSensor imu = 16;
inline bool Sensor::_internal_has_imu() const {
  return this != internal_default_instance() && imu_ != nullptr;
}
inline bool Sensor::has_imu() const {
  return _internal_has_imu();
}
inline const ::ignition::msgs::IMUSensor& Sensor::_internal_imu() const {
  const ::ignition::msgs::IMUSensor* p = imu_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::IMUSensor&>(
      ::ignition::msgs::_IMUSensor_default_instance_);
}
inline const ::ignition::msgs::IMUSensor& Sensor::imu() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.imu)
  return _internal_imu();
}
inline void Sensor::unsafe_arena_set_allocated_imu(
    ::ignition::msgs::IMUSensor* imu) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu_);
  }
  imu_ = imu;
  if (imu) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.imu)
}
inline ::ignition::msgs::IMUSensor* Sensor::release_imu() {
  
  ::ignition::msgs::IMUSensor* temp = imu_;
  imu_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::IMUSensor* Sensor::unsafe_arena_release_imu() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.imu)
  
  ::ignition::msgs::IMUSensor* temp = imu_;
  imu_ = nullptr;
  return temp;
}
inline ::ignition::msgs::IMUSensor* Sensor::_internal_mutable_imu() {
  
  if (imu_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::IMUSensor>(GetArenaForAllocation());
    imu_ = p;
  }
  return imu_;
}
inline ::ignition::msgs::IMUSensor* Sensor::mutable_imu() {
  ::ignition::msgs::IMUSensor* _msg = _internal_mutable_imu();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.imu)
  return _msg;
}
inline void Sensor::set_allocated_imu(::ignition::msgs::IMUSensor* imu) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu_);
  }
  if (imu) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(imu));
    if (message_arena != submessage_arena) {
      imu = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, imu, submessage_arena);
    }
    
  } else {
    
  }
  imu_ = imu;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.imu)
}

// .ignition.msgs.MagnetometerSensor magnetometer = 17;
inline bool Sensor::_internal_has_magnetometer() const {
  return this != internal_default_instance() && magnetometer_ != nullptr;
}
inline bool Sensor::has_magnetometer() const {
  return _internal_has_magnetometer();
}
inline const ::ignition::msgs::MagnetometerSensor& Sensor::_internal_magnetometer() const {
  const ::ignition::msgs::MagnetometerSensor* p = magnetometer_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::MagnetometerSensor&>(
      ::ignition::msgs::_MagnetometerSensor_default_instance_);
}
inline const ::ignition::msgs::MagnetometerSensor& Sensor::magnetometer() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.magnetometer)
  return _internal_magnetometer();
}
inline void Sensor::unsafe_arena_set_allocated_magnetometer(
    ::ignition::msgs::MagnetometerSensor* magnetometer) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetometer_);
  }
  magnetometer_ = magnetometer;
  if (magnetometer) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.magnetometer)
}
inline ::ignition::msgs::MagnetometerSensor* Sensor::release_magnetometer() {
  
  ::ignition::msgs::MagnetometerSensor* temp = magnetometer_;
  magnetometer_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::MagnetometerSensor* Sensor::unsafe_arena_release_magnetometer() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.magnetometer)
  
  ::ignition::msgs::MagnetometerSensor* temp = magnetometer_;
  magnetometer_ = nullptr;
  return temp;
}
inline ::ignition::msgs::MagnetometerSensor* Sensor::_internal_mutable_magnetometer() {
  
  if (magnetometer_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::MagnetometerSensor>(GetArenaForAllocation());
    magnetometer_ = p;
  }
  return magnetometer_;
}
inline ::ignition::msgs::MagnetometerSensor* Sensor::mutable_magnetometer() {
  ::ignition::msgs::MagnetometerSensor* _msg = _internal_mutable_magnetometer();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.magnetometer)
  return _msg;
}
inline void Sensor::set_allocated_magnetometer(::ignition::msgs::MagnetometerSensor* magnetometer) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetometer_);
  }
  if (magnetometer) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(magnetometer));
    if (message_arena != submessage_arena) {
      magnetometer = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, magnetometer, submessage_arena);
    }
    
  } else {
    
  }
  magnetometer_ = magnetometer;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.magnetometer)
}

// .ignition.msgs.AltimeterSensor altimeter = 18;
inline bool Sensor::_internal_has_altimeter() const {
  return this != internal_default_instance() && altimeter_ != nullptr;
}
inline bool Sensor::has_altimeter() const {
  return _internal_has_altimeter();
}
inline const ::ignition::msgs::AltimeterSensor& Sensor::_internal_altimeter() const {
  const ::ignition::msgs::AltimeterSensor* p = altimeter_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::AltimeterSensor&>(
      ::ignition::msgs::_AltimeterSensor_default_instance_);
}
inline const ::ignition::msgs::AltimeterSensor& Sensor::altimeter() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.altimeter)
  return _internal_altimeter();
}
inline void Sensor::unsafe_arena_set_allocated_altimeter(
    ::ignition::msgs::AltimeterSensor* altimeter) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(altimeter_);
  }
  altimeter_ = altimeter;
  if (altimeter) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.altimeter)
}
inline ::ignition::msgs::AltimeterSensor* Sensor::release_altimeter() {
  
  ::ignition::msgs::AltimeterSensor* temp = altimeter_;
  altimeter_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::AltimeterSensor* Sensor::unsafe_arena_release_altimeter() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.altimeter)
  
  ::ignition::msgs::AltimeterSensor* temp = altimeter_;
  altimeter_ = nullptr;
  return temp;
}
inline ::ignition::msgs::AltimeterSensor* Sensor::_internal_mutable_altimeter() {
  
  if (altimeter_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::AltimeterSensor>(GetArenaForAllocation());
    altimeter_ = p;
  }
  return altimeter_;
}
inline ::ignition::msgs::AltimeterSensor* Sensor::mutable_altimeter() {
  ::ignition::msgs::AltimeterSensor* _msg = _internal_mutable_altimeter();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.altimeter)
  return _msg;
}
inline void Sensor::set_allocated_altimeter(::ignition::msgs::AltimeterSensor* altimeter) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(altimeter_);
  }
  if (altimeter) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(altimeter));
    if (message_arena != submessage_arena) {
      altimeter = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, altimeter, submessage_arena);
    }
    
  } else {
    
  }
  altimeter_ = altimeter;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.altimeter)
}

// .ignition.msgs.AirPressureSensor air_pressure = 19;
inline bool Sensor::_internal_has_air_pressure() const {
  return this != internal_default_instance() && air_pressure_ != nullptr;
}
inline bool Sensor::has_air_pressure() const {
  return _internal_has_air_pressure();
}
inline const ::ignition::msgs::AirPressureSensor& Sensor::_internal_air_pressure() const {
  const ::ignition::msgs::AirPressureSensor* p = air_pressure_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::AirPressureSensor&>(
      ::ignition::msgs::_AirPressureSensor_default_instance_);
}
inline const ::ignition::msgs::AirPressureSensor& Sensor::air_pressure() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.air_pressure)
  return _internal_air_pressure();
}
inline void Sensor::unsafe_arena_set_allocated_air_pressure(
    ::ignition::msgs::AirPressureSensor* air_pressure) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(air_pressure_);
  }
  air_pressure_ = air_pressure;
  if (air_pressure) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.air_pressure)
}
inline ::ignition::msgs::AirPressureSensor* Sensor::release_air_pressure() {
  
  ::ignition::msgs::AirPressureSensor* temp = air_pressure_;
  air_pressure_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::AirPressureSensor* Sensor::unsafe_arena_release_air_pressure() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.air_pressure)
  
  ::ignition::msgs::AirPressureSensor* temp = air_pressure_;
  air_pressure_ = nullptr;
  return temp;
}
inline ::ignition::msgs::AirPressureSensor* Sensor::_internal_mutable_air_pressure() {
  
  if (air_pressure_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::AirPressureSensor>(GetArenaForAllocation());
    air_pressure_ = p;
  }
  return air_pressure_;
}
inline ::ignition::msgs::AirPressureSensor* Sensor::mutable_air_pressure() {
  ::ignition::msgs::AirPressureSensor* _msg = _internal_mutable_air_pressure();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.air_pressure)
  return _msg;
}
inline void Sensor::set_allocated_air_pressure(::ignition::msgs::AirPressureSensor* air_pressure) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(air_pressure_);
  }
  if (air_pressure) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(air_pressure));
    if (message_arena != submessage_arena) {
      air_pressure = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, air_pressure, submessage_arena);
    }
    
  } else {
    
  }
  air_pressure_ = air_pressure;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.air_pressure)
}

// .ignition.msgs.LidarSensor lidar = 20;
inline bool Sensor::_internal_has_lidar() const {
  return this != internal_default_instance() && lidar_ != nullptr;
}
inline bool Sensor::has_lidar() const {
  return _internal_has_lidar();
}
inline const ::ignition::msgs::LidarSensor& Sensor::_internal_lidar() const {
  const ::ignition::msgs::LidarSensor* p = lidar_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::LidarSensor&>(
      ::ignition::msgs::_LidarSensor_default_instance_);
}
inline const ::ignition::msgs::LidarSensor& Sensor::lidar() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Sensor.lidar)
  return _internal_lidar();
}
inline void Sensor::unsafe_arena_set_allocated_lidar(
    ::ignition::msgs::LidarSensor* lidar) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lidar_);
  }
  lidar_ = lidar;
  if (lidar) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Sensor.lidar)
}
inline ::ignition::msgs::LidarSensor* Sensor::release_lidar() {
  
  ::ignition::msgs::LidarSensor* temp = lidar_;
  lidar_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::LidarSensor* Sensor::unsafe_arena_release_lidar() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Sensor.lidar)
  
  ::ignition::msgs::LidarSensor* temp = lidar_;
  lidar_ = nullptr;
  return temp;
}
inline ::ignition::msgs::LidarSensor* Sensor::_internal_mutable_lidar() {
  
  if (lidar_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::LidarSensor>(GetArenaForAllocation());
    lidar_ = p;
  }
  return lidar_;
}
inline ::ignition::msgs::LidarSensor* Sensor::mutable_lidar() {
  ::ignition::msgs::LidarSensor* _msg = _internal_mutable_lidar();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Sensor.lidar)
  return _msg;
}
inline void Sensor::set_allocated_lidar(::ignition::msgs::LidarSensor* lidar) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(lidar_);
  }
  if (lidar) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lidar));
    if (message_arena != submessage_arena) {
      lidar = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, lidar, submessage_arena);
    }
    
  } else {
    
  }
  lidar_ = lidar;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Sensor.lidar)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<Sensor> SensorUniquePtr;
typedef std::unique_ptr<const Sensor> ConstSensorUniquePtr;
typedef std::shared_ptr<Sensor> SensorSharedPtr;
typedef std::shared_ptr<const Sensor> ConstSensorSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fsensor_2eproto
