# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/gui_camera.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/track_visual_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/gui_camera.proto", :syntax => :proto3) do
    add_message "ignition.msgs.GUICamera" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :name, :string, 2
      optional :view_controller, :string, 3
      optional :pose, :message, 4, "ignition.msgs.Pose"
      optional :track, :message, 5, "ignition.msgs.TrackVisual"
      optional :projection_type, :string, 6
    end
  end
end

module Ignition
  module Msgs
    GUICamera = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.GUICamera").msgclass
  end
end
