/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "HeightmapGeomProtos";

/// \ingroup ignition.msgs
/// \interface HeightmapGeom 
/// \brief Message for a heightmap geometry

import "ignition/msgs/image.proto";
import "ignition/msgs/vector3d.proto";
import "ignition/msgs/header.proto";

message HeightmapGeom
{
  /// \brief Optional header data
  Header header           = 1;

  Image  image            = 2; // The height data
  Vector3d size           = 3; // Size in meters
  Vector3d origin         = 4; // Origin in world coordinate frame
  repeated float heights           = 5;
  int32 width             = 6;
  int32 height            = 7;

  message Texture
  {
    string diffuse        = 1;
    string normal         = 2;
    double size           = 3;
  }

  message Blend
  {
    double min_height     = 1;
    double fade_dist      = 2;
  }

  repeated Texture texture         = 8; // List of textures
  repeated Blend blend             = 9; // How to blend the textures
  bool use_terrain_paging = 10; // Enable terrain paging in rendering

  // The image filename
  string filename         = 11;

  // Sample level
  uint32 sampling         = 12;
}
