// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/pointcloud_packed.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[2]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto;
namespace ignition {
namespace msgs {
class PointCloudPacked;
struct PointCloudPackedDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PointCloudPackedDefaultTypeInternal _PointCloudPacked_default_instance_;
class PointCloudPacked_Field;
struct PointCloudPacked_FieldDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern PointCloudPacked_FieldDefaultTypeInternal _PointCloudPacked_Field_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::PointCloudPacked* Arena::CreateMaybeMessage<::ignition::msgs::PointCloudPacked>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::PointCloudPacked_Field* Arena::CreateMaybeMessage<::ignition::msgs::PointCloudPacked_Field>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum PointCloudPacked_Field_DataType : int {
  PointCloudPacked_Field_DataType_INT8 = 0,
  PointCloudPacked_Field_DataType_UINT8 = 1,
  PointCloudPacked_Field_DataType_INT16 = 2,
  PointCloudPacked_Field_DataType_UINT16 = 3,
  PointCloudPacked_Field_DataType_INT32 = 4,
  PointCloudPacked_Field_DataType_UINT32 = 5,
  PointCloudPacked_Field_DataType_FLOAT32 = 6,
  PointCloudPacked_Field_DataType_FLOAT64 = 7,
  PointCloudPacked_Field_DataType_PointCloudPacked_Field_DataType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  PointCloudPacked_Field_DataType_PointCloudPacked_Field_DataType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool PointCloudPacked_Field_DataType_IsValid(int value);
constexpr PointCloudPacked_Field_DataType PointCloudPacked_Field_DataType_DataType_MIN = PointCloudPacked_Field_DataType_INT8;
constexpr PointCloudPacked_Field_DataType PointCloudPacked_Field_DataType_DataType_MAX = PointCloudPacked_Field_DataType_FLOAT64;
constexpr int PointCloudPacked_Field_DataType_DataType_ARRAYSIZE = PointCloudPacked_Field_DataType_DataType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* PointCloudPacked_Field_DataType_descriptor();
template<typename T>
inline const std::string& PointCloudPacked_Field_DataType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, PointCloudPacked_Field_DataType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function PointCloudPacked_Field_DataType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    PointCloudPacked_Field_DataType_descriptor(), enum_t_value);
}
inline bool PointCloudPacked_Field_DataType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, PointCloudPacked_Field_DataType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<PointCloudPacked_Field_DataType>(
    PointCloudPacked_Field_DataType_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE PointCloudPacked_Field final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.PointCloudPacked.Field) */ {
 public:
  inline PointCloudPacked_Field() : PointCloudPacked_Field(nullptr) {}
  ~PointCloudPacked_Field() override;
  explicit constexpr PointCloudPacked_Field(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PointCloudPacked_Field(const PointCloudPacked_Field& from);
  PointCloudPacked_Field(PointCloudPacked_Field&& from) noexcept
    : PointCloudPacked_Field() {
    *this = ::std::move(from);
  }

  inline PointCloudPacked_Field& operator=(const PointCloudPacked_Field& from) {
    CopyFrom(from);
    return *this;
  }
  inline PointCloudPacked_Field& operator=(PointCloudPacked_Field&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PointCloudPacked_Field& default_instance() {
    return *internal_default_instance();
  }
  static inline const PointCloudPacked_Field* internal_default_instance() {
    return reinterpret_cast<const PointCloudPacked_Field*>(
               &_PointCloudPacked_Field_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(PointCloudPacked_Field& a, PointCloudPacked_Field& b) {
    a.Swap(&b);
  }
  inline void Swap(PointCloudPacked_Field* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PointCloudPacked_Field* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline PointCloudPacked_Field* New() const final {
    return new PointCloudPacked_Field();
  }

  PointCloudPacked_Field* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<PointCloudPacked_Field>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PointCloudPacked_Field& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PointCloudPacked_Field& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PointCloudPacked_Field* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.PointCloudPacked.Field";
  }
  protected:
  explicit PointCloudPacked_Field(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef PointCloudPacked_Field_DataType DataType;
  static constexpr DataType INT8 =
    PointCloudPacked_Field_DataType_INT8;
  static constexpr DataType UINT8 =
    PointCloudPacked_Field_DataType_UINT8;
  static constexpr DataType INT16 =
    PointCloudPacked_Field_DataType_INT16;
  static constexpr DataType UINT16 =
    PointCloudPacked_Field_DataType_UINT16;
  static constexpr DataType INT32 =
    PointCloudPacked_Field_DataType_INT32;
  static constexpr DataType UINT32 =
    PointCloudPacked_Field_DataType_UINT32;
  static constexpr DataType FLOAT32 =
    PointCloudPacked_Field_DataType_FLOAT32;
  static constexpr DataType FLOAT64 =
    PointCloudPacked_Field_DataType_FLOAT64;
  static inline bool DataType_IsValid(int value) {
    return PointCloudPacked_Field_DataType_IsValid(value);
  }
  static constexpr DataType DataType_MIN =
    PointCloudPacked_Field_DataType_DataType_MIN;
  static constexpr DataType DataType_MAX =
    PointCloudPacked_Field_DataType_DataType_MAX;
  static constexpr int DataType_ARRAYSIZE =
    PointCloudPacked_Field_DataType_DataType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  DataType_descriptor() {
    return PointCloudPacked_Field_DataType_descriptor();
  }
  template<typename T>
  static inline const std::string& DataType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, DataType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function DataType_Name.");
    return PointCloudPacked_Field_DataType_Name(enum_t_value);
  }
  static inline bool DataType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      DataType* value) {
    return PointCloudPacked_Field_DataType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 1,
    kOffsetFieldNumber = 2,
    kDatatypeFieldNumber = 3,
    kCountFieldNumber = 4,
  };
  // string name = 1;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // uint32 offset = 2;
  void clear_offset();
  ::PROTOBUF_NAMESPACE_ID::uint32 offset() const;
  void set_offset(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_offset() const;
  void _internal_set_offset(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // .ignition.msgs.PointCloudPacked.Field.DataType datatype = 3;
  void clear_datatype();
  ::ignition::msgs::PointCloudPacked_Field_DataType datatype() const;
  void set_datatype(::ignition::msgs::PointCloudPacked_Field_DataType value);
  private:
  ::ignition::msgs::PointCloudPacked_Field_DataType _internal_datatype() const;
  void _internal_set_datatype(::ignition::msgs::PointCloudPacked_Field_DataType value);
  public:

  // uint32 count = 4;
  void clear_count();
  ::PROTOBUF_NAMESPACE_ID::uint32 count() const;
  void set_count(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_count() const;
  void _internal_set_count(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.PointCloudPacked.Field)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::uint32 offset_;
  int datatype_;
  ::PROTOBUF_NAMESPACE_ID::uint32 count_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE PointCloudPacked final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.PointCloudPacked) */ {
 public:
  inline PointCloudPacked() : PointCloudPacked(nullptr) {}
  ~PointCloudPacked() override;
  explicit constexpr PointCloudPacked(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  PointCloudPacked(const PointCloudPacked& from);
  PointCloudPacked(PointCloudPacked&& from) noexcept
    : PointCloudPacked() {
    *this = ::std::move(from);
  }

  inline PointCloudPacked& operator=(const PointCloudPacked& from) {
    CopyFrom(from);
    return *this;
  }
  inline PointCloudPacked& operator=(PointCloudPacked&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const PointCloudPacked& default_instance() {
    return *internal_default_instance();
  }
  static inline const PointCloudPacked* internal_default_instance() {
    return reinterpret_cast<const PointCloudPacked*>(
               &_PointCloudPacked_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(PointCloudPacked& a, PointCloudPacked& b) {
    a.Swap(&b);
  }
  inline void Swap(PointCloudPacked* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(PointCloudPacked* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline PointCloudPacked* New() const final {
    return new PointCloudPacked();
  }

  PointCloudPacked* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<PointCloudPacked>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const PointCloudPacked& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const PointCloudPacked& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(PointCloudPacked* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.PointCloudPacked";
  }
  protected:
  explicit PointCloudPacked(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef PointCloudPacked_Field Field;

  // accessors -------------------------------------------------------

  enum : int {
    kFieldFieldNumber = 2,
    kDataFieldNumber = 8,
    kHeaderFieldNumber = 1,
    kHeightFieldNumber = 3,
    kWidthFieldNumber = 4,
    kPointStepFieldNumber = 6,
    kRowStepFieldNumber = 7,
    kIsBigendianFieldNumber = 5,
    kIsDenseFieldNumber = 9,
  };
  // repeated .ignition.msgs.PointCloudPacked.Field field = 2;
  int field_size() const;
  private:
  int _internal_field_size() const;
  public:
  void clear_field();
  ::ignition::msgs::PointCloudPacked_Field* mutable_field(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::PointCloudPacked_Field >*
      mutable_field();
  private:
  const ::ignition::msgs::PointCloudPacked_Field& _internal_field(int index) const;
  ::ignition::msgs::PointCloudPacked_Field* _internal_add_field();
  public:
  const ::ignition::msgs::PointCloudPacked_Field& field(int index) const;
  ::ignition::msgs::PointCloudPacked_Field* add_field();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::PointCloudPacked_Field >&
      field() const;

  // bytes data = 8;
  void clear_data();
  const std::string& data() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_data(ArgT0&& arg0, ArgT... args);
  std::string* mutable_data();
  PROTOBUF_MUST_USE_RESULT std::string* release_data();
  void set_allocated_data(std::string* data);
  private:
  const std::string& _internal_data() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_data(const std::string& value);
  std::string* _internal_mutable_data();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // uint32 height = 3;
  void clear_height();
  ::PROTOBUF_NAMESPACE_ID::uint32 height() const;
  void set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_height() const;
  void _internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 width = 4;
  void clear_width();
  ::PROTOBUF_NAMESPACE_ID::uint32 width() const;
  void set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_width() const;
  void _internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 point_step = 6;
  void clear_point_step();
  ::PROTOBUF_NAMESPACE_ID::uint32 point_step() const;
  void set_point_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_point_step() const;
  void _internal_set_point_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 row_step = 7;
  void clear_row_step();
  ::PROTOBUF_NAMESPACE_ID::uint32 row_step() const;
  void set_row_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_row_step() const;
  void _internal_set_row_step(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // bool is_bigendian = 5;
  void clear_is_bigendian();
  bool is_bigendian() const;
  void set_is_bigendian(bool value);
  private:
  bool _internal_is_bigendian() const;
  void _internal_set_is_bigendian(bool value);
  public:

  // bool is_dense = 9;
  void clear_is_dense();
  bool is_dense() const;
  void set_is_dense(bool value);
  private:
  bool _internal_is_dense() const;
  void _internal_set_is_dense(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.PointCloudPacked)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::PointCloudPacked_Field > field_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr data_;
  ::ignition::msgs::Header* header_;
  ::PROTOBUF_NAMESPACE_ID::uint32 height_;
  ::PROTOBUF_NAMESPACE_ID::uint32 width_;
  ::PROTOBUF_NAMESPACE_ID::uint32 point_step_;
  ::PROTOBUF_NAMESPACE_ID::uint32 row_step_;
  bool is_bigendian_;
  bool is_dense_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// PointCloudPacked_Field

// string name = 1;
inline void PointCloudPacked_Field::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& PointCloudPacked_Field::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.Field.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void PointCloudPacked_Field::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.Field.name)
}
inline std::string* PointCloudPacked_Field::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PointCloudPacked.Field.name)
  return _s;
}
inline const std::string& PointCloudPacked_Field::_internal_name() const {
  return name_.Get();
}
inline void PointCloudPacked_Field::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* PointCloudPacked_Field::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* PointCloudPacked_Field::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PointCloudPacked.Field.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void PointCloudPacked_Field::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PointCloudPacked.Field.name)
}

// uint32 offset = 2;
inline void PointCloudPacked_Field::clear_offset() {
  offset_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked_Field::_internal_offset() const {
  return offset_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked_Field::offset() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.Field.offset)
  return _internal_offset();
}
inline void PointCloudPacked_Field::_internal_set_offset(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  offset_ = value;
}
inline void PointCloudPacked_Field::set_offset(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_offset(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.Field.offset)
}

// .ignition.msgs.PointCloudPacked.Field.DataType datatype = 3;
inline void PointCloudPacked_Field::clear_datatype() {
  datatype_ = 0;
}
inline ::ignition::msgs::PointCloudPacked_Field_DataType PointCloudPacked_Field::_internal_datatype() const {
  return static_cast< ::ignition::msgs::PointCloudPacked_Field_DataType >(datatype_);
}
inline ::ignition::msgs::PointCloudPacked_Field_DataType PointCloudPacked_Field::datatype() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.Field.datatype)
  return _internal_datatype();
}
inline void PointCloudPacked_Field::_internal_set_datatype(::ignition::msgs::PointCloudPacked_Field_DataType value) {
  
  datatype_ = value;
}
inline void PointCloudPacked_Field::set_datatype(::ignition::msgs::PointCloudPacked_Field_DataType value) {
  _internal_set_datatype(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.Field.datatype)
}

// uint32 count = 4;
inline void PointCloudPacked_Field::clear_count() {
  count_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked_Field::_internal_count() const {
  return count_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked_Field::count() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.Field.count)
  return _internal_count();
}
inline void PointCloudPacked_Field::_internal_set_count(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  count_ = value;
}
inline void PointCloudPacked_Field::set_count(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_count(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.Field.count)
}

// -------------------------------------------------------------------

// PointCloudPacked

// .ignition.msgs.Header header = 1;
inline bool PointCloudPacked::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool PointCloudPacked::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& PointCloudPacked::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& PointCloudPacked::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.header)
  return _internal_header();
}
inline void PointCloudPacked::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.PointCloudPacked.header)
}
inline ::ignition::msgs::Header* PointCloudPacked::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* PointCloudPacked::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PointCloudPacked.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* PointCloudPacked::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* PointCloudPacked::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PointCloudPacked.header)
  return _msg;
}
inline void PointCloudPacked::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PointCloudPacked.header)
}

// repeated .ignition.msgs.PointCloudPacked.Field field = 2;
inline int PointCloudPacked::_internal_field_size() const {
  return field_.size();
}
inline int PointCloudPacked::field_size() const {
  return _internal_field_size();
}
inline void PointCloudPacked::clear_field() {
  field_.Clear();
}
inline ::ignition::msgs::PointCloudPacked_Field* PointCloudPacked::mutable_field(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PointCloudPacked.field)
  return field_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::PointCloudPacked_Field >*
PointCloudPacked::mutable_field() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.PointCloudPacked.field)
  return &field_;
}
inline const ::ignition::msgs::PointCloudPacked_Field& PointCloudPacked::_internal_field(int index) const {
  return field_.Get(index);
}
inline const ::ignition::msgs::PointCloudPacked_Field& PointCloudPacked::field(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.field)
  return _internal_field(index);
}
inline ::ignition::msgs::PointCloudPacked_Field* PointCloudPacked::_internal_add_field() {
  return field_.Add();
}
inline ::ignition::msgs::PointCloudPacked_Field* PointCloudPacked::add_field() {
  ::ignition::msgs::PointCloudPacked_Field* _add = _internal_add_field();
  // @@protoc_insertion_point(field_add:ignition.msgs.PointCloudPacked.field)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::PointCloudPacked_Field >&
PointCloudPacked::field() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.PointCloudPacked.field)
  return field_;
}

// uint32 height = 3;
inline void PointCloudPacked::clear_height() {
  height_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::_internal_height() const {
  return height_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::height() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.height)
  return _internal_height();
}
inline void PointCloudPacked::_internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  height_ = value;
}
inline void PointCloudPacked::set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_height(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.height)
}

// uint32 width = 4;
inline void PointCloudPacked::clear_width() {
  width_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::_internal_width() const {
  return width_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::width() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.width)
  return _internal_width();
}
inline void PointCloudPacked::_internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  width_ = value;
}
inline void PointCloudPacked::set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_width(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.width)
}

// bool is_bigendian = 5;
inline void PointCloudPacked::clear_is_bigendian() {
  is_bigendian_ = false;
}
inline bool PointCloudPacked::_internal_is_bigendian() const {
  return is_bigendian_;
}
inline bool PointCloudPacked::is_bigendian() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.is_bigendian)
  return _internal_is_bigendian();
}
inline void PointCloudPacked::_internal_set_is_bigendian(bool value) {
  
  is_bigendian_ = value;
}
inline void PointCloudPacked::set_is_bigendian(bool value) {
  _internal_set_is_bigendian(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.is_bigendian)
}

// uint32 point_step = 6;
inline void PointCloudPacked::clear_point_step() {
  point_step_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::_internal_point_step() const {
  return point_step_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::point_step() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.point_step)
  return _internal_point_step();
}
inline void PointCloudPacked::_internal_set_point_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  point_step_ = value;
}
inline void PointCloudPacked::set_point_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_point_step(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.point_step)
}

// uint32 row_step = 7;
inline void PointCloudPacked::clear_row_step() {
  row_step_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::_internal_row_step() const {
  return row_step_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 PointCloudPacked::row_step() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.row_step)
  return _internal_row_step();
}
inline void PointCloudPacked::_internal_set_row_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  row_step_ = value;
}
inline void PointCloudPacked::set_row_step(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_row_step(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.row_step)
}

// bytes data = 8;
inline void PointCloudPacked::clear_data() {
  data_.ClearToEmpty();
}
inline const std::string& PointCloudPacked::data() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.data)
  return _internal_data();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void PointCloudPacked::set_data(ArgT0&& arg0, ArgT... args) {
 
 data_.SetBytes(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.data)
}
inline std::string* PointCloudPacked::mutable_data() {
  std::string* _s = _internal_mutable_data();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.PointCloudPacked.data)
  return _s;
}
inline const std::string& PointCloudPacked::_internal_data() const {
  return data_.Get();
}
inline void PointCloudPacked::_internal_set_data(const std::string& value) {
  
  data_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* PointCloudPacked::_internal_mutable_data() {
  
  return data_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* PointCloudPacked::release_data() {
  // @@protoc_insertion_point(field_release:ignition.msgs.PointCloudPacked.data)
  return data_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void PointCloudPacked::set_allocated_data(std::string* data) {
  if (data != nullptr) {
    
  } else {
    
  }
  data_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), data,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.PointCloudPacked.data)
}

// bool is_dense = 9;
inline void PointCloudPacked::clear_is_dense() {
  is_dense_ = false;
}
inline bool PointCloudPacked::_internal_is_dense() const {
  return is_dense_;
}
inline bool PointCloudPacked::is_dense() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.PointCloudPacked.is_dense)
  return _internal_is_dense();
}
inline void PointCloudPacked::_internal_set_is_dense(bool value) {
  
  is_dense_ = value;
}
inline void PointCloudPacked::set_is_dense(bool value) {
  _internal_set_is_dense(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.PointCloudPacked.is_dense)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------


typedef std::unique_ptr<PointCloudPacked> PointCloudPackedUniquePtr;
typedef std::unique_ptr<const PointCloudPacked> ConstPointCloudPackedUniquePtr;
typedef std::shared_ptr<PointCloudPacked> PointCloudPackedSharedPtr;
typedef std::shared_ptr<const PointCloudPacked> ConstPointCloudPackedSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::PointCloudPacked_Field_DataType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::PointCloudPacked_Field_DataType>() {
  return ::ignition::msgs::PointCloudPacked_Field_DataType_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fpointcloud_5fpacked_2eproto
