# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/gui.proto

require 'ignition/msgs/gui_camera_pb'
require 'ignition/msgs/plugin_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/gui.proto", :syntax => :proto3) do
    add_message "ignition.msgs.GUI" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :fullscreen, :bool, 2
      optional :camera, :message, 3, "ignition.msgs.GUICamera"
      repeated :plugin, :message, 4, "ignition.msgs.Plugin"
    end
  end
end

module Ignition
  module Msgs
    GUI = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.GUI").msgclass
  end
end
