# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/gps.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/gps.proto", :syntax => :proto3) do
    add_message "ignition.msgs.GPS" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :link_name, :string, 2
      optional :latitude_deg, :double, 3
      optional :longitude_deg, :double, 4
      optional :altitude, :double, 5
      optional :velocity_east, :double, 6
      optional :velocity_north, :double, 7
      optional :velocity_up, :double, 8
    end
  end
end

module Ignition
  module Msgs
    GPS = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.GPS").msgclass
  end
end
