# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/heightmapgeom.proto

require 'ignition/msgs/image_pb'
require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/heightmapgeom.proto", :syntax => :proto3) do
    add_message "ignition.msgs.HeightmapGeom" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :image, :message, 2, "ignition.msgs.Image"
      optional :size, :message, 3, "ignition.msgs.Vector3d"
      optional :origin, :message, 4, "ignition.msgs.Vector3d"
      repeated :heights, :float, 5
      optional :width, :int32, 6
      optional :height, :int32, 7
      repeated :texture, :message, 8, "ignition.msgs.HeightmapGeom.Texture"
      repeated :blend, :message, 9, "ignition.msgs.HeightmapGeom.Blend"
      optional :use_terrain_paging, :bool, 10
      optional :filename, :string, 11
      optional :sampling, :uint32, 12
    end
    add_message "ignition.msgs.HeightmapGeom.Texture" do
      optional :diffuse, :string, 1
      optional :normal, :string, 2
      optional :size, :double, 3
    end
    add_message "ignition.msgs.HeightmapGeom.Blend" do
      optional :min_height, :double, 1
      optional :fade_dist, :double, 2
    end
  end
end

module Ignition
  module Msgs
    HeightmapGeom = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.HeightmapGeom").msgclass
    HeightmapGeom::Texture = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.HeightmapGeom.Texture").msgclass
    HeightmapGeom::Blend = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.HeightmapGeom.Blend").msgclass
  end
end
