# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/pointcloud_packed.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/pointcloud_packed.proto", :syntax => :proto3) do
    add_message "ignition.msgs.PointCloudPacked" do
      optional :header, :message, 1, "ignition.msgs.Header"
      repeated :field, :message, 2, "ignition.msgs.PointCloudPacked.Field"
      optional :height, :uint32, 3
      optional :width, :uint32, 4
      optional :is_bigendian, :bool, 5
      optional :point_step, :uint32, 6
      optional :row_step, :uint32, 7
      optional :data, :bytes, 8
      optional :is_dense, :bool, 9
    end
    add_message "ignition.msgs.PointCloudPacked.Field" do
      optional :name, :string, 1
      optional :offset, :uint32, 2
      optional :datatype, :enum, 3, "ignition.msgs.PointCloudPacked.Field.DataType"
      optional :count, :uint32, 4
    end
    add_enum "ignition.msgs.PointCloudPacked.Field.DataType" do
      value :INT8, 0
      value :UINT8, 1
      value :INT16, 2
      value :UINT16, 3
      value :INT32, 4
      value :UINT32, 5
      value :FLOAT32, 6
      value :FLOAT64, 7
    end
  end
end

module Ignition
  module Msgs
    PointCloudPacked = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PointCloudPacked").msgclass
    PointCloudPacked::Field = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PointCloudPacked.Field").msgclass
    PointCloudPacked::Field::DataType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.PointCloudPacked.Field.DataType").enummodule
  end
end
