# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/joint_animation.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/joint_animation.proto", :syntax => :proto3) do
    add_message "ignition.msgs.JointAnimation" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :model_name, :string, 2
      repeated :joint, :message, 3, "ignition.msgs.JointAnimation.Joint"
      repeated :time, :message, 4, "ignition.msgs.Time"
    end
    add_message "ignition.msgs.JointAnimation.Joint" do
      repeated :name, :string, 1
      repeated :angle, :double, 2
    end
  end
end

module Ignition
  module Msgs
    JointAnimation = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.JointAnimation").msgclass
    JointAnimation::Joint = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.JointAnimation.Joint").msgclass
  end
end
