/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "Protos";

/// \ingroup ignition.msgs
/// \interface SensorNoise
/// \brief Information about a sensor noise

import "ignition/msgs/header.proto";

message SensorNoise
{
  /// \brief Noise types
  enum Type
  {
    /// \brief No noise
    NONE               = 0;

    /// \brief Gaussian noise
    GAUSSIAN           = 2;

    /// \brief Gaussian noise plus quantization of outputs (rounding)
    GAUSSIAN_QUANTIZED = 3;
  }

  /// \brief Optional header data
  Header header      = 1;

  /// \brief The type of noise
  Type type          = 2;

  /// \brief Noise mean
  /// Used by GAUSSIAN, and GAUSSIAN_QUANTIZED
  double mean        = 3;

  /// \brief Noise standard deviation
  /// Used by GAUSSIAN, and GAUSSIAN_QUANTIZED
  double stddev      = 4;

  /// \brief Noise mean bias
  /// Used by GAUSSIAN, and GAUSSIAN_QUANTIZED
  double bias_mean   = 5;

  /// \brief Noise standard deviation bias
  /// Used by GAUSSIAN, and GAUSSIAN_QUANTIZED
  double bias_stddev = 6;

  /// \brief Noise  precision.
  /// Used by GAUSSIAN_QUANTIZED
  double precision   = 7;

  /// \brief For type "gaussian*", the standard deviation of the noise used to
  /// drive a process to model slow variations in a sensor bias.
  double dynamic_bias_stddev           = 8;

  /// \brief For type "gaussian*", the correlation time in seconds of the
  /// noise used to drive a process to model slow variations in a sensor bias.
  /// A typical value, when used, would be on the order of
  /// 3600 seconds (1 hour).
  double dynamic_bias_correlation_time = 9;
}
