// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/battery_state.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fbattery_5fstate_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fbattery_5fstate_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fbattery_5fstate_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fbattery_5fstate_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fbattery_5fstate_2eproto;
namespace ignition {
namespace msgs {
class BatteryState;
struct BatteryStateDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern BatteryStateDefaultTypeInternal _BatteryState_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::BatteryState* Arena::CreateMaybeMessage<::ignition::msgs::BatteryState>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum BatteryState_PowerSupplyStatus : int {
  BatteryState_PowerSupplyStatus_UNKNOWN = 0,
  BatteryState_PowerSupplyStatus_CHARGING = 1,
  BatteryState_PowerSupplyStatus_DISCHARGING = 2,
  BatteryState_PowerSupplyStatus_NOT_CHARGING = 3,
  BatteryState_PowerSupplyStatus_FULL = 4,
  BatteryState_PowerSupplyStatus_BatteryState_PowerSupplyStatus_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  BatteryState_PowerSupplyStatus_BatteryState_PowerSupplyStatus_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool BatteryState_PowerSupplyStatus_IsValid(int value);
constexpr BatteryState_PowerSupplyStatus BatteryState_PowerSupplyStatus_PowerSupplyStatus_MIN = BatteryState_PowerSupplyStatus_UNKNOWN;
constexpr BatteryState_PowerSupplyStatus BatteryState_PowerSupplyStatus_PowerSupplyStatus_MAX = BatteryState_PowerSupplyStatus_FULL;
constexpr int BatteryState_PowerSupplyStatus_PowerSupplyStatus_ARRAYSIZE = BatteryState_PowerSupplyStatus_PowerSupplyStatus_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* BatteryState_PowerSupplyStatus_descriptor();
template<typename T>
inline const std::string& BatteryState_PowerSupplyStatus_Name(T enum_t_value) {
  static_assert(::std::is_same<T, BatteryState_PowerSupplyStatus>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function BatteryState_PowerSupplyStatus_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    BatteryState_PowerSupplyStatus_descriptor(), enum_t_value);
}
inline bool BatteryState_PowerSupplyStatus_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, BatteryState_PowerSupplyStatus* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<BatteryState_PowerSupplyStatus>(
    BatteryState_PowerSupplyStatus_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE BatteryState final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.BatteryState) */ {
 public:
  inline BatteryState() : BatteryState(nullptr) {}
  ~BatteryState() override;
  explicit constexpr BatteryState(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  BatteryState(const BatteryState& from);
  BatteryState(BatteryState&& from) noexcept
    : BatteryState() {
    *this = ::std::move(from);
  }

  inline BatteryState& operator=(const BatteryState& from) {
    CopyFrom(from);
    return *this;
  }
  inline BatteryState& operator=(BatteryState&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const BatteryState& default_instance() {
    return *internal_default_instance();
  }
  static inline const BatteryState* internal_default_instance() {
    return reinterpret_cast<const BatteryState*>(
               &_BatteryState_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(BatteryState& a, BatteryState& b) {
    a.Swap(&b);
  }
  inline void Swap(BatteryState* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(BatteryState* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline BatteryState* New() const final {
    return new BatteryState();
  }

  BatteryState* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<BatteryState>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const BatteryState& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const BatteryState& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(BatteryState* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.BatteryState";
  }
  protected:
  explicit BatteryState(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef BatteryState_PowerSupplyStatus PowerSupplyStatus;
  static constexpr PowerSupplyStatus UNKNOWN =
    BatteryState_PowerSupplyStatus_UNKNOWN;
  static constexpr PowerSupplyStatus CHARGING =
    BatteryState_PowerSupplyStatus_CHARGING;
  static constexpr PowerSupplyStatus DISCHARGING =
    BatteryState_PowerSupplyStatus_DISCHARGING;
  static constexpr PowerSupplyStatus NOT_CHARGING =
    BatteryState_PowerSupplyStatus_NOT_CHARGING;
  static constexpr PowerSupplyStatus FULL =
    BatteryState_PowerSupplyStatus_FULL;
  static inline bool PowerSupplyStatus_IsValid(int value) {
    return BatteryState_PowerSupplyStatus_IsValid(value);
  }
  static constexpr PowerSupplyStatus PowerSupplyStatus_MIN =
    BatteryState_PowerSupplyStatus_PowerSupplyStatus_MIN;
  static constexpr PowerSupplyStatus PowerSupplyStatus_MAX =
    BatteryState_PowerSupplyStatus_PowerSupplyStatus_MAX;
  static constexpr int PowerSupplyStatus_ARRAYSIZE =
    BatteryState_PowerSupplyStatus_PowerSupplyStatus_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  PowerSupplyStatus_descriptor() {
    return BatteryState_PowerSupplyStatus_descriptor();
  }
  template<typename T>
  static inline const std::string& PowerSupplyStatus_Name(T enum_t_value) {
    static_assert(::std::is_same<T, PowerSupplyStatus>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function PowerSupplyStatus_Name.");
    return BatteryState_PowerSupplyStatus_Name(enum_t_value);
  }
  static inline bool PowerSupplyStatus_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      PowerSupplyStatus* value) {
    return BatteryState_PowerSupplyStatus_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kHeaderFieldNumber = 1,
    kVoltageFieldNumber = 2,
    kCurrentFieldNumber = 3,
    kChargeFieldNumber = 4,
    kCapacityFieldNumber = 5,
    kPercentageFieldNumber = 6,
    kPowerSupplyStatusFieldNumber = 7,
  };
  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // double voltage = 2;
  void clear_voltage();
  double voltage() const;
  void set_voltage(double value);
  private:
  double _internal_voltage() const;
  void _internal_set_voltage(double value);
  public:

  // double current = 3;
  void clear_current();
  double current() const;
  void set_current(double value);
  private:
  double _internal_current() const;
  void _internal_set_current(double value);
  public:

  // double charge = 4;
  void clear_charge();
  double charge() const;
  void set_charge(double value);
  private:
  double _internal_charge() const;
  void _internal_set_charge(double value);
  public:

  // double capacity = 5;
  void clear_capacity();
  double capacity() const;
  void set_capacity(double value);
  private:
  double _internal_capacity() const;
  void _internal_set_capacity(double value);
  public:

  // double percentage = 6;
  void clear_percentage();
  double percentage() const;
  void set_percentage(double value);
  private:
  double _internal_percentage() const;
  void _internal_set_percentage(double value);
  public:

  // .ignition.msgs.BatteryState.PowerSupplyStatus power_supply_status = 7;
  void clear_power_supply_status();
  ::ignition::msgs::BatteryState_PowerSupplyStatus power_supply_status() const;
  void set_power_supply_status(::ignition::msgs::BatteryState_PowerSupplyStatus value);
  private:
  ::ignition::msgs::BatteryState_PowerSupplyStatus _internal_power_supply_status() const;
  void _internal_set_power_supply_status(::ignition::msgs::BatteryState_PowerSupplyStatus value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.BatteryState)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Header* header_;
  double voltage_;
  double current_;
  double charge_;
  double capacity_;
  double percentage_;
  int power_supply_status_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fbattery_5fstate_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// BatteryState

// .ignition.msgs.Header header = 1;
inline bool BatteryState::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool BatteryState::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& BatteryState::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& BatteryState::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.header)
  return _internal_header();
}
inline void BatteryState::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.BatteryState.header)
}
inline ::ignition::msgs::Header* BatteryState::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* BatteryState::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.BatteryState.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* BatteryState::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* BatteryState::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.BatteryState.header)
  return _msg;
}
inline void BatteryState::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.BatteryState.header)
}

// double voltage = 2;
inline void BatteryState::clear_voltage() {
  voltage_ = 0;
}
inline double BatteryState::_internal_voltage() const {
  return voltage_;
}
inline double BatteryState::voltage() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.voltage)
  return _internal_voltage();
}
inline void BatteryState::_internal_set_voltage(double value) {
  
  voltage_ = value;
}
inline void BatteryState::set_voltage(double value) {
  _internal_set_voltage(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.voltage)
}

// double current = 3;
inline void BatteryState::clear_current() {
  current_ = 0;
}
inline double BatteryState::_internal_current() const {
  return current_;
}
inline double BatteryState::current() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.current)
  return _internal_current();
}
inline void BatteryState::_internal_set_current(double value) {
  
  current_ = value;
}
inline void BatteryState::set_current(double value) {
  _internal_set_current(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.current)
}

// double charge = 4;
inline void BatteryState::clear_charge() {
  charge_ = 0;
}
inline double BatteryState::_internal_charge() const {
  return charge_;
}
inline double BatteryState::charge() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.charge)
  return _internal_charge();
}
inline void BatteryState::_internal_set_charge(double value) {
  
  charge_ = value;
}
inline void BatteryState::set_charge(double value) {
  _internal_set_charge(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.charge)
}

// double capacity = 5;
inline void BatteryState::clear_capacity() {
  capacity_ = 0;
}
inline double BatteryState::_internal_capacity() const {
  return capacity_;
}
inline double BatteryState::capacity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.capacity)
  return _internal_capacity();
}
inline void BatteryState::_internal_set_capacity(double value) {
  
  capacity_ = value;
}
inline void BatteryState::set_capacity(double value) {
  _internal_set_capacity(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.capacity)
}

// double percentage = 6;
inline void BatteryState::clear_percentage() {
  percentage_ = 0;
}
inline double BatteryState::_internal_percentage() const {
  return percentage_;
}
inline double BatteryState::percentage() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.percentage)
  return _internal_percentage();
}
inline void BatteryState::_internal_set_percentage(double value) {
  
  percentage_ = value;
}
inline void BatteryState::set_percentage(double value) {
  _internal_set_percentage(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.percentage)
}

// .ignition.msgs.BatteryState.PowerSupplyStatus power_supply_status = 7;
inline void BatteryState::clear_power_supply_status() {
  power_supply_status_ = 0;
}
inline ::ignition::msgs::BatteryState_PowerSupplyStatus BatteryState::_internal_power_supply_status() const {
  return static_cast< ::ignition::msgs::BatteryState_PowerSupplyStatus >(power_supply_status_);
}
inline ::ignition::msgs::BatteryState_PowerSupplyStatus BatteryState::power_supply_status() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.BatteryState.power_supply_status)
  return _internal_power_supply_status();
}
inline void BatteryState::_internal_set_power_supply_status(::ignition::msgs::BatteryState_PowerSupplyStatus value) {
  
  power_supply_status_ = value;
}
inline void BatteryState::set_power_supply_status(::ignition::msgs::BatteryState_PowerSupplyStatus value) {
  _internal_set_power_supply_status(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.BatteryState.power_supply_status)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<BatteryState> BatteryStateUniquePtr;
typedef std::unique_ptr<const BatteryState> ConstBatteryStateUniquePtr;
typedef std::shared_ptr<BatteryState> BatteryStateSharedPtr;
typedef std::shared_ptr<const BatteryState> ConstBatteryStateSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::BatteryState_PowerSupplyStatus> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::BatteryState_PowerSupplyStatus>() {
  return ::ignition::msgs::BatteryState_PowerSupplyStatus_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fbattery_5fstate_2eproto
