// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/actor.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2factor_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2factor_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/entity.pb.h"
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/pose.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2factor_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2factor_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[4]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2factor_2eproto;
namespace ignition {
namespace msgs {
class Actor;
struct ActorDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern ActorDefaultTypeInternal _Actor_default_instance_;
class Actor_Animation;
struct Actor_AnimationDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern Actor_AnimationDefaultTypeInternal _Actor_Animation_default_instance_;
class Actor_Trajectory;
struct Actor_TrajectoryDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern Actor_TrajectoryDefaultTypeInternal _Actor_Trajectory_default_instance_;
class Actor_Waypoint;
struct Actor_WaypointDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern Actor_WaypointDefaultTypeInternal _Actor_Waypoint_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Actor* Arena::CreateMaybeMessage<::ignition::msgs::Actor>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Actor_Animation* Arena::CreateMaybeMessage<::ignition::msgs::Actor_Animation>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Actor_Trajectory* Arena::CreateMaybeMessage<::ignition::msgs::Actor_Trajectory>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::Actor_Waypoint* Arena::CreateMaybeMessage<::ignition::msgs::Actor_Waypoint>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE Actor_Animation final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Actor.Animation) */ {
 public:
  inline Actor_Animation() : Actor_Animation(nullptr) {}
  ~Actor_Animation() override;
  explicit constexpr Actor_Animation(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Actor_Animation(const Actor_Animation& from);
  Actor_Animation(Actor_Animation&& from) noexcept
    : Actor_Animation() {
    *this = ::std::move(from);
  }

  inline Actor_Animation& operator=(const Actor_Animation& from) {
    CopyFrom(from);
    return *this;
  }
  inline Actor_Animation& operator=(Actor_Animation&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Actor_Animation& default_instance() {
    return *internal_default_instance();
  }
  static inline const Actor_Animation* internal_default_instance() {
    return reinterpret_cast<const Actor_Animation*>(
               &_Actor_Animation_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(Actor_Animation& a, Actor_Animation& b) {
    a.Swap(&b);
  }
  inline void Swap(Actor_Animation* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Actor_Animation* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Actor_Animation* New() const final {
    return new Actor_Animation();
  }

  Actor_Animation* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Actor_Animation>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Actor_Animation& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Actor_Animation& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Actor_Animation* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Actor.Animation";
  }
  protected:
  explicit Actor_Animation(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 1,
    kFilenameFieldNumber = 2,
    kScaleFieldNumber = 3,
    kInterpolateXFieldNumber = 4,
  };
  // string name = 1;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // string filename = 2;
  void clear_filename();
  const std::string& filename() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_filename(ArgT0&& arg0, ArgT... args);
  std::string* mutable_filename();
  PROTOBUF_MUST_USE_RESULT std::string* release_filename();
  void set_allocated_filename(std::string* filename);
  private:
  const std::string& _internal_filename() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_filename(const std::string& value);
  std::string* _internal_mutable_filename();
  public:

  // float scale = 3;
  void clear_scale();
  float scale() const;
  void set_scale(float value);
  private:
  float _internal_scale() const;
  void _internal_set_scale(float value);
  public:

  // bool interpolate_x = 4;
  void clear_interpolate_x();
  bool interpolate_x() const;
  void set_interpolate_x(bool value);
  private:
  bool _internal_interpolate_x() const;
  void _internal_set_interpolate_x(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Actor.Animation)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr filename_;
  float scale_;
  bool interpolate_x_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2factor_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE Actor_Waypoint final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Actor.Waypoint) */ {
 public:
  inline Actor_Waypoint() : Actor_Waypoint(nullptr) {}
  ~Actor_Waypoint() override;
  explicit constexpr Actor_Waypoint(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Actor_Waypoint(const Actor_Waypoint& from);
  Actor_Waypoint(Actor_Waypoint&& from) noexcept
    : Actor_Waypoint() {
    *this = ::std::move(from);
  }

  inline Actor_Waypoint& operator=(const Actor_Waypoint& from) {
    CopyFrom(from);
    return *this;
  }
  inline Actor_Waypoint& operator=(Actor_Waypoint&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Actor_Waypoint& default_instance() {
    return *internal_default_instance();
  }
  static inline const Actor_Waypoint* internal_default_instance() {
    return reinterpret_cast<const Actor_Waypoint*>(
               &_Actor_Waypoint_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(Actor_Waypoint& a, Actor_Waypoint& b) {
    a.Swap(&b);
  }
  inline void Swap(Actor_Waypoint* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Actor_Waypoint* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Actor_Waypoint* New() const final {
    return new Actor_Waypoint();
  }

  Actor_Waypoint* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Actor_Waypoint>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Actor_Waypoint& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Actor_Waypoint& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Actor_Waypoint* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Actor.Waypoint";
  }
  protected:
  explicit Actor_Waypoint(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPoseFieldNumber = 2,
    kTimeFieldNumber = 1,
  };
  // .ignition.msgs.Pose pose = 2;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // float time = 1;
  void clear_time();
  float time() const;
  void set_time(float value);
  private:
  float _internal_time() const;
  void _internal_set_time(float value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Actor.Waypoint)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::Pose* pose_;
  float time_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2factor_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE Actor_Trajectory final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Actor.Trajectory) */ {
 public:
  inline Actor_Trajectory() : Actor_Trajectory(nullptr) {}
  ~Actor_Trajectory() override;
  explicit constexpr Actor_Trajectory(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Actor_Trajectory(const Actor_Trajectory& from);
  Actor_Trajectory(Actor_Trajectory&& from) noexcept
    : Actor_Trajectory() {
    *this = ::std::move(from);
  }

  inline Actor_Trajectory& operator=(const Actor_Trajectory& from) {
    CopyFrom(from);
    return *this;
  }
  inline Actor_Trajectory& operator=(Actor_Trajectory&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Actor_Trajectory& default_instance() {
    return *internal_default_instance();
  }
  static inline const Actor_Trajectory* internal_default_instance() {
    return reinterpret_cast<const Actor_Trajectory*>(
               &_Actor_Trajectory_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(Actor_Trajectory& a, Actor_Trajectory& b) {
    a.Swap(&b);
  }
  inline void Swap(Actor_Trajectory* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Actor_Trajectory* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Actor_Trajectory* New() const final {
    return new Actor_Trajectory();
  }

  Actor_Trajectory* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Actor_Trajectory>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Actor_Trajectory& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Actor_Trajectory& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Actor_Trajectory* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Actor.Trajectory";
  }
  protected:
  explicit Actor_Trajectory(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kWaypointsFieldNumber = 4,
    kTypeFieldNumber = 2,
    kIdFieldNumber = 1,
    kTensionFieldNumber = 3,
  };
  // repeated .ignition.msgs.Actor.Waypoint waypoints = 4;
  int waypoints_size() const;
  private:
  int _internal_waypoints_size() const;
  public:
  void clear_waypoints();
  ::ignition::msgs::Actor_Waypoint* mutable_waypoints(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Waypoint >*
      mutable_waypoints();
  private:
  const ::ignition::msgs::Actor_Waypoint& _internal_waypoints(int index) const;
  ::ignition::msgs::Actor_Waypoint* _internal_add_waypoints();
  public:
  const ::ignition::msgs::Actor_Waypoint& waypoints(int index) const;
  ::ignition::msgs::Actor_Waypoint* add_waypoints();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Waypoint >&
      waypoints() const;

  // string type = 2;
  void clear_type();
  const std::string& type() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_type(ArgT0&& arg0, ArgT... args);
  std::string* mutable_type();
  PROTOBUF_MUST_USE_RESULT std::string* release_type();
  void set_allocated_type(std::string* type);
  private:
  const std::string& _internal_type() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_type(const std::string& value);
  std::string* _internal_mutable_type();
  public:

  // uint32 id = 1;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // float tension = 3;
  void clear_tension();
  float tension() const;
  void set_tension(float value);
  private:
  float _internal_tension() const;
  void _internal_set_tension(float value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Actor.Trajectory)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Waypoint > waypoints_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr type_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  float tension_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2factor_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE Actor final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.Actor) */ {
 public:
  inline Actor() : Actor(nullptr) {}
  ~Actor() override;
  explicit constexpr Actor(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  Actor(const Actor& from);
  Actor(Actor&& from) noexcept
    : Actor() {
    *this = ::std::move(from);
  }

  inline Actor& operator=(const Actor& from) {
    CopyFrom(from);
    return *this;
  }
  inline Actor& operator=(Actor&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const Actor& default_instance() {
    return *internal_default_instance();
  }
  static inline const Actor* internal_default_instance() {
    return reinterpret_cast<const Actor*>(
               &_Actor_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    3;

  friend void swap(Actor& a, Actor& b) {
    a.Swap(&b);
  }
  inline void Swap(Actor* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(Actor* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline Actor* New() const final {
    return new Actor();
  }

  Actor* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<Actor>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const Actor& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const Actor& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(Actor* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.Actor";
  }
  protected:
  explicit Actor(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef Actor_Animation Animation;
  typedef Actor_Waypoint Waypoint;
  typedef Actor_Trajectory Trajectory;

  // accessors -------------------------------------------------------

  enum : int {
    kAnimationsFieldNumber = 6,
    kTrajectoriesFieldNumber = 10,
    kSkinFilenameFieldNumber = 4,
    kHeaderFieldNumber = 1,
    kEntityFieldNumber = 2,
    kPoseFieldNumber = 3,
    kParentFieldNumber = 11,
    kSkinScaleFieldNumber = 5,
    kScriptDelayStartFieldNumber = 8,
    kScriptLoopFieldNumber = 7,
    kScriptAutoStartFieldNumber = 9,
  };
  // repeated .ignition.msgs.Actor.Animation animations = 6;
  int animations_size() const;
  private:
  int _internal_animations_size() const;
  public:
  void clear_animations();
  ::ignition::msgs::Actor_Animation* mutable_animations(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Animation >*
      mutable_animations();
  private:
  const ::ignition::msgs::Actor_Animation& _internal_animations(int index) const;
  ::ignition::msgs::Actor_Animation* _internal_add_animations();
  public:
  const ::ignition::msgs::Actor_Animation& animations(int index) const;
  ::ignition::msgs::Actor_Animation* add_animations();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Animation >&
      animations() const;

  // repeated .ignition.msgs.Actor.Trajectory trajectories = 10;
  int trajectories_size() const;
  private:
  int _internal_trajectories_size() const;
  public:
  void clear_trajectories();
  ::ignition::msgs::Actor_Trajectory* mutable_trajectories(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Trajectory >*
      mutable_trajectories();
  private:
  const ::ignition::msgs::Actor_Trajectory& _internal_trajectories(int index) const;
  ::ignition::msgs::Actor_Trajectory* _internal_add_trajectories();
  public:
  const ::ignition::msgs::Actor_Trajectory& trajectories(int index) const;
  ::ignition::msgs::Actor_Trajectory* add_trajectories();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Trajectory >&
      trajectories() const;

  // string skin_filename = 4;
  void clear_skin_filename();
  const std::string& skin_filename() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_skin_filename(ArgT0&& arg0, ArgT... args);
  std::string* mutable_skin_filename();
  PROTOBUF_MUST_USE_RESULT std::string* release_skin_filename();
  void set_allocated_skin_filename(std::string* skin_filename);
  private:
  const std::string& _internal_skin_filename() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_skin_filename(const std::string& value);
  std::string* _internal_mutable_skin_filename();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Entity entity = 2;
  bool has_entity() const;
  private:
  bool _internal_has_entity() const;
  public:
  void clear_entity();
  const ::ignition::msgs::Entity& entity() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Entity* release_entity();
  ::ignition::msgs::Entity* mutable_entity();
  void set_allocated_entity(::ignition::msgs::Entity* entity);
  private:
  const ::ignition::msgs::Entity& _internal_entity() const;
  ::ignition::msgs::Entity* _internal_mutable_entity();
  public:
  void unsafe_arena_set_allocated_entity(
      ::ignition::msgs::Entity* entity);
  ::ignition::msgs::Entity* unsafe_arena_release_entity();

  // .ignition.msgs.Pose pose = 3;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // .ignition.msgs.Entity parent = 11;
  bool has_parent() const;
  private:
  bool _internal_has_parent() const;
  public:
  void clear_parent();
  const ::ignition::msgs::Entity& parent() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Entity* release_parent();
  ::ignition::msgs::Entity* mutable_parent();
  void set_allocated_parent(::ignition::msgs::Entity* parent);
  private:
  const ::ignition::msgs::Entity& _internal_parent() const;
  ::ignition::msgs::Entity* _internal_mutable_parent();
  public:
  void unsafe_arena_set_allocated_parent(
      ::ignition::msgs::Entity* parent);
  ::ignition::msgs::Entity* unsafe_arena_release_parent();

  // float skin_scale = 5;
  void clear_skin_scale();
  float skin_scale() const;
  void set_skin_scale(float value);
  private:
  float _internal_skin_scale() const;
  void _internal_set_skin_scale(float value);
  public:

  // float script_delay_start = 8;
  void clear_script_delay_start();
  float script_delay_start() const;
  void set_script_delay_start(float value);
  private:
  float _internal_script_delay_start() const;
  void _internal_set_script_delay_start(float value);
  public:

  // bool script_loop = 7;
  void clear_script_loop();
  bool script_loop() const;
  void set_script_loop(bool value);
  private:
  bool _internal_script_loop() const;
  void _internal_set_script_loop(bool value);
  public:

  // bool script_auto_start = 9;
  void clear_script_auto_start();
  bool script_auto_start() const;
  void set_script_auto_start(bool value);
  private:
  bool _internal_script_auto_start() const;
  void _internal_set_script_auto_start(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.Actor)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Animation > animations_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Trajectory > trajectories_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr skin_filename_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Entity* entity_;
  ::ignition::msgs::Pose* pose_;
  ::ignition::msgs::Entity* parent_;
  float skin_scale_;
  float script_delay_start_;
  bool script_loop_;
  bool script_auto_start_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2factor_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// Actor_Animation

// string name = 1;
inline void Actor_Animation::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& Actor_Animation::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Animation.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Actor_Animation::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Animation.name)
}
inline std::string* Actor_Animation::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.Animation.name)
  return _s;
}
inline const std::string& Actor_Animation::_internal_name() const {
  return name_.Get();
}
inline void Actor_Animation::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Actor_Animation::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Actor_Animation::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.Animation.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Actor_Animation::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.Animation.name)
}

// string filename = 2;
inline void Actor_Animation::clear_filename() {
  filename_.ClearToEmpty();
}
inline const std::string& Actor_Animation::filename() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Animation.filename)
  return _internal_filename();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Actor_Animation::set_filename(ArgT0&& arg0, ArgT... args) {
 
 filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Animation.filename)
}
inline std::string* Actor_Animation::mutable_filename() {
  std::string* _s = _internal_mutable_filename();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.Animation.filename)
  return _s;
}
inline const std::string& Actor_Animation::_internal_filename() const {
  return filename_.Get();
}
inline void Actor_Animation::_internal_set_filename(const std::string& value) {
  
  filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Actor_Animation::_internal_mutable_filename() {
  
  return filename_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Actor_Animation::release_filename() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.Animation.filename)
  return filename_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Actor_Animation::set_allocated_filename(std::string* filename) {
  if (filename != nullptr) {
    
  } else {
    
  }
  filename_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), filename,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.Animation.filename)
}

// float scale = 3;
inline void Actor_Animation::clear_scale() {
  scale_ = 0;
}
inline float Actor_Animation::_internal_scale() const {
  return scale_;
}
inline float Actor_Animation::scale() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Animation.scale)
  return _internal_scale();
}
inline void Actor_Animation::_internal_set_scale(float value) {
  
  scale_ = value;
}
inline void Actor_Animation::set_scale(float value) {
  _internal_set_scale(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Animation.scale)
}

// bool interpolate_x = 4;
inline void Actor_Animation::clear_interpolate_x() {
  interpolate_x_ = false;
}
inline bool Actor_Animation::_internal_interpolate_x() const {
  return interpolate_x_;
}
inline bool Actor_Animation::interpolate_x() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Animation.interpolate_x)
  return _internal_interpolate_x();
}
inline void Actor_Animation::_internal_set_interpolate_x(bool value) {
  
  interpolate_x_ = value;
}
inline void Actor_Animation::set_interpolate_x(bool value) {
  _internal_set_interpolate_x(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Animation.interpolate_x)
}

// -------------------------------------------------------------------

// Actor_Waypoint

// float time = 1;
inline void Actor_Waypoint::clear_time() {
  time_ = 0;
}
inline float Actor_Waypoint::_internal_time() const {
  return time_;
}
inline float Actor_Waypoint::time() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Waypoint.time)
  return _internal_time();
}
inline void Actor_Waypoint::_internal_set_time(float value) {
  
  time_ = value;
}
inline void Actor_Waypoint::set_time(float value) {
  _internal_set_time(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Waypoint.time)
}

// .ignition.msgs.Pose pose = 2;
inline bool Actor_Waypoint::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Actor_Waypoint::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Actor_Waypoint::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Actor_Waypoint::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Waypoint.pose)
  return _internal_pose();
}
inline void Actor_Waypoint::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Actor.Waypoint.pose)
}
inline ::ignition::msgs::Pose* Actor_Waypoint::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* Actor_Waypoint::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.Waypoint.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Actor_Waypoint::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Actor_Waypoint::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.Waypoint.pose)
  return _msg;
}
inline void Actor_Waypoint::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.Waypoint.pose)
}

// -------------------------------------------------------------------

// Actor_Trajectory

// uint32 id = 1;
inline void Actor_Trajectory::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Actor_Trajectory::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 Actor_Trajectory::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Trajectory.id)
  return _internal_id();
}
inline void Actor_Trajectory::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void Actor_Trajectory::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Trajectory.id)
}

// string type = 2;
inline void Actor_Trajectory::clear_type() {
  type_.ClearToEmpty();
}
inline const std::string& Actor_Trajectory::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Trajectory.type)
  return _internal_type();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Actor_Trajectory::set_type(ArgT0&& arg0, ArgT... args) {
 
 type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Trajectory.type)
}
inline std::string* Actor_Trajectory::mutable_type() {
  std::string* _s = _internal_mutable_type();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.Trajectory.type)
  return _s;
}
inline const std::string& Actor_Trajectory::_internal_type() const {
  return type_.Get();
}
inline void Actor_Trajectory::_internal_set_type(const std::string& value) {
  
  type_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Actor_Trajectory::_internal_mutable_type() {
  
  return type_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Actor_Trajectory::release_type() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.Trajectory.type)
  return type_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Actor_Trajectory::set_allocated_type(std::string* type) {
  if (type != nullptr) {
    
  } else {
    
  }
  type_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), type,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.Trajectory.type)
}

// float tension = 3;
inline void Actor_Trajectory::clear_tension() {
  tension_ = 0;
}
inline float Actor_Trajectory::_internal_tension() const {
  return tension_;
}
inline float Actor_Trajectory::tension() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Trajectory.tension)
  return _internal_tension();
}
inline void Actor_Trajectory::_internal_set_tension(float value) {
  
  tension_ = value;
}
inline void Actor_Trajectory::set_tension(float value) {
  _internal_set_tension(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.Trajectory.tension)
}

// repeated .ignition.msgs.Actor.Waypoint waypoints = 4;
inline int Actor_Trajectory::_internal_waypoints_size() const {
  return waypoints_.size();
}
inline int Actor_Trajectory::waypoints_size() const {
  return _internal_waypoints_size();
}
inline void Actor_Trajectory::clear_waypoints() {
  waypoints_.Clear();
}
inline ::ignition::msgs::Actor_Waypoint* Actor_Trajectory::mutable_waypoints(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.Trajectory.waypoints)
  return waypoints_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Waypoint >*
Actor_Trajectory::mutable_waypoints() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Actor.Trajectory.waypoints)
  return &waypoints_;
}
inline const ::ignition::msgs::Actor_Waypoint& Actor_Trajectory::_internal_waypoints(int index) const {
  return waypoints_.Get(index);
}
inline const ::ignition::msgs::Actor_Waypoint& Actor_Trajectory::waypoints(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.Trajectory.waypoints)
  return _internal_waypoints(index);
}
inline ::ignition::msgs::Actor_Waypoint* Actor_Trajectory::_internal_add_waypoints() {
  return waypoints_.Add();
}
inline ::ignition::msgs::Actor_Waypoint* Actor_Trajectory::add_waypoints() {
  ::ignition::msgs::Actor_Waypoint* _add = _internal_add_waypoints();
  // @@protoc_insertion_point(field_add:ignition.msgs.Actor.Trajectory.waypoints)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Waypoint >&
Actor_Trajectory::waypoints() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Actor.Trajectory.waypoints)
  return waypoints_;
}

// -------------------------------------------------------------------

// Actor

// .ignition.msgs.Header header = 1;
inline bool Actor::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool Actor::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& Actor::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& Actor::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.header)
  return _internal_header();
}
inline void Actor::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Actor.header)
}
inline ::ignition::msgs::Header* Actor::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* Actor::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* Actor::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* Actor::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.header)
  return _msg;
}
inline void Actor::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.header)
}

// .ignition.msgs.Entity entity = 2;
inline bool Actor::_internal_has_entity() const {
  return this != internal_default_instance() && entity_ != nullptr;
}
inline bool Actor::has_entity() const {
  return _internal_has_entity();
}
inline const ::ignition::msgs::Entity& Actor::_internal_entity() const {
  const ::ignition::msgs::Entity* p = entity_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Entity&>(
      ::ignition::msgs::_Entity_default_instance_);
}
inline const ::ignition::msgs::Entity& Actor::entity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.entity)
  return _internal_entity();
}
inline void Actor::unsafe_arena_set_allocated_entity(
    ::ignition::msgs::Entity* entity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(entity_);
  }
  entity_ = entity;
  if (entity) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Actor.entity)
}
inline ::ignition::msgs::Entity* Actor::release_entity() {
  
  ::ignition::msgs::Entity* temp = entity_;
  entity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Entity* Actor::unsafe_arena_release_entity() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.entity)
  
  ::ignition::msgs::Entity* temp = entity_;
  entity_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Entity* Actor::_internal_mutable_entity() {
  
  if (entity_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Entity>(GetArenaForAllocation());
    entity_ = p;
  }
  return entity_;
}
inline ::ignition::msgs::Entity* Actor::mutable_entity() {
  ::ignition::msgs::Entity* _msg = _internal_mutable_entity();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.entity)
  return _msg;
}
inline void Actor::set_allocated_entity(::ignition::msgs::Entity* entity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(entity_);
  }
  if (entity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(entity));
    if (message_arena != submessage_arena) {
      entity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, entity, submessage_arena);
    }
    
  } else {
    
  }
  entity_ = entity;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.entity)
}

// .ignition.msgs.Pose pose = 3;
inline bool Actor::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool Actor::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& Actor::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& Actor::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.pose)
  return _internal_pose();
}
inline void Actor::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Actor.pose)
}
inline ::ignition::msgs::Pose* Actor::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* Actor::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* Actor::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* Actor::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.pose)
  return _msg;
}
inline void Actor::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.pose)
}

// string skin_filename = 4;
inline void Actor::clear_skin_filename() {
  skin_filename_.ClearToEmpty();
}
inline const std::string& Actor::skin_filename() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.skin_filename)
  return _internal_skin_filename();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void Actor::set_skin_filename(ArgT0&& arg0, ArgT... args) {
 
 skin_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.skin_filename)
}
inline std::string* Actor::mutable_skin_filename() {
  std::string* _s = _internal_mutable_skin_filename();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.skin_filename)
  return _s;
}
inline const std::string& Actor::_internal_skin_filename() const {
  return skin_filename_.Get();
}
inline void Actor::_internal_set_skin_filename(const std::string& value) {
  
  skin_filename_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* Actor::_internal_mutable_skin_filename() {
  
  return skin_filename_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* Actor::release_skin_filename() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.skin_filename)
  return skin_filename_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void Actor::set_allocated_skin_filename(std::string* skin_filename) {
  if (skin_filename != nullptr) {
    
  } else {
    
  }
  skin_filename_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), skin_filename,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.skin_filename)
}

// float skin_scale = 5;
inline void Actor::clear_skin_scale() {
  skin_scale_ = 0;
}
inline float Actor::_internal_skin_scale() const {
  return skin_scale_;
}
inline float Actor::skin_scale() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.skin_scale)
  return _internal_skin_scale();
}
inline void Actor::_internal_set_skin_scale(float value) {
  
  skin_scale_ = value;
}
inline void Actor::set_skin_scale(float value) {
  _internal_set_skin_scale(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.skin_scale)
}

// repeated .ignition.msgs.Actor.Animation animations = 6;
inline int Actor::_internal_animations_size() const {
  return animations_.size();
}
inline int Actor::animations_size() const {
  return _internal_animations_size();
}
inline void Actor::clear_animations() {
  animations_.Clear();
}
inline ::ignition::msgs::Actor_Animation* Actor::mutable_animations(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.animations)
  return animations_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Animation >*
Actor::mutable_animations() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Actor.animations)
  return &animations_;
}
inline const ::ignition::msgs::Actor_Animation& Actor::_internal_animations(int index) const {
  return animations_.Get(index);
}
inline const ::ignition::msgs::Actor_Animation& Actor::animations(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.animations)
  return _internal_animations(index);
}
inline ::ignition::msgs::Actor_Animation* Actor::_internal_add_animations() {
  return animations_.Add();
}
inline ::ignition::msgs::Actor_Animation* Actor::add_animations() {
  ::ignition::msgs::Actor_Animation* _add = _internal_add_animations();
  // @@protoc_insertion_point(field_add:ignition.msgs.Actor.animations)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Animation >&
Actor::animations() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Actor.animations)
  return animations_;
}

// bool script_loop = 7;
inline void Actor::clear_script_loop() {
  script_loop_ = false;
}
inline bool Actor::_internal_script_loop() const {
  return script_loop_;
}
inline bool Actor::script_loop() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.script_loop)
  return _internal_script_loop();
}
inline void Actor::_internal_set_script_loop(bool value) {
  
  script_loop_ = value;
}
inline void Actor::set_script_loop(bool value) {
  _internal_set_script_loop(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.script_loop)
}

// float script_delay_start = 8;
inline void Actor::clear_script_delay_start() {
  script_delay_start_ = 0;
}
inline float Actor::_internal_script_delay_start() const {
  return script_delay_start_;
}
inline float Actor::script_delay_start() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.script_delay_start)
  return _internal_script_delay_start();
}
inline void Actor::_internal_set_script_delay_start(float value) {
  
  script_delay_start_ = value;
}
inline void Actor::set_script_delay_start(float value) {
  _internal_set_script_delay_start(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.script_delay_start)
}

// bool script_auto_start = 9;
inline void Actor::clear_script_auto_start() {
  script_auto_start_ = false;
}
inline bool Actor::_internal_script_auto_start() const {
  return script_auto_start_;
}
inline bool Actor::script_auto_start() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.script_auto_start)
  return _internal_script_auto_start();
}
inline void Actor::_internal_set_script_auto_start(bool value) {
  
  script_auto_start_ = value;
}
inline void Actor::set_script_auto_start(bool value) {
  _internal_set_script_auto_start(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.Actor.script_auto_start)
}

// repeated .ignition.msgs.Actor.Trajectory trajectories = 10;
inline int Actor::_internal_trajectories_size() const {
  return trajectories_.size();
}
inline int Actor::trajectories_size() const {
  return _internal_trajectories_size();
}
inline void Actor::clear_trajectories() {
  trajectories_.Clear();
}
inline ::ignition::msgs::Actor_Trajectory* Actor::mutable_trajectories(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.trajectories)
  return trajectories_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Trajectory >*
Actor::mutable_trajectories() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.Actor.trajectories)
  return &trajectories_;
}
inline const ::ignition::msgs::Actor_Trajectory& Actor::_internal_trajectories(int index) const {
  return trajectories_.Get(index);
}
inline const ::ignition::msgs::Actor_Trajectory& Actor::trajectories(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.trajectories)
  return _internal_trajectories(index);
}
inline ::ignition::msgs::Actor_Trajectory* Actor::_internal_add_trajectories() {
  return trajectories_.Add();
}
inline ::ignition::msgs::Actor_Trajectory* Actor::add_trajectories() {
  ::ignition::msgs::Actor_Trajectory* _add = _internal_add_trajectories();
  // @@protoc_insertion_point(field_add:ignition.msgs.Actor.trajectories)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::Actor_Trajectory >&
Actor::trajectories() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.Actor.trajectories)
  return trajectories_;
}

// .ignition.msgs.Entity parent = 11;
inline bool Actor::_internal_has_parent() const {
  return this != internal_default_instance() && parent_ != nullptr;
}
inline bool Actor::has_parent() const {
  return _internal_has_parent();
}
inline const ::ignition::msgs::Entity& Actor::_internal_parent() const {
  const ::ignition::msgs::Entity* p = parent_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Entity&>(
      ::ignition::msgs::_Entity_default_instance_);
}
inline const ::ignition::msgs::Entity& Actor::parent() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.Actor.parent)
  return _internal_parent();
}
inline void Actor::unsafe_arena_set_allocated_parent(
    ::ignition::msgs::Entity* parent) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(parent_);
  }
  parent_ = parent;
  if (parent) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.Actor.parent)
}
inline ::ignition::msgs::Entity* Actor::release_parent() {
  
  ::ignition::msgs::Entity* temp = parent_;
  parent_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Entity* Actor::unsafe_arena_release_parent() {
  // @@protoc_insertion_point(field_release:ignition.msgs.Actor.parent)
  
  ::ignition::msgs::Entity* temp = parent_;
  parent_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Entity* Actor::_internal_mutable_parent() {
  
  if (parent_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Entity>(GetArenaForAllocation());
    parent_ = p;
  }
  return parent_;
}
inline ::ignition::msgs::Entity* Actor::mutable_parent() {
  ::ignition::msgs::Entity* _msg = _internal_mutable_parent();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.Actor.parent)
  return _msg;
}
inline void Actor::set_allocated_parent(::ignition::msgs::Entity* parent) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(parent_);
  }
  if (parent) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(parent));
    if (message_arena != submessage_arena) {
      parent = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, parent, submessage_arena);
    }
    
  } else {
    
  }
  parent_ = parent;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.Actor.parent)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<Actor> ActorUniquePtr;
typedef std::unique_ptr<const Actor> ConstActorUniquePtr;
typedef std::shared_ptr<Actor> ActorSharedPtr;
typedef std::shared_ptr<const Actor> ConstActorSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2factor_2eproto
