# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/inertial.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/inertial.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Inertial" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :mass, :double, 2
      optional :pose, :message, 3, "ignition.msgs.Pose"
      optional :ixx, :double, 4
      optional :ixy, :double, 5
      optional :ixz, :double, 6
      optional :iyy, :double, 7
      optional :iyz, :double, 8
      optional :izz, :double, 9
    end
  end
end

module Ignition
  module Msgs
    Inertial = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Inertial").msgclass
  end
end
