# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/twist.proto

require 'ignition/msgs/vector3d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/twist.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Twist" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :linear, :message, 2, "ignition.msgs.Vector3d"
      optional :angular, :message, 3, "ignition.msgs.Vector3d"
    end
  end
end

module Ignition
  module Msgs
    Twist = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Twist").msgclass
  end
end
