# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/imu_sensor.proto

require 'ignition/msgs/sensor_noise_pb'
require 'ignition/msgs/header_pb'
require 'ignition/msgs/vector3d_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/imu_sensor.proto", :syntax => :proto3) do
    add_message "ignition.msgs.IMUSensor" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :angular_velocity, :message, 2, "ignition.msgs.IMUSensor.AngularVelocity"
      optional :linear_acceleration, :message, 3, "ignition.msgs.IMUSensor.LinearAcceleration"
      optional :orientation_ref_frame, :message, 4, "ignition.msgs.IMUSensor.OrientationReferenceFrame"
    end
    add_message "ignition.msgs.IMUSensor.AngularVelocity" do
      optional :x_noise, :message, 1, "ignition.msgs.SensorNoise"
      optional :y_noise, :message, 2, "ignition.msgs.SensorNoise"
      optional :z_noise, :message, 3, "ignition.msgs.SensorNoise"
    end
    add_message "ignition.msgs.IMUSensor.LinearAcceleration" do
      optional :x_noise, :message, 1, "ignition.msgs.SensorNoise"
      optional :y_noise, :message, 2, "ignition.msgs.SensorNoise"
      optional :z_noise, :message, 3, "ignition.msgs.SensorNoise"
    end
    add_message "ignition.msgs.IMUSensor.OrientationReferenceFrame" do
      optional :localization, :string, 1
      optional :custom_rpy, :message, 2, "ignition.msgs.Vector3d"
      optional :custom_rpy_parent_frame, :string, 3
      optional :gravity_dir_x, :message, 4, "ignition.msgs.Vector3d"
      optional :gravity_dir_x_parent_frame, :string, 5
    end
  end
end

module Ignition
  module Msgs
    IMUSensor = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.IMUSensor").msgclass
    IMUSensor::AngularVelocity = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.IMUSensor.AngularVelocity").msgclass
    IMUSensor::LinearAcceleration = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.IMUSensor.LinearAcceleration").msgclass
    IMUSensor::OrientationReferenceFrame = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.IMUSensor.OrientationReferenceFrame").msgclass
  end
end
