// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/particle_emitter.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/boolean.pb.h"
#include "ignition/msgs/color.pb.h"
#include "ignition/msgs/float.pb.h"
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/material.pb.h"
#include "ignition/msgs/pose.pb.h"
#include "ignition/msgs/stringmsg.pb.h"
#include "ignition/msgs/vector3d.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fparticle_5femitter_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fparticle_5femitter_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[1]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fparticle_5femitter_2eproto;
namespace ignition {
namespace msgs {
class ParticleEmitter;
struct ParticleEmitterDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern ParticleEmitterDefaultTypeInternal _ParticleEmitter_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::ParticleEmitter* Arena::CreateMaybeMessage<::ignition::msgs::ParticleEmitter>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum ParticleEmitter_EmitterType : int {
  ParticleEmitter_EmitterType_POINT = 0,
  ParticleEmitter_EmitterType_BOX = 1,
  ParticleEmitter_EmitterType_CYLINDER = 2,
  ParticleEmitter_EmitterType_ELLIPSOID = 3,
  ParticleEmitter_EmitterType_ParticleEmitter_EmitterType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  ParticleEmitter_EmitterType_ParticleEmitter_EmitterType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool ParticleEmitter_EmitterType_IsValid(int value);
constexpr ParticleEmitter_EmitterType ParticleEmitter_EmitterType_EmitterType_MIN = ParticleEmitter_EmitterType_POINT;
constexpr ParticleEmitter_EmitterType ParticleEmitter_EmitterType_EmitterType_MAX = ParticleEmitter_EmitterType_ELLIPSOID;
constexpr int ParticleEmitter_EmitterType_EmitterType_ARRAYSIZE = ParticleEmitter_EmitterType_EmitterType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* ParticleEmitter_EmitterType_descriptor();
template<typename T>
inline const std::string& ParticleEmitter_EmitterType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, ParticleEmitter_EmitterType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function ParticleEmitter_EmitterType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    ParticleEmitter_EmitterType_descriptor(), enum_t_value);
}
inline bool ParticleEmitter_EmitterType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, ParticleEmitter_EmitterType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<ParticleEmitter_EmitterType>(
    ParticleEmitter_EmitterType_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE ParticleEmitter final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.ParticleEmitter) */ {
 public:
  inline ParticleEmitter() : ParticleEmitter(nullptr) {}
  ~ParticleEmitter() override;
  explicit constexpr ParticleEmitter(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  ParticleEmitter(const ParticleEmitter& from);
  ParticleEmitter(ParticleEmitter&& from) noexcept
    : ParticleEmitter() {
    *this = ::std::move(from);
  }

  inline ParticleEmitter& operator=(const ParticleEmitter& from) {
    CopyFrom(from);
    return *this;
  }
  inline ParticleEmitter& operator=(ParticleEmitter&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const ParticleEmitter& default_instance() {
    return *internal_default_instance();
  }
  static inline const ParticleEmitter* internal_default_instance() {
    return reinterpret_cast<const ParticleEmitter*>(
               &_ParticleEmitter_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(ParticleEmitter& a, ParticleEmitter& b) {
    a.Swap(&b);
  }
  inline void Swap(ParticleEmitter* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(ParticleEmitter* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline ParticleEmitter* New() const final {
    return new ParticleEmitter();
  }

  ParticleEmitter* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<ParticleEmitter>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const ParticleEmitter& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const ParticleEmitter& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(ParticleEmitter* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.ParticleEmitter";
  }
  protected:
  explicit ParticleEmitter(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef ParticleEmitter_EmitterType EmitterType;
  static constexpr EmitterType POINT =
    ParticleEmitter_EmitterType_POINT;
  static constexpr EmitterType BOX =
    ParticleEmitter_EmitterType_BOX;
  static constexpr EmitterType CYLINDER =
    ParticleEmitter_EmitterType_CYLINDER;
  static constexpr EmitterType ELLIPSOID =
    ParticleEmitter_EmitterType_ELLIPSOID;
  static inline bool EmitterType_IsValid(int value) {
    return ParticleEmitter_EmitterType_IsValid(value);
  }
  static constexpr EmitterType EmitterType_MIN =
    ParticleEmitter_EmitterType_EmitterType_MIN;
  static constexpr EmitterType EmitterType_MAX =
    ParticleEmitter_EmitterType_EmitterType_MAX;
  static constexpr int EmitterType_ARRAYSIZE =
    ParticleEmitter_EmitterType_EmitterType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  EmitterType_descriptor() {
    return ParticleEmitter_EmitterType_descriptor();
  }
  template<typename T>
  static inline const std::string& EmitterType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, EmitterType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function EmitterType_Name.");
    return ParticleEmitter_EmitterType_Name(enum_t_value);
  }
  static inline bool EmitterType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      EmitterType* value) {
    return ParticleEmitter_EmitterType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kNameFieldNumber = 2,
    kHeaderFieldNumber = 1,
    kPoseFieldNumber = 5,
    kSizeFieldNumber = 6,
    kRateFieldNumber = 7,
    kDurationFieldNumber = 8,
    kEmittingFieldNumber = 9,
    kParticleSizeFieldNumber = 10,
    kLifetimeFieldNumber = 11,
    kMaterialFieldNumber = 12,
    kMinVelocityFieldNumber = 13,
    kMaxVelocityFieldNumber = 14,
    kColorStartFieldNumber = 15,
    kColorEndFieldNumber = 16,
    kScaleRateFieldNumber = 17,
    kColorRangeImageFieldNumber = 18,
    kIdFieldNumber = 3,
    kTypeFieldNumber = 4,
  };
  // string name = 2;
  void clear_name();
  const std::string& name() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_name(ArgT0&& arg0, ArgT... args);
  std::string* mutable_name();
  PROTOBUF_MUST_USE_RESULT std::string* release_name();
  void set_allocated_name(std::string* name);
  private:
  const std::string& _internal_name() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_name(const std::string& value);
  std::string* _internal_mutable_name();
  public:

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.Pose pose = 5;
  bool has_pose() const;
  private:
  bool _internal_has_pose() const;
  public:
  void clear_pose();
  const ::ignition::msgs::Pose& pose() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Pose* release_pose();
  ::ignition::msgs::Pose* mutable_pose();
  void set_allocated_pose(::ignition::msgs::Pose* pose);
  private:
  const ::ignition::msgs::Pose& _internal_pose() const;
  ::ignition::msgs::Pose* _internal_mutable_pose();
  public:
  void unsafe_arena_set_allocated_pose(
      ::ignition::msgs::Pose* pose);
  ::ignition::msgs::Pose* unsafe_arena_release_pose();

  // .ignition.msgs.Vector3d size = 6;
  bool has_size() const;
  private:
  bool _internal_has_size() const;
  public:
  void clear_size();
  const ::ignition::msgs::Vector3d& size() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_size();
  ::ignition::msgs::Vector3d* mutable_size();
  void set_allocated_size(::ignition::msgs::Vector3d* size);
  private:
  const ::ignition::msgs::Vector3d& _internal_size() const;
  ::ignition::msgs::Vector3d* _internal_mutable_size();
  public:
  void unsafe_arena_set_allocated_size(
      ::ignition::msgs::Vector3d* size);
  ::ignition::msgs::Vector3d* unsafe_arena_release_size();

  // .ignition.msgs.Float rate = 7;
  bool has_rate() const;
  private:
  bool _internal_has_rate() const;
  public:
  void clear_rate();
  const ::ignition::msgs::Float& rate() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_rate();
  ::ignition::msgs::Float* mutable_rate();
  void set_allocated_rate(::ignition::msgs::Float* rate);
  private:
  const ::ignition::msgs::Float& _internal_rate() const;
  ::ignition::msgs::Float* _internal_mutable_rate();
  public:
  void unsafe_arena_set_allocated_rate(
      ::ignition::msgs::Float* rate);
  ::ignition::msgs::Float* unsafe_arena_release_rate();

  // .ignition.msgs.Float duration = 8;
  bool has_duration() const;
  private:
  bool _internal_has_duration() const;
  public:
  void clear_duration();
  const ::ignition::msgs::Float& duration() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_duration();
  ::ignition::msgs::Float* mutable_duration();
  void set_allocated_duration(::ignition::msgs::Float* duration);
  private:
  const ::ignition::msgs::Float& _internal_duration() const;
  ::ignition::msgs::Float* _internal_mutable_duration();
  public:
  void unsafe_arena_set_allocated_duration(
      ::ignition::msgs::Float* duration);
  ::ignition::msgs::Float* unsafe_arena_release_duration();

  // .ignition.msgs.Boolean emitting = 9;
  bool has_emitting() const;
  private:
  bool _internal_has_emitting() const;
  public:
  void clear_emitting();
  const ::ignition::msgs::Boolean& emitting() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Boolean* release_emitting();
  ::ignition::msgs::Boolean* mutable_emitting();
  void set_allocated_emitting(::ignition::msgs::Boolean* emitting);
  private:
  const ::ignition::msgs::Boolean& _internal_emitting() const;
  ::ignition::msgs::Boolean* _internal_mutable_emitting();
  public:
  void unsafe_arena_set_allocated_emitting(
      ::ignition::msgs::Boolean* emitting);
  ::ignition::msgs::Boolean* unsafe_arena_release_emitting();

  // .ignition.msgs.Vector3d particle_size = 10;
  bool has_particle_size() const;
  private:
  bool _internal_has_particle_size() const;
  public:
  void clear_particle_size();
  const ::ignition::msgs::Vector3d& particle_size() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Vector3d* release_particle_size();
  ::ignition::msgs::Vector3d* mutable_particle_size();
  void set_allocated_particle_size(::ignition::msgs::Vector3d* particle_size);
  private:
  const ::ignition::msgs::Vector3d& _internal_particle_size() const;
  ::ignition::msgs::Vector3d* _internal_mutable_particle_size();
  public:
  void unsafe_arena_set_allocated_particle_size(
      ::ignition::msgs::Vector3d* particle_size);
  ::ignition::msgs::Vector3d* unsafe_arena_release_particle_size();

  // .ignition.msgs.Float lifetime = 11;
  bool has_lifetime() const;
  private:
  bool _internal_has_lifetime() const;
  public:
  void clear_lifetime();
  const ::ignition::msgs::Float& lifetime() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_lifetime();
  ::ignition::msgs::Float* mutable_lifetime();
  void set_allocated_lifetime(::ignition::msgs::Float* lifetime);
  private:
  const ::ignition::msgs::Float& _internal_lifetime() const;
  ::ignition::msgs::Float* _internal_mutable_lifetime();
  public:
  void unsafe_arena_set_allocated_lifetime(
      ::ignition::msgs::Float* lifetime);
  ::ignition::msgs::Float* unsafe_arena_release_lifetime();

  // .ignition.msgs.Material material = 12;
  bool has_material() const;
  private:
  bool _internal_has_material() const;
  public:
  void clear_material();
  const ::ignition::msgs::Material& material() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Material* release_material();
  ::ignition::msgs::Material* mutable_material();
  void set_allocated_material(::ignition::msgs::Material* material);
  private:
  const ::ignition::msgs::Material& _internal_material() const;
  ::ignition::msgs::Material* _internal_mutable_material();
  public:
  void unsafe_arena_set_allocated_material(
      ::ignition::msgs::Material* material);
  ::ignition::msgs::Material* unsafe_arena_release_material();

  // .ignition.msgs.Float min_velocity = 13;
  bool has_min_velocity() const;
  private:
  bool _internal_has_min_velocity() const;
  public:
  void clear_min_velocity();
  const ::ignition::msgs::Float& min_velocity() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_min_velocity();
  ::ignition::msgs::Float* mutable_min_velocity();
  void set_allocated_min_velocity(::ignition::msgs::Float* min_velocity);
  private:
  const ::ignition::msgs::Float& _internal_min_velocity() const;
  ::ignition::msgs::Float* _internal_mutable_min_velocity();
  public:
  void unsafe_arena_set_allocated_min_velocity(
      ::ignition::msgs::Float* min_velocity);
  ::ignition::msgs::Float* unsafe_arena_release_min_velocity();

  // .ignition.msgs.Float max_velocity = 14;
  bool has_max_velocity() const;
  private:
  bool _internal_has_max_velocity() const;
  public:
  void clear_max_velocity();
  const ::ignition::msgs::Float& max_velocity() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_max_velocity();
  ::ignition::msgs::Float* mutable_max_velocity();
  void set_allocated_max_velocity(::ignition::msgs::Float* max_velocity);
  private:
  const ::ignition::msgs::Float& _internal_max_velocity() const;
  ::ignition::msgs::Float* _internal_mutable_max_velocity();
  public:
  void unsafe_arena_set_allocated_max_velocity(
      ::ignition::msgs::Float* max_velocity);
  ::ignition::msgs::Float* unsafe_arena_release_max_velocity();

  // .ignition.msgs.Color color_start = 15;
  bool has_color_start() const;
  private:
  bool _internal_has_color_start() const;
  public:
  void clear_color_start();
  const ::ignition::msgs::Color& color_start() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_color_start();
  ::ignition::msgs::Color* mutable_color_start();
  void set_allocated_color_start(::ignition::msgs::Color* color_start);
  private:
  const ::ignition::msgs::Color& _internal_color_start() const;
  ::ignition::msgs::Color* _internal_mutable_color_start();
  public:
  void unsafe_arena_set_allocated_color_start(
      ::ignition::msgs::Color* color_start);
  ::ignition::msgs::Color* unsafe_arena_release_color_start();

  // .ignition.msgs.Color color_end = 16;
  bool has_color_end() const;
  private:
  bool _internal_has_color_end() const;
  public:
  void clear_color_end();
  const ::ignition::msgs::Color& color_end() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Color* release_color_end();
  ::ignition::msgs::Color* mutable_color_end();
  void set_allocated_color_end(::ignition::msgs::Color* color_end);
  private:
  const ::ignition::msgs::Color& _internal_color_end() const;
  ::ignition::msgs::Color* _internal_mutable_color_end();
  public:
  void unsafe_arena_set_allocated_color_end(
      ::ignition::msgs::Color* color_end);
  ::ignition::msgs::Color* unsafe_arena_release_color_end();

  // .ignition.msgs.Float scale_rate = 17;
  bool has_scale_rate() const;
  private:
  bool _internal_has_scale_rate() const;
  public:
  void clear_scale_rate();
  const ::ignition::msgs::Float& scale_rate() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Float* release_scale_rate();
  ::ignition::msgs::Float* mutable_scale_rate();
  void set_allocated_scale_rate(::ignition::msgs::Float* scale_rate);
  private:
  const ::ignition::msgs::Float& _internal_scale_rate() const;
  ::ignition::msgs::Float* _internal_mutable_scale_rate();
  public:
  void unsafe_arena_set_allocated_scale_rate(
      ::ignition::msgs::Float* scale_rate);
  ::ignition::msgs::Float* unsafe_arena_release_scale_rate();

  // .ignition.msgs.StringMsg color_range_image = 18;
  bool has_color_range_image() const;
  private:
  bool _internal_has_color_range_image() const;
  public:
  void clear_color_range_image();
  const ::ignition::msgs::StringMsg& color_range_image() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::StringMsg* release_color_range_image();
  ::ignition::msgs::StringMsg* mutable_color_range_image();
  void set_allocated_color_range_image(::ignition::msgs::StringMsg* color_range_image);
  private:
  const ::ignition::msgs::StringMsg& _internal_color_range_image() const;
  ::ignition::msgs::StringMsg* _internal_mutable_color_range_image();
  public:
  void unsafe_arena_set_allocated_color_range_image(
      ::ignition::msgs::StringMsg* color_range_image);
  ::ignition::msgs::StringMsg* unsafe_arena_release_color_range_image();

  // uint32 id = 3;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint32 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // .ignition.msgs.ParticleEmitter.EmitterType type = 4;
  void clear_type();
  ::ignition::msgs::ParticleEmitter_EmitterType type() const;
  void set_type(::ignition::msgs::ParticleEmitter_EmitterType value);
  private:
  ::ignition::msgs::ParticleEmitter_EmitterType _internal_type() const;
  void _internal_set_type(::ignition::msgs::ParticleEmitter_EmitterType value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.ParticleEmitter)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr name_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::Pose* pose_;
  ::ignition::msgs::Vector3d* size_;
  ::ignition::msgs::Float* rate_;
  ::ignition::msgs::Float* duration_;
  ::ignition::msgs::Boolean* emitting_;
  ::ignition::msgs::Vector3d* particle_size_;
  ::ignition::msgs::Float* lifetime_;
  ::ignition::msgs::Material* material_;
  ::ignition::msgs::Float* min_velocity_;
  ::ignition::msgs::Float* max_velocity_;
  ::ignition::msgs::Color* color_start_;
  ::ignition::msgs::Color* color_end_;
  ::ignition::msgs::Float* scale_rate_;
  ::ignition::msgs::StringMsg* color_range_image_;
  ::PROTOBUF_NAMESPACE_ID::uint32 id_;
  int type_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fparticle_5femitter_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// ParticleEmitter

// .ignition.msgs.Header header = 1;
inline bool ParticleEmitter::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool ParticleEmitter::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& ParticleEmitter::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& ParticleEmitter::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.header)
  return _internal_header();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.header)
}
inline ::ignition::msgs::Header* ParticleEmitter::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* ParticleEmitter::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* ParticleEmitter::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* ParticleEmitter::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.header)
  return _msg;
}
inline void ParticleEmitter::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.header)
}

// string name = 2;
inline void ParticleEmitter::clear_name() {
  name_.ClearToEmpty();
}
inline const std::string& ParticleEmitter::name() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.name)
  return _internal_name();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void ParticleEmitter::set_name(ArgT0&& arg0, ArgT... args) {
 
 name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.ParticleEmitter.name)
}
inline std::string* ParticleEmitter::mutable_name() {
  std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.name)
  return _s;
}
inline const std::string& ParticleEmitter::_internal_name() const {
  return name_.Get();
}
inline void ParticleEmitter::_internal_set_name(const std::string& value) {
  
  name_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* ParticleEmitter::_internal_mutable_name() {
  
  return name_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* ParticleEmitter::release_name() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.name)
  return name_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void ParticleEmitter::set_allocated_name(std::string* name) {
  if (name != nullptr) {
    
  } else {
    
  }
  name_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), name,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.name)
}

// uint32 id = 3;
inline void ParticleEmitter::clear_id() {
  id_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 ParticleEmitter::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 ParticleEmitter::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.id)
  return _internal_id();
}
inline void ParticleEmitter::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  id_ = value;
}
inline void ParticleEmitter::set_id(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.ParticleEmitter.id)
}

// .ignition.msgs.ParticleEmitter.EmitterType type = 4;
inline void ParticleEmitter::clear_type() {
  type_ = 0;
}
inline ::ignition::msgs::ParticleEmitter_EmitterType ParticleEmitter::_internal_type() const {
  return static_cast< ::ignition::msgs::ParticleEmitter_EmitterType >(type_);
}
inline ::ignition::msgs::ParticleEmitter_EmitterType ParticleEmitter::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.type)
  return _internal_type();
}
inline void ParticleEmitter::_internal_set_type(::ignition::msgs::ParticleEmitter_EmitterType value) {
  
  type_ = value;
}
inline void ParticleEmitter::set_type(::ignition::msgs::ParticleEmitter_EmitterType value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.ParticleEmitter.type)
}

// .ignition.msgs.Pose pose = 5;
inline bool ParticleEmitter::_internal_has_pose() const {
  return this != internal_default_instance() && pose_ != nullptr;
}
inline bool ParticleEmitter::has_pose() const {
  return _internal_has_pose();
}
inline const ::ignition::msgs::Pose& ParticleEmitter::_internal_pose() const {
  const ::ignition::msgs::Pose* p = pose_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Pose&>(
      ::ignition::msgs::_Pose_default_instance_);
}
inline const ::ignition::msgs::Pose& ParticleEmitter::pose() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.pose)
  return _internal_pose();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_pose(
    ::ignition::msgs::Pose* pose) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  pose_ = pose;
  if (pose) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.pose)
}
inline ::ignition::msgs::Pose* ParticleEmitter::release_pose() {
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Pose* ParticleEmitter::unsafe_arena_release_pose() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.pose)
  
  ::ignition::msgs::Pose* temp = pose_;
  pose_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Pose* ParticleEmitter::_internal_mutable_pose() {
  
  if (pose_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Pose>(GetArenaForAllocation());
    pose_ = p;
  }
  return pose_;
}
inline ::ignition::msgs::Pose* ParticleEmitter::mutable_pose() {
  ::ignition::msgs::Pose* _msg = _internal_mutable_pose();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.pose)
  return _msg;
}
inline void ParticleEmitter::set_allocated_pose(::ignition::msgs::Pose* pose) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose_);
  }
  if (pose) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(pose));
    if (message_arena != submessage_arena) {
      pose = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, pose, submessage_arena);
    }
    
  } else {
    
  }
  pose_ = pose;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.pose)
}

// .ignition.msgs.Vector3d size = 6;
inline bool ParticleEmitter::_internal_has_size() const {
  return this != internal_default_instance() && size_ != nullptr;
}
inline bool ParticleEmitter::has_size() const {
  return _internal_has_size();
}
inline const ::ignition::msgs::Vector3d& ParticleEmitter::_internal_size() const {
  const ::ignition::msgs::Vector3d* p = size_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& ParticleEmitter::size() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.size)
  return _internal_size();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_size(
    ::ignition::msgs::Vector3d* size) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(size_);
  }
  size_ = size;
  if (size) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.size)
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::release_size() {
  
  ::ignition::msgs::Vector3d* temp = size_;
  size_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::unsafe_arena_release_size() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.size)
  
  ::ignition::msgs::Vector3d* temp = size_;
  size_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::_internal_mutable_size() {
  
  if (size_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    size_ = p;
  }
  return size_;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::mutable_size() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_size();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.size)
  return _msg;
}
inline void ParticleEmitter::set_allocated_size(::ignition::msgs::Vector3d* size) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(size_);
  }
  if (size) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(size));
    if (message_arena != submessage_arena) {
      size = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, size, submessage_arena);
    }
    
  } else {
    
  }
  size_ = size;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.size)
}

// .ignition.msgs.Float rate = 7;
inline bool ParticleEmitter::_internal_has_rate() const {
  return this != internal_default_instance() && rate_ != nullptr;
}
inline bool ParticleEmitter::has_rate() const {
  return _internal_has_rate();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_rate() const {
  const ::ignition::msgs::Float* p = rate_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::rate() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.rate)
  return _internal_rate();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_rate(
    ::ignition::msgs::Float* rate) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(rate_);
  }
  rate_ = rate;
  if (rate) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.rate)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_rate() {
  
  ::ignition::msgs::Float* temp = rate_;
  rate_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_rate() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.rate)
  
  ::ignition::msgs::Float* temp = rate_;
  rate_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_rate() {
  
  if (rate_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    rate_ = p;
  }
  return rate_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_rate() {
  ::ignition::msgs::Float* _msg = _internal_mutable_rate();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.rate)
  return _msg;
}
inline void ParticleEmitter::set_allocated_rate(::ignition::msgs::Float* rate) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(rate_);
  }
  if (rate) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(rate));
    if (message_arena != submessage_arena) {
      rate = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, rate, submessage_arena);
    }
    
  } else {
    
  }
  rate_ = rate;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.rate)
}

// .ignition.msgs.Float duration = 8;
inline bool ParticleEmitter::_internal_has_duration() const {
  return this != internal_default_instance() && duration_ != nullptr;
}
inline bool ParticleEmitter::has_duration() const {
  return _internal_has_duration();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_duration() const {
  const ::ignition::msgs::Float* p = duration_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::duration() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.duration)
  return _internal_duration();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_duration(
    ::ignition::msgs::Float* duration) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(duration_);
  }
  duration_ = duration;
  if (duration) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.duration)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_duration() {
  
  ::ignition::msgs::Float* temp = duration_;
  duration_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_duration() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.duration)
  
  ::ignition::msgs::Float* temp = duration_;
  duration_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_duration() {
  
  if (duration_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    duration_ = p;
  }
  return duration_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_duration() {
  ::ignition::msgs::Float* _msg = _internal_mutable_duration();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.duration)
  return _msg;
}
inline void ParticleEmitter::set_allocated_duration(::ignition::msgs::Float* duration) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(duration_);
  }
  if (duration) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(duration));
    if (message_arena != submessage_arena) {
      duration = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, duration, submessage_arena);
    }
    
  } else {
    
  }
  duration_ = duration;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.duration)
}

// .ignition.msgs.Boolean emitting = 9;
inline bool ParticleEmitter::_internal_has_emitting() const {
  return this != internal_default_instance() && emitting_ != nullptr;
}
inline bool ParticleEmitter::has_emitting() const {
  return _internal_has_emitting();
}
inline const ::ignition::msgs::Boolean& ParticleEmitter::_internal_emitting() const {
  const ::ignition::msgs::Boolean* p = emitting_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Boolean&>(
      ::ignition::msgs::_Boolean_default_instance_);
}
inline const ::ignition::msgs::Boolean& ParticleEmitter::emitting() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.emitting)
  return _internal_emitting();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_emitting(
    ::ignition::msgs::Boolean* emitting) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(emitting_);
  }
  emitting_ = emitting;
  if (emitting) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.emitting)
}
inline ::ignition::msgs::Boolean* ParticleEmitter::release_emitting() {
  
  ::ignition::msgs::Boolean* temp = emitting_;
  emitting_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Boolean* ParticleEmitter::unsafe_arena_release_emitting() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.emitting)
  
  ::ignition::msgs::Boolean* temp = emitting_;
  emitting_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Boolean* ParticleEmitter::_internal_mutable_emitting() {
  
  if (emitting_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Boolean>(GetArenaForAllocation());
    emitting_ = p;
  }
  return emitting_;
}
inline ::ignition::msgs::Boolean* ParticleEmitter::mutable_emitting() {
  ::ignition::msgs::Boolean* _msg = _internal_mutable_emitting();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.emitting)
  return _msg;
}
inline void ParticleEmitter::set_allocated_emitting(::ignition::msgs::Boolean* emitting) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(emitting_);
  }
  if (emitting) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(emitting));
    if (message_arena != submessage_arena) {
      emitting = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, emitting, submessage_arena);
    }
    
  } else {
    
  }
  emitting_ = emitting;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.emitting)
}

// .ignition.msgs.Vector3d particle_size = 10;
inline bool ParticleEmitter::_internal_has_particle_size() const {
  return this != internal_default_instance() && particle_size_ != nullptr;
}
inline bool ParticleEmitter::has_particle_size() const {
  return _internal_has_particle_size();
}
inline const ::ignition::msgs::Vector3d& ParticleEmitter::_internal_particle_size() const {
  const ::ignition::msgs::Vector3d* p = particle_size_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Vector3d&>(
      ::ignition::msgs::_Vector3d_default_instance_);
}
inline const ::ignition::msgs::Vector3d& ParticleEmitter::particle_size() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.particle_size)
  return _internal_particle_size();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_particle_size(
    ::ignition::msgs::Vector3d* particle_size) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(particle_size_);
  }
  particle_size_ = particle_size;
  if (particle_size) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.particle_size)
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::release_particle_size() {
  
  ::ignition::msgs::Vector3d* temp = particle_size_;
  particle_size_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::unsafe_arena_release_particle_size() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.particle_size)
  
  ::ignition::msgs::Vector3d* temp = particle_size_;
  particle_size_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::_internal_mutable_particle_size() {
  
  if (particle_size_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Vector3d>(GetArenaForAllocation());
    particle_size_ = p;
  }
  return particle_size_;
}
inline ::ignition::msgs::Vector3d* ParticleEmitter::mutable_particle_size() {
  ::ignition::msgs::Vector3d* _msg = _internal_mutable_particle_size();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.particle_size)
  return _msg;
}
inline void ParticleEmitter::set_allocated_particle_size(::ignition::msgs::Vector3d* particle_size) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(particle_size_);
  }
  if (particle_size) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(particle_size));
    if (message_arena != submessage_arena) {
      particle_size = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, particle_size, submessage_arena);
    }
    
  } else {
    
  }
  particle_size_ = particle_size;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.particle_size)
}

// .ignition.msgs.Float lifetime = 11;
inline bool ParticleEmitter::_internal_has_lifetime() const {
  return this != internal_default_instance() && lifetime_ != nullptr;
}
inline bool ParticleEmitter::has_lifetime() const {
  return _internal_has_lifetime();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_lifetime() const {
  const ::ignition::msgs::Float* p = lifetime_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::lifetime() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.lifetime)
  return _internal_lifetime();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_lifetime(
    ::ignition::msgs::Float* lifetime) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime_);
  }
  lifetime_ = lifetime;
  if (lifetime) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.lifetime)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_lifetime() {
  
  ::ignition::msgs::Float* temp = lifetime_;
  lifetime_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_lifetime() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.lifetime)
  
  ::ignition::msgs::Float* temp = lifetime_;
  lifetime_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_lifetime() {
  
  if (lifetime_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    lifetime_ = p;
  }
  return lifetime_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_lifetime() {
  ::ignition::msgs::Float* _msg = _internal_mutable_lifetime();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.lifetime)
  return _msg;
}
inline void ParticleEmitter::set_allocated_lifetime(::ignition::msgs::Float* lifetime) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime_);
  }
  if (lifetime) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(lifetime));
    if (message_arena != submessage_arena) {
      lifetime = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, lifetime, submessage_arena);
    }
    
  } else {
    
  }
  lifetime_ = lifetime;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.lifetime)
}

// .ignition.msgs.Material material = 12;
inline bool ParticleEmitter::_internal_has_material() const {
  return this != internal_default_instance() && material_ != nullptr;
}
inline bool ParticleEmitter::has_material() const {
  return _internal_has_material();
}
inline const ::ignition::msgs::Material& ParticleEmitter::_internal_material() const {
  const ::ignition::msgs::Material* p = material_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Material&>(
      ::ignition::msgs::_Material_default_instance_);
}
inline const ::ignition::msgs::Material& ParticleEmitter::material() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.material)
  return _internal_material();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_material(
    ::ignition::msgs::Material* material) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(material_);
  }
  material_ = material;
  if (material) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.material)
}
inline ::ignition::msgs::Material* ParticleEmitter::release_material() {
  
  ::ignition::msgs::Material* temp = material_;
  material_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Material* ParticleEmitter::unsafe_arena_release_material() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.material)
  
  ::ignition::msgs::Material* temp = material_;
  material_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Material* ParticleEmitter::_internal_mutable_material() {
  
  if (material_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Material>(GetArenaForAllocation());
    material_ = p;
  }
  return material_;
}
inline ::ignition::msgs::Material* ParticleEmitter::mutable_material() {
  ::ignition::msgs::Material* _msg = _internal_mutable_material();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.material)
  return _msg;
}
inline void ParticleEmitter::set_allocated_material(::ignition::msgs::Material* material) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(material_);
  }
  if (material) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(material));
    if (message_arena != submessage_arena) {
      material = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, material, submessage_arena);
    }
    
  } else {
    
  }
  material_ = material;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.material)
}

// .ignition.msgs.Float min_velocity = 13;
inline bool ParticleEmitter::_internal_has_min_velocity() const {
  return this != internal_default_instance() && min_velocity_ != nullptr;
}
inline bool ParticleEmitter::has_min_velocity() const {
  return _internal_has_min_velocity();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_min_velocity() const {
  const ::ignition::msgs::Float* p = min_velocity_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::min_velocity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.min_velocity)
  return _internal_min_velocity();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_min_velocity(
    ::ignition::msgs::Float* min_velocity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(min_velocity_);
  }
  min_velocity_ = min_velocity;
  if (min_velocity) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.min_velocity)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_min_velocity() {
  
  ::ignition::msgs::Float* temp = min_velocity_;
  min_velocity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_min_velocity() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.min_velocity)
  
  ::ignition::msgs::Float* temp = min_velocity_;
  min_velocity_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_min_velocity() {
  
  if (min_velocity_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    min_velocity_ = p;
  }
  return min_velocity_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_min_velocity() {
  ::ignition::msgs::Float* _msg = _internal_mutable_min_velocity();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.min_velocity)
  return _msg;
}
inline void ParticleEmitter::set_allocated_min_velocity(::ignition::msgs::Float* min_velocity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(min_velocity_);
  }
  if (min_velocity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(min_velocity));
    if (message_arena != submessage_arena) {
      min_velocity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, min_velocity, submessage_arena);
    }
    
  } else {
    
  }
  min_velocity_ = min_velocity;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.min_velocity)
}

// .ignition.msgs.Float max_velocity = 14;
inline bool ParticleEmitter::_internal_has_max_velocity() const {
  return this != internal_default_instance() && max_velocity_ != nullptr;
}
inline bool ParticleEmitter::has_max_velocity() const {
  return _internal_has_max_velocity();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_max_velocity() const {
  const ::ignition::msgs::Float* p = max_velocity_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::max_velocity() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.max_velocity)
  return _internal_max_velocity();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_max_velocity(
    ::ignition::msgs::Float* max_velocity) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(max_velocity_);
  }
  max_velocity_ = max_velocity;
  if (max_velocity) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.max_velocity)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_max_velocity() {
  
  ::ignition::msgs::Float* temp = max_velocity_;
  max_velocity_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_max_velocity() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.max_velocity)
  
  ::ignition::msgs::Float* temp = max_velocity_;
  max_velocity_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_max_velocity() {
  
  if (max_velocity_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    max_velocity_ = p;
  }
  return max_velocity_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_max_velocity() {
  ::ignition::msgs::Float* _msg = _internal_mutable_max_velocity();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.max_velocity)
  return _msg;
}
inline void ParticleEmitter::set_allocated_max_velocity(::ignition::msgs::Float* max_velocity) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(max_velocity_);
  }
  if (max_velocity) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(max_velocity));
    if (message_arena != submessage_arena) {
      max_velocity = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, max_velocity, submessage_arena);
    }
    
  } else {
    
  }
  max_velocity_ = max_velocity;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.max_velocity)
}

// .ignition.msgs.Color color_start = 15;
inline bool ParticleEmitter::_internal_has_color_start() const {
  return this != internal_default_instance() && color_start_ != nullptr;
}
inline bool ParticleEmitter::has_color_start() const {
  return _internal_has_color_start();
}
inline const ::ignition::msgs::Color& ParticleEmitter::_internal_color_start() const {
  const ::ignition::msgs::Color* p = color_start_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& ParticleEmitter::color_start() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.color_start)
  return _internal_color_start();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_color_start(
    ::ignition::msgs::Color* color_start) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_start_);
  }
  color_start_ = color_start;
  if (color_start) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.color_start)
}
inline ::ignition::msgs::Color* ParticleEmitter::release_color_start() {
  
  ::ignition::msgs::Color* temp = color_start_;
  color_start_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* ParticleEmitter::unsafe_arena_release_color_start() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.color_start)
  
  ::ignition::msgs::Color* temp = color_start_;
  color_start_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* ParticleEmitter::_internal_mutable_color_start() {
  
  if (color_start_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    color_start_ = p;
  }
  return color_start_;
}
inline ::ignition::msgs::Color* ParticleEmitter::mutable_color_start() {
  ::ignition::msgs::Color* _msg = _internal_mutable_color_start();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.color_start)
  return _msg;
}
inline void ParticleEmitter::set_allocated_color_start(::ignition::msgs::Color* color_start) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_start_);
  }
  if (color_start) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_start));
    if (message_arena != submessage_arena) {
      color_start = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, color_start, submessage_arena);
    }
    
  } else {
    
  }
  color_start_ = color_start;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.color_start)
}

// .ignition.msgs.Color color_end = 16;
inline bool ParticleEmitter::_internal_has_color_end() const {
  return this != internal_default_instance() && color_end_ != nullptr;
}
inline bool ParticleEmitter::has_color_end() const {
  return _internal_has_color_end();
}
inline const ::ignition::msgs::Color& ParticleEmitter::_internal_color_end() const {
  const ::ignition::msgs::Color* p = color_end_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Color&>(
      ::ignition::msgs::_Color_default_instance_);
}
inline const ::ignition::msgs::Color& ParticleEmitter::color_end() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.color_end)
  return _internal_color_end();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_color_end(
    ::ignition::msgs::Color* color_end) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_end_);
  }
  color_end_ = color_end;
  if (color_end) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.color_end)
}
inline ::ignition::msgs::Color* ParticleEmitter::release_color_end() {
  
  ::ignition::msgs::Color* temp = color_end_;
  color_end_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Color* ParticleEmitter::unsafe_arena_release_color_end() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.color_end)
  
  ::ignition::msgs::Color* temp = color_end_;
  color_end_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Color* ParticleEmitter::_internal_mutable_color_end() {
  
  if (color_end_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Color>(GetArenaForAllocation());
    color_end_ = p;
  }
  return color_end_;
}
inline ::ignition::msgs::Color* ParticleEmitter::mutable_color_end() {
  ::ignition::msgs::Color* _msg = _internal_mutable_color_end();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.color_end)
  return _msg;
}
inline void ParticleEmitter::set_allocated_color_end(::ignition::msgs::Color* color_end) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_end_);
  }
  if (color_end) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_end));
    if (message_arena != submessage_arena) {
      color_end = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, color_end, submessage_arena);
    }
    
  } else {
    
  }
  color_end_ = color_end;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.color_end)
}

// .ignition.msgs.Float scale_rate = 17;
inline bool ParticleEmitter::_internal_has_scale_rate() const {
  return this != internal_default_instance() && scale_rate_ != nullptr;
}
inline bool ParticleEmitter::has_scale_rate() const {
  return _internal_has_scale_rate();
}
inline const ::ignition::msgs::Float& ParticleEmitter::_internal_scale_rate() const {
  const ::ignition::msgs::Float* p = scale_rate_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Float&>(
      ::ignition::msgs::_Float_default_instance_);
}
inline const ::ignition::msgs::Float& ParticleEmitter::scale_rate() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.scale_rate)
  return _internal_scale_rate();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_scale_rate(
    ::ignition::msgs::Float* scale_rate) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_rate_);
  }
  scale_rate_ = scale_rate;
  if (scale_rate) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.scale_rate)
}
inline ::ignition::msgs::Float* ParticleEmitter::release_scale_rate() {
  
  ::ignition::msgs::Float* temp = scale_rate_;
  scale_rate_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::unsafe_arena_release_scale_rate() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.scale_rate)
  
  ::ignition::msgs::Float* temp = scale_rate_;
  scale_rate_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Float* ParticleEmitter::_internal_mutable_scale_rate() {
  
  if (scale_rate_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Float>(GetArenaForAllocation());
    scale_rate_ = p;
  }
  return scale_rate_;
}
inline ::ignition::msgs::Float* ParticleEmitter::mutable_scale_rate() {
  ::ignition::msgs::Float* _msg = _internal_mutable_scale_rate();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.scale_rate)
  return _msg;
}
inline void ParticleEmitter::set_allocated_scale_rate(::ignition::msgs::Float* scale_rate) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_rate_);
  }
  if (scale_rate) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(scale_rate));
    if (message_arena != submessage_arena) {
      scale_rate = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, scale_rate, submessage_arena);
    }
    
  } else {
    
  }
  scale_rate_ = scale_rate;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.scale_rate)
}

// .ignition.msgs.StringMsg color_range_image = 18;
inline bool ParticleEmitter::_internal_has_color_range_image() const {
  return this != internal_default_instance() && color_range_image_ != nullptr;
}
inline bool ParticleEmitter::has_color_range_image() const {
  return _internal_has_color_range_image();
}
inline const ::ignition::msgs::StringMsg& ParticleEmitter::_internal_color_range_image() const {
  const ::ignition::msgs::StringMsg* p = color_range_image_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::StringMsg&>(
      ::ignition::msgs::_StringMsg_default_instance_);
}
inline const ::ignition::msgs::StringMsg& ParticleEmitter::color_range_image() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.ParticleEmitter.color_range_image)
  return _internal_color_range_image();
}
inline void ParticleEmitter::unsafe_arena_set_allocated_color_range_image(
    ::ignition::msgs::StringMsg* color_range_image) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_range_image_);
  }
  color_range_image_ = color_range_image;
  if (color_range_image) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.ParticleEmitter.color_range_image)
}
inline ::ignition::msgs::StringMsg* ParticleEmitter::release_color_range_image() {
  
  ::ignition::msgs::StringMsg* temp = color_range_image_;
  color_range_image_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::StringMsg* ParticleEmitter::unsafe_arena_release_color_range_image() {
  // @@protoc_insertion_point(field_release:ignition.msgs.ParticleEmitter.color_range_image)
  
  ::ignition::msgs::StringMsg* temp = color_range_image_;
  color_range_image_ = nullptr;
  return temp;
}
inline ::ignition::msgs::StringMsg* ParticleEmitter::_internal_mutable_color_range_image() {
  
  if (color_range_image_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::StringMsg>(GetArenaForAllocation());
    color_range_image_ = p;
  }
  return color_range_image_;
}
inline ::ignition::msgs::StringMsg* ParticleEmitter::mutable_color_range_image() {
  ::ignition::msgs::StringMsg* _msg = _internal_mutable_color_range_image();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.ParticleEmitter.color_range_image)
  return _msg;
}
inline void ParticleEmitter::set_allocated_color_range_image(::ignition::msgs::StringMsg* color_range_image) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_range_image_);
  }
  if (color_range_image) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(color_range_image));
    if (message_arena != submessage_arena) {
      color_range_image = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, color_range_image, submessage_arena);
    }
    
  } else {
    
  }
  color_range_image_ = color_range_image;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.ParticleEmitter.color_range_image)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__

typedef std::unique_ptr<ParticleEmitter> ParticleEmitterUniquePtr;
typedef std::unique_ptr<const ParticleEmitter> ConstParticleEmitterUniquePtr;
typedef std::shared_ptr<ParticleEmitter> ParticleEmitterSharedPtr;
typedef std::shared_ptr<const ParticleEmitter> ConstParticleEmitterSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::ParticleEmitter_EmitterType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::ParticleEmitter_EmitterType>() {
  return ::ignition::msgs::ParticleEmitter_EmitterType_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fparticle_5femitter_2eproto
