/*
 * Copyright (C) 2019 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "ActuatorsProtos";

/// \ingroup ignition.msgs
/// \interface Actuators
/// \brief Commands to be sent to the actuator[s].

import "ignition/msgs/header.proto";

/// \brief Actuator commands.
message Actuators
{
  // Optional header data.
  Header header                    = 1;

  /// \brief Position of the actuators in [rad] for angular actuators
  /// and [m] for linear actuators.
  repeated double position         = 2;

  /// \brief Velocities of the actuators in [rad/s] for angular actuators
  /// and [m/s] for linear actuators.
  repeated double velocity         = 3;

  /// \brief Everything that does not fit the above,
  /// normalized between [-1 ... 1].
  repeated double normalized       = 4;
}
