# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/distortion.proto

require 'ignition/msgs/vector2d_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/distortion.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Distortion" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :center, :message, 2, "ignition.msgs.Vector2d"
      optional :k1, :double, 3
      optional :k2, :double, 4
      optional :k3, :double, 5
      optional :p1, :double, 6
      optional :p2, :double, 7
    end
  end
end

module Ignition
  module Msgs
    Distortion = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Distortion").msgclass
  end
end
