# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/collision.proto

require 'ignition/msgs/pose_pb'
require 'ignition/msgs/geometry_pb'
require 'ignition/msgs/surface_pb'
require 'ignition/msgs/visual_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/collision.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Collision" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :id, :uint32, 2
      optional :name, :string, 3
      optional :laser_retro, :double, 4
      optional :max_contacts, :double, 5
      optional :pose, :message, 6, "ignition.msgs.Pose"
      optional :geometry, :message, 7, "ignition.msgs.Geometry"
      optional :surface, :message, 8, "ignition.msgs.Surface"
      repeated :visual, :message, 9, "ignition.msgs.Visual"
    end
  end
end

module Ignition
  module Msgs
    Collision = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Collision").msgclass
  end
end
