# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/log_status.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/log_status.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LogStatus" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :sim_time, :message, 2, "ignition.msgs.Time"
      optional :log_file, :message, 3, "ignition.msgs.LogStatus.LogFile"
    end
    add_message "ignition.msgs.LogStatus.LogFile" do
      optional :uri, :string, 1
      optional :base_path, :string, 2
      optional :full_path, :string, 3
      optional :size, :float, 4
      optional :size_units, :enum, 5, "ignition.msgs.LogStatus.LogFile.Units"
      optional :record_resources, :bool, 6
    end
    add_enum "ignition.msgs.LogStatus.LogFile.Units" do
      value :BYTES, 0
      value :K_BYTES, 1
      value :M_BYTES, 2
      value :G_BYTES, 3
    end
  end
end

module Ignition
  module Msgs
    LogStatus = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogStatus").msgclass
    LogStatus::LogFile = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogStatus.LogFile").msgclass
    LogStatus::LogFile::Units = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogStatus.LogFile.Units").enummodule
  end
end
