/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "AtmosphereProtos";

/// \ingroup ignition.msgs
/// \interface Atmosphere
/// \brief A message containing a description of the global atmosphere
/// properties

import "ignition/msgs/header.proto";

message Atmosphere
{
  /// \brief Types of atmosphere models.
  enum Type
  {
    /// \brief Adiabatic atmosphere model.
    ADIABATIC = 0;
  }

  /// \brief Optional header data
  Header header                     = 1;

  /// \brief Type of the atmosphere model.
  Type type                         = 2;

  /// \brief Temperature at sea level in kelvins.
  double temperature                = 3;

  /// \brief Pressure at sea level in pascals.
  double pressure                   = 4;

  /// \brief Mass density of the air at sea level in kg/m^3.
  double mass_density               = 5;

  /// \brief Enable atmosphere model
  bool enable_atmosphere            = 6;
}
