/*
 * Copyright (C) 2017 Open Source Robotics Foundation
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
*/

syntax = "proto3";
package ignition.msgs;
option java_package = "com.ignition.msgs";
option java_outer_classname = "JointCmdProtos";

/// \ingroup ignition.msgs
/// \interface JointCmd
/// \brief Message for joint command, used by physics::JointControlWidget

import "ignition/msgs/double.proto";
import "ignition/msgs/pid.proto";
import "ignition/msgs/header.proto";

message JointCmd
{
  /// \brief Optional header data
  Header header   = 1;

  string name     = 2;
  int32 axis      = 3;
  double force    = 4[deprecated = true];

  PID position    = 5;
  PID velocity    = 6;
  bool reset      = 7;
  Double force_optional = 8;
}
