# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/version.proto

require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/version.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Version" do
      optional :major, :int32, 1
      optional :minor, :int32, 2
      optional :patch, :int32, 3
      optional :prerelease, :string, 4
      optional :build, :string, 5
    end
  end
end

module Ignition
  module Msgs
    Version = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Version").msgclass
  end
end
