# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/sky.proto

require 'ignition/msgs/color_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/sky.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Sky" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :time, :double, 2
      optional :sunrise, :double, 3
      optional :sunset, :double, 4
      optional :wind_speed, :double, 5
      optional :wind_direction, :double, 6
      optional :cloud_ambient, :message, 7, "ignition.msgs.Color"
      optional :humidity, :double, 8
      optional :mean_cloud_size, :double, 9
    end
  end
end

module Ignition
  module Msgs
    Sky = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Sky").msgclass
  end
end
