# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/sensor_noise.proto

require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/sensor_noise.proto", :syntax => :proto3) do
    add_message "ignition.msgs.SensorNoise" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.SensorNoise.Type"
      optional :mean, :double, 3
      optional :stddev, :double, 4
      optional :bias_mean, :double, 5
      optional :bias_stddev, :double, 6
      optional :precision, :double, 7
      optional :dynamic_bias_stddev, :double, 8
      optional :dynamic_bias_correlation_time, :double, 9
    end
    add_enum "ignition.msgs.SensorNoise.Type" do
      value :NONE, 0
      value :GAUSSIAN, 2
      value :GAUSSIAN_QUANTIZED, 3
    end
  end
end

module Ignition
  module Msgs
    SensorNoise = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SensorNoise").msgclass
    SensorNoise::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SensorNoise.Type").enummodule
  end
end
