# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/any.proto

require 'ignition/msgs/header_pb'
require 'ignition/msgs/color_pb'
require 'ignition/msgs/pose_pb'
require 'ignition/msgs/quaternion_pb'
require 'ignition/msgs/time_pb'
require 'ignition/msgs/vector3d_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/any.proto", :syntax => :proto3) do
    add_message "ignition.msgs.Any" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :type, :enum, 2, "ignition.msgs.Any.ValueType"
      oneof :value do
        optional :double_value, :double, 3
        optional :int_value, :int32, 4
        optional :string_value, :string, 5
        optional :bool_value, :bool, 6
        optional :vector3d_value, :message, 7, "ignition.msgs.Vector3d"
        optional :color_value, :message, 8, "ignition.msgs.Color"
        optional :pose3d_value, :message, 9, "ignition.msgs.Pose"
        optional :quaternion_value, :message, 10, "ignition.msgs.Quaternion"
        optional :time_value, :message, 11, "ignition.msgs.Time"
      end
    end
    add_enum "ignition.msgs.Any.ValueType" do
      value :NONE, 0
      value :DOUBLE, 1
      value :INT32, 2
      value :STRING, 3
      value :BOOLEAN, 4
      value :VECTOR3D, 5
      value :COLOR, 6
      value :POSE3D, 7
      value :QUATERNIOND, 8
      value :TIME, 9
    end
  end
end

module Ignition
  module Msgs
    Any = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Any").msgclass
    Any::ValueType = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.Any.ValueType").enummodule
  end
end
