# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/log_playback_control.proto

require 'ignition/msgs/time_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/log_playback_control.proto", :syntax => :proto3) do
    add_message "ignition.msgs.LogPlaybackControl" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :pause, :bool, 2
      optional :multi_step, :sint32, 3
      optional :rewind, :bool, 4
      optional :forward, :bool, 5
      optional :seek, :message, 6, "ignition.msgs.Time"
    end
  end
end

module Ignition
  module Msgs
    LogPlaybackControl = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.LogPlaybackControl").msgclass
  end
end
