// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/serialized.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#include "ignition/msgs/world_stats.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fserialized_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fserialized_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[4]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fserialized_2eproto;
namespace ignition {
namespace msgs {
class SerializedComponent;
struct SerializedComponentDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedComponentDefaultTypeInternal _SerializedComponent_default_instance_;
class SerializedEntity;
struct SerializedEntityDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedEntityDefaultTypeInternal _SerializedEntity_default_instance_;
class SerializedState;
struct SerializedStateDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedStateDefaultTypeInternal _SerializedState_default_instance_;
class SerializedStep;
struct SerializedStepDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern SerializedStepDefaultTypeInternal _SerializedStep_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedComponent* Arena::CreateMaybeMessage<::ignition::msgs::SerializedComponent>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedEntity* Arena::CreateMaybeMessage<::ignition::msgs::SerializedEntity>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedState* Arena::CreateMaybeMessage<::ignition::msgs::SerializedState>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::SerializedStep* Arena::CreateMaybeMessage<::ignition::msgs::SerializedStep>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

// ===================================================================

class IGNITION_MSGS_VISIBLE SerializedComponent final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedComponent) */ {
 public:
  inline SerializedComponent() : SerializedComponent(nullptr) {}
  ~SerializedComponent() override;
  explicit constexpr SerializedComponent(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedComponent(const SerializedComponent& from);
  SerializedComponent(SerializedComponent&& from) noexcept
    : SerializedComponent() {
    *this = ::std::move(from);
  }

  inline SerializedComponent& operator=(const SerializedComponent& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedComponent& operator=(SerializedComponent&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedComponent& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedComponent* internal_default_instance() {
    return reinterpret_cast<const SerializedComponent*>(
               &_SerializedComponent_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(SerializedComponent& a, SerializedComponent& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedComponent* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedComponent* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedComponent* New() const final {
    return new SerializedComponent();
  }

  SerializedComponent* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedComponent>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedComponent& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedComponent& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedComponent* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedComponent";
  }
  protected:
  explicit SerializedComponent(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kComponentFieldNumber = 2,
    kTypeFieldNumber = 1,
    kRemoveFieldNumber = 3,
  };
  // bytes component = 2;
  void clear_component();
  const std::string& component() const;
  template <typename ArgT0 = const std::string&, typename... ArgT>
  void set_component(ArgT0&& arg0, ArgT... args);
  std::string* mutable_component();
  PROTOBUF_MUST_USE_RESULT std::string* release_component();
  void set_allocated_component(std::string* component);
  private:
  const std::string& _internal_component() const;
  inline PROTOBUF_ALWAYS_INLINE void _internal_set_component(const std::string& value);
  std::string* _internal_mutable_component();
  public:

  // uint64 type = 1;
  void clear_type();
  ::PROTOBUF_NAMESPACE_ID::uint64 type() const;
  void set_type(::PROTOBUF_NAMESPACE_ID::uint64 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint64 _internal_type() const;
  void _internal_set_type(::PROTOBUF_NAMESPACE_ID::uint64 value);
  public:

  // bool remove = 3;
  void clear_remove();
  bool remove() const;
  void set_remove(bool value);
  private:
  bool _internal_remove() const;
  void _internal_set_remove(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedComponent)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr component_;
  ::PROTOBUF_NAMESPACE_ID::uint64 type_;
  bool remove_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedEntity final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedEntity) */ {
 public:
  inline SerializedEntity() : SerializedEntity(nullptr) {}
  ~SerializedEntity() override;
  explicit constexpr SerializedEntity(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedEntity(const SerializedEntity& from);
  SerializedEntity(SerializedEntity&& from) noexcept
    : SerializedEntity() {
    *this = ::std::move(from);
  }

  inline SerializedEntity& operator=(const SerializedEntity& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedEntity& operator=(SerializedEntity&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedEntity& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedEntity* internal_default_instance() {
    return reinterpret_cast<const SerializedEntity*>(
               &_SerializedEntity_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(SerializedEntity& a, SerializedEntity& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedEntity* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedEntity* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedEntity* New() const final {
    return new SerializedEntity();
  }

  SerializedEntity* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedEntity>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedEntity& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedEntity& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedEntity* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedEntity";
  }
  protected:
  explicit SerializedEntity(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kComponentsFieldNumber = 2,
    kIdFieldNumber = 1,
    kRemoveFieldNumber = 3,
  };
  // repeated .ignition.msgs.SerializedComponent components = 2;
  int components_size() const;
  private:
  int _internal_components_size() const;
  public:
  void clear_components();
  ::ignition::msgs::SerializedComponent* mutable_components(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedComponent >*
      mutable_components();
  private:
  const ::ignition::msgs::SerializedComponent& _internal_components(int index) const;
  ::ignition::msgs::SerializedComponent* _internal_add_components();
  public:
  const ::ignition::msgs::SerializedComponent& components(int index) const;
  ::ignition::msgs::SerializedComponent* add_components();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedComponent >&
      components() const;

  // uint64 id = 1;
  void clear_id();
  ::PROTOBUF_NAMESPACE_ID::uint64 id() const;
  void set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint64 _internal_id() const;
  void _internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value);
  public:

  // bool remove = 3;
  void clear_remove();
  bool remove() const;
  void set_remove(bool value);
  private:
  bool _internal_remove() const;
  void _internal_set_remove(bool value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedEntity)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedComponent > components_;
  ::PROTOBUF_NAMESPACE_ID::uint64 id_;
  bool remove_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedState final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedState) */ {
 public:
  inline SerializedState() : SerializedState(nullptr) {}
  ~SerializedState() override;
  explicit constexpr SerializedState(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedState(const SerializedState& from);
  SerializedState(SerializedState&& from) noexcept
    : SerializedState() {
    *this = ::std::move(from);
  }

  inline SerializedState& operator=(const SerializedState& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedState& operator=(SerializedState&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedState& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedState* internal_default_instance() {
    return reinterpret_cast<const SerializedState*>(
               &_SerializedState_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(SerializedState& a, SerializedState& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedState* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedState* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedState* New() const final {
    return new SerializedState();
  }

  SerializedState* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedState>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedState& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedState& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedState* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedState";
  }
  protected:
  explicit SerializedState(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kEntitiesFieldNumber = 2,
    kHeaderFieldNumber = 1,
  };
  // repeated .ignition.msgs.SerializedEntity entities = 2;
  int entities_size() const;
  private:
  int _internal_entities_size() const;
  public:
  void clear_entities();
  ::ignition::msgs::SerializedEntity* mutable_entities(int index);
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedEntity >*
      mutable_entities();
  private:
  const ::ignition::msgs::SerializedEntity& _internal_entities(int index) const;
  ::ignition::msgs::SerializedEntity* _internal_add_entities();
  public:
  const ::ignition::msgs::SerializedEntity& entities(int index) const;
  ::ignition::msgs::SerializedEntity* add_entities();
  const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedEntity >&
      entities() const;

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedState)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedEntity > entities_;
  ::ignition::msgs::Header* header_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE SerializedStep final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.SerializedStep) */ {
 public:
  inline SerializedStep() : SerializedStep(nullptr) {}
  ~SerializedStep() override;
  explicit constexpr SerializedStep(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  SerializedStep(const SerializedStep& from);
  SerializedStep(SerializedStep&& from) noexcept
    : SerializedStep() {
    *this = ::std::move(from);
  }

  inline SerializedStep& operator=(const SerializedStep& from) {
    CopyFrom(from);
    return *this;
  }
  inline SerializedStep& operator=(SerializedStep&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const SerializedStep& default_instance() {
    return *internal_default_instance();
  }
  static inline const SerializedStep* internal_default_instance() {
    return reinterpret_cast<const SerializedStep*>(
               &_SerializedStep_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    3;

  friend void swap(SerializedStep& a, SerializedStep& b) {
    a.Swap(&b);
  }
  inline void Swap(SerializedStep* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SerializedStep* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline SerializedStep* New() const final {
    return new SerializedStep();
  }

  SerializedStep* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<SerializedStep>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const SerializedStep& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const SerializedStep& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(SerializedStep* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.SerializedStep";
  }
  protected:
  explicit SerializedStep(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kStatsFieldNumber = 1,
    kStateFieldNumber = 2,
  };
  // .ignition.msgs.WorldStatistics stats = 1;
  bool has_stats() const;
  private:
  bool _internal_has_stats() const;
  public:
  void clear_stats();
  const ::ignition::msgs::WorldStatistics& stats() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::WorldStatistics* release_stats();
  ::ignition::msgs::WorldStatistics* mutable_stats();
  void set_allocated_stats(::ignition::msgs::WorldStatistics* stats);
  private:
  const ::ignition::msgs::WorldStatistics& _internal_stats() const;
  ::ignition::msgs::WorldStatistics* _internal_mutable_stats();
  public:
  void unsafe_arena_set_allocated_stats(
      ::ignition::msgs::WorldStatistics* stats);
  ::ignition::msgs::WorldStatistics* unsafe_arena_release_stats();

  // .ignition.msgs.SerializedState state = 2;
  bool has_state() const;
  private:
  bool _internal_has_state() const;
  public:
  void clear_state();
  const ::ignition::msgs::SerializedState& state() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::SerializedState* release_state();
  ::ignition::msgs::SerializedState* mutable_state();
  void set_allocated_state(::ignition::msgs::SerializedState* state);
  private:
  const ::ignition::msgs::SerializedState& _internal_state() const;
  ::ignition::msgs::SerializedState* _internal_mutable_state();
  public:
  void unsafe_arena_set_allocated_state(
      ::ignition::msgs::SerializedState* state);
  ::ignition::msgs::SerializedState* unsafe_arena_release_state();

  // @@protoc_insertion_point(class_scope:ignition.msgs.SerializedStep)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::ignition::msgs::WorldStatistics* stats_;
  ::ignition::msgs::SerializedState* state_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fserialized_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// SerializedComponent

// uint64 type = 1;
inline void SerializedComponent::clear_type() {
  type_ = uint64_t{0u};
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedComponent::_internal_type() const {
  return type_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedComponent::type() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedComponent.type)
  return _internal_type();
}
inline void SerializedComponent::_internal_set_type(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  
  type_ = value;
}
inline void SerializedComponent::set_type(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  _internal_set_type(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedComponent.type)
}

// bytes component = 2;
inline void SerializedComponent::clear_component() {
  component_.ClearToEmpty();
}
inline const std::string& SerializedComponent::component() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedComponent.component)
  return _internal_component();
}
template <typename ArgT0, typename... ArgT>
inline PROTOBUF_ALWAYS_INLINE
void SerializedComponent::set_component(ArgT0&& arg0, ArgT... args) {
 
 component_.SetBytes(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, static_cast<ArgT0 &&>(arg0), args..., GetArenaForAllocation());
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedComponent.component)
}
inline std::string* SerializedComponent::mutable_component() {
  std::string* _s = _internal_mutable_component();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedComponent.component)
  return _s;
}
inline const std::string& SerializedComponent::_internal_component() const {
  return component_.Get();
}
inline void SerializedComponent::_internal_set_component(const std::string& value) {
  
  component_.Set(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, value, GetArenaForAllocation());
}
inline std::string* SerializedComponent::_internal_mutable_component() {
  
  return component_.Mutable(::PROTOBUF_NAMESPACE_ID::internal::ArenaStringPtr::EmptyDefault{}, GetArenaForAllocation());
}
inline std::string* SerializedComponent::release_component() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedComponent.component)
  return component_.Release(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), GetArenaForAllocation());
}
inline void SerializedComponent::set_allocated_component(std::string* component) {
  if (component != nullptr) {
    
  } else {
    
  }
  component_.SetAllocated(&::PROTOBUF_NAMESPACE_ID::internal::GetEmptyStringAlreadyInited(), component,
      GetArenaForAllocation());
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedComponent.component)
}

// bool remove = 3;
inline void SerializedComponent::clear_remove() {
  remove_ = false;
}
inline bool SerializedComponent::_internal_remove() const {
  return remove_;
}
inline bool SerializedComponent::remove() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedComponent.remove)
  return _internal_remove();
}
inline void SerializedComponent::_internal_set_remove(bool value) {
  
  remove_ = value;
}
inline void SerializedComponent::set_remove(bool value) {
  _internal_set_remove(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedComponent.remove)
}

// -------------------------------------------------------------------

// SerializedEntity

// uint64 id = 1;
inline void SerializedEntity::clear_id() {
  id_ = uint64_t{0u};
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedEntity::_internal_id() const {
  return id_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint64 SerializedEntity::id() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedEntity.id)
  return _internal_id();
}
inline void SerializedEntity::_internal_set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  
  id_ = value;
}
inline void SerializedEntity::set_id(::PROTOBUF_NAMESPACE_ID::uint64 value) {
  _internal_set_id(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedEntity.id)
}

// repeated .ignition.msgs.SerializedComponent components = 2;
inline int SerializedEntity::_internal_components_size() const {
  return components_.size();
}
inline int SerializedEntity::components_size() const {
  return _internal_components_size();
}
inline void SerializedEntity::clear_components() {
  components_.Clear();
}
inline ::ignition::msgs::SerializedComponent* SerializedEntity::mutable_components(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedEntity.components)
  return components_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedComponent >*
SerializedEntity::mutable_components() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.SerializedEntity.components)
  return &components_;
}
inline const ::ignition::msgs::SerializedComponent& SerializedEntity::_internal_components(int index) const {
  return components_.Get(index);
}
inline const ::ignition::msgs::SerializedComponent& SerializedEntity::components(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedEntity.components)
  return _internal_components(index);
}
inline ::ignition::msgs::SerializedComponent* SerializedEntity::_internal_add_components() {
  return components_.Add();
}
inline ::ignition::msgs::SerializedComponent* SerializedEntity::add_components() {
  ::ignition::msgs::SerializedComponent* _add = _internal_add_components();
  // @@protoc_insertion_point(field_add:ignition.msgs.SerializedEntity.components)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedComponent >&
SerializedEntity::components() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.SerializedEntity.components)
  return components_;
}

// bool remove = 3;
inline void SerializedEntity::clear_remove() {
  remove_ = false;
}
inline bool SerializedEntity::_internal_remove() const {
  return remove_;
}
inline bool SerializedEntity::remove() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedEntity.remove)
  return _internal_remove();
}
inline void SerializedEntity::_internal_set_remove(bool value) {
  
  remove_ = value;
}
inline void SerializedEntity::set_remove(bool value) {
  _internal_set_remove(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.SerializedEntity.remove)
}

// -------------------------------------------------------------------

// SerializedState

// .ignition.msgs.Header header = 1;
inline bool SerializedState::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool SerializedState::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& SerializedState::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& SerializedState::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedState.header)
  return _internal_header();
}
inline void SerializedState::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedState.header)
}
inline ::ignition::msgs::Header* SerializedState::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* SerializedState::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedState.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* SerializedState::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* SerializedState::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedState.header)
  return _msg;
}
inline void SerializedState::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedState.header)
}

// repeated .ignition.msgs.SerializedEntity entities = 2;
inline int SerializedState::_internal_entities_size() const {
  return entities_.size();
}
inline int SerializedState::entities_size() const {
  return _internal_entities_size();
}
inline void SerializedState::clear_entities() {
  entities_.Clear();
}
inline ::ignition::msgs::SerializedEntity* SerializedState::mutable_entities(int index) {
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedState.entities)
  return entities_.Mutable(index);
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedEntity >*
SerializedState::mutable_entities() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.SerializedState.entities)
  return &entities_;
}
inline const ::ignition::msgs::SerializedEntity& SerializedState::_internal_entities(int index) const {
  return entities_.Get(index);
}
inline const ::ignition::msgs::SerializedEntity& SerializedState::entities(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedState.entities)
  return _internal_entities(index);
}
inline ::ignition::msgs::SerializedEntity* SerializedState::_internal_add_entities() {
  return entities_.Add();
}
inline ::ignition::msgs::SerializedEntity* SerializedState::add_entities() {
  ::ignition::msgs::SerializedEntity* _add = _internal_add_entities();
  // @@protoc_insertion_point(field_add:ignition.msgs.SerializedState.entities)
  return _add;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedPtrField< ::ignition::msgs::SerializedEntity >&
SerializedState::entities() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.SerializedState.entities)
  return entities_;
}

// -------------------------------------------------------------------

// SerializedStep

// .ignition.msgs.WorldStatistics stats = 1;
inline bool SerializedStep::_internal_has_stats() const {
  return this != internal_default_instance() && stats_ != nullptr;
}
inline bool SerializedStep::has_stats() const {
  return _internal_has_stats();
}
inline const ::ignition::msgs::WorldStatistics& SerializedStep::_internal_stats() const {
  const ::ignition::msgs::WorldStatistics* p = stats_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::WorldStatistics&>(
      ::ignition::msgs::_WorldStatistics_default_instance_);
}
inline const ::ignition::msgs::WorldStatistics& SerializedStep::stats() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedStep.stats)
  return _internal_stats();
}
inline void SerializedStep::unsafe_arena_set_allocated_stats(
    ::ignition::msgs::WorldStatistics* stats) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats_);
  }
  stats_ = stats;
  if (stats) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedStep.stats)
}
inline ::ignition::msgs::WorldStatistics* SerializedStep::release_stats() {
  
  ::ignition::msgs::WorldStatistics* temp = stats_;
  stats_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::WorldStatistics* SerializedStep::unsafe_arena_release_stats() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedStep.stats)
  
  ::ignition::msgs::WorldStatistics* temp = stats_;
  stats_ = nullptr;
  return temp;
}
inline ::ignition::msgs::WorldStatistics* SerializedStep::_internal_mutable_stats() {
  
  if (stats_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::WorldStatistics>(GetArenaForAllocation());
    stats_ = p;
  }
  return stats_;
}
inline ::ignition::msgs::WorldStatistics* SerializedStep::mutable_stats() {
  ::ignition::msgs::WorldStatistics* _msg = _internal_mutable_stats();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedStep.stats)
  return _msg;
}
inline void SerializedStep::set_allocated_stats(::ignition::msgs::WorldStatistics* stats) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats_);
  }
  if (stats) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(stats));
    if (message_arena != submessage_arena) {
      stats = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, stats, submessage_arena);
    }
    
  } else {
    
  }
  stats_ = stats;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedStep.stats)
}

// .ignition.msgs.SerializedState state = 2;
inline bool SerializedStep::_internal_has_state() const {
  return this != internal_default_instance() && state_ != nullptr;
}
inline bool SerializedStep::has_state() const {
  return _internal_has_state();
}
inline void SerializedStep::clear_state() {
  if (GetArenaForAllocation() == nullptr && state_ != nullptr) {
    delete state_;
  }
  state_ = nullptr;
}
inline const ::ignition::msgs::SerializedState& SerializedStep::_internal_state() const {
  const ::ignition::msgs::SerializedState* p = state_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::SerializedState&>(
      ::ignition::msgs::_SerializedState_default_instance_);
}
inline const ::ignition::msgs::SerializedState& SerializedStep::state() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.SerializedStep.state)
  return _internal_state();
}
inline void SerializedStep::unsafe_arena_set_allocated_state(
    ::ignition::msgs::SerializedState* state) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(state_);
  }
  state_ = state;
  if (state) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.SerializedStep.state)
}
inline ::ignition::msgs::SerializedState* SerializedStep::release_state() {
  
  ::ignition::msgs::SerializedState* temp = state_;
  state_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::SerializedState* SerializedStep::unsafe_arena_release_state() {
  // @@protoc_insertion_point(field_release:ignition.msgs.SerializedStep.state)
  
  ::ignition::msgs::SerializedState* temp = state_;
  state_ = nullptr;
  return temp;
}
inline ::ignition::msgs::SerializedState* SerializedStep::_internal_mutable_state() {
  
  if (state_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::SerializedState>(GetArenaForAllocation());
    state_ = p;
  }
  return state_;
}
inline ::ignition::msgs::SerializedState* SerializedStep::mutable_state() {
  ::ignition::msgs::SerializedState* _msg = _internal_mutable_state();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.SerializedStep.state)
  return _msg;
}
inline void SerializedStep::set_allocated_state(::ignition::msgs::SerializedState* state) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete state_;
  }
  if (state) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::SerializedState>::GetOwningArena(state);
    if (message_arena != submessage_arena) {
      state = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, state, submessage_arena);
    }
    
  } else {
    
  }
  state_ = state;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.SerializedStep.state)
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<SerializedComponent> SerializedComponentUniquePtr;
typedef std::unique_ptr<const SerializedComponent> ConstSerializedComponentUniquePtr;
typedef std::shared_ptr<SerializedComponent> SerializedComponentSharedPtr;
typedef std::shared_ptr<const SerializedComponent> ConstSerializedComponentSharedPtr;
typedef std::unique_ptr<SerializedEntity> SerializedEntityUniquePtr;
typedef std::unique_ptr<const SerializedEntity> ConstSerializedEntityUniquePtr;
typedef std::shared_ptr<SerializedEntity> SerializedEntitySharedPtr;
typedef std::shared_ptr<const SerializedEntity> ConstSerializedEntitySharedPtr;
typedef std::unique_ptr<SerializedState> SerializedStateUniquePtr;
typedef std::unique_ptr<const SerializedState> ConstSerializedStateUniquePtr;
typedef std::shared_ptr<SerializedState> SerializedStateSharedPtr;
typedef std::shared_ptr<const SerializedState> ConstSerializedStateSharedPtr;
typedef std::unique_ptr<SerializedStep> SerializedStepUniquePtr;
typedef std::unique_ptr<const SerializedStep> ConstSerializedStepUniquePtr;
typedef std::shared_ptr<SerializedStep> SerializedStepSharedPtr;
typedef std::shared_ptr<const SerializedStep> ConstSerializedStepSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fserialized_2eproto
