# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/user_cmd.proto

require 'ignition/msgs/light_pb'
require 'ignition/msgs/model_pb'
require 'ignition/msgs/world_control_pb'
require 'ignition/msgs/wrench_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/user_cmd.proto", :syntax => :proto3) do
    add_message "ignition.msgs.UserCmd" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :id, :uint32, 2
      optional :description, :string, 3
      optional :type, :enum, 4, "ignition.msgs.UserCmd.Type"
      repeated :model, :message, 5, "ignition.msgs.Model"
      repeated :light, :message, 6, "ignition.msgs.Light"
      optional :entity_name, :string, 7
      optional :world_control, :message, 8, "ignition.msgs.WorldControl"
      optional :wrench, :message, 9, "ignition.msgs.Wrench"
    end
    add_enum "ignition.msgs.UserCmd.Type" do
      value :MOVING, 0
      value :WORLD_CONTROL, 1
      value :WRENCH, 2
      value :SCALING, 3
    end
  end
end

module Ignition
  module Msgs
    UserCmd = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.UserCmd").msgclass
    UserCmd::Type = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.UserCmd.Type").enummodule
  end
end
