# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ignition/msgs/sdf_generator_config.proto

require 'ignition/msgs/boolean_pb'
require 'ignition/msgs/header_pb'
require 'google/protobuf'

Google::Protobuf::DescriptorPool.generated_pool.build do
  add_file("ignition/msgs/sdf_generator_config.proto", :syntax => :proto3) do
    add_message "ignition.msgs.SdfGeneratorConfig" do
      optional :header, :message, 1, "ignition.msgs.Header"
      optional :global_entity_gen_config, :message, 2, "ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig"
      map :override_entity_gen_configs, :string, :message, 3, "ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig"
    end
    add_message "ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig" do
      optional :expand_include_tags, :message, 1, "ignition.msgs.Boolean"
      optional :save_fuel_version, :message, 2, "ignition.msgs.Boolean"
      optional :resources_use_absolute_paths, :message, 3, "ignition.msgs.Boolean"
      optional :copy_model_resources, :message, 4, "ignition.msgs.Boolean"
    end
  end
end

module Ignition
  module Msgs
    SdfGeneratorConfig = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SdfGeneratorConfig").msgclass
    SdfGeneratorConfig::EntityGeneratorConfig = ::Google::Protobuf::DescriptorPool.generated_pool.lookup("ignition.msgs.SdfGeneratorConfig.EntityGeneratorConfig").msgclass
  end
end
