// Generated by the protocol buffer compiler.  DO NOT EDIT!
// source: ignition/msgs/camera_info.proto

#ifndef GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcamera_5finfo_2eproto
#define GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcamera_5finfo_2eproto

#include <limits>
#include <string>

#include <google/protobuf/port_def.inc>
#if PROTOBUF_VERSION < 3018000
#error This file was generated by a newer version of protoc which is
#error incompatible with your Protocol Buffer headers. Please update
#error your headers.
#endif
#if 3018000 < PROTOBUF_MIN_PROTOC_VERSION
#error This file was generated by an older version of protoc which is
#error incompatible with your Protocol Buffer headers. Please
#error regenerate this file with a newer version of protoc.
#endif

#include <google/protobuf/port_undef.inc>
#include <google/protobuf/io/coded_stream.h>
#include <google/protobuf/arena.h>
#include <google/protobuf/arenastring.h>
#include <google/protobuf/generated_message_table_driven.h>
#include <google/protobuf/generated_message_util.h>
#include <google/protobuf/metadata_lite.h>
#include <google/protobuf/generated_message_reflection.h>
#include <google/protobuf/message.h>
#include <google/protobuf/repeated_field.h>  // IWYU pragma: export
#include <google/protobuf/extension_set.h>  // IWYU pragma: export
#include <google/protobuf/generated_enum_reflection.h>
#include <google/protobuf/unknown_field_set.h>
#include "ignition/msgs/header.pb.h"
#ifndef _MSC_VER
#pragma GCC system_header
#else
#pragma warning(push)
#pragma warning(disable: 4244 4267 4100 4244 4512 4127 4068 4275 4251)
#endif
#ifdef __linux__
#include <sys/sysmacros.h>
#endif
#include <memory>
#include <ignition/msgs/Export.hh>
// @@protoc_insertion_point(includes)
#include <google/protobuf/port_def.inc>
#define PROTOBUF_INTERNAL_EXPORT_ignition_2fmsgs_2fcamera_5finfo_2eproto IGNITION_MSGS_VISIBLE
PROTOBUF_NAMESPACE_OPEN
namespace internal {
class AnyMetadata;
}  // namespace internal
PROTOBUF_NAMESPACE_CLOSE

// Internal implementation detail -- do not use these members.
struct IGNITION_MSGS_VISIBLE TableStruct_ignition_2fmsgs_2fcamera_5finfo_2eproto {
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTableField entries[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::AuxiliaryParseTableField aux[]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::ParseTable schema[4]
    PROTOBUF_SECTION_VARIABLE(protodesc_cold);
  static const ::PROTOBUF_NAMESPACE_ID::internal::FieldMetadata field_metadata[];
  static const ::PROTOBUF_NAMESPACE_ID::internal::SerializationTable serialization_table[];
  static const ::PROTOBUF_NAMESPACE_ID::uint32 offsets[];
};
IGNITION_MSGS_VISIBLE extern const ::PROTOBUF_NAMESPACE_ID::internal::DescriptorTable descriptor_table_ignition_2fmsgs_2fcamera_5finfo_2eproto;
namespace ignition {
namespace msgs {
class CameraInfo;
struct CameraInfoDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern CameraInfoDefaultTypeInternal _CameraInfo_default_instance_;
class CameraInfo_Distortion;
struct CameraInfo_DistortionDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern CameraInfo_DistortionDefaultTypeInternal _CameraInfo_Distortion_default_instance_;
class CameraInfo_Intrinsics;
struct CameraInfo_IntrinsicsDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern CameraInfo_IntrinsicsDefaultTypeInternal _CameraInfo_Intrinsics_default_instance_;
class CameraInfo_Projection;
struct CameraInfo_ProjectionDefaultTypeInternal;
IGNITION_MSGS_VISIBLE extern CameraInfo_ProjectionDefaultTypeInternal _CameraInfo_Projection_default_instance_;
}  // namespace msgs
}  // namespace ignition
PROTOBUF_NAMESPACE_OPEN
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::CameraInfo* Arena::CreateMaybeMessage<::ignition::msgs::CameraInfo>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::CameraInfo_Distortion* Arena::CreateMaybeMessage<::ignition::msgs::CameraInfo_Distortion>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::CameraInfo_Intrinsics* Arena::CreateMaybeMessage<::ignition::msgs::CameraInfo_Intrinsics>(Arena*);
template<> IGNITION_MSGS_VISIBLE ::ignition::msgs::CameraInfo_Projection* Arena::CreateMaybeMessage<::ignition::msgs::CameraInfo_Projection>(Arena*);
PROTOBUF_NAMESPACE_CLOSE
namespace ignition {
namespace msgs {

enum CameraInfo_Distortion_DistortionModelType : int {
  CameraInfo_Distortion_DistortionModelType_PLUMB_BOB = 0,
  CameraInfo_Distortion_DistortionModelType_RATIONAL_POLYNOMIAL = 1,
  CameraInfo_Distortion_DistortionModelType_EQUIDISTANT = 2,
  CameraInfo_Distortion_DistortionModelType_CameraInfo_Distortion_DistortionModelType_INT_MIN_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::min(),
  CameraInfo_Distortion_DistortionModelType_CameraInfo_Distortion_DistortionModelType_INT_MAX_SENTINEL_DO_NOT_USE_ = std::numeric_limits<::PROTOBUF_NAMESPACE_ID::int32>::max()
};
IGNITION_MSGS_VISIBLE bool CameraInfo_Distortion_DistortionModelType_IsValid(int value);
constexpr CameraInfo_Distortion_DistortionModelType CameraInfo_Distortion_DistortionModelType_DistortionModelType_MIN = CameraInfo_Distortion_DistortionModelType_PLUMB_BOB;
constexpr CameraInfo_Distortion_DistortionModelType CameraInfo_Distortion_DistortionModelType_DistortionModelType_MAX = CameraInfo_Distortion_DistortionModelType_EQUIDISTANT;
constexpr int CameraInfo_Distortion_DistortionModelType_DistortionModelType_ARRAYSIZE = CameraInfo_Distortion_DistortionModelType_DistortionModelType_MAX + 1;

IGNITION_MSGS_VISIBLE const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor* CameraInfo_Distortion_DistortionModelType_descriptor();
template<typename T>
inline const std::string& CameraInfo_Distortion_DistortionModelType_Name(T enum_t_value) {
  static_assert(::std::is_same<T, CameraInfo_Distortion_DistortionModelType>::value ||
    ::std::is_integral<T>::value,
    "Incorrect type passed to function CameraInfo_Distortion_DistortionModelType_Name.");
  return ::PROTOBUF_NAMESPACE_ID::internal::NameOfEnum(
    CameraInfo_Distortion_DistortionModelType_descriptor(), enum_t_value);
}
inline bool CameraInfo_Distortion_DistortionModelType_Parse(
    ::PROTOBUF_NAMESPACE_ID::ConstStringParam name, CameraInfo_Distortion_DistortionModelType* value) {
  return ::PROTOBUF_NAMESPACE_ID::internal::ParseNamedEnum<CameraInfo_Distortion_DistortionModelType>(
    CameraInfo_Distortion_DistortionModelType_descriptor(), name, value);
}
// ===================================================================

class IGNITION_MSGS_VISIBLE CameraInfo_Distortion final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.CameraInfo.Distortion) */ {
 public:
  inline CameraInfo_Distortion() : CameraInfo_Distortion(nullptr) {}
  ~CameraInfo_Distortion() override;
  explicit constexpr CameraInfo_Distortion(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  CameraInfo_Distortion(const CameraInfo_Distortion& from);
  CameraInfo_Distortion(CameraInfo_Distortion&& from) noexcept
    : CameraInfo_Distortion() {
    *this = ::std::move(from);
  }

  inline CameraInfo_Distortion& operator=(const CameraInfo_Distortion& from) {
    CopyFrom(from);
    return *this;
  }
  inline CameraInfo_Distortion& operator=(CameraInfo_Distortion&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CameraInfo_Distortion& default_instance() {
    return *internal_default_instance();
  }
  static inline const CameraInfo_Distortion* internal_default_instance() {
    return reinterpret_cast<const CameraInfo_Distortion*>(
               &_CameraInfo_Distortion_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    0;

  friend void swap(CameraInfo_Distortion& a, CameraInfo_Distortion& b) {
    a.Swap(&b);
  }
  inline void Swap(CameraInfo_Distortion* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CameraInfo_Distortion* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline CameraInfo_Distortion* New() const final {
    return new CameraInfo_Distortion();
  }

  CameraInfo_Distortion* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<CameraInfo_Distortion>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const CameraInfo_Distortion& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const CameraInfo_Distortion& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(CameraInfo_Distortion* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.CameraInfo.Distortion";
  }
  protected:
  explicit CameraInfo_Distortion(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef CameraInfo_Distortion_DistortionModelType DistortionModelType;
  static constexpr DistortionModelType PLUMB_BOB =
    CameraInfo_Distortion_DistortionModelType_PLUMB_BOB;
  static constexpr DistortionModelType RATIONAL_POLYNOMIAL =
    CameraInfo_Distortion_DistortionModelType_RATIONAL_POLYNOMIAL;
  static constexpr DistortionModelType EQUIDISTANT =
    CameraInfo_Distortion_DistortionModelType_EQUIDISTANT;
  static inline bool DistortionModelType_IsValid(int value) {
    return CameraInfo_Distortion_DistortionModelType_IsValid(value);
  }
  static constexpr DistortionModelType DistortionModelType_MIN =
    CameraInfo_Distortion_DistortionModelType_DistortionModelType_MIN;
  static constexpr DistortionModelType DistortionModelType_MAX =
    CameraInfo_Distortion_DistortionModelType_DistortionModelType_MAX;
  static constexpr int DistortionModelType_ARRAYSIZE =
    CameraInfo_Distortion_DistortionModelType_DistortionModelType_ARRAYSIZE;
  static inline const ::PROTOBUF_NAMESPACE_ID::EnumDescriptor*
  DistortionModelType_descriptor() {
    return CameraInfo_Distortion_DistortionModelType_descriptor();
  }
  template<typename T>
  static inline const std::string& DistortionModelType_Name(T enum_t_value) {
    static_assert(::std::is_same<T, DistortionModelType>::value ||
      ::std::is_integral<T>::value,
      "Incorrect type passed to function DistortionModelType_Name.");
    return CameraInfo_Distortion_DistortionModelType_Name(enum_t_value);
  }
  static inline bool DistortionModelType_Parse(::PROTOBUF_NAMESPACE_ID::ConstStringParam name,
      DistortionModelType* value) {
    return CameraInfo_Distortion_DistortionModelType_Parse(name, value);
  }

  // accessors -------------------------------------------------------

  enum : int {
    kKFieldNumber = 2,
    kModelFieldNumber = 1,
  };
  // repeated double k = 2;
  int k_size() const;
  private:
  int _internal_k_size() const;
  public:
  void clear_k();
  private:
  double _internal_k(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_k() const;
  void _internal_add_k(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_k();
  public:
  double k(int index) const;
  void set_k(int index, double value);
  void add_k(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      k() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_k();

  // .ignition.msgs.CameraInfo.Distortion.DistortionModelType model = 1;
  void clear_model();
  ::ignition::msgs::CameraInfo_Distortion_DistortionModelType model() const;
  void set_model(::ignition::msgs::CameraInfo_Distortion_DistortionModelType value);
  private:
  ::ignition::msgs::CameraInfo_Distortion_DistortionModelType _internal_model() const;
  void _internal_set_model(::ignition::msgs::CameraInfo_Distortion_DistortionModelType value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.CameraInfo.Distortion)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > k_;
  int model_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fcamera_5finfo_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE CameraInfo_Intrinsics final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.CameraInfo.Intrinsics) */ {
 public:
  inline CameraInfo_Intrinsics() : CameraInfo_Intrinsics(nullptr) {}
  ~CameraInfo_Intrinsics() override;
  explicit constexpr CameraInfo_Intrinsics(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  CameraInfo_Intrinsics(const CameraInfo_Intrinsics& from);
  CameraInfo_Intrinsics(CameraInfo_Intrinsics&& from) noexcept
    : CameraInfo_Intrinsics() {
    *this = ::std::move(from);
  }

  inline CameraInfo_Intrinsics& operator=(const CameraInfo_Intrinsics& from) {
    CopyFrom(from);
    return *this;
  }
  inline CameraInfo_Intrinsics& operator=(CameraInfo_Intrinsics&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CameraInfo_Intrinsics& default_instance() {
    return *internal_default_instance();
  }
  static inline const CameraInfo_Intrinsics* internal_default_instance() {
    return reinterpret_cast<const CameraInfo_Intrinsics*>(
               &_CameraInfo_Intrinsics_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    1;

  friend void swap(CameraInfo_Intrinsics& a, CameraInfo_Intrinsics& b) {
    a.Swap(&b);
  }
  inline void Swap(CameraInfo_Intrinsics* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CameraInfo_Intrinsics* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline CameraInfo_Intrinsics* New() const final {
    return new CameraInfo_Intrinsics();
  }

  CameraInfo_Intrinsics* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<CameraInfo_Intrinsics>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const CameraInfo_Intrinsics& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const CameraInfo_Intrinsics& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(CameraInfo_Intrinsics* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.CameraInfo.Intrinsics";
  }
  protected:
  explicit CameraInfo_Intrinsics(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kKFieldNumber = 1,
  };
  // repeated double k = 1;
  int k_size() const;
  private:
  int _internal_k_size() const;
  public:
  void clear_k();
  private:
  double _internal_k(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_k() const;
  void _internal_add_k(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_k();
  public:
  double k(int index) const;
  void set_k(int index, double value);
  void add_k(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      k() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_k();

  // @@protoc_insertion_point(class_scope:ignition.msgs.CameraInfo.Intrinsics)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > k_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fcamera_5finfo_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE CameraInfo_Projection final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.CameraInfo.Projection) */ {
 public:
  inline CameraInfo_Projection() : CameraInfo_Projection(nullptr) {}
  ~CameraInfo_Projection() override;
  explicit constexpr CameraInfo_Projection(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  CameraInfo_Projection(const CameraInfo_Projection& from);
  CameraInfo_Projection(CameraInfo_Projection&& from) noexcept
    : CameraInfo_Projection() {
    *this = ::std::move(from);
  }

  inline CameraInfo_Projection& operator=(const CameraInfo_Projection& from) {
    CopyFrom(from);
    return *this;
  }
  inline CameraInfo_Projection& operator=(CameraInfo_Projection&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CameraInfo_Projection& default_instance() {
    return *internal_default_instance();
  }
  static inline const CameraInfo_Projection* internal_default_instance() {
    return reinterpret_cast<const CameraInfo_Projection*>(
               &_CameraInfo_Projection_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    2;

  friend void swap(CameraInfo_Projection& a, CameraInfo_Projection& b) {
    a.Swap(&b);
  }
  inline void Swap(CameraInfo_Projection* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CameraInfo_Projection* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline CameraInfo_Projection* New() const final {
    return new CameraInfo_Projection();
  }

  CameraInfo_Projection* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<CameraInfo_Projection>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const CameraInfo_Projection& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const CameraInfo_Projection& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(CameraInfo_Projection* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.CameraInfo.Projection";
  }
  protected:
  explicit CameraInfo_Projection(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------

  enum : int {
    kPFieldNumber = 1,
  };
  // repeated double p = 1;
  int p_size() const;
  private:
  int _internal_p_size() const;
  public:
  void clear_p();
  private:
  double _internal_p(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_p() const;
  void _internal_add_p(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_p();
  public:
  double p(int index) const;
  void set_p(int index, double value);
  void add_p(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      p() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_p();

  // @@protoc_insertion_point(class_scope:ignition.msgs.CameraInfo.Projection)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > p_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fcamera_5finfo_2eproto;
};
// -------------------------------------------------------------------

class IGNITION_MSGS_VISIBLE CameraInfo final :
    public ::PROTOBUF_NAMESPACE_ID::Message /* @@protoc_insertion_point(class_definition:ignition.msgs.CameraInfo) */ {
 public:
  inline CameraInfo() : CameraInfo(nullptr) {}
  ~CameraInfo() override;
  explicit constexpr CameraInfo(::PROTOBUF_NAMESPACE_ID::internal::ConstantInitialized);

  CameraInfo(const CameraInfo& from);
  CameraInfo(CameraInfo&& from) noexcept
    : CameraInfo() {
    *this = ::std::move(from);
  }

  inline CameraInfo& operator=(const CameraInfo& from) {
    CopyFrom(from);
    return *this;
  }
  inline CameraInfo& operator=(CameraInfo&& from) noexcept {
    if (this == &from) return *this;
    if (GetOwningArena() == from.GetOwningArena()
  #ifdef PROTOBUF_FORCE_COPY_IN_MOVE
        && GetOwningArena() != nullptr
  #endif  // !PROTOBUF_FORCE_COPY_IN_MOVE
    ) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* descriptor() {
    return GetDescriptor();
  }
  static const ::PROTOBUF_NAMESPACE_ID::Descriptor* GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  static const ::PROTOBUF_NAMESPACE_ID::Reflection* GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  static const CameraInfo& default_instance() {
    return *internal_default_instance();
  }
  static inline const CameraInfo* internal_default_instance() {
    return reinterpret_cast<const CameraInfo*>(
               &_CameraInfo_default_instance_);
  }
  static constexpr int kIndexInFileMessages =
    3;

  friend void swap(CameraInfo& a, CameraInfo& b) {
    a.Swap(&b);
  }
  inline void Swap(CameraInfo* other) {
    if (other == this) return;
    if (GetOwningArena() == other->GetOwningArena()) {
      InternalSwap(other);
    } else {
      ::PROTOBUF_NAMESPACE_ID::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(CameraInfo* other) {
    if (other == this) return;
    GOOGLE_DCHECK(GetOwningArena() == other->GetOwningArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  inline CameraInfo* New() const final {
    return new CameraInfo();
  }

  CameraInfo* New(::PROTOBUF_NAMESPACE_ID::Arena* arena) const final {
    return CreateMaybeMessage<CameraInfo>(arena);
  }
  using ::PROTOBUF_NAMESPACE_ID::Message::CopyFrom;
  void CopyFrom(const CameraInfo& from);
  using ::PROTOBUF_NAMESPACE_ID::Message::MergeFrom;
  void MergeFrom(const CameraInfo& from);
  private:
  static void MergeImpl(::PROTOBUF_NAMESPACE_ID::Message* to, const ::PROTOBUF_NAMESPACE_ID::Message& from);
  public:
  PROTOBUF_ATTRIBUTE_REINITIALIZES void Clear() final;
  bool IsInitialized() const final;

  size_t ByteSizeLong() const final;
  const char* _InternalParse(const char* ptr, ::PROTOBUF_NAMESPACE_ID::internal::ParseContext* ctx) final;
  ::PROTOBUF_NAMESPACE_ID::uint8* _InternalSerialize(
      ::PROTOBUF_NAMESPACE_ID::uint8* target, ::PROTOBUF_NAMESPACE_ID::io::EpsCopyOutputStream* stream) const final;
  int GetCachedSize() const final { return _cached_size_.Get(); }

  private:
  void SharedCtor();
  void SharedDtor();
  void SetCachedSize(int size) const final;
  void InternalSwap(CameraInfo* other);
  friend class ::PROTOBUF_NAMESPACE_ID::internal::AnyMetadata;
  static ::PROTOBUF_NAMESPACE_ID::StringPiece FullMessageName() {
    return "ignition.msgs.CameraInfo";
  }
  protected:
  explicit CameraInfo(::PROTOBUF_NAMESPACE_ID::Arena* arena,
                       bool is_message_owned = false);
  private:
  static void ArenaDtor(void* object);
  inline void RegisterArenaDtor(::PROTOBUF_NAMESPACE_ID::Arena* arena);
  public:

  static const ClassData _class_data_;
  const ::PROTOBUF_NAMESPACE_ID::Message::ClassData*GetClassData() const final;

  ::PROTOBUF_NAMESPACE_ID::Metadata GetMetadata() const final;

  // nested types ----------------------------------------------------

  typedef CameraInfo_Distortion Distortion;
  typedef CameraInfo_Intrinsics Intrinsics;
  typedef CameraInfo_Projection Projection;

  // accessors -------------------------------------------------------

  enum : int {
    kRectificationMatrixFieldNumber = 7,
    kHeaderFieldNumber = 1,
    kDistortionFieldNumber = 4,
    kIntrinsicsFieldNumber = 5,
    kProjectionFieldNumber = 6,
    kWidthFieldNumber = 2,
    kHeightFieldNumber = 3,
  };
  // repeated double rectification_matrix = 7 [packed = true];
  int rectification_matrix_size() const;
  private:
  int _internal_rectification_matrix_size() const;
  public:
  void clear_rectification_matrix();
  private:
  double _internal_rectification_matrix(int index) const;
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      _internal_rectification_matrix() const;
  void _internal_add_rectification_matrix(double value);
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      _internal_mutable_rectification_matrix();
  public:
  double rectification_matrix(int index) const;
  void set_rectification_matrix(int index, double value);
  void add_rectification_matrix(double value);
  const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
      rectification_matrix() const;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
      mutable_rectification_matrix();

  // .ignition.msgs.Header header = 1;
  bool has_header() const;
  private:
  bool _internal_has_header() const;
  public:
  void clear_header();
  const ::ignition::msgs::Header& header() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::Header* release_header();
  ::ignition::msgs::Header* mutable_header();
  void set_allocated_header(::ignition::msgs::Header* header);
  private:
  const ::ignition::msgs::Header& _internal_header() const;
  ::ignition::msgs::Header* _internal_mutable_header();
  public:
  void unsafe_arena_set_allocated_header(
      ::ignition::msgs::Header* header);
  ::ignition::msgs::Header* unsafe_arena_release_header();

  // .ignition.msgs.CameraInfo.Distortion distortion = 4;
  bool has_distortion() const;
  private:
  bool _internal_has_distortion() const;
  public:
  void clear_distortion();
  const ::ignition::msgs::CameraInfo_Distortion& distortion() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::CameraInfo_Distortion* release_distortion();
  ::ignition::msgs::CameraInfo_Distortion* mutable_distortion();
  void set_allocated_distortion(::ignition::msgs::CameraInfo_Distortion* distortion);
  private:
  const ::ignition::msgs::CameraInfo_Distortion& _internal_distortion() const;
  ::ignition::msgs::CameraInfo_Distortion* _internal_mutable_distortion();
  public:
  void unsafe_arena_set_allocated_distortion(
      ::ignition::msgs::CameraInfo_Distortion* distortion);
  ::ignition::msgs::CameraInfo_Distortion* unsafe_arena_release_distortion();

  // .ignition.msgs.CameraInfo.Intrinsics intrinsics = 5;
  bool has_intrinsics() const;
  private:
  bool _internal_has_intrinsics() const;
  public:
  void clear_intrinsics();
  const ::ignition::msgs::CameraInfo_Intrinsics& intrinsics() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::CameraInfo_Intrinsics* release_intrinsics();
  ::ignition::msgs::CameraInfo_Intrinsics* mutable_intrinsics();
  void set_allocated_intrinsics(::ignition::msgs::CameraInfo_Intrinsics* intrinsics);
  private:
  const ::ignition::msgs::CameraInfo_Intrinsics& _internal_intrinsics() const;
  ::ignition::msgs::CameraInfo_Intrinsics* _internal_mutable_intrinsics();
  public:
  void unsafe_arena_set_allocated_intrinsics(
      ::ignition::msgs::CameraInfo_Intrinsics* intrinsics);
  ::ignition::msgs::CameraInfo_Intrinsics* unsafe_arena_release_intrinsics();

  // .ignition.msgs.CameraInfo.Projection projection = 6;
  bool has_projection() const;
  private:
  bool _internal_has_projection() const;
  public:
  void clear_projection();
  const ::ignition::msgs::CameraInfo_Projection& projection() const;
  PROTOBUF_MUST_USE_RESULT ::ignition::msgs::CameraInfo_Projection* release_projection();
  ::ignition::msgs::CameraInfo_Projection* mutable_projection();
  void set_allocated_projection(::ignition::msgs::CameraInfo_Projection* projection);
  private:
  const ::ignition::msgs::CameraInfo_Projection& _internal_projection() const;
  ::ignition::msgs::CameraInfo_Projection* _internal_mutable_projection();
  public:
  void unsafe_arena_set_allocated_projection(
      ::ignition::msgs::CameraInfo_Projection* projection);
  ::ignition::msgs::CameraInfo_Projection* unsafe_arena_release_projection();

  // uint32 width = 2;
  void clear_width();
  ::PROTOBUF_NAMESPACE_ID::uint32 width() const;
  void set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_width() const;
  void _internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // uint32 height = 3;
  void clear_height();
  ::PROTOBUF_NAMESPACE_ID::uint32 height() const;
  void set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  private:
  ::PROTOBUF_NAMESPACE_ID::uint32 _internal_height() const;
  void _internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value);
  public:

  // @@protoc_insertion_point(class_scope:ignition.msgs.CameraInfo)
 private:
  class _Internal;

  template <typename T> friend class ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper;
  typedef void InternalArenaConstructable_;
  typedef void DestructorSkippable_;
  ::PROTOBUF_NAMESPACE_ID::RepeatedField< double > rectification_matrix_;
  ::ignition::msgs::Header* header_;
  ::ignition::msgs::CameraInfo_Distortion* distortion_;
  ::ignition::msgs::CameraInfo_Intrinsics* intrinsics_;
  ::ignition::msgs::CameraInfo_Projection* projection_;
  ::PROTOBUF_NAMESPACE_ID::uint32 width_;
  ::PROTOBUF_NAMESPACE_ID::uint32 height_;
  mutable ::PROTOBUF_NAMESPACE_ID::internal::CachedSize _cached_size_;
  friend struct ::TableStruct_ignition_2fmsgs_2fcamera_5finfo_2eproto;
};
// ===================================================================


// ===================================================================

#ifdef __GNUC__
  #pragma GCC diagnostic push
  #pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// CameraInfo_Distortion

// .ignition.msgs.CameraInfo.Distortion.DistortionModelType model = 1;
inline void CameraInfo_Distortion::clear_model() {
  model_ = 0;
}
inline ::ignition::msgs::CameraInfo_Distortion_DistortionModelType CameraInfo_Distortion::_internal_model() const {
  return static_cast< ::ignition::msgs::CameraInfo_Distortion_DistortionModelType >(model_);
}
inline ::ignition::msgs::CameraInfo_Distortion_DistortionModelType CameraInfo_Distortion::model() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.Distortion.model)
  return _internal_model();
}
inline void CameraInfo_Distortion::_internal_set_model(::ignition::msgs::CameraInfo_Distortion_DistortionModelType value) {
  
  model_ = value;
}
inline void CameraInfo_Distortion::set_model(::ignition::msgs::CameraInfo_Distortion_DistortionModelType value) {
  _internal_set_model(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.Distortion.model)
}

// repeated double k = 2;
inline int CameraInfo_Distortion::_internal_k_size() const {
  return k_.size();
}
inline int CameraInfo_Distortion::k_size() const {
  return _internal_k_size();
}
inline void CameraInfo_Distortion::clear_k() {
  k_.Clear();
}
inline double CameraInfo_Distortion::_internal_k(int index) const {
  return k_.Get(index);
}
inline double CameraInfo_Distortion::k(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.Distortion.k)
  return _internal_k(index);
}
inline void CameraInfo_Distortion::set_k(int index, double value) {
  k_.Set(index, value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.Distortion.k)
}
inline void CameraInfo_Distortion::_internal_add_k(double value) {
  k_.Add(value);
}
inline void CameraInfo_Distortion::add_k(double value) {
  _internal_add_k(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.CameraInfo.Distortion.k)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Distortion::_internal_k() const {
  return k_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Distortion::k() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.CameraInfo.Distortion.k)
  return _internal_k();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Distortion::_internal_mutable_k() {
  return &k_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Distortion::mutable_k() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.CameraInfo.Distortion.k)
  return _internal_mutable_k();
}

// -------------------------------------------------------------------

// CameraInfo_Intrinsics

// repeated double k = 1;
inline int CameraInfo_Intrinsics::_internal_k_size() const {
  return k_.size();
}
inline int CameraInfo_Intrinsics::k_size() const {
  return _internal_k_size();
}
inline void CameraInfo_Intrinsics::clear_k() {
  k_.Clear();
}
inline double CameraInfo_Intrinsics::_internal_k(int index) const {
  return k_.Get(index);
}
inline double CameraInfo_Intrinsics::k(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.Intrinsics.k)
  return _internal_k(index);
}
inline void CameraInfo_Intrinsics::set_k(int index, double value) {
  k_.Set(index, value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.Intrinsics.k)
}
inline void CameraInfo_Intrinsics::_internal_add_k(double value) {
  k_.Add(value);
}
inline void CameraInfo_Intrinsics::add_k(double value) {
  _internal_add_k(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.CameraInfo.Intrinsics.k)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Intrinsics::_internal_k() const {
  return k_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Intrinsics::k() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.CameraInfo.Intrinsics.k)
  return _internal_k();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Intrinsics::_internal_mutable_k() {
  return &k_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Intrinsics::mutable_k() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.CameraInfo.Intrinsics.k)
  return _internal_mutable_k();
}

// -------------------------------------------------------------------

// CameraInfo_Projection

// repeated double p = 1;
inline int CameraInfo_Projection::_internal_p_size() const {
  return p_.size();
}
inline int CameraInfo_Projection::p_size() const {
  return _internal_p_size();
}
inline void CameraInfo_Projection::clear_p() {
  p_.Clear();
}
inline double CameraInfo_Projection::_internal_p(int index) const {
  return p_.Get(index);
}
inline double CameraInfo_Projection::p(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.Projection.p)
  return _internal_p(index);
}
inline void CameraInfo_Projection::set_p(int index, double value) {
  p_.Set(index, value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.Projection.p)
}
inline void CameraInfo_Projection::_internal_add_p(double value) {
  p_.Add(value);
}
inline void CameraInfo_Projection::add_p(double value) {
  _internal_add_p(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.CameraInfo.Projection.p)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Projection::_internal_p() const {
  return p_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo_Projection::p() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.CameraInfo.Projection.p)
  return _internal_p();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Projection::_internal_mutable_p() {
  return &p_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo_Projection::mutable_p() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.CameraInfo.Projection.p)
  return _internal_mutable_p();
}

// -------------------------------------------------------------------

// CameraInfo

// .ignition.msgs.Header header = 1;
inline bool CameraInfo::_internal_has_header() const {
  return this != internal_default_instance() && header_ != nullptr;
}
inline bool CameraInfo::has_header() const {
  return _internal_has_header();
}
inline const ::ignition::msgs::Header& CameraInfo::_internal_header() const {
  const ::ignition::msgs::Header* p = header_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::Header&>(
      ::ignition::msgs::_Header_default_instance_);
}
inline const ::ignition::msgs::Header& CameraInfo::header() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.header)
  return _internal_header();
}
inline void CameraInfo::unsafe_arena_set_allocated_header(
    ::ignition::msgs::Header* header) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  header_ = header;
  if (header) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.CameraInfo.header)
}
inline ::ignition::msgs::Header* CameraInfo::release_header() {
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::Header* CameraInfo::unsafe_arena_release_header() {
  // @@protoc_insertion_point(field_release:ignition.msgs.CameraInfo.header)
  
  ::ignition::msgs::Header* temp = header_;
  header_ = nullptr;
  return temp;
}
inline ::ignition::msgs::Header* CameraInfo::_internal_mutable_header() {
  
  if (header_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::Header>(GetArenaForAllocation());
    header_ = p;
  }
  return header_;
}
inline ::ignition::msgs::Header* CameraInfo::mutable_header() {
  ::ignition::msgs::Header* _msg = _internal_mutable_header();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.CameraInfo.header)
  return _msg;
}
inline void CameraInfo::set_allocated_header(::ignition::msgs::Header* header) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete reinterpret_cast< ::PROTOBUF_NAMESPACE_ID::MessageLite*>(header_);
  }
  if (header) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<
            ::PROTOBUF_NAMESPACE_ID::MessageLite>::GetOwningArena(
                reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(header));
    if (message_arena != submessage_arena) {
      header = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, header, submessage_arena);
    }
    
  } else {
    
  }
  header_ = header;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.CameraInfo.header)
}

// uint32 width = 2;
inline void CameraInfo::clear_width() {
  width_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 CameraInfo::_internal_width() const {
  return width_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 CameraInfo::width() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.width)
  return _internal_width();
}
inline void CameraInfo::_internal_set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  width_ = value;
}
inline void CameraInfo::set_width(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_width(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.width)
}

// uint32 height = 3;
inline void CameraInfo::clear_height() {
  height_ = 0u;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 CameraInfo::_internal_height() const {
  return height_;
}
inline ::PROTOBUF_NAMESPACE_ID::uint32 CameraInfo::height() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.height)
  return _internal_height();
}
inline void CameraInfo::_internal_set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  
  height_ = value;
}
inline void CameraInfo::set_height(::PROTOBUF_NAMESPACE_ID::uint32 value) {
  _internal_set_height(value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.height)
}

// .ignition.msgs.CameraInfo.Distortion distortion = 4;
inline bool CameraInfo::_internal_has_distortion() const {
  return this != internal_default_instance() && distortion_ != nullptr;
}
inline bool CameraInfo::has_distortion() const {
  return _internal_has_distortion();
}
inline void CameraInfo::clear_distortion() {
  if (GetArenaForAllocation() == nullptr && distortion_ != nullptr) {
    delete distortion_;
  }
  distortion_ = nullptr;
}
inline const ::ignition::msgs::CameraInfo_Distortion& CameraInfo::_internal_distortion() const {
  const ::ignition::msgs::CameraInfo_Distortion* p = distortion_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::CameraInfo_Distortion&>(
      ::ignition::msgs::_CameraInfo_Distortion_default_instance_);
}
inline const ::ignition::msgs::CameraInfo_Distortion& CameraInfo::distortion() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.distortion)
  return _internal_distortion();
}
inline void CameraInfo::unsafe_arena_set_allocated_distortion(
    ::ignition::msgs::CameraInfo_Distortion* distortion) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(distortion_);
  }
  distortion_ = distortion;
  if (distortion) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.CameraInfo.distortion)
}
inline ::ignition::msgs::CameraInfo_Distortion* CameraInfo::release_distortion() {
  
  ::ignition::msgs::CameraInfo_Distortion* temp = distortion_;
  distortion_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::CameraInfo_Distortion* CameraInfo::unsafe_arena_release_distortion() {
  // @@protoc_insertion_point(field_release:ignition.msgs.CameraInfo.distortion)
  
  ::ignition::msgs::CameraInfo_Distortion* temp = distortion_;
  distortion_ = nullptr;
  return temp;
}
inline ::ignition::msgs::CameraInfo_Distortion* CameraInfo::_internal_mutable_distortion() {
  
  if (distortion_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::CameraInfo_Distortion>(GetArenaForAllocation());
    distortion_ = p;
  }
  return distortion_;
}
inline ::ignition::msgs::CameraInfo_Distortion* CameraInfo::mutable_distortion() {
  ::ignition::msgs::CameraInfo_Distortion* _msg = _internal_mutable_distortion();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.CameraInfo.distortion)
  return _msg;
}
inline void CameraInfo::set_allocated_distortion(::ignition::msgs::CameraInfo_Distortion* distortion) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete distortion_;
  }
  if (distortion) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::CameraInfo_Distortion>::GetOwningArena(distortion);
    if (message_arena != submessage_arena) {
      distortion = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, distortion, submessage_arena);
    }
    
  } else {
    
  }
  distortion_ = distortion;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.CameraInfo.distortion)
}

// .ignition.msgs.CameraInfo.Intrinsics intrinsics = 5;
inline bool CameraInfo::_internal_has_intrinsics() const {
  return this != internal_default_instance() && intrinsics_ != nullptr;
}
inline bool CameraInfo::has_intrinsics() const {
  return _internal_has_intrinsics();
}
inline void CameraInfo::clear_intrinsics() {
  if (GetArenaForAllocation() == nullptr && intrinsics_ != nullptr) {
    delete intrinsics_;
  }
  intrinsics_ = nullptr;
}
inline const ::ignition::msgs::CameraInfo_Intrinsics& CameraInfo::_internal_intrinsics() const {
  const ::ignition::msgs::CameraInfo_Intrinsics* p = intrinsics_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::CameraInfo_Intrinsics&>(
      ::ignition::msgs::_CameraInfo_Intrinsics_default_instance_);
}
inline const ::ignition::msgs::CameraInfo_Intrinsics& CameraInfo::intrinsics() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.intrinsics)
  return _internal_intrinsics();
}
inline void CameraInfo::unsafe_arena_set_allocated_intrinsics(
    ::ignition::msgs::CameraInfo_Intrinsics* intrinsics) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(intrinsics_);
  }
  intrinsics_ = intrinsics;
  if (intrinsics) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.CameraInfo.intrinsics)
}
inline ::ignition::msgs::CameraInfo_Intrinsics* CameraInfo::release_intrinsics() {
  
  ::ignition::msgs::CameraInfo_Intrinsics* temp = intrinsics_;
  intrinsics_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::CameraInfo_Intrinsics* CameraInfo::unsafe_arena_release_intrinsics() {
  // @@protoc_insertion_point(field_release:ignition.msgs.CameraInfo.intrinsics)
  
  ::ignition::msgs::CameraInfo_Intrinsics* temp = intrinsics_;
  intrinsics_ = nullptr;
  return temp;
}
inline ::ignition::msgs::CameraInfo_Intrinsics* CameraInfo::_internal_mutable_intrinsics() {
  
  if (intrinsics_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::CameraInfo_Intrinsics>(GetArenaForAllocation());
    intrinsics_ = p;
  }
  return intrinsics_;
}
inline ::ignition::msgs::CameraInfo_Intrinsics* CameraInfo::mutable_intrinsics() {
  ::ignition::msgs::CameraInfo_Intrinsics* _msg = _internal_mutable_intrinsics();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.CameraInfo.intrinsics)
  return _msg;
}
inline void CameraInfo::set_allocated_intrinsics(::ignition::msgs::CameraInfo_Intrinsics* intrinsics) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete intrinsics_;
  }
  if (intrinsics) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::CameraInfo_Intrinsics>::GetOwningArena(intrinsics);
    if (message_arena != submessage_arena) {
      intrinsics = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, intrinsics, submessage_arena);
    }
    
  } else {
    
  }
  intrinsics_ = intrinsics;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.CameraInfo.intrinsics)
}

// .ignition.msgs.CameraInfo.Projection projection = 6;
inline bool CameraInfo::_internal_has_projection() const {
  return this != internal_default_instance() && projection_ != nullptr;
}
inline bool CameraInfo::has_projection() const {
  return _internal_has_projection();
}
inline void CameraInfo::clear_projection() {
  if (GetArenaForAllocation() == nullptr && projection_ != nullptr) {
    delete projection_;
  }
  projection_ = nullptr;
}
inline const ::ignition::msgs::CameraInfo_Projection& CameraInfo::_internal_projection() const {
  const ::ignition::msgs::CameraInfo_Projection* p = projection_;
  return p != nullptr ? *p : reinterpret_cast<const ::ignition::msgs::CameraInfo_Projection&>(
      ::ignition::msgs::_CameraInfo_Projection_default_instance_);
}
inline const ::ignition::msgs::CameraInfo_Projection& CameraInfo::projection() const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.projection)
  return _internal_projection();
}
inline void CameraInfo::unsafe_arena_set_allocated_projection(
    ::ignition::msgs::CameraInfo_Projection* projection) {
  if (GetArenaForAllocation() == nullptr) {
    delete reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(projection_);
  }
  projection_ = projection;
  if (projection) {
    
  } else {
    
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:ignition.msgs.CameraInfo.projection)
}
inline ::ignition::msgs::CameraInfo_Projection* CameraInfo::release_projection() {
  
  ::ignition::msgs::CameraInfo_Projection* temp = projection_;
  projection_ = nullptr;
#ifdef PROTOBUF_FORCE_COPY_IN_RELEASE
  auto* old =  reinterpret_cast<::PROTOBUF_NAMESPACE_ID::MessageLite*>(temp);
  temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  if (GetArenaForAllocation() == nullptr) { delete old; }
#else  // PROTOBUF_FORCE_COPY_IN_RELEASE
  if (GetArenaForAllocation() != nullptr) {
    temp = ::PROTOBUF_NAMESPACE_ID::internal::DuplicateIfNonNull(temp);
  }
#endif  // !PROTOBUF_FORCE_COPY_IN_RELEASE
  return temp;
}
inline ::ignition::msgs::CameraInfo_Projection* CameraInfo::unsafe_arena_release_projection() {
  // @@protoc_insertion_point(field_release:ignition.msgs.CameraInfo.projection)
  
  ::ignition::msgs::CameraInfo_Projection* temp = projection_;
  projection_ = nullptr;
  return temp;
}
inline ::ignition::msgs::CameraInfo_Projection* CameraInfo::_internal_mutable_projection() {
  
  if (projection_ == nullptr) {
    auto* p = CreateMaybeMessage<::ignition::msgs::CameraInfo_Projection>(GetArenaForAllocation());
    projection_ = p;
  }
  return projection_;
}
inline ::ignition::msgs::CameraInfo_Projection* CameraInfo::mutable_projection() {
  ::ignition::msgs::CameraInfo_Projection* _msg = _internal_mutable_projection();
  // @@protoc_insertion_point(field_mutable:ignition.msgs.CameraInfo.projection)
  return _msg;
}
inline void CameraInfo::set_allocated_projection(::ignition::msgs::CameraInfo_Projection* projection) {
  ::PROTOBUF_NAMESPACE_ID::Arena* message_arena = GetArenaForAllocation();
  if (message_arena == nullptr) {
    delete projection_;
  }
  if (projection) {
    ::PROTOBUF_NAMESPACE_ID::Arena* submessage_arena =
        ::PROTOBUF_NAMESPACE_ID::Arena::InternalHelper<::ignition::msgs::CameraInfo_Projection>::GetOwningArena(projection);
    if (message_arena != submessage_arena) {
      projection = ::PROTOBUF_NAMESPACE_ID::internal::GetOwnedMessage(
          message_arena, projection, submessage_arena);
    }
    
  } else {
    
  }
  projection_ = projection;
  // @@protoc_insertion_point(field_set_allocated:ignition.msgs.CameraInfo.projection)
}

// repeated double rectification_matrix = 7 [packed = true];
inline int CameraInfo::_internal_rectification_matrix_size() const {
  return rectification_matrix_.size();
}
inline int CameraInfo::rectification_matrix_size() const {
  return _internal_rectification_matrix_size();
}
inline void CameraInfo::clear_rectification_matrix() {
  rectification_matrix_.Clear();
}
inline double CameraInfo::_internal_rectification_matrix(int index) const {
  return rectification_matrix_.Get(index);
}
inline double CameraInfo::rectification_matrix(int index) const {
  // @@protoc_insertion_point(field_get:ignition.msgs.CameraInfo.rectification_matrix)
  return _internal_rectification_matrix(index);
}
inline void CameraInfo::set_rectification_matrix(int index, double value) {
  rectification_matrix_.Set(index, value);
  // @@protoc_insertion_point(field_set:ignition.msgs.CameraInfo.rectification_matrix)
}
inline void CameraInfo::_internal_add_rectification_matrix(double value) {
  rectification_matrix_.Add(value);
}
inline void CameraInfo::add_rectification_matrix(double value) {
  _internal_add_rectification_matrix(value);
  // @@protoc_insertion_point(field_add:ignition.msgs.CameraInfo.rectification_matrix)
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo::_internal_rectification_matrix() const {
  return rectification_matrix_;
}
inline const ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >&
CameraInfo::rectification_matrix() const {
  // @@protoc_insertion_point(field_list:ignition.msgs.CameraInfo.rectification_matrix)
  return _internal_rectification_matrix();
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo::_internal_mutable_rectification_matrix() {
  return &rectification_matrix_;
}
inline ::PROTOBUF_NAMESPACE_ID::RepeatedField< double >*
CameraInfo::mutable_rectification_matrix() {
  // @@protoc_insertion_point(field_mutable_list:ignition.msgs.CameraInfo.rectification_matrix)
  return _internal_mutable_rectification_matrix();
}

#ifdef __GNUC__
  #pragma GCC diagnostic pop
#endif  // __GNUC__
// -------------------------------------------------------------------

// -------------------------------------------------------------------

// -------------------------------------------------------------------


typedef std::unique_ptr<CameraInfo> CameraInfoUniquePtr;
typedef std::unique_ptr<const CameraInfo> ConstCameraInfoUniquePtr;
typedef std::shared_ptr<CameraInfo> CameraInfoSharedPtr;
typedef std::shared_ptr<const CameraInfo> ConstCameraInfoSharedPtr;
// @@protoc_insertion_point(namespace_scope)

}  // namespace msgs
}  // namespace ignition

PROTOBUF_NAMESPACE_OPEN

template <> struct is_proto_enum< ::ignition::msgs::CameraInfo_Distortion_DistortionModelType> : ::std::true_type {};
template <>
inline const EnumDescriptor* GetEnumDescriptor< ::ignition::msgs::CameraInfo_Distortion_DistortionModelType>() {
  return ::ignition::msgs::CameraInfo_Distortion_DistortionModelType_descriptor();
}

PROTOBUF_NAMESPACE_CLOSE

#ifdef _MSC_VER
#pragma warning(pop)
#endif
// @@protoc_insertion_point(global_scope)

#include <google/protobuf/port_undef.inc>
#endif  // GOOGLE_PROTOBUF_INCLUDED_GOOGLE_PROTOBUF_INCLUDED_ignition_2fmsgs_2fcamera_5finfo_2eproto
